@@ -1,13 +1,10 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright: Ansible Project
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
-
-
-DOCUMENTATION = '''
+DOCUMENTATION = r"""
 ---
 module: ec2_key
 version_added: 1.0.0
@@ -45,31 +42,43 @@ options:
         EC2 Instance Connect, and EC2 Serial Console.
       - By default Amazon will create an RSA key.
       - Mutually exclusive with parameter I(key_material).
-      - Requires at least botocore version 1.21.23.
     type: str
     choices:
       - rsa
       - ed25519
     version_added: 3.1.0
+  file_name:
+    description:
+      - Name of the file where the generated private key will be saved.
+      - When provided, the I(key.private_key) attribute will be removed from the return value.
+      - The file is written out on the 'host' side rather than the 'controller' side.
+      - Ignored when I(state=absent) or I(key_material) is provided.
+    type: path
+    version_added: 6.4.0
 notes:
   - Support for I(tags) and I(purge_tags) was added in release 2.1.0.
+  - For security reasons, this module should be used with B(no_log=true) and (register) functionalities
+    when creating new key pair without providing I(key_material).
 extends_documentation_fragment:
-  - amazon.aws.aws
-  - amazon.aws.ec2
+  - amazon.aws.common.modules
+  - amazon.aws.region.modules
   - amazon.aws.tags
   - amazon.aws.boto3
 
 author:
   - "Vincent Viallet (@zbal)"
   - "Prasad Katti (@prasadkatti)"
-'''
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
 # Note: These examples do not set authentication details, see the AWS Guide for details.
 
 - name: create a new EC2 key pair, returns generated private key
+  # use no_log to avoid private key being displayed into output
   amazon.aws.ec2_key:
     name: my_keypair
+  no_log: true
+  register: aws_ec2_key_pair
 
 - name: create key pair using provided key_material
   amazon.aws.ec2_key:
@@ -81,10 +90,11 @@ EXAMPLES = '''
     name: my_keypair
     key_material: "{{ lookup('file', '/path/to/public_key/id_rsa.pub') }}"
 
-- name: Create ED25519 key pair
+- name: Create ED25519 key pair and save private key into a file
   amazon.aws.ec2_key:
     name: my_keypair
     key_type: ed25519
+    file_name: /tmp/aws_ssh_rsa
 
 # try creating a key pair with the name of an already existing keypair
 # but don't overwrite it even if the key is different (force=false)
@@ -94,13 +104,13 @@ EXAMPLES = '''
     key_material: 'ssh-rsa AAAAxyz...== me@example.com'
     force: false
 
-- name: remove key pair by name
+- name: remove key pair from AWS by name
   amazon.aws.ec2_key:
     name: my_keypair
     state: absent
-'''
+"""
 
-RETURN = '''
+RETURN = r"""
 changed:
   description: whether a keypair was created/deleted
   returned: always
@@ -138,7 +148,7 @@ key:
       sample: '{"my_key": "my value"}'
     private_key:
       description: private key of a newly created keypair
-      returned: when a new keypair is created by AWS (key_material is not provided)
+      returned: when a new keypair is created by AWS (I(key_material) is not provided) and I(file_name) is not provided.
       type: str
       sample: '-----BEGIN RSA PRIVATE KEY-----
         MIIEowIBAAKC...
@@ -149,8 +159,9 @@ key:
       type: str
       sample: rsa
       version_added: 3.1.0
-'''
+"""
 
+import os
 import uuid
 
 try:
@@ -160,13 +171,13 @@ except ImportError:
 
 from ansible.module_utils._text import to_bytes
 
-from ansible_collections.amazon.aws.plugins.module_utils.core import AnsibleAWSModule
-from ansible_collections.amazon.aws.plugins.module_utils.core import is_boto3_error_code
-from ansible_collections.amazon.aws.plugins.module_utils.core import scrub_none_parameters
-from ansible_collections.amazon.aws.plugins.module_utils.ec2 import AWSRetry
+from ansible_collections.amazon.aws.plugins.module_utils.botocore import is_boto3_error_code
 from ansible_collections.amazon.aws.plugins.module_utils.ec2 import ensure_ec2_tags
-from ansible_collections.amazon.aws.plugins.module_utils.tagging import boto3_tag_specifications
+from ansible_collections.amazon.aws.plugins.module_utils.modules import AnsibleAWSModule
+from ansible_collections.amazon.aws.plugins.module_utils.retries import AWSRetry
 from ansible_collections.amazon.aws.plugins.module_utils.tagging import boto3_tag_list_to_ansible_dict
+from ansible_collections.amazon.aws.plugins.module_utils.tagging import boto3_tag_specifications
+from ansible_collections.amazon.aws.plugins.module_utils.transformation import scrub_none_parameters
 
 
 class Ec2KeyFailure(Exception):
@@ -177,11 +188,7 @@ class Ec2KeyFailure(Exception):
 
 
 def _import_key_pair(ec2_client, name, key_material, tag_spec=None):
-    params = {
-        'KeyName': name,
-        'PublicKeyMaterial': to_bytes(key_material),
-        'TagSpecifications': tag_spec
-    }
+    params = {"KeyName": name, "PublicKeyMaterial": to_bytes(key_material), "TagSpecifications": tag_spec}
 
     params = scrub_none_parameters(params)
 
@@ -192,28 +199,31 @@ def _import_key_pair(ec2_client, name, key_material, tag_spec=None):
     return key
 
 
-def extract_key_data(key, key_type=None):
+def extract_key_data(key, key_type=None, file_name=None):
     data = {
-        'name': key['KeyName'],
-        'fingerprint': key['KeyFingerprint'],
-        'id': key['KeyPairId'],
-        'tags': boto3_tag_list_to_ansible_dict(key.get('Tags') or []),
+        "name": key["KeyName"],
+        "fingerprint": key["KeyFingerprint"],
+        "id": key["KeyPairId"],
+        "tags": boto3_tag_list_to_ansible_dict(key.get("Tags") or []),
         # KeyMaterial is returned by create_key_pair, but not by describe_key_pairs
-        'private_key': key.get('KeyMaterial'),
+        "private_key": key.get("KeyMaterial"),
         # KeyType is only set by describe_key_pairs
-        'type': key.get('KeyType') or key_type
+        "type": key.get("KeyType") or key_type,
     }
 
+    # Write the private key to disk and remove it from the return value
+    if file_name and data["private_key"] is not None:
+        data = _write_private_key(data, file_name)
     return scrub_none_parameters(data)
 
 
 def get_key_fingerprint(check_mode, ec2_client, key_material):
-    '''
+    """
     EC2's fingerprints are non-trivial to generate, so push this key
     to a temporary name and make ec2 calculate the fingerprint for us.
     http://blog.jbrowne.com/?p=23
     https://forums.aws.amazon.com/thread.jspa?messageID=352828
-    '''
+    """
     # find an unused name
     name_in_use = True
     while name_in_use:
@@ -221,27 +231,30 @@ def get_key_fingerprint(check_mode, ec2_client, key_material):
         name_in_use = find_key_pair(ec2_client, random_name)
     temp_key = _import_key_pair(ec2_client, random_name, key_material)
     delete_key_pair(check_mode, ec2_client, random_name, finish_task=False)
-    return temp_key['KeyFingerprint']
+    return temp_key["KeyFingerprint"]
 
 
 def find_key_pair(ec2_client, name):
     try:
         key = ec2_client.describe_key_pairs(aws_retry=True, KeyNames=[name])
-    except is_boto3_error_code('InvalidKeyPair.NotFound'):
+    except is_boto3_error_code("InvalidKeyPair.NotFound"):
         return None
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as err:  # pylint: disable=duplicate-except
+    except (
+        botocore.exceptions.ClientError,
+        botocore.exceptions.BotoCoreError,
+    ) as err:  # pylint: disable=duplicate-except
         raise Ec2KeyFailure(err, "error finding keypair")
     except IndexError:
         key = None
 
-    return key['KeyPairs'][0]
+    return key["KeyPairs"][0]
 
 
 def _create_key_pair(ec2_client, name, tag_spec, key_type):
     params = {
-        'KeyName': name,
-        'TagSpecifications': tag_spec,
-        'KeyType': key_type,
+        "KeyName": name,
+        "TagSpecifications": tag_spec,
+        "KeyType": key_type,
     }
 
     params = scrub_none_parameters(params)
@@ -253,31 +266,47 @@ def _create_key_pair(ec2_client, name, tag_spec, key_type):
     return key
 
 
-def create_new_key_pair(ec2_client, name, key_material, key_type, tags, check_mode):
-    '''
-    key does not exist, we create new key
-    '''
-    if check_mode:
-        return {'changed': True, 'key': None, 'msg': 'key pair created'}
+def _write_private_key(key_data, file_name):
+    """
+    Write the private key data to the specified file, and remove 'private_key'
+    from the ouput. This ensures we don't expose the key data in logs or task output.
+    """
+    try:
+        file = os.open(file_name, os.O_WRONLY | os.O_CREAT | os.O_TRUNC, 0o600)
+        os.write(file, key_data["private_key"].encode("utf-8"))
+        os.close(file)
+    except (IOError, OSError) as e:
+        raise Ec2KeyFailure(e, "Could not save private key to specified path. Private key is irretrievable.")
 
-    tag_spec = boto3_tag_specifications(tags, ['key-pair'])
+    del key_data["private_key"]
+    return key_data
+
+
+def create_new_key_pair(ec2_client, name, key_material, key_type, tags, file_name, check_mode):
+    """
+    key does not exist, we create new key
+    """
+    if check_mode:
+        return {"changed": True, "key": None, "msg": "key pair created"}
+
+    tag_spec = boto3_tag_specifications(tags, ["key-pair"])
     if key_material:
         key = _import_key_pair(ec2_client, name, key_material, tag_spec)
     else:
         key = _create_key_pair(ec2_client, name, tag_spec, key_type)
-    key_data = extract_key_data(key, key_type)
+    key_data = extract_key_data(key, key_type, file_name)
 
-    result = {'changed': True, 'key': key_data, 'msg': 'key pair created'}
+    result = {"changed": True, "key": key_data, "msg": "key pair created"}
     return result
 
 
 def update_key_pair_by_key_material(check_mode, ec2_client, name, key, key_material, tag_spec):
     if check_mode:
-        return {'changed': True, 'key': None, 'msg': 'key pair updated'}
+        return {"changed": True, "key": None, "msg": "key pair updated"}
     new_fingerprint = get_key_fingerprint(check_mode, ec2_client, key_material)
     changed = False
     msg = "key pair already exists"
-    if key['KeyFingerprint'] != new_fingerprint:
+    if key["KeyFingerprint"] != new_fingerprint:
         delete_key_pair(check_mode, ec2_client, name, finish_task=False)
         key = _import_key_pair(ec2_client, name, key_material, tag_spec)
         msg = "key pair updated"
@@ -286,14 +315,14 @@ def update_key_pair_by_key_material(check_mode, ec2_client, name, key, key_mater
     return {"changed": changed, "key": key_data, "msg": msg}
 
 
-def update_key_pair_by_key_type(check_mode, ec2_client, name, key_type, tag_spec):
+def update_key_pair_by_key_type(check_mode, ec2_client, name, key_type, tag_spec, file_name):
     if check_mode:
-        return {'changed': True, 'key': None, 'msg': 'key pair updated'}
+        return {"changed": True, "key": None, "msg": "key pair updated"}
     else:
         delete_key_pair(check_mode, ec2_client, name, finish_task=False)
         key = _create_key_pair(ec2_client, name, tag_spec, key_type)
-        key_data = extract_key_data(key, key_type)
-        return {'changed': True, 'key': key_data, 'msg': "key pair updated"}
+        key_data = extract_key_data(key, key_type, file_name)
+        return {"changed": True, "key": key_data, "msg": "key pair updated"}
 
 
 def _delete_key_pair(ec2_client, key_name):
@@ -307,82 +336,83 @@ def delete_key_pair(check_mode, ec2_client, name, finish_task=True):
     key = find_key_pair(ec2_client, name)
 
     if key and check_mode:
-        result = {'changed': True, 'key': None, 'msg': 'key deleted'}
+        result = {"changed": True, "key": None, "msg": "key deleted"}
     elif not key:
-        result = {'key': None, 'msg': 'key did not exist'}
+        result = {"key": None, "msg": "key did not exist"}
+        return result
     else:
         _delete_key_pair(ec2_client, name)
         if not finish_task:
             return
-        result = {'changed': True, 'key': None, 'msg': 'key deleted'}
+        result = {"changed": True, "key": None, "msg": "key deleted"}
 
     return result
 
 
 def handle_existing_key_pair_update(module, ec2_client, name, key):
-    key_material = module.params.get('key_material')
-    force = module.params.get('force')
-    key_type = module.params.get('key_type')
-    tags = module.params.get('tags')
-    purge_tags = module.params.get('purge_tags')
-    tag_spec = boto3_tag_specifications(tags, ['key-pair'])
+    key_material = module.params.get("key_material")
+    force = module.params.get("force")
+    key_type = module.params.get("key_type")
+    tags = module.params.get("tags")
+    purge_tags = module.params.get("purge_tags")
+    tag_spec = boto3_tag_specifications(tags, ["key-pair"])
     check_mode = module.check_mode
+    file_name = module.params.get("file_name")
     if key_material and force:
         result = update_key_pair_by_key_material(check_mode, ec2_client, name, key, key_material, tag_spec)
-    elif key_type and key_type != key['KeyType']:
-        result = update_key_pair_by_key_type(check_mode, ec2_client, name, key_type, tag_spec)
+    elif key_type and key_type != key["KeyType"]:
+        result = update_key_pair_by_key_type(check_mode, ec2_client, name, key_type, tag_spec, file_name)
     else:
         changed = False
-        changed |= ensure_ec2_tags(ec2_client, module, key['KeyPairId'], tags=tags, purge_tags=purge_tags)
+        changed |= ensure_ec2_tags(ec2_client, module, key["KeyPairId"], tags=tags, purge_tags=purge_tags)
         key = find_key_pair(ec2_client, name)
-        key_data = extract_key_data(key)
+        key_data = extract_key_data(key, file_name=file_name)
         result = {"changed": changed, "key": key_data, "msg": "key pair already exists"}
     return result
 
 
 def main():
-
     argument_spec = dict(
         name=dict(required=True),
         key_material=dict(no_log=False),
-        force=dict(type='bool', default=True),
-        state=dict(default='present', choices=['present', 'absent']),
-        tags=dict(type='dict', aliases=['resource_tags']),
-        purge_tags=dict(type='bool', default=True),
-        key_type=dict(type='str', choices=['rsa', 'ed25519']),
+        force=dict(type="bool", default=True),
+        state=dict(default="present", choices=["present", "absent"]),
+        tags=dict(type="dict", aliases=["resource_tags"]),
+        purge_tags=dict(type="bool", default=True),
+        key_type=dict(type="str", choices=["rsa", "ed25519"]),
+        file_name=dict(type="path", required=False),
     )
 
     module = AnsibleAWSModule(
         argument_spec=argument_spec,
-        mutually_exclusive=[
-            ['key_material', 'key_type']
-        ],
-        supports_check_mode=True
+        mutually_exclusive=[["key_material", "key_type"]],
+        supports_check_mode=True,
     )
 
-    ec2_client = module.client('ec2', retry_decorator=AWSRetry.jittered_backoff())
+    ec2_client = module.client("ec2", retry_decorator=AWSRetry.jittered_backoff())
 
-    name = module.params['name']
-    state = module.params.get('state')
-    key_material = module.params.get('key_material')
-    key_type = module.params.get('key_type')
-    tags = module.params.get('tags')
+    name = module.params["name"]
+    state = module.params.get("state")
+    key_material = module.params.get("key_material")
+    key_type = module.params.get("key_type")
+    tags = module.params.get("tags")
+    file_name = module.params.get("file_name")
 
     result = {}
 
-    if key_type:
-        module.require_botocore_at_least('1.21.23', reason='to set the key_type for a keypair')
     try:
-        if state == 'absent':
+        if state == "absent":
             result = delete_key_pair(module.check_mode, ec2_client, name)
 
-        elif state == 'present':
+        elif state == "present":
             # check if key already exists
             key = find_key_pair(ec2_client, name)
             if key:
                 result = handle_existing_key_pair_update(module, ec2_client, name, key)
             else:
-                result = create_new_key_pair(ec2_client, name, key_material, key_type, tags, module.check_mode)
+                result = create_new_key_pair(
+                    ec2_client, name, key_material, key_type, tags, file_name, module.check_mode
+                )
 
     except Ec2KeyFailure as e:
         if e.original_e:
@@ -393,5 +423,5 @@ def main():
     module.exit_json(**result)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
