@@ -1,12 +1,10 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*
+
+# Copyright: Contributors to the Ansible project
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
-
-
-DOCUMENTATION = r'''
+DOCUMENTATION = r"""
 ---
 module: kms_key
 version_added: 5.0.0
@@ -148,8 +146,8 @@ author:
   - Will Thames (@willthames)
   - Mark Chappell (@tremble)
 extends_documentation_fragment:
-  - amazon.aws.aws
-  - amazon.aws.ec2
+  - amazon.aws.common.modules
+  - amazon.aws.region.modules
   - amazon.aws.tags
   - amazon.aws.boto3
 
@@ -158,9 +156,9 @@ notes:
     This can cause issues when running duplicate tasks in succession or using the M(amazon.aws.kms_key_info) module to fetch key metadata
     shortly after modifying keys.
     For this reason, it is recommended to use the return data from this module (M(amazon.aws.kms_key)) to fetch a key's metadata.
-'''
+"""
 
-EXAMPLES = r'''
+EXAMPLES = r"""
 # Create a new KMS key
 - amazon.aws.kms_key:
     alias: mykey
@@ -211,9 +209,9 @@ EXAMPLES = r'''
     alias: my-kms-key
     policy: "{{ lookup('template', 'kms_iam_policy_template.json.j2') }}"
     state: present
-'''
+"""
 
-RETURN = r'''
+RETURN = r"""
 key_id:
   description: ID of key.
   type: str
@@ -435,16 +433,14 @@ multi_region:
   version_added: 5.5.0
   returned: always
   sample: False
-
-
-'''
+"""
 
 # these mappings are used to go from simple labels to the actual 'Sid' values returned
 # by get_policy. They seem to be magic values.
 statement_label = {
-    'role': 'Allow use of the key',
-    'role grant': 'Allow attachment of persistent resources',
-    'admin': 'Allow access for Key Administrators'
+    "role": "Allow use of the key",
+    "role grant": "Allow attachment of persistent resources",
+    "admin": "Allow access for Key Administrators",
 }
 
 import json
@@ -454,44 +450,45 @@ try:
 except ImportError:
     pass  # caught by AnsibleAWSModule
 
-from ansible_collections.amazon.aws.plugins.module_utils.core import AnsibleAWSModule
-from ansible_collections.amazon.aws.plugins.module_utils.core import is_boto3_error_code
-from ansible_collections.amazon.aws.plugins.module_utils.ec2 import AWSRetry
-from ansible_collections.amazon.aws.plugins.module_utils.ec2 import ansible_dict_to_boto3_tag_list
-from ansible_collections.amazon.aws.plugins.module_utils.ec2 import boto3_tag_list_to_ansible_dict
-from ansible_collections.amazon.aws.plugins.module_utils.ec2 import camel_dict_to_snake_dict
-from ansible_collections.amazon.aws.plugins.module_utils.ec2 import compare_aws_tags
-from ansible_collections.amazon.aws.plugins.module_utils.ec2 import compare_policies
+from ansible.module_utils.common.dict_transformations import camel_dict_to_snake_dict
+
+from ansible_collections.amazon.aws.plugins.module_utils.botocore import is_boto3_error_code
+from ansible_collections.amazon.aws.plugins.module_utils.modules import AnsibleAWSModule
+from ansible_collections.amazon.aws.plugins.module_utils.policy import compare_policies
+from ansible_collections.amazon.aws.plugins.module_utils.retries import AWSRetry
+from ansible_collections.amazon.aws.plugins.module_utils.tagging import ansible_dict_to_boto3_tag_list
+from ansible_collections.amazon.aws.plugins.module_utils.tagging import boto3_tag_list_to_ansible_dict
+from ansible_collections.amazon.aws.plugins.module_utils.tagging import compare_aws_tags
 
 
 @AWSRetry.jittered_backoff(retries=5, delay=5, backoff=2.0)
 def get_iam_roles_with_backoff(connection):
-    paginator = connection.get_paginator('list_roles')
+    paginator = connection.get_paginator("list_roles")
     return paginator.paginate().build_full_result()
 
 
 @AWSRetry.jittered_backoff(retries=5, delay=5, backoff=2.0)
 def get_kms_keys_with_backoff(connection):
-    paginator = connection.get_paginator('list_keys')
+    paginator = connection.get_paginator("list_keys")
     return paginator.paginate().build_full_result()
 
 
 @AWSRetry.jittered_backoff(retries=5, delay=5, backoff=2.0)
 def get_kms_aliases_with_backoff(connection):
-    paginator = connection.get_paginator('list_aliases')
+    paginator = connection.get_paginator("list_aliases")
     return paginator.paginate().build_full_result()
 
 
 def get_kms_aliases_lookup(connection):
     _aliases = dict()
-    for alias in get_kms_aliases_with_backoff(connection)['Aliases']:
+    for alias in get_kms_aliases_with_backoff(connection)["Aliases"]:
         # Not all aliases are actually associated with a key
-        if 'TargetKeyId' in alias:
+        if "TargetKeyId" in alias:
             # strip off leading 'alias/' and add it to key's aliases
-            if alias['TargetKeyId'] in _aliases:
-                _aliases[alias['TargetKeyId']].append(alias['AliasName'][6:])
+            if alias["TargetKeyId"] in _aliases:
+                _aliases[alias["TargetKeyId"]].append(alias["AliasName"][6:])
             else:
-                _aliases[alias['TargetKeyId']] = [alias['AliasName'][6:]]
+                _aliases[alias["TargetKeyId"]] = [alias["AliasName"][6:]]
     return _aliases
 
 
@@ -503,7 +500,7 @@ def get_kms_tags_with_backoff(connection, key_id, **kwargs):
 @AWSRetry.jittered_backoff(retries=5, delay=5, backoff=2.0)
 def get_kms_grants_with_backoff(connection, key_id):
     params = dict(KeyId=key_id)
-    paginator = connection.get_paginator('list_grants')
+    paginator = connection.get_paginator("list_grants")
     return paginator.paginate(**params).build_full_result()
 
 
@@ -514,7 +511,7 @@ def get_kms_metadata_with_backoff(connection, key_id):
 
 @AWSRetry.jittered_backoff(retries=5, delay=5, backoff=2.0)
 def list_key_policies_with_backoff(connection, key_id):
-    paginator = connection.get_paginator('list_key_policies')
+    paginator = connection.get_paginator("list_key_policies")
     return paginator.paginate(KeyId=key_id).build_full_result()
 
 
@@ -532,13 +529,16 @@ def get_kms_tags(connection, module, key_id):
     while more:
         try:
             tag_response = get_kms_tags_with_backoff(connection, key_id, **kwargs)
-            tags.extend(tag_response['Tags'])
-        except is_boto3_error_code('AccessDeniedException'):
+            tags.extend(tag_response["Tags"])
+        except is_boto3_error_code("AccessDeniedException"):
             tag_response = {}
-        except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:  # pylint: disable=duplicate-except
+        except (
+            botocore.exceptions.ClientError,
+            botocore.exceptions.BotoCoreError,
+        ) as e:  # pylint: disable=duplicate-except
             module.fail_json_aws(e, msg="Failed to obtain key tags")
-        if tag_response.get('NextMarker'):
-            kwargs['Marker'] = tag_response['NextMarker']
+        if tag_response.get("NextMarker"):
+            kwargs["Marker"] = tag_response["NextMarker"]
         else:
             more = False
     return tags
@@ -546,34 +546,34 @@ def get_kms_tags(connection, module, key_id):
 
 def get_kms_policies(connection, module, key_id):
     try:
-        policies = list_key_policies_with_backoff(connection, key_id)['PolicyNames']
-        return [
-            get_key_policy_with_backoff(connection, key_id, policy)['Policy']
-            for policy in policies
-        ]
-    except is_boto3_error_code('AccessDeniedException'):
+        policies = list_key_policies_with_backoff(connection, key_id)["PolicyNames"]
+        return [get_key_policy_with_backoff(connection, key_id, policy)["Policy"] for policy in policies]
+    except is_boto3_error_code("AccessDeniedException"):
         return []
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:  # pylint: disable=duplicate-except
+    except (
+        botocore.exceptions.ClientError,
+        botocore.exceptions.BotoCoreError,
+    ) as e:  # pylint: disable=duplicate-except
         module.fail_json_aws(e, msg="Failed to obtain key policies")
 
 
 def camel_to_snake_grant(grant):
-    '''camel_to_snake_grant snakifies everything except the encryption context '''
-    constraints = grant.get('Constraints', {})
+    """camel_to_snake_grant snakifies everything except the encryption context"""
+    constraints = grant.get("Constraints", {})
     result = camel_dict_to_snake_dict(grant)
-    if 'EncryptionContextEquals' in constraints:
-        result['constraints']['encryption_context_equals'] = constraints['EncryptionContextEquals']
-    if 'EncryptionContextSubset' in constraints:
-        result['constraints']['encryption_context_subset'] = constraints['EncryptionContextSubset']
+    if "EncryptionContextEquals" in constraints:
+        result["constraints"]["encryption_context_equals"] = constraints["EncryptionContextEquals"]
+    if "EncryptionContextSubset" in constraints:
+        result["constraints"]["encryption_context_subset"] = constraints["EncryptionContextSubset"]
     return result
 
 
 def get_key_details(connection, module, key_id):
     try:
-        result = get_kms_metadata_with_backoff(connection, key_id)['KeyMetadata']
+        result = get_kms_metadata_with_backoff(connection, key_id)["KeyMetadata"]
     except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
         module.fail_json_aws(e, msg="Failed to obtain key metadata")
-    result['KeyArn'] = result.pop('Arn')
+    result["KeyArn"] = result.pop("Arn")
 
     try:
         aliases = get_kms_aliases_lookup(connection)
@@ -582,71 +582,68 @@ def get_key_details(connection, module, key_id):
 
     try:
         current_rotation_status = connection.get_key_rotation_status(KeyId=key_id)
-        result['enable_key_rotation'] = current_rotation_status.get('KeyRotationEnabled')
-    except is_boto3_error_code(['AccessDeniedException', 'UnsupportedOperationException']) as e:
-        result['enable_key_rotation'] = None
-    result['aliases'] = aliases.get(result['KeyId'], [])
+        result["enable_key_rotation"] = current_rotation_status.get("KeyRotationEnabled")
+    except is_boto3_error_code(["AccessDeniedException", "UnsupportedOperationException"]) as e:
+        result["enable_key_rotation"] = None
+    result["aliases"] = aliases.get(result["KeyId"], [])
 
     result = camel_dict_to_snake_dict(result)
 
     # grants and tags get snakified differently
     try:
-        result['grants'] = [
-            camel_to_snake_grant(grant)
-            for grant in get_kms_grants_with_backoff(connection, key_id)['Grants']
+        result["grants"] = [
+            camel_to_snake_grant(grant) for grant in get_kms_grants_with_backoff(connection, key_id)["Grants"]
         ]
     except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
         module.fail_json_aws(e, msg="Failed to obtain key grants")
     tags = get_kms_tags(connection, module, key_id)
-    result['tags'] = boto3_tag_list_to_ansible_dict(tags, 'TagKey', 'TagValue')
-    result['policies'] = get_kms_policies(connection, module, key_id)
-    result['key_policies'] = [json.loads(policy) for policy in result['policies']]
+    result["tags"] = boto3_tag_list_to_ansible_dict(tags, "TagKey", "TagValue")
+    result["policies"] = get_kms_policies(connection, module, key_id)
+    result["key_policies"] = [json.loads(policy) for policy in result["policies"]]
     return result
 
 
 def get_kms_facts(connection, module):
     try:
-        keys = get_kms_keys_with_backoff(connection)['Keys']
+        keys = get_kms_keys_with_backoff(connection)["Keys"]
     except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
         module.fail_json_aws(e, msg="Failed to obtain keys")
 
-    return [get_key_details(connection, module, key['KeyId']) for key in keys]
+    return [get_key_details(connection, module, key["KeyId"]) for key in keys]
 
 
 def convert_grant_params(grant, key):
-    grant_params = dict(
-        KeyId=key['key_arn'], GranteePrincipal=grant['grantee_principal']
-    )
-    if grant.get('operations'):
-        grant_params['Operations'] = grant['operations']
-    if grant.get('retiring_principal'):
-        grant_params['RetiringPrincipal'] = grant['retiring_principal']
-    if grant.get('name'):
-        grant_params['Name'] = grant['name']
-    if grant.get('constraints'):
-        grant_params['Constraints'] = dict()
-        if grant['constraints'].get('encryption_context_subset'):
-            grant_params['Constraints']['EncryptionContextSubset'] = grant['constraints']['encryption_context_subset']
-        if grant['constraints'].get('encryption_context_equals'):
-            grant_params['Constraints']['EncryptionContextEquals'] = grant['constraints']['encryption_context_equals']
+    grant_params = dict(KeyId=key["key_arn"], GranteePrincipal=grant["grantee_principal"])
+    if grant.get("operations"):
+        grant_params["Operations"] = grant["operations"]
+    if grant.get("retiring_principal"):
+        grant_params["RetiringPrincipal"] = grant["retiring_principal"]
+    if grant.get("name"):
+        grant_params["Name"] = grant["name"]
+    if grant.get("constraints"):
+        grant_params["Constraints"] = dict()
+        if grant["constraints"].get("encryption_context_subset"):
+            grant_params["Constraints"]["EncryptionContextSubset"] = grant["constraints"]["encryption_context_subset"]
+        if grant["constraints"].get("encryption_context_equals"):
+            grant_params["Constraints"]["EncryptionContextEquals"] = grant["constraints"]["encryption_context_equals"]
     return grant_params
 
 
 def different_grant(existing_grant, desired_grant):
-    if existing_grant.get('grantee_principal') != desired_grant.get('grantee_principal'):
+    if existing_grant.get("grantee_principal") != desired_grant.get("grantee_principal"):
         return True
-    if existing_grant.get('retiring_principal') != desired_grant.get('retiring_principal'):
+    if existing_grant.get("retiring_principal") != desired_grant.get("retiring_principal"):
         return True
-    if set(existing_grant.get('operations', [])) != set(desired_grant.get('operations')):
+    if set(existing_grant.get("operations", [])) != set(desired_grant.get("operations")):
         return True
-    if existing_grant.get('constraints') != desired_grant.get('constraints'):
+    if existing_grant.get("constraints") != desired_grant.get("constraints"):
         return True
     return False
 
 
 def compare_grants(existing_grants, desired_grants, purge_grants=False):
-    existing_dict = dict((eg['name'], eg) for eg in existing_grants)
-    desired_dict = dict((dg['name'], dg) for dg in desired_grants)
+    existing_dict = dict((eg["name"], eg) for eg in existing_grants)
+    desired_dict = dict((dg["name"], dg) for dg in desired_grants)
     to_add_keys = set(desired_dict.keys()) - set(existing_dict.keys())
     if purge_grants:
         to_remove_keys = set(existing_dict.keys()) - set(desired_dict.keys())
@@ -670,15 +667,15 @@ def compare_grants(existing_grants, desired_grants, purge_grants=False):
 
 
 def start_key_deletion(connection, module, key_metadata):
-    if key_metadata['KeyState'] == 'PendingDeletion':
+    if key_metadata["KeyState"] == "PendingDeletion":
         return False
 
     if module.check_mode:
         return True
 
-    deletion_params = {'KeyId': key_metadata['Arn']}
-    if module.params.get('pending_window'):
-        deletion_params['PendingWindowInDays'] = module.params.get('pending_window')
+    deletion_params = {"KeyId": key_metadata["Arn"]}
+    if module.params.get("pending_window"):
+        deletion_params["PendingWindowInDays"] = module.params.get("pending_window")
 
     try:
         connection.schedule_key_deletion(**deletion_params)
@@ -688,8 +685,8 @@ def start_key_deletion(connection, module, key_metadata):
 
 
 def cancel_key_deletion(connection, module, key):
-    key_id = key['key_arn']
-    if key['key_state'] != 'PendingDeletion':
+    key_id = key["key_arn"]
+    if key["key_state"] != "PendingDeletion":
         return False
 
     if module.check_mode:
@@ -699,7 +696,7 @@ def cancel_key_deletion(connection, module, key):
         connection.cancel_key_deletion(KeyId=key_id)
         # key is disabled after deletion cancellation
         # set this so that ensure_enabled_disabled works correctly
-        key['key_state'] = 'Disabled'
+        key["key_state"] = "Disabled"
     except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
         module.fail_json_aws(e, msg="Failed to cancel key deletion")
 
@@ -707,14 +704,14 @@ def cancel_key_deletion(connection, module, key):
 
 
 def ensure_enabled_disabled(connection, module, key, enabled):
-    desired_state = 'Enabled'
+    desired_state = "Enabled"
     if not enabled:
-        desired_state = 'Disabled'
+        desired_state = "Disabled"
 
-    if key['key_state'] == desired_state:
+    if key["key_state"] == desired_state:
         return False
 
-    key_id = key['key_arn']
+    key_id = key["key_arn"]
     if not module.check_mode:
         if enabled:
             try:
@@ -736,10 +733,10 @@ def update_alias(connection, module, key, alias):
     if alias is None:
         return False
 
-    key_id = key['key_arn']
-    aliases = get_kms_aliases_with_backoff(connection)['Aliases']
+    key_id = key["key_arn"]
+    aliases = get_kms_aliases_with_backoff(connection)["Aliases"]
     # We will only add new aliases, not rename existing ones
-    if alias in [_alias['AliasName'] for _alias in aliases]:
+    if alias in [_alias["AliasName"] for _alias in aliases]:
         return False
 
     if not module.check_mode:
@@ -754,10 +751,10 @@ def update_alias(connection, module, key, alias):
 def update_description(connection, module, key, description):
     if description is None:
         return False
-    if key['description'] == description:
+    if key["description"] == description:
         return False
 
-    key_id = key['key_arn']
+    key_id = key["key_arn"]
     if not module.check_mode:
         try:
             connection.update_key_description(KeyId=key_id, Description=description)
@@ -771,11 +768,11 @@ def update_tags(connection, module, key, desired_tags, purge_tags):
     if desired_tags is None:
         return False
 
-    to_add, to_remove = compare_aws_tags(key['tags'], desired_tags, purge_tags)
+    to_add, to_remove = compare_aws_tags(key["tags"], desired_tags, purge_tags)
     if not (bool(to_add) or bool(to_remove)):
         return False
 
-    key_id = key['key_arn']
+    key_id = key["key_arn"]
     if not module.check_mode:
         if to_remove:
             try:
@@ -785,9 +782,9 @@ def update_tags(connection, module, key, desired_tags, purge_tags):
         if to_add:
             try:
                 tags = ansible_dict_to_boto3_tag_list(
-                    module.params['tags'],
-                    tag_name_key_name='TagKey',
-                    tag_value_key_name='TagValue',
+                    module.params["tags"],
+                    tag_name_key_name="TagKey",
+                    tag_value_key_name="TagValue",
                 )
                 connection.tag_resource(KeyId=key_id, Tags=tags)
             except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
@@ -804,10 +801,10 @@ def update_policy(connection, module, key, policy):
     except ValueError as e:
         module.fail_json_aws(e, msg="Unable to parse new policy as JSON")
 
-    key_id = key['key_arn']
+    key_id = key["key_arn"]
     try:
-        keyret = connection.get_key_policy(KeyId=key_id, PolicyName='default')
-        original_policy = json.loads(keyret['Policy'])
+        keyret = connection.get_key_policy(KeyId=key_id, PolicyName="default")
+        original_policy = json.loads(keyret["Policy"])
     except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError):
         # If we can't fetch the current policy assume we're making a change
         # Could occur if we have PutKeyPolicy without GetKeyPolicy
@@ -818,7 +815,7 @@ def update_policy(connection, module, key, policy):
 
     if not module.check_mode:
         try:
-            connection.put_key_policy(KeyId=key_id, PolicyName='default', Policy=policy)
+            connection.put_key_policy(KeyId=key_id, PolicyName="default", Policy=policy)
         except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
             module.fail_json_aws(e, msg="Unable to update key policy")
 
@@ -828,15 +825,18 @@ def update_policy(connection, module, key, policy):
 def update_key_rotation(connection, module, key, enable_key_rotation):
     if enable_key_rotation is None:
         return False
-    key_id = key['key_arn']
+    key_id = key["key_arn"]
 
     try:
         current_rotation_status = connection.get_key_rotation_status(KeyId=key_id)
-        if current_rotation_status.get('KeyRotationEnabled') == enable_key_rotation:
+        if current_rotation_status.get("KeyRotationEnabled") == enable_key_rotation:
             return False
-    except is_boto3_error_code('AccessDeniedException'):
+    except is_boto3_error_code("AccessDeniedException"):
         pass
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:  # pylint: disable=duplicate-except
+    except (
+        botocore.exceptions.ClientError,
+        botocore.exceptions.BotoCoreError,
+    ) as e:  # pylint: disable=duplicate-except
         module.fail_json_aws(e, msg="Unable to get current key rotation status")
 
     if not module.check_mode:
@@ -852,17 +852,17 @@ def update_key_rotation(connection, module, key, enable_key_rotation):
 
 
 def update_grants(connection, module, key, desired_grants, purge_grants):
-    existing_grants = key['grants']
+    existing_grants = key["grants"]
 
     to_add, to_remove = compare_grants(existing_grants, desired_grants, purge_grants)
     if not (bool(to_add) or bool(to_remove)):
         return False
 
-    key_id = key['key_arn']
+    key_id = key["key_arn"]
     if not module.check_mode:
         for grant in to_remove:
             try:
-                connection.retire_grant(KeyId=key_id, GrantId=grant['grant_id'])
+                connection.retire_grant(KeyId=key_id, GrantId=grant["grant_id"])
             except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
                 module.fail_json_aws(e, msg="Unable to retire grant")
         for grant in to_add:
@@ -879,61 +879,61 @@ def update_key(connection, module, key):
     changed = False
 
     changed |= cancel_key_deletion(connection, module, key)
-    changed |= ensure_enabled_disabled(connection, module, key, module.params['enabled'])
-    changed |= update_alias(connection, module, key, module.params['alias'])
-    changed |= update_description(connection, module, key, module.params['description'])
-    changed |= update_tags(connection, module, key, module.params['tags'], module.params.get('purge_tags'))
-    changed |= update_policy(connection, module, key, module.params.get('policy'))
-    changed |= update_grants(connection, module, key, module.params.get('grants'), module.params.get('purge_grants'))
-    changed |= update_key_rotation(connection, module, key, module.params.get('enable_key_rotation'))
+    changed |= ensure_enabled_disabled(connection, module, key, module.params["enabled"])
+    changed |= update_alias(connection, module, key, module.params["alias"])
+    changed |= update_description(connection, module, key, module.params["description"])
+    changed |= update_tags(connection, module, key, module.params["tags"], module.params.get("purge_tags"))
+    changed |= update_policy(connection, module, key, module.params.get("policy"))
+    changed |= update_grants(connection, module, key, module.params.get("grants"), module.params.get("purge_grants"))
+    changed |= update_key_rotation(connection, module, key, module.params.get("enable_key_rotation"))
 
     # make results consistent with kms_facts before returning
-    result = get_key_details(connection, module, key['key_arn'])
-    result['changed'] = changed
+    result = get_key_details(connection, module, key["key_arn"])
+    result["changed"] = changed
     return result
 
 
 def create_key(connection, module):
-    key_usage = module.params.get('key_usage')
-    key_spec = module.params.get('key_spec')
-    multi_region = module.params.get('multi_region')
+    key_usage = module.params.get("key_usage")
+    key_spec = module.params.get("key_spec")
+    multi_region = module.params.get("multi_region")
     tags_list = ansible_dict_to_boto3_tag_list(
-        module.params['tags'] or {},
+        module.params["tags"] or {},
         # KMS doesn't use 'Key' and 'Value' as other APIs do.
-        tag_name_key_name='TagKey',
-        tag_value_key_name='TagValue',
+        tag_name_key_name="TagKey",
+        tag_value_key_name="TagValue",
     )
     params = dict(
         BypassPolicyLockoutSafetyCheck=False,
         Tags=tags_list,
         KeyUsage=key_usage,
         CustomerMasterKeySpec=key_spec,
-        Origin='AWS_KMS',
+        Origin="AWS_KMS",
         MultiRegion=multi_region,
     )
 
     if module.check_mode:
-        return {'changed': True}
+        return {"changed": True}
 
-    if module.params.get('description'):
-        params['Description'] = module.params['description']
-    if module.params.get('policy'):
-        params['Policy'] = module.params['policy']
+    if module.params.get("description"):
+        params["Description"] = module.params["description"]
+    if module.params.get("policy"):
+        params["Policy"] = module.params["policy"]
     try:
-        result = connection.create_key(**params)['KeyMetadata']
+        result = connection.create_key(**params)["KeyMetadata"]
     except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
         module.fail_json_aws(e, msg="Failed to create initial key")
 
-    key = get_key_details(connection, module, result['KeyId'])
-    update_alias(connection, module, key, module.params['alias'])
-    update_key_rotation(connection, module, key, module.params.get('enable_key_rotation'))
+    key = get_key_details(connection, module, result["KeyId"])
+    update_alias(connection, module, key, module.params["alias"])
+    update_key_rotation(connection, module, key, module.params.get("enable_key_rotation"))
 
-    ensure_enabled_disabled(connection, module, key, module.params.get('enabled'))
-    update_grants(connection, module, key, module.params.get('grants'), False)
+    ensure_enabled_disabled(connection, module, key, module.params.get("enabled"))
+    update_grants(connection, module, key, module.params.get("grants"), False)
 
     # make results consistent with kms_facts
-    result = get_key_details(connection, module, key['key_id'])
-    result['changed'] = True
+    result = get_key_details(connection, module, key["key_id"])
+    result["changed"] = True
     return result
 
 
@@ -942,24 +942,24 @@ def delete_key(connection, module, key_metadata):
 
     changed |= start_key_deletion(connection, module, key_metadata)
 
-    result = get_key_details(connection, module, key_metadata['Arn'])
-    result['changed'] = changed
+    result = get_key_details(connection, module, key_metadata["Arn"])
+    result["changed"] = changed
     return result
 
 
 def get_arn_from_role_name(iam, rolename):
     ret = iam.get_role(RoleName=rolename)
-    if ret.get('Role') and ret['Role'].get('Arn'):
-        return ret['Role']['Arn']
-    raise Exception('could not find arn for name {0}.'.format(rolename))
+    if ret.get("Role") and ret["Role"].get("Arn"):
+        return ret["Role"]["Arn"]
+    raise Exception(f"could not find arn for name {rolename}.")
 
 
 def canonicalize_alias_name(alias):
     if alias is None:
         return None
-    if alias.startswith('alias/'):
+    if alias.startswith("alias/"):
         return alias
-    return 'alias/' + alias
+    return "alias/" + alias
 
 
 def fetch_key_metadata(connection, module, key_id, alias):
@@ -969,14 +969,14 @@ def fetch_key_metadata(connection, module, key_id, alias):
     # Integration tests will wait for 10 seconds to combat this issue.
     # See https://github.com/ansible-collections/community.aws/pull/1052.
 
-    alias = canonicalize_alias_name(module.params.get('alias'))
+    alias = canonicalize_alias_name(module.params.get("alias"))
 
     try:
         # Fetch by key_id where possible
         if key_id:
-            return get_kms_metadata_with_backoff(connection, key_id)['KeyMetadata']
+            return get_kms_metadata_with_backoff(connection, key_id)["KeyMetadata"]
         # Or try alias as a backup
-        return get_kms_metadata_with_backoff(connection, alias)['KeyMetadata']
+        return get_kms_metadata_with_backoff(connection, alias)["KeyMetadata"]
 
     except connection.exceptions.NotFoundException:
         return None
@@ -986,88 +986,77 @@ def fetch_key_metadata(connection, module, key_id, alias):
 
 def validate_params(module, key_metadata):
     # We can't create keys with a specific ID, if we can't access the key we'll have to fail
-    if (
-        module.params.get('state') == 'present'
-        and module.params.get('key_id')
-        and not key_metadata
-    ):
-        module.fail_json(
-            msg='Could not find key with id {0} to update'.format(
-                module.params.get('key_id')
-            )
-        )
-    if (
-        module.params.get('multi_region')
-        and key_metadata
-        and module.params.get('state') == 'present'
-    ):
-        module.fail_json(
-            msg='You cannot change the multi-region property on an existing key.'
-        )
+    if module.params.get("state") == "present" and module.params.get("key_id") and not key_metadata:
+        module.fail_json(msg=f"Could not find key with id {module.params.get('key_id')} to update")
+    if module.params.get("multi_region") and key_metadata and module.params.get("state") == "present":
+        module.fail_json(msg="You cannot change the multi-region property on an existing key.")
 
 
 def main():
     argument_spec = dict(
-        alias=dict(aliases=['key_alias']),
-        pending_window=dict(aliases=['deletion_delay'], type='int'),
-        key_id=dict(aliases=['key_arn']),
+        alias=dict(aliases=["key_alias"]),
+        pending_window=dict(aliases=["deletion_delay"], type="int"),
+        key_id=dict(aliases=["key_arn"]),
         description=dict(),
-        enabled=dict(type='bool', default=True),
-        multi_region=dict(type='bool', default=False),
-        tags=dict(type='dict', aliases=['resource_tags']),
-        purge_tags=dict(type='bool', default=True),
-        grants=dict(type='list', default=[], elements='dict'),
-        policy=dict(type='json'),
-        purge_grants=dict(type='bool', default=False),
-        state=dict(default='present', choices=['present', 'absent']),
-        enable_key_rotation=(dict(type='bool')),
+        enabled=dict(type="bool", default=True),
+        multi_region=dict(type="bool", default=False),
+        tags=dict(type="dict", aliases=["resource_tags"]),
+        purge_tags=dict(type="bool", default=True),
+        grants=dict(type="list", default=[], elements="dict"),
+        policy=dict(type="json"),
+        purge_grants=dict(type="bool", default=False),
+        state=dict(default="present", choices=["present", "absent"]),
+        enable_key_rotation=(dict(type="bool")),
         key_spec=dict(
-            type='str',
-            default='SYMMETRIC_DEFAULT',
-            aliases=['customer_master_key_spec'],
+            type="str",
+            default="SYMMETRIC_DEFAULT",
+            aliases=["customer_master_key_spec"],
             choices=[
-                'SYMMETRIC_DEFAULT',
-                'RSA_2048',
-                'RSA_3072',
-                'RSA_4096',
-                'ECC_NIST_P256',
-                'ECC_NIST_P384',
-                'ECC_NIST_P521',
-                'ECC_SECG_P256K1',
+                "SYMMETRIC_DEFAULT",
+                "RSA_2048",
+                "RSA_3072",
+                "RSA_4096",
+                "ECC_NIST_P256",
+                "ECC_NIST_P384",
+                "ECC_NIST_P521",
+                "ECC_SECG_P256K1",
             ],
         ),
         key_usage=dict(
-            type='str',
-            default='ENCRYPT_DECRYPT',
-            choices=['ENCRYPT_DECRYPT', 'SIGN_VERIFY'],
+            type="str",
+            default="ENCRYPT_DECRYPT",
+            choices=["ENCRYPT_DECRYPT", "SIGN_VERIFY"],
         ),
     )
 
     module = AnsibleAWSModule(
         supports_check_mode=True,
         argument_spec=argument_spec,
-        required_one_of=[['alias', 'key_id']],
+        required_one_of=[["alias", "key_id"]],
     )
 
-    kms = module.client('kms')
+    kms = module.client("kms")
 
     module.deprecate(
-        "The 'policies' return key is deprecated and will be replaced by 'key_policies'. Both values are returned for now.",
-        date='2024-05-01',
-        collection_name='amazon.aws',
+        (
+            "The 'policies' return key is deprecated and will be replaced by 'key_policies'. Both values are returned"
+            " for now."
+        ),
+        date="2024-05-01",
+        collection_name="amazon.aws",
     )
 
-    key_metadata = fetch_key_metadata(kms, module, module.params.get('key_id'), module.params.get('alias'))
+    key_metadata = fetch_key_metadata(kms, module, module.params.get("key_id"), module.params.get("alias"))
     validate_params(module, key_metadata)
 
-    if module.params.get('state') == 'absent':
+    if module.params.get("state") == "absent":
         if key_metadata is None:
             module.exit_json(changed=False)
         result = delete_key(kms, module, key_metadata)
         module.exit_json(**result)
 
     if key_metadata:
-        key_details = get_key_details(kms, module, key_metadata['Arn'])
+        key_details = get_key_details(kms, module, key_metadata["Arn"])
         result = update_key(kms, module, key_details)
         module.exit_json(**result)
 
@@ -1075,5 +1064,5 @@ def main():
     module.exit_json(**result)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
