@@ -1,12 +1,10 @@
 #!/usr/bin/python
-# This file is part of Ansible
+# -*- coding: utf-8 -*-
+
+# Copyright: Contributors to the Ansible project
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
-
-
-DOCUMENTATION = '''
+DOCUMENTATION = r"""
 ---
 module: lambda_info
 version_added: 5.0.0
@@ -36,12 +34,12 @@ options:
 author:
   - Pierre Jodouin (@pjodouin)
 extends_documentation_fragment:
-  - amazon.aws.aws
-  - amazon.aws.ec2
+  - amazon.aws.common.modules
+  - amazon.aws.region.modules
   - amazon.aws.boto3
-'''
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
 ---
 # Simple example of listing all info for a function
 - name: List all for a specific function
@@ -66,9 +64,9 @@ EXAMPLES = '''
 - name: show Lambda information
   ansible.builtin.debug:
     msg: "{{ output['function'] }}"
-'''
+"""
 
-RETURN = '''
+RETURN = r"""
 ---
 function:
     description:
@@ -267,7 +265,8 @@ functions:
             'subnet_ids': [],
             'vpc_id': '123'
             }
-'''
+"""
+
 import json
 import re
 
@@ -278,9 +277,9 @@ except ImportError:
 
 from ansible.module_utils.common.dict_transformations import camel_dict_to_snake_dict
 
-from ansible_collections.amazon.aws.plugins.module_utils.core import AnsibleAWSModule
-from ansible_collections.amazon.aws.plugins.module_utils.core import is_boto3_error_code
-from ansible_collections.amazon.aws.plugins.module_utils.ec2 import AWSRetry
+from ansible_collections.amazon.aws.plugins.module_utils.botocore import is_boto3_error_code
+from ansible_collections.amazon.aws.plugins.module_utils.modules import AnsibleAWSModule
+from ansible_collections.amazon.aws.plugins.module_utils.retries import AWSRetry
 
 
 @AWSRetry.jittered_backoff()
@@ -302,15 +301,29 @@ def alias_details(client, module, function_name):
     lambda_info = dict()
 
     try:
-        lambda_info.update(aliases=_paginate(client, 'list_aliases', FunctionName=function_name)['Aliases'])
-    except is_boto3_error_code('ResourceNotFoundException'):
+        lambda_info.update(aliases=_paginate(client, "list_aliases", FunctionName=function_name)["Aliases"])
+    except is_boto3_error_code("ResourceNotFoundException"):
         lambda_info.update(aliases=[])
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:  # pylint: disable=duplicate-except
+    except (
+        botocore.exceptions.ClientError,
+        botocore.exceptions.BotoCoreError,
+    ) as e:  # pylint: disable=duplicate-except
         module.fail_json_aws(e, msg="Trying to get aliases")
 
     return camel_dict_to_snake_dict(lambda_info)
 
 
+def _get_query(query, function_name):
+    # create default values for query if not specified.
+    # if function name exists, query should default to 'all'.
+    # if function name does not exist, query should default to 'config' to limit the runtime when listing all lambdas.
+    if query:
+        return query
+    if function_name:
+        return "all"
+    return "config"
+
+
 def list_functions(client, module):
     """
     Returns queried facts for a specified function (or all functions).
@@ -319,17 +332,17 @@ def list_functions(client, module):
     :param module: Ansible module reference
     """
 
-    function_name = module.params.get('function_name')
+    function_name = module.params.get("function_name")
     if function_name:
         # Function name is specified - retrieve info on that function
         function_names = [function_name]
 
     else:
         # Function name is not specified - retrieve all function names
-        all_function_info = _paginate(client, 'list_functions')['Functions']
-        function_names = [function_info['FunctionName'] for function_info in all_function_info]
+        all_function_info = _paginate(client, "list_functions")["Functions"]
+        function_names = [function_info["FunctionName"] for function_info in all_function_info]
 
-    query = module.params['query']
+    query = _get_query(module.params["query"], function_name)
     functions = []
 
     # keep returning deprecated response (dict of dicts) until removed
@@ -342,22 +355,22 @@ def list_functions(client, module):
         # these details should be returned regardless of the query
         function.update(config_details(client, module, function_name))
 
-        if query in ['all', 'aliases']:
+        if query in ["all", "aliases"]:
             function.update(alias_details(client, module, function_name))
 
-        if query in ['all', 'policy']:
+        if query in ["all", "policy"]:
             function.update(policy_details(client, module, function_name))
 
-        if query in ['all', 'versions']:
+        if query in ["all", "versions"]:
             function.update(version_details(client, module, function_name))
 
-        if query in ['all', 'mappings']:
+        if query in ["all", "mappings"]:
             function.update(mapping_details(client, module, function_name))
 
-        if query in ['all', 'tags']:
+        if query in ["all", "tags"]:
             function.update(tags_details(client, module, function_name))
 
-        all_facts[function['function_name']] = function
+        all_facts[function["function_name"]] = function
 
         # add current lambda to list of lambdas
         functions.append(function)
@@ -380,10 +393,13 @@ def config_details(client, module, function_name):
 
     try:
         lambda_info.update(client.get_function_configuration(aws_retry=True, FunctionName=function_name))
-    except is_boto3_error_code('ResourceNotFoundException'):
+    except is_boto3_error_code("ResourceNotFoundException"):
         lambda_info.update(function={})
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:  # pylint: disable=duplicate-except
-        module.fail_json_aws(e, msg="Trying to get {0} configuration".format(function_name))
+    except (
+        botocore.exceptions.ClientError,
+        botocore.exceptions.BotoCoreError,
+    ) as e:  # pylint: disable=duplicate-except
+        module.fail_json_aws(e, msg=f"Trying to get {function_name} configuration")
 
     if "Environment" in lambda_info and "Variables" in lambda_info["Environment"]:
         env_vars = lambda_info["Environment"]["Variables"]
@@ -408,16 +424,19 @@ def mapping_details(client, module, function_name):
     lambda_info = dict()
     params = dict()
 
-    params['FunctionName'] = function_name
+    params["FunctionName"] = function_name
 
-    if module.params.get('event_source_arn'):
-        params['EventSourceArn'] = module.params.get('event_source_arn')
+    if module.params.get("event_source_arn"):
+        params["EventSourceArn"] = module.params.get("event_source_arn")
 
     try:
-        lambda_info.update(mappings=_paginate(client, 'list_event_source_mappings', **params)['EventSourceMappings'])
-    except is_boto3_error_code('ResourceNotFoundException'):
+        lambda_info.update(mappings=_paginate(client, "list_event_source_mappings", **params)["EventSourceMappings"])
+    except is_boto3_error_code("ResourceNotFoundException"):
         lambda_info.update(mappings=[])
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:  # pylint: disable=duplicate-except
+    except (
+        botocore.exceptions.ClientError,
+        botocore.exceptions.BotoCoreError,
+    ) as e:  # pylint: disable=duplicate-except
         module.fail_json_aws(e, msg="Trying to get source event mappings")
 
     return camel_dict_to_snake_dict(lambda_info)
@@ -437,11 +456,14 @@ def policy_details(client, module, function_name):
 
     try:
         # get_policy returns a JSON string so must convert to dict before reassigning to its key
-        lambda_info.update(policy=json.loads(client.get_policy(aws_retry=True, FunctionName=function_name)['Policy']))
-    except is_boto3_error_code('ResourceNotFoundException'):
+        lambda_info.update(policy=json.loads(client.get_policy(aws_retry=True, FunctionName=function_name)["Policy"]))
+    except is_boto3_error_code("ResourceNotFoundException"):
         lambda_info.update(policy={})
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:  # pylint: disable=duplicate-except
-        module.fail_json_aws(e, msg="Trying to get {0} policy".format(function_name))
+    except (
+        botocore.exceptions.ClientError,
+        botocore.exceptions.BotoCoreError,
+    ) as e:  # pylint: disable=duplicate-except
+        module.fail_json_aws(e, msg=f"Trying to get {function_name} policy")
 
     return camel_dict_to_snake_dict(lambda_info)
 
@@ -459,11 +481,16 @@ def version_details(client, module, function_name):
     lambda_info = dict()
 
     try:
-        lambda_info.update(versions=_paginate(client, 'list_versions_by_function', FunctionName=function_name)['Versions'])
-    except is_boto3_error_code('ResourceNotFoundException'):
+        lambda_info.update(
+            versions=_paginate(client, "list_versions_by_function", FunctionName=function_name)["Versions"]
+        )
+    except is_boto3_error_code("ResourceNotFoundException"):
         lambda_info.update(versions=[])
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:  # pylint: disable=duplicate-except
-        module.fail_json_aws(e, msg="Trying to get {0} versions".format(function_name))
+    except (
+        botocore.exceptions.ClientError,
+        botocore.exceptions.BotoCoreError,
+    ) as e:  # pylint: disable=duplicate-except
+        module.fail_json_aws(e, msg=f"Trying to get {function_name} versions")
 
     return camel_dict_to_snake_dict(lambda_info)
 
@@ -481,11 +508,14 @@ def tags_details(client, module, function_name):
     lambda_info = dict()
 
     try:
-        lambda_info.update(tags=client.get_function(aws_retry=True, FunctionName=function_name).get('Tags', {}))
-    except is_boto3_error_code('ResourceNotFoundException'):
+        lambda_info.update(tags=client.get_function(aws_retry=True, FunctionName=function_name).get("Tags", {}))
+    except is_boto3_error_code("ResourceNotFoundException"):
         lambda_info.update(function={})
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:  # pylint: disable=duplicate-except
-        module.fail_json_aws(e, msg="Trying to get {0} tags".format(function_name))
+    except (
+        botocore.exceptions.ClientError,
+        botocore.exceptions.BotoCoreError,
+    ) as e:  # pylint: disable=duplicate-except
+        module.fail_json_aws(e, msg=f"Trying to get {function_name} tags")
 
     return camel_dict_to_snake_dict(lambda_info)
 
@@ -497,49 +527,41 @@ def main():
     :return dict: ansible facts
     """
     argument_spec = dict(
-        function_name=dict(required=False, default=None, aliases=['function', 'name']),
-        query=dict(required=False, choices=['aliases', 'all', 'config', 'mappings', 'policy', 'versions', 'tags'], default=None),
+        function_name=dict(required=False, default=None, aliases=["function", "name"]),
+        query=dict(
+            required=False, choices=["aliases", "all", "config", "mappings", "policy", "versions", "tags"], default=None
+        ),
         event_source_arn=dict(required=False, default=None),
     )
 
     module = AnsibleAWSModule(
-        argument_spec=argument_spec,
-        supports_check_mode=True,
-        mutually_exclusive=[],
-        required_together=[]
+        argument_spec=argument_spec, supports_check_mode=True, mutually_exclusive=[], required_together=[]
     )
 
     # validate function_name if present
-    function_name = module.params['function_name']
+    function_name = module.params["function_name"]
     if function_name:
         if not re.search(r"^[\w\-:]+$", function_name):
             module.fail_json(
-                msg='Function name {0} is invalid. Names must contain only alphanumeric characters and hyphens.'.format(function_name)
+                msg=f"Function name {function_name} is invalid. Names must contain only alphanumeric characters and hyphens.",
             )
         if len(function_name) > 64:
-            module.fail_json(msg='Function name "{0}" exceeds 64 character limit'.format(function_name))
+            module.fail_json(msg=f'Function name "{function_name}" exceeds 64 character limit')
 
-    # create default values for query if not specified.
-    # if function name exists, query should default to 'all'.
-    # if function name does not exist, query should default to 'config' to limit the runtime when listing all lambdas.
-    if not module.params.get('query'):
-        if function_name:
-            module.params['query'] = 'all'
-        else:
-            module.params['query'] = 'config'
-
-    client = module.client('lambda', retry_decorator=AWSRetry.jittered_backoff())
+    client = module.client("lambda", retry_decorator=AWSRetry.jittered_backoff())
 
     # Deprecate previous return key of `function`, as it was a dict of dicts, as opposed to a list of dicts
     module.deprecate(
-        "The returned key 'function', which returned a dictionary of dictionaries, is deprecated and will be replaced by 'functions',"
-        " which returns a list of dictionaries. Both keys are returned for now.",
-        date='2025-01-01',
-        collection_name='amazon.aws'
+        (
+            "The returned key 'function', which returned a dictionary of dictionaries, is deprecated and will be"
+            " replaced by 'functions', which returns a list of dictionaries. Both keys are returned for now."
+        ),
+        date="2025-01-01",
+        collection_name="amazon.aws",
     )
 
     list_functions(client, module)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
