@@ -3,10 +3,9 @@
 # This file is part of Ansible
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
-
 import sys
+from unittest.mock import MagicMock
+
 import pytest
 
 if sys.version_info < (3, 7):
@@ -20,8 +19,6 @@ except ImportError:
     # Handled by HAS_BOTO3
     pass
 
-from ansible_collections.amazon.aws.tests.unit.compat.mock import MagicMock
-
 from ansible_collections.amazon.aws.plugins.module_utils import rds
 from ansible_collections.amazon.aws.plugins.module_utils.botocore import HAS_BOTO3
 
@@ -37,13 +34,11 @@ def error(*args, **kwargs):
     return MagicMock(), pytest.raises(*args, **kwargs)
 
 
-def build_exception(
-    operation_name, code=None, message=None, http_status_code=None, error=True
-):
+def build_exception(operation_name, code=None, message=None, http_status_code=None, error=True):
     # Support skipping the test is botocore isn't installed
     # (called by parametrize before skip is evaluated)
     if not HAS_BOTO3:
-        return Exception('MissingBotoCore')
+        return Exception("MissingBotoCore")
     response = {}
     if error or code or message:
         response["Error"] = {}
@@ -74,9 +69,7 @@ def test__wait_for_cluster_snapshot_status(waiter_name):
             "db_snapshot_available",
             "Failed to wait for DB snapshot test to be available",
         ),
-        (
-            "db_snapshot_deleted",
-            "Failed to wait for DB snapshot test to be deleted"),
+        ("db_snapshot_deleted", "Failed to wait for DB snapshot test to be deleted"),
     ],
 )
 def test__wait_for_instance_snapshot_status_failed(input, expected):
@@ -125,8 +118,8 @@ def test__wait_for_cluster_snapshot_status_failed(input, expected):
                     name="delete_db_cluster",
                     waiter="cluster_deleted",
                     operation_description="delete DB cluster",
-                    resource='cluster',
-                    retry_codes=['InvalidDBClusterState']
+                    resource="cluster",
+                    retry_codes=["InvalidDBClusterState"],
                 )
             ),
         ),
@@ -140,8 +133,38 @@ def test__wait_for_cluster_snapshot_status_failed(input, expected):
                     name="create_db_cluster",
                     waiter="cluster_available",
                     operation_description="create DB cluster",
-                    resource='cluster',
-                    retry_codes=['InvalidDBClusterState']
+                    resource="cluster",
+                    retry_codes=["InvalidDBClusterState"],
+                )
+            ),
+        ),
+        (
+            "start_db_cluster",
+            {
+                "new_db_cluster_identifier": "test",
+            },
+            *expected(
+                rds.Boto3ClientMethod(
+                    name="start_db_cluster",
+                    waiter="cluster_available",
+                    operation_description="start DB cluster",
+                    resource="cluster",
+                    retry_codes=["InvalidDBClusterState"],
+                )
+            ),
+        ),
+        (
+            "stop_db_cluster",
+            {
+                "new_db_cluster_identifier": "test",
+            },
+            *expected(
+                rds.Boto3ClientMethod(
+                    name="stop_db_cluster",
+                    waiter="cluster_available",
+                    operation_description="stop DB cluster",
+                    resource="cluster",
+                    retry_codes=["InvalidDBClusterState"],
                 )
             ),
         ),
@@ -155,8 +178,8 @@ def test__wait_for_cluster_snapshot_status_failed(input, expected):
                     name="restore_db_cluster_from_snapshot",
                     waiter="cluster_available",
                     operation_description="restore DB cluster from snapshot",
-                    resource='cluster',
-                    retry_codes=['InvalidDBClusterSnapshotState']
+                    resource="cluster",
+                    retry_codes=["InvalidDBClusterSnapshotState"],
                 )
             ),
         ),
@@ -170,8 +193,8 @@ def test__wait_for_cluster_snapshot_status_failed(input, expected):
                     name="modify_db_cluster",
                     waiter="cluster_available",
                     operation_description="modify DB cluster",
-                    resource='cluster',
-                    retry_codes=['InvalidDBClusterState']
+                    resource="cluster",
+                    retry_codes=["InvalidDBClusterState"],
                 )
             ),
         ),
@@ -185,34 +208,29 @@ def test__wait_for_cluster_snapshot_status_failed(input, expected):
                     name="list_tags_for_resource",
                     waiter="cluster_available",
                     operation_description="list tags for resource",
-                    resource='cluster',
-                    retry_codes=['InvalidDBClusterState']
+                    resource="cluster",
+                    retry_codes=["InvalidDBClusterState"],
                 )
             ),
         ),
         (
             "fake_method",
-            {
-                "wait": False
-            },
+            {"wait": False},
             *expected(
                 rds.Boto3ClientMethod(
-                    name="fake_method",
-                    waiter="",
-                    operation_description="fake method",
-                    resource='',
-                    retry_codes=[]
+                    name="fake_method", waiter="", operation_description="fake method", resource="", retry_codes=[]
                 )
             ),
         ),
         (
             "fake_method",
-            {
-                "wait": True
-            },
+            {"wait": True},
             *error(
                 NotImplementedError,
-                match="method fake_method hasn't been added to the list of accepted methods to use a waiter in module_utils/rds.py",
+                match=(
+                    "method fake_method hasn't been added to the list of accepted methods to use a waiter in"
+                    " module_utils/rds.py"
+                ),
             ),
         ),
     ],
@@ -237,8 +255,8 @@ def test__get_rds_method_attribute_cluster(method_name, params, expected, error)
                     name="delete_db_instance",
                     waiter="db_instance_deleted",
                     operation_description="delete DB instance",
-                    resource='instance',
-                    retry_codes=['InvalidDBInstanceState', 'InvalidDBSecurityGroupState']
+                    resource="instance",
+                    retry_codes=["InvalidDBInstanceState", "InvalidDBSecurityGroupState"],
                 )
             ),
         ),
@@ -252,8 +270,8 @@ def test__get_rds_method_attribute_cluster(method_name, params, expected, error)
                     name="create_db_instance",
                     waiter="db_instance_available",
                     operation_description="create DB instance",
-                    resource='instance',
-                    retry_codes=['InvalidDBInstanceState', 'InvalidDBSecurityGroupState']
+                    resource="instance",
+                    retry_codes=["InvalidDBInstanceState", "InvalidDBSecurityGroupState"],
                 )
             ),
         ),
@@ -267,8 +285,8 @@ def test__get_rds_method_attribute_cluster(method_name, params, expected, error)
                     name="stop_db_instance",
                     waiter="db_instance_stopped",
                     operation_description="stop DB instance",
-                    resource='instance',
-                    retry_codes=['InvalidDBInstanceState', 'InvalidDBSecurityGroupState']
+                    resource="instance",
+                    retry_codes=["InvalidDBInstanceState", "InvalidDBSecurityGroupState"],
                 )
             ),
         ),
@@ -282,8 +300,8 @@ def test__get_rds_method_attribute_cluster(method_name, params, expected, error)
                     name="promote_read_replica",
                     waiter="read_replica_promoted",
                     operation_description="promote read replica",
-                    resource='instance',
-                    retry_codes=['InvalidDBInstanceState', 'InvalidDBSecurityGroupState']
+                    resource="instance",
+                    retry_codes=["InvalidDBInstanceState", "InvalidDBSecurityGroupState"],
                 )
             ),
         ),
@@ -297,8 +315,8 @@ def test__get_rds_method_attribute_cluster(method_name, params, expected, error)
                     name="restore_db_instance_from_db_snapshot",
                     waiter="db_instance_available",
                     operation_description="restore DB instance from DB snapshot",
-                    resource='instance',
-                    retry_codes=['InvalidDBSnapshotState']
+                    resource="instance",
+                    retry_codes=["InvalidDBSnapshotState"],
                 )
             ),
         ),
@@ -312,8 +330,8 @@ def test__get_rds_method_attribute_cluster(method_name, params, expected, error)
                     name="modify_db_instance",
                     waiter="db_instance_available",
                     operation_description="modify DB instance",
-                    resource='instance',
-                    retry_codes=['InvalidDBInstanceState', 'InvalidDBSecurityGroupState']
+                    resource="instance",
+                    retry_codes=["InvalidDBInstanceState", "InvalidDBSecurityGroupState"],
                 )
             ),
         ),
@@ -327,8 +345,8 @@ def test__get_rds_method_attribute_cluster(method_name, params, expected, error)
                     name="add_role_to_db_instance",
                     waiter="role_associated",
                     operation_description="add role to DB instance",
-                    resource='instance',
-                    retry_codes=['InvalidDBInstanceState', 'InvalidDBSecurityGroupState']
+                    resource="instance",
+                    retry_codes=["InvalidDBInstanceState", "InvalidDBSecurityGroupState"],
                 )
             ),
         ),
@@ -342,8 +360,8 @@ def test__get_rds_method_attribute_cluster(method_name, params, expected, error)
                     name="remove_role_from_db_instance",
                     waiter="role_disassociated",
                     operation_description="remove role from DB instance",
-                    resource='instance',
-                    retry_codes=['InvalidDBInstanceState', 'InvalidDBSecurityGroupState']
+                    resource="instance",
+                    retry_codes=["InvalidDBInstanceState", "InvalidDBSecurityGroupState"],
                 )
             ),
         ),
@@ -357,34 +375,29 @@ def test__get_rds_method_attribute_cluster(method_name, params, expected, error)
                     name="list_tags_for_resource",
                     waiter="db_instance_available",
                     operation_description="list tags for resource",
-                    resource='instance',
-                    retry_codes=['InvalidDBInstanceState', 'InvalidDBSecurityGroupState']
+                    resource="instance",
+                    retry_codes=["InvalidDBInstanceState", "InvalidDBSecurityGroupState"],
                 )
             ),
         ),
         (
             "fake_method",
-            {
-                "wait": False
-            },
+            {"wait": False},
             *expected(
                 rds.Boto3ClientMethod(
-                    name="fake_method",
-                    waiter="",
-                    operation_description="fake method",
-                    resource='',
-                    retry_codes=[]
+                    name="fake_method", waiter="", operation_description="fake method", resource="", retry_codes=[]
                 )
             ),
         ),
         (
             "fake_method",
-            {
-                "wait": True
-            },
+            {"wait": True},
             *error(
                 NotImplementedError,
-                match="method fake_method hasn't been added to the list of accepted methods to use a waiter in module_utils/rds.py",
+                match=(
+                    "method fake_method hasn't been added to the list of accepted methods to use a waiter in"
+                    " module_utils/rds.py"
+                ),
             ),
         ),
     ],
@@ -409,8 +422,8 @@ def test__get_rds_method_attribute_instance(method_name, params, expected, error
                     name="delete_db_snapshot",
                     waiter="db_snapshot_deleted",
                     operation_description="delete DB snapshot",
-                    resource='instance_snapshot',
-                    retry_codes=['InvalidDBSnapshotState']
+                    resource="instance_snapshot",
+                    retry_codes=["InvalidDBSnapshotState"],
                 )
             ),
         ),
@@ -424,24 +437,21 @@ def test__get_rds_method_attribute_instance(method_name, params, expected, error
                     name="create_db_snapshot",
                     waiter="db_snapshot_available",
                     operation_description="create DB snapshot",
-                    resource='instance_snapshot',
-                    retry_codes=['InvalidDBInstanceState']
+                    resource="instance_snapshot",
+                    retry_codes=["InvalidDBInstanceState"],
                 )
             ),
         ),
         (
             "copy_db_snapshot",
-            {
-                "source_db_snapshot_identifier": "test",
-                "db_snapshot_identifier": "test-copy"
-            },
+            {"source_db_snapshot_identifier": "test", "db_snapshot_identifier": "test-copy"},
             *expected(
                 rds.Boto3ClientMethod(
                     name="copy_db_snapshot",
                     waiter="db_snapshot_available",
                     operation_description="copy DB snapshot",
-                    resource='instance_snapshot',
-                    retry_codes=['InvalidDBSnapshotState']
+                    resource="instance_snapshot",
+                    retry_codes=["InvalidDBSnapshotState"],
                 )
             ),
         ),
@@ -455,8 +465,8 @@ def test__get_rds_method_attribute_instance(method_name, params, expected, error
                     name="list_tags_for_resource",
                     waiter="db_snapshot_available",
                     operation_description="list tags for resource",
-                    resource='instance_snapshot',
-                    retry_codes=['InvalidDBSnapshotState']
+                    resource="instance_snapshot",
+                    retry_codes=["InvalidDBSnapshotState"],
                 )
             ),
         ),
@@ -470,8 +480,8 @@ def test__get_rds_method_attribute_instance(method_name, params, expected, error
                     name="delete_db_cluster_snapshot",
                     waiter="db_cluster_snapshot_deleted",
                     operation_description="delete DB cluster snapshot",
-                    resource='cluster_snapshot',
-                    retry_codes=['InvalidDBClusterSnapshotState']
+                    resource="cluster_snapshot",
+                    retry_codes=["InvalidDBClusterSnapshotState"],
                 )
             ),
         ),
@@ -485,24 +495,21 @@ def test__get_rds_method_attribute_instance(method_name, params, expected, error
                     name="create_db_cluster_snapshot",
                     waiter="db_cluster_snapshot_available",
                     operation_description="create DB cluster snapshot",
-                    resource='cluster_snapshot',
-                    retry_codes=['InvalidDBClusterState']
+                    resource="cluster_snapshot",
+                    retry_codes=["InvalidDBClusterState"],
                 )
             ),
         ),
         (
             "copy_db_cluster_snapshot",
-            {
-                "source_db_cluster_snapshot_identifier": "test",
-                "db_cluster_snapshot_identifier": "test-copy"
-            },
+            {"source_db_cluster_snapshot_identifier": "test", "db_cluster_snapshot_identifier": "test-copy"},
             *expected(
                 rds.Boto3ClientMethod(
                     name="copy_db_cluster_snapshot",
                     waiter="db_cluster_snapshot_available",
                     operation_description="copy DB cluster snapshot",
-                    resource='cluster_snapshot',
-                    retry_codes=['InvalidDBClusterSnapshotState']
+                    resource="cluster_snapshot",
+                    retry_codes=["InvalidDBClusterSnapshotState"],
                 )
             ),
         ),
@@ -516,34 +523,29 @@ def test__get_rds_method_attribute_instance(method_name, params, expected, error
                     name="list_tags_for_resource",
                     waiter="db_cluster_snapshot_available",
                     operation_description="list tags for resource",
-                    resource='cluster_snapshot',
-                    retry_codes=['InvalidDBClusterSnapshotState']
+                    resource="cluster_snapshot",
+                    retry_codes=["InvalidDBClusterSnapshotState"],
                 )
             ),
         ),
         (
             "fake_method",
-            {
-                "wait": False
-            },
+            {"wait": False},
             *expected(
                 rds.Boto3ClientMethod(
-                    name="fake_method",
-                    waiter="",
-                    operation_description="fake method",
-                    resource='',
-                    retry_codes=[]
+                    name="fake_method", waiter="", operation_description="fake method", resource="", retry_codes=[]
                 )
             ),
         ),
         (
             "fake_method",
-            {
-                "wait": True
-            },
+            {"wait": True},
             *error(
                 NotImplementedError,
-                match="method fake_method hasn't been added to the list of accepted methods to use a waiter in module_utils/rds.py",
+                match=(
+                    "method fake_method hasn't been added to the list of accepted methods to use a waiter in"
+                    " module_utils/rds.py"
+                ),
             ),
         ),
     ],
@@ -558,19 +560,10 @@ def test__get_rds_method_attribute_snapshot(method_name, params, expected, error
 @pytest.mark.parametrize(
     "method_name, params, expected",
     [
+        ("create_db_snapshot", {"db_snapshot_identifier": "test"}, "test"),
         (
             "create_db_snapshot",
-            {
-                "db_snapshot_identifier": "test"
-            },
-            "test"
-        ),
-        (
-            "create_db_snapshot",
-            {
-                "db_snapshot_identifier": "test",
-                "apply_immediately": True
-            },
+            {"db_snapshot_identifier": "test", "apply_immediately": True},
             "test",
         ),
         (
@@ -583,10 +576,7 @@ def test__get_rds_method_attribute_snapshot(method_name, params, expected, error
         ),
         (
             "create_db_snapshot",
-            {
-                "db_snapshot_identifier": "test",
-                "apply_immediately": True
-            },
+            {"db_snapshot_identifier": "test", "apply_immediately": True},
             "test",
         ),
         (
@@ -608,10 +598,7 @@ def test__get_rds_method_attribute_snapshot(method_name, params, expected, error
         ),
         (
             "create_db_snapshot",
-            {
-                "db_snapshot_identifier": "test",
-                "apply_immediately": True
-            },
+            {"db_snapshot_identifier": "test", "apply_immediately": True},
             "test",
         ),
         (
@@ -680,7 +667,8 @@ def test__handle_errors(method_name, exception, expected):
                 message="ModifyDbCluster API",
             ),
             *expected(
-                "It appears you are trying to modify attributes that are managed at the cluster level. Please see rds_cluster"
+                "It appears you are trying to modify attributes that are managed at the cluster level. Please see"
+                " rds_cluster"
             ),
         ),
         (
@@ -688,7 +676,10 @@ def test__handle_errors(method_name, exception, expected):
             build_exception("modify_db_instance", code="InvalidParameterCombination"),
             *error(
                 NotImplementedError,
-                match="method modify_db_instance hasn't been added to the list of accepted methods to use a waiter in module_utils/rds.py",
+                match=(
+                    "method modify_db_instance hasn't been added to the list of accepted methods to use a waiter in"
+                    " module_utils/rds.py"
+                ),
             ),
         ),
         (
@@ -696,25 +687,27 @@ def test__handle_errors(method_name, exception, expected):
             build_exception("promote_read_replica", code="InvalidDBInstanceState"),
             *error(
                 NotImplementedError,
-                match="method promote_read_replica hasn't been added to the list of accepted methods to use a waiter in module_utils/rds.py",
+                match=(
+                    "method promote_read_replica hasn't been added to the list of accepted methods to use a waiter in"
+                    " module_utils/rds.py"
+                ),
             ),
         ),
         (
             "promote_read_replica_db_cluster",
-            build_exception(
-                "promote_read_replica_db_cluster", code="InvalidDBClusterStateFault"
-            ),
+            build_exception("promote_read_replica_db_cluster", code="InvalidDBClusterStateFault"),
             *error(
                 NotImplementedError,
-                match="method promote_read_replica_db_cluster hasn't been added to the list of accepted methods to use a waiter in module_utils/rds.py",
+                match=(
+                    "method promote_read_replica_db_cluster hasn't been added to the list of accepted methods to use a"
+                    " waiter in module_utils/rds.py"
+                ),
             ),
         ),
         (
             "create_db_cluster",
             build_exception("create_db_cluster", code="InvalidParameterValue"),
-            *expected(
-                "DB engine fake_engine should be one of aurora, aurora-mysql, aurora-postgresql"
-            ),
+            *expected("DB engine fake_engine should be one of aurora, aurora-mysql, aurora-postgresql"),
         ),
     ],
 )
@@ -727,25 +720,15 @@ def test__handle_errors_failed(method_name, exception, expected, error):
         module.fail_json_aws.call_args[1]["msg"] == expected
 
 
-class TestRdsUtils():
-
+class TestRdsUtils:
     # ========================================================
     # Setup some initial data that we can use within our tests
     # ========================================================
     def setup_method(self):
         self.target_role_list = [
-            {
-                'role_arn': 'role_won',
-                'feature_name': 's3Export'
-            },
-            {
-                'role_arn': 'role_too',
-                'feature_name': 'Lambda'
-            },
-            {
-                'role_arn': 'role_thrie',
-                'feature_name': 's3Import'
-            }
+            {"role_arn": "role_won", "feature_name": "s3Export"},
+            {"role_arn": "role_too", "feature_name": "Lambda"},
+            {"role_arn": "role_thrie", "feature_name": "s3Import"},
         ]
 
     # ========================================================
@@ -779,11 +762,7 @@ class TestRdsUtils():
         assert self.target_role_list == roles_to_delete
 
     def test_compare_iam_roles_different(self):
-        existing_list = [
-            {
-                'role_arn': 'role_wonn',
-                'feature_name': 's3Export'
-            }]
+        existing_list = [{"role_arn": "role_wonn", "feature_name": "s3Export"}]
         roles_to_add, roles_to_delete = rds.compare_iam_roles(existing_list, self.target_role_list, purge_roles=False)
         assert self.target_role_list == roles_to_add
         assert [] == roles_to_delete
@@ -792,11 +771,7 @@ class TestRdsUtils():
         assert existing_list == roles_to_delete
 
         existing_list = self.target_role_list.copy()
-        self.target_role_list = [
-            {
-                'role_arn': 'role_wonn',
-                'feature_name': 's3Export'
-            }]
+        self.target_role_list = [{"role_arn": "role_wonn", "feature_name": "s3Export"}]
         roles_to_add, roles_to_delete = rds.compare_iam_roles(existing_list, self.target_role_list, purge_roles=False)
         assert self.target_role_list == roles_to_add
         assert [] == roles_to_delete
