@@ -10,9 +10,7 @@ __metaclass__ = type
 
 from ansible_collections.arista.eos.plugins.modules import eos_bgp_global
 from ansible_collections.arista.eos.tests.unit.compat.mock import patch
-from ansible_collections.arista.eos.tests.unit.modules.utils import (
-    set_module_args,
-)
+from ansible_collections.arista.eos.tests.unit.modules.utils import set_module_args
 
 from .eos_module import TestEosModule, load_fixture
 
@@ -26,9 +24,7 @@ class TestEosBgpglobalModule(TestEosModule):
         self.mock_get_resource_connection_config = patch(
             "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.resource_module_base.get_resource_connection",
         )
-        self.get_resource_connection_config = (
-            self.mock_get_resource_connection_config.start()
-        )
+        self.get_resource_connection_config = self.mock_get_resource_connection_config.start()
 
         self.mock_execute_show_command = patch(
             "ansible_collections.arista.eos.plugins.module_utils.network.eos.facts.bgp_global.bgp_global.Bgp_globalFacts.get_config",
@@ -38,9 +34,7 @@ class TestEosBgpglobalModule(TestEosModule):
         self.mock_execute_show_command_config = patch(
             "ansible_collections.arista.eos.plugins.module_utils.network.eos.config.bgp_global.bgp_global.Bgp_global._get_config",
         )
-        self.execute_show_command_config = (
-            self.mock_execute_show_command_config.start()
-        )
+        self.execute_show_command_config = self.mock_execute_show_command_config.start()
 
     def tearDown(self):
         super(TestEosBgpglobalModule, self).tearDown()
