@@ -8,11 +8,13 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
+from textwrap import dedent
+
 from ansible_collections.cisco.ios.plugins.modules import ios_ospfv2
 from ansible_collections.cisco.ios.tests.unit.compat.mock import patch
 from ansible_collections.cisco.ios.tests.unit.modules.utils import set_module_args
 
-from .ios_module import TestIosModule, load_fixture
+from .ios_module import TestIosModule
 
 
 class TestIosOspfV2Module(TestIosModule):
@@ -21,33 +23,12 @@ class TestIosOspfV2Module(TestIosModule):
     def setUp(self):
         super(TestIosOspfV2Module, self).setUp()
 
-        self.mock_get_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.get_config",
-        )
-        self.get_config = self.mock_get_config.start()
-
-        self.mock_load_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.load_config",
-        )
-        self.load_config = self.mock_load_config.start()
-
-        self.mock_get_resource_connection_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.cfg.base."
-            "get_resource_connection",
-        )
-        self.get_resource_connection_config = self.mock_get_resource_connection_config.start()
-
         self.mock_get_resource_connection_facts = patch(
             "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.resource_module_base."
             "get_resource_connection",
         )
         self.get_resource_connection_facts = self.mock_get_resource_connection_facts.start()
 
-        self.mock_edit_config = patch(
-            "ansible_collections.cisco.ios.plugins.module_utils.network.ios.providers.providers.CliProvider.edit_config",
-        )
-        self.edit_config = self.mock_edit_config.start()
-
         self.mock_execute_show_command = patch(
             "ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.ospfv2.ospfv2."
             "Ospfv2Facts.get_ospfv2_data",
@@ -56,20 +37,24 @@ class TestIosOspfV2Module(TestIosModule):
 
     def tearDown(self):
         super(TestIosOspfV2Module, self).tearDown()
-        self.mock_get_resource_connection_config.stop()
         self.mock_get_resource_connection_facts.stop()
-        self.mock_edit_config.stop()
-        self.mock_get_config.stop()
-        self.mock_load_config.stop()
         self.mock_execute_show_command.stop()
 
-    def load_fixtures(self, commands=None):
-        def load_from_file(*args, **kwargs):
-            return load_fixture("ios_ospfv2.cfg")
-
-        self.execute_show_command.side_effect = load_from_file
-
     def test_ios_ospfv2_merged(self):
+        self.execute_show_command.return_value = dedent(
+            """\
+            router ospf 200 vrf blue
+             auto-cost reference-bandwidth 4
+             distribute-list 10 out
+             distribute-list 123 in
+             domain-id 192.0.3.1
+             max-metric router-lsa on-startup 100
+             area 10 capability default-exclusion
+             passive-interface default
+             no passive-interface GigabitEthernet0/1
+             no passive-interface GigabitEthernet0/2
+            """,
+        )
         set_module_args(
             dict(
                 config=dict(
@@ -122,6 +107,20 @@ class TestIosOspfV2Module(TestIosModule):
         self.assertEqual(sorted(result["commands"]), sorted(commands))
 
     def test_ios_ospfv2_merged_specific_param(self):
+        self.execute_show_command.return_value = dedent(
+            """\
+            router ospf 200 vrf blue
+             auto-cost reference-bandwidth 4
+             distribute-list 10 out
+             distribute-list 123 in
+             domain-id 192.0.3.1
+             max-metric router-lsa on-startup 100
+             area 10 capability default-exclusion
+             passive-interface default
+             no passive-interface GigabitEthernet0/1
+             no passive-interface GigabitEthernet0/2
+            """,
+        )
         set_module_args(
             dict(
                 config={
@@ -143,6 +142,20 @@ class TestIosOspfV2Module(TestIosModule):
         self.assertEqual(sorted(result["commands"]), sorted(commands))
 
     def test_ios_ospfv2_merged_idempotent(self):
+        self.execute_show_command.return_value = dedent(
+            """\
+            router ospf 200 vrf blue
+             auto-cost reference-bandwidth 4
+             distribute-list 10 out
+             distribute-list 123 in
+             domain-id 192.0.3.1
+             max-metric router-lsa on-startup 100
+             area 10 capability default-exclusion
+             passive-interface default
+             no passive-interface GigabitEthernet0/1
+             no passive-interface GigabitEthernet0/2
+            """,
+        )
         set_module_args(
             dict(
                 config=dict(
@@ -176,25 +189,56 @@ class TestIosOspfV2Module(TestIosModule):
         self.execute_module(changed=False, commands=[])
 
     def test_ios_ospfv2_replaced(self):
+        self.execute_show_command.return_value = dedent(
+            """\
+            router ospf 200 vrf blue
+             auto-cost reference-bandwidth 4
+             distribute-list 10 out
+             distribute-list 123 in
+             domain-id 192.0.3.1
+             max-metric router-lsa on-startup 100
+             area 10 capability default-exclusion
+             passive-interface default
+             no passive-interface GigabitEthernet0/1
+             no passive-interface GigabitEthernet0/2
+            """,
+        )
         set_module_args(
             dict(
-                config=dict(
-                    processes=[
-                        dict(
-                            process_id="200",
-                            auto_cost=dict(reference_bandwidth="4"),
-                            domain_id=dict(ip_address=dict(address="192.0.1.1")),
-                            max_metric=dict(on_startup=dict(time=200), router_lsa=True),
-                            areas=[dict(area_id="10", capability=True)],
-                            vrf="blue",
-                        ),
+                config={
+                    "processes": [
+                        {
+                            "process_id": "200",
+                            "auto_cost": {
+                                "reference_bandwidth": "4",
+                            },
+                            "domain_id": {
+                                "ip_address": {
+                                    "address": "192.0.1.1",
+                                },
+                            },
+                            "max_metric": {
+                                "on_startup": {
+                                    "time": 200,
+                                },
+                                "router_lsa": True,
+                            },
+                            "areas": [
+                                {
+                                    "area_id": "10",
+                                    "capability": True,
+                                },
+                            ],
+                            "vrf": "blue",
+                        },
                     ],
-                ),
+                },
                 state="replaced",
             ),
         )
         commands = [
             "router ospf 200 vrf blue",
+            "auto-cost reference-bandwidth 4",
             "no distribute-list 123 in",
             "no distribute-list 10 out",
             "domain-id 192.0.1.1",
@@ -203,73 +247,21 @@ class TestIosOspfV2Module(TestIosModule):
         result = self.execute_module(changed=True)
         self.assertEqual(sorted(result["commands"]), sorted(commands))
 
-    def test_ios_ospfv2_replaced_idempotent(self):
-        set_module_args(
-            dict(
-                config=dict(
-                    processes=[
-                        dict(
-                            process_id="200",
-                            auto_cost=dict(reference_bandwidth="4"),
-                            distribute_list=dict(
-                                acls=[
-                                    dict(direction="out", name="10"),
-                                    dict(direction="in", name="123"),
-                                ],
-                            ),
-                            domain_id=dict(ip_address=dict(address="192.0.3.1")),
-                            max_metric=dict(on_startup=dict(time=100), router_lsa=True),
-                            areas=[dict(area_id="10", capability=True)],
-                            passive_interfaces=dict(
-                                default=True,
-                                interface=dict(
-                                    set_interface=False,
-                                    name=["GigabitEthernet0/1", "GigabitEthernet0/2"],
-                                ),
-                            ),
-                            vrf="blue",
-                        ),
-                    ],
-                ),
-                state="replaced",
-            ),
-        )
-        self.execute_module(changed=False, commands=[])
-
-    def test_ios_ospfv2_overridden_idempotent(self):
-        set_module_args(
-            dict(
-                config=dict(
-                    processes=[
-                        dict(
-                            process_id="200",
-                            auto_cost=dict(reference_bandwidth="4"),
-                            distribute_list=dict(
-                                acls=[
-                                    dict(direction="out", name="10"),
-                                    dict(direction="in", name="123"),
-                                ],
-                            ),
-                            domain_id=dict(ip_address=dict(address="192.0.3.1")),
-                            max_metric=dict(on_startup=dict(time=100), router_lsa=True),
-                            areas=[dict(area_id="10", capability=True)],
-                            passive_interfaces=dict(
-                                default=True,
-                                interface=dict(
-                                    set_interface=False,
-                                    name=["GigabitEthernet0/1", "GigabitEthernet0/2"],
-                                ),
-                            ),
-                            vrf="blue",
-                        ),
-                    ],
-                ),
-                state="overridden",
-            ),
-        )
-        self.execute_module(changed=False, commands=[])
-
     def test_ios_ospfv2_overridden(self):
+        self.execute_show_command.return_value = dedent(
+            """\
+            router ospf 200 vrf blue
+             auto-cost reference-bandwidth 4
+             distribute-list 10 out
+             distribute-list 123 in
+             domain-id 192.0.3.1
+             max-metric router-lsa on-startup 100
+             area 10 capability default-exclusion
+             passive-interface default
+             no passive-interface GigabitEthernet0/1
+             no passive-interface GigabitEthernet0/2
+            """,
+        )
         set_module_args(
             dict(
                 config={
@@ -318,7 +310,6 @@ class TestIosOspfV2Module(TestIosModule):
                                     "ranges": [
                                         {
                                             "address": "172.16.1.0",
-                                            "advertise": True,
                                             "cost": 20,
                                             "netmask": "0.0.0.255",
                                             "not_advertise": True,
@@ -344,14 +335,14 @@ class TestIosOspfV2Module(TestIosModule):
                             "bfd": True,
                             "capability": {
                                 "lls": True,
-                                "opaque": True,
-                                "transit": True,
-                                "vrf_lite": True,
+                                "opaque": False,
+                                "transit": False,
+                                "vrf_lite": False,
                             },
                             "compatible": {
                                 "rfc1583": True,
-                                "rfc1587": True,
-                                "rfc5243": True,
+                                "rfc1587": False,
+                                "rfc5243": False,
                             },
                             "default_information": {
                                 "always": True,
@@ -400,11 +391,9 @@ class TestIosOspfV2Module(TestIosModule):
                             "limit": {
                                 "dc": {
                                     "disable": True,
-                                    "number": 20,
                                 },
                                 "non_dc": {
                                     "disable": True,
-                                    "number": 10,
                                 },
                             },
                             "local_rib_criteria": {
@@ -436,7 +425,6 @@ class TestIosOspfV2Module(TestIosModule):
                                         "area": "area1",
                                         "set": True,
                                     },
-                                    "sync": True,
                                 },
                                 "traffic_eng": {
                                     "area": "area12",
@@ -479,7 +467,6 @@ class TestIosOspfV2Module(TestIosModule):
                                     "strict_lsa_checking": True,
                                 },
                             },
-                            # "passive_interface": "GigabitEthernet0/1",
                             "passive_interfaces": {
                                 "default": True,
                                 "interface": {
@@ -493,11 +480,9 @@ class TestIosOspfV2Module(TestIosModule):
                             "queue_depth": {
                                 "hello": {
                                     "max_packets": 10,
-                                    "unlimited": True,
                                 },
                                 "update": {
                                     "max_packets": 30,
-                                    "unlimited": True,
                                 },
                             },
                             "router_id": "router1",
@@ -505,7 +490,6 @@ class TestIosOspfV2Module(TestIosModule):
                             "summary_address": {
                                 "address": "172.16.1.0",
                                 "mask": "0.0.0.255",
-                                "not_advertise": True,
                                 "nssa_only": True,
                                 "tag": 12,
                             },
@@ -513,8 +497,6 @@ class TestIosOspfV2Module(TestIosModule):
                                 "lsa": 12,
                                 "pacing": {
                                     "flood": 25,
-                                    "lsa_group": 15,
-                                    "retransmission": 30,
                                 },
                                 "throttle": {
                                     "lsa": {
@@ -542,7 +524,7 @@ class TestIosOspfV2Module(TestIosModule):
         commands = [
             "no router ospf 200 vrf blue",
             "router ospf 1 vrf vrf1",
-            "adjacency stagger  none 2",
+            "adjacency stagger none 10",
             "address-family ipv4 multicast",
             "topology base",
             "exit-address-family",
@@ -553,47 +535,71 @@ class TestIosOspfV2Module(TestIosModule):
             "default-information originate always metric 25 metric-type 26 route-map rmap1",
             "default-metric 50",
             "discard-route external 5 internal 2",
-            "domain-id 192.168.1.0 True",
+            "distance ospf inter-area 2 intra-area 3 external 1",
+            "domain-id 192.168.1.0 secondary",
             "domain-tag 54",
             "event-log one-shot pause size 10",
             "help",
             "ignore lsa mospf",
             "interface-id snmp-if-index",
             "ispf",
-            "limit retransmissions dc 20 dc disable non-dc 10 non-dc disable",
+            "limit retransmissions dc disable non-dc disable",
             "local-rib-criteria forwarding-address inter-area-summary nssa-translation",
             "log-adjacency-changes detail",
-            "max-lsa 10 10 ignore-count 10 ignore-time 10 reset-time 10 warning-only",
+            "max-lsa 10 10 warning-only",
             "max-metric router-lsa external-lsa 10 include-stub on-startup 110 summary-lsa 20",
             "maximum-paths 15",
+            "mpls ldp autoconfig area area1",
+            "mpls traffic-eng area area12",
             "neighbor 172.16.1.0 cost 2 database-filter all out poll-interval 20 priority 10",
-            "network 198.51.100.0 0.0.0.255 area 5",
+            "nsf cisco helper disable",
+            "nsf ietf helper disable",
+            "nsf ietf helper strict-lsa-checking",
             "prefix-suppression",
             "priority 10",
+            "queue-depth hello 10",
+            "queue-depth update 30",
             "router-id router1",
             "shutdown",
-            "summary-address 172.16.1.0 0.0.0.255 not-advertise",
+            "summary-address 172.16.1.0 0.0.0.255 nssa-only tag 12",
+            "timers pacing flood 25",
             "traffic-share min across-interfaces",
             "ttl-security all-interfaces hops 12",
             "area 5 authentication message-digest",
             "area 10 authentication message-digest",
             "area 10 capability default-exclusion",
             "area 10 default-cost 10",
-            "area 10 nssa translate type7 suppress-fa",
             "area 10 nssa default-information-originate metric 10 metric-type 1 nssa-only no-ext-capability no-redistribution no-summary",
-            "area 10 range 172.16.1.0 0.0.0.255 advertise cost 20",
+            "area 10 nssa translate type7 suppress-fa",
             "area 10 sham-link checkSource checkDestination cost 10 ttl-security hops 20",
             "area 10 stub no-ext-capability no-summary",
             "area 10 filter-list prefix test_prefix_in in",
             "area 10 filter-list prefix test_prefix_out out",
+            "area 10 range 172.16.1.0 0.0.0.255 not-advertise cost 20",
+            "network 198.51.100.0 0.0.0.255 area 5",
             "passive-interface default",
             "no passive-interface GigabitEthernet0/1",
             "no passive-interface GigabitEthernet0/2",
         ]
         result = self.execute_module(changed=True)
+        self.maxDiff = None
         self.assertEqual(commands, result["commands"])
 
     def test_ios_ospfv2_deleted(self):
+        self.execute_show_command.return_value = dedent(
+            """\
+            router ospf 200 vrf blue
+             auto-cost reference-bandwidth 4
+             distribute-list 10 out
+             distribute-list 123 in
+             domain-id 192.0.3.1
+             max-metric router-lsa on-startup 100
+             area 10 capability default-exclusion
+             passive-interface default
+             no passive-interface GigabitEthernet0/1
+             no passive-interface GigabitEthernet0/2
+            """,
+        )
         set_module_args(
             dict(config=dict(processes=[dict(process_id="200", vrf="blue")]), state="deleted"),
         )
@@ -601,6 +607,20 @@ class TestIosOspfV2Module(TestIosModule):
         self.execute_module(changed=True, commands=commands)
 
     def test_ios_ospfv2_parsed(self):
+        self.execute_show_command.return_value = dedent(
+            """\
+            router ospf 200 vrf blue
+             auto-cost reference-bandwidth 4
+             distribute-list 10 out
+             distribute-list 123 in
+             domain-id 192.0.3.1
+             max-metric router-lsa on-startup 100
+             area 10 capability default-exclusion
+             passive-interface default
+             no passive-interface GigabitEthernet0/1
+             no passive-interface GigabitEthernet0/2
+            """,
+        )
         set_module_args(
             dict(
                 running_config="router ospf 1\n area 5 authentication\n area 5 capability default-exclusion",
@@ -621,6 +641,20 @@ class TestIosOspfV2Module(TestIosModule):
         self.assertEqual(parsed_list, result["parsed"])
 
     def test_ios_ospfv2_rendered(self):
+        self.execute_show_command.return_value = dedent(
+            """\
+            router ospf 200 vrf blue
+             auto-cost reference-bandwidth 4
+             distribute-list 10 out
+             distribute-list 123 in
+             domain-id 192.0.3.1
+             max-metric router-lsa on-startup 100
+             area 10 capability default-exclusion
+             passive-interface default
+             no passive-interface GigabitEthernet0/1
+             no passive-interface GigabitEthernet0/2
+            """,
+        )
         set_module_args(
             dict(
                 config={
@@ -672,7 +706,6 @@ class TestIosOspfV2Module(TestIosModule):
                                             "advertise": True,
                                             "cost": 20,
                                             "netmask": "0.0.0.255",
-                                            "not_advertise": True,
                                         },
                                     ],
                                     "sham_link": {
@@ -695,14 +728,14 @@ class TestIosOspfV2Module(TestIosModule):
                             "bfd": True,
                             "capability": {
                                 "lls": True,
-                                "opaque": True,
-                                "transit": True,
-                                "vrf_lite": True,
+                                "opaque": False,
+                                "transit": False,
+                                "vrf_lite": False,
                             },
                             "compatible": {
                                 "rfc1583": True,
-                                "rfc1587": True,
-                                "rfc5243": True,
+                                "rfc1587": False,
+                                "rfc5243": False,
                             },
                             "default_information": {
                                 "always": True,
@@ -771,7 +804,7 @@ class TestIosOspfV2Module(TestIosModule):
                                 "number": 10,
                                 "reset_time": 10,
                                 "threshold_value": 10,
-                                "warning_only": True,
+                                "warning_only": False,
                             },
                             "max_metric": {
                                 "external_lsa": 10,
@@ -783,10 +816,6 @@ class TestIosOspfV2Module(TestIosModule):
                             "maximum_paths": 15,
                             "mpls": {
                                 "ldp": {
-                                    "autoconfig": {
-                                        "area": "area1",
-                                        "set": True,
-                                    },
                                     "sync": True,
                                 },
                                 "traffic_eng": {
@@ -830,7 +859,6 @@ class TestIosOspfV2Module(TestIosModule):
                                     "strict_lsa_checking": True,
                                 },
                             },
-                            # "passive_interface": "GigabitEthernet0/1",
                             "passive_interfaces": {
                                 "default": True,
                                 "interface": {
@@ -843,11 +871,9 @@ class TestIosOspfV2Module(TestIosModule):
                             "process_id": 1,
                             "queue_depth": {
                                 "hello": {
-                                    "max_packets": 10,
                                     "unlimited": True,
                                 },
                                 "update": {
-                                    "max_packets": 30,
                                     "unlimited": True,
                                 },
                             },
@@ -856,15 +882,12 @@ class TestIosOspfV2Module(TestIosModule):
                             "summary_address": {
                                 "address": "172.16.1.0",
                                 "mask": "0.0.0.255",
-                                "not_advertise": True,
                                 "nssa_only": True,
                                 "tag": 12,
                             },
                             "timers": {
                                 "lsa": 12,
                                 "pacing": {
-                                    "flood": 25,
-                                    "lsa_group": 15,
                                     "retransmission": 30,
                                 },
                                 "throttle": {
@@ -891,7 +914,7 @@ class TestIosOspfV2Module(TestIosModule):
         )
         commands = [
             "address-family ipv4 multicast",
-            "adjacency stagger  none 2",
+            "adjacency stagger none 10",
             "area 10 authentication message-digest",
             "area 10 capability default-exclusion",
             "area 10 default-cost 10",
@@ -910,7 +933,8 @@ class TestIosOspfV2Module(TestIosModule):
             "default-information originate always metric 25 metric-type 26 route-map rmap1",
             "default-metric 50",
             "discard-route external 5 internal 2",
-            "domain-id 192.168.1.0 True",
+            "distance ospf inter-area 2 intra-area 3 external 1",
+            "domain-id 192.168.1.0 secondary",
             "domain-tag 54",
             "event-log one-shot pause size 10",
             "exit-address-family",
@@ -918,26 +942,218 @@ class TestIosOspfV2Module(TestIosModule):
             "ignore lsa mospf",
             "interface-id snmp-if-index",
             "ispf",
-            "limit retransmissions dc 20 dc disable non-dc 10 non-dc disable",
+            "limit retransmissions dc 20 non-dc 10",
             "local-rib-criteria forwarding-address inter-area-summary nssa-translation",
             "log-adjacency-changes detail",
-            "max-lsa 10 10 ignore-count 10 ignore-time 10 reset-time 10 warning-only",
+            "max-lsa 10 10 ignore-count 10 ignore-time 10 reset-time 10",
             "max-metric router-lsa external-lsa 10 include-stub on-startup 110 summary-lsa 20",
             "maximum-paths 15",
+            "mpls ldp sync",
+            "mpls traffic-eng area area12",
             "neighbor 172.16.1.0 cost 2 database-filter all out poll-interval 20 priority 10",
             "network 198.51.100.0 0.0.0.255 area 5",
             "no passive-interface GigabitEthernet0/1",
             "no passive-interface GigabitEthernet0/2",
+            "nsf cisco helper disable",
+            "nsf ietf helper disable",
+            "nsf ietf helper strict-lsa-checking",
             "passive-interface default",
             "prefix-suppression",
             "priority 10",
+            "queue-depth hello unlimited",
+            "queue-depth update unlimited",
             "router ospf 1 vrf vrf1",
             "router-id router1",
             "shutdown",
-            "summary-address 172.16.1.0 0.0.0.255 not-advertise",
+            "summary-address 172.16.1.0 0.0.0.255 nssa-only tag 12",
+            "timers pacing retransmission 30",
             "topology base",
             "traffic-share min across-interfaces",
             "ttl-security all-interfaces hops 12",
         ]
         result = self.execute_module(changed=False)
+        self.maxDiff = None
         self.assertEqual(sorted(result["rendered"]), commands)
+
+    def test_ios_ospfv2_overridden_2(self):
+        self.execute_show_command.return_value = dedent(
+            """\
+            router ospf 200 vrf blue
+             auto-cost reference-bandwidth 4
+             distribute-list 10 out
+             distribute-list 123 in
+             domain-id 192.0.3.1
+             max-metric router-lsa on-startup 100
+             area 10 capability default-exclusion
+             area 10 filter-list prefix test_prefix_in in
+             passive-interface default
+             no passive-interface GigabitEthernet0/1
+             no passive-interface GigabitEthernet0/2
+            router ospf 210 vrf green
+             auto-cost reference-bandwidth 4
+             distribute-list 10 out
+             distribute-list 123 in
+             domain-id 192.0.3.1
+             area 10 capability default-exclusion
+             passive-interface default
+             no passive-interface GigabitEthernet0/1
+             no passive-interface GigabitEthernet0/2
+            """,
+        )
+
+        set_module_args(
+            dict(
+                config={
+                    "processes": [
+                        {
+                            "process_id": 200,
+                            "vrf": "blue",
+                            "auto_cost": {"set": True, "reference_bandwidth": 4},
+                            "distribute_list": {
+                                "acls": [
+                                    {"name": "110", "direction": "out"},
+                                    {"name": "123", "direction": "in"},
+                                ],
+                            },
+                            "queue_depth": {
+                                "hello": {
+                                    "unlimited": True,
+                                },
+                                "update": {
+                                    "unlimited": True,
+                                },
+                            },
+                            "domain_id": {"null": True},
+                            "timers": {
+                                "pacing": {
+                                    "lsa_group": 25,
+                                },
+                            },
+                            "max_metric": {"router_lsa": True, "on_startup": {"time": 100}},
+                            "areas": [{"area_id": "10", "capability": True}],
+                            "passive_interfaces": {
+                                "default": True,
+                                "interface": {
+                                    "set_interface": False,
+                                    "name": ["GigabitEthernet0/2", "GigabitEthernet0/1"],
+                                },
+                            },
+                        },
+                        {
+                            "process_id": 210,
+                            "vrf": "green",
+                            "auto_cost": {"set": True, "reference_bandwidth": 5},
+                            "distribute_list": {
+                                "acls": [
+                                    {"name": "5120", "direction": "out"},
+                                    {"name": "123", "direction": "out"},
+                                ],
+                            },
+                            "domain_id": {"ip_address": {"address": "192.0.3.1"}},
+                            "nsf": {
+                                "ietf": {
+                                    "strict_lsa_checking": True,
+                                },
+                            },
+                            "mpls": {
+                                "ldp": {
+                                    "sync": True,
+                                },
+                            },
+                            "timers": {
+                                "pacing": {
+                                    "flood": 25,
+                                },
+                            },
+                            "max_metric": {
+                                "router_lsa": True,
+                                "on_startup": {"wait_for_bgp": True},
+                            },
+                            "areas": [{"area_id": "11", "capability": True}],
+                            "passive_interfaces": {
+                                "default": True,
+                                "interface": {
+                                    "set_interface": False,
+                                    "name": ["GigabitEthernet0/2"],
+                                },
+                            },
+                        },
+                    ],
+                },
+                state="overridden",
+            ),
+        )
+
+        result = self.execute_module(changed=True)
+        print(result["commands"])
+        commands = [
+            "router ospf 200 vrf blue",
+            "domain-id null",
+            "queue-depth hello unlimited",
+            "queue-depth update unlimited",
+            "timers pacing lsa-group 25",
+            "no area 10 filter-list prefix test_prefix_in in",
+            "distribute-list 110 out",
+            "no distribute-list 10 out",
+            "router ospf 210 vrf green",
+            "auto-cost reference-bandwidth 5",
+            "max-metric router-lsa on-startup wait-for-bgp",
+            "mpls ldp sync",
+            "nsf ietf helper strict-lsa-checking",
+            "timers pacing flood 25",
+            "area 11 capability default-exclusion",
+            "no area 10 capability default-exclusion",
+            "distribute-list 5120 out",
+            "no distribute-list 123 in",
+            "distribute-list 123 out",
+            "no distribute-list 10 out",
+            "passive-interface GigabitEthernet0/1",
+        ]
+        self.assertEqual(result["commands"], commands)
+
+    def test_ios_ospfv2_overridden_idempotent(self):
+        self.execute_show_command.return_value = dedent(
+            """\
+            router ospf 200 vrf blue
+             auto-cost reference-bandwidth 4
+             distribute-list 10 out
+             distribute-list 123 in
+             domain-id 192.0.3.1
+             max-metric router-lsa on-startup 100
+             area 10 capability default-exclusion
+             passive-interface default
+             no passive-interface GigabitEthernet0/1
+             no passive-interface GigabitEthernet0/2
+            """,
+        )
+        set_module_args(
+            dict(
+                config=dict(
+                    processes=[
+                        {
+                            "process_id": 200,
+                            "vrf": "blue",
+                            "auto_cost": {"set": True, "reference_bandwidth": 4},
+                            "distribute_list": {
+                                "acls": [
+                                    {"name": "10", "direction": "out"},
+                                    {"name": "123", "direction": "in"},
+                                ],
+                            },
+                            "domain_id": {"ip_address": {"address": "192.0.3.1"}},
+                            "max_metric": {"router_lsa": True, "on_startup": {"time": 100}},
+                            "areas": [{"area_id": "10", "capability": True}],
+                            "passive_interfaces": {
+                                "default": True,
+                                "interface": {
+                                    "set_interface": False,
+                                    "name": ["GigabitEthernet0/2", "GigabitEthernet0/1"],
+                                },
+                            },
+                        },
+                    ],
+                ),
+                state="overridden",
+            ),
+        )
+        self.execute_module(changed=False, commands=[])
