@@ -94,44 +94,44 @@ class TestPluginCLIConfIOS(unittest.TestCase):
         """Test get_capabilities"""
         capabilities = json.loads(self._cliconf.get_capabilities())
         mock_capabilities = {
+            "device_info": {
+                "network_os": "ios",
+                "network_os_hostname": "an-csr-01",
+                "network_os_image": "bootflash:packages.conf",
+                "network_os_model": "CSR1000V",
+                "network_os_type": "L2",
+                "network_os_version": "16.06.01",
+            },
+            "device_operations": {
+                "supports_commit": False,
+                "supports_commit_comment": False,
+                "supports_defaults": True,
+                "supports_diff_ignore_lines": True,
+                "supports_diff_match": True,
+                "supports_diff_replace": True,
+                "supports_generate_diff": True,
+                "supports_multiline_delimiter": True,
+                "supports_onbox_diff": False,
+                "supports_replace": False,
+                "supports_rollback": False,
+            },
+            "diff_match": ["line", "strict", "exact", "none"],
+            "diff_replace": ["line", "block"],
+            "format": ["text"],
             "network_api": "cliconf",
+            "output": [],
             "rpc": [
-                "get_config",
                 "edit_config",
-                "get_capabilities",
-                "get",
                 "enable_response_logging",
+                "get",
+                "get_capabilities",
+                "get_config",
                 "disable_response_logging",
+                "run_commands",
                 "edit_banner",
                 "get_diff",
                 "run_commands",
                 "get_defaults_flag",
             ],
-            "device_operations": {
-                "supports_diff_replace": True,
-                "supports_commit": False,
-                "supports_rollback": False,
-                "supports_defaults": True,
-                "supports_onbox_diff": False,
-                "supports_commit_comment": False,
-                "supports_multiline_delimiter": True,
-                "supports_diff_match": True,
-                "supports_diff_ignore_lines": True,
-                "supports_generate_diff": True,
-                "supports_replace": False,
-            },
-            "device_info": {
-                "network_os_hostname": "an-csr-01",
-                "network_os_image": "bootflash:packages.conf",
-                "network_os_model": "CSR1000V",
-                "network_os_version": "16.06.01",
-                "network_os": "ios",
-                "network_os_type": "L2",
-            },
-            "format": ["text"],
-            "diff_match": ["line", "strict", "exact", "none"],
-            "diff_replace": ["line", "block"],
-            "output": [],
         }
-
-        self.assertEqual(mock_capabilities, capabilities)
+        self.assertEqual(sorted(mock_capabilities), sorted(capabilities))
