@@ -224,6 +224,19 @@ class TestIosxrBgpGlobalModule(TestIosxrModule):
                                 minimum_interval=20,
                                 fast_detect=dict(strict_mode=True),
                             ),
+                            use=dict(
+                                neighbor_group="test_ng",
+                                session_group="test_sg",
+                            ),
+                            password=dict(
+                                inheritance_disable="true",
+                            ),
+                            local_as=dict(
+                                value="65539",
+                                no_prepend=dict(
+                                    set="true",
+                                ),
+                            ),
                         ),
                     ],
                     vrfs=[dict(vrf="vrf1", default_metric=5)],
@@ -240,6 +253,10 @@ class TestIosxrBgpGlobalModule(TestIosxrModule):
             "bfd fast-detect strict-mode",
             "bfd minimum-interval 20",
             "bfd multiplier 6",
+            "use session-group test_sg",
+            "use neighbor-group test_ng",
+            "local-as 65539 no-prepend",
+            "password inheritance-disable",
             "remote-as 65538",
         ]
         result = self.execute_module(changed=True)
@@ -264,6 +281,8 @@ class TestIosxrBgpGlobalModule(TestIosxrModule):
                 bfd fast-detect strict-mode
                 bfd multiplier 6
                 bfd minimum-interval 20
+                use session-group test_sg
+                use neighbor-group test_ng
               vrf vrf1
                 default-metric 5
             """,
@@ -298,6 +317,10 @@ class TestIosxrBgpGlobalModule(TestIosxrModule):
                                 minimum_interval=20,
                                 fast_detect=dict(strict_mode=True),
                             ),
+                            use=dict(
+                                neighbor_group="test_ng",
+                                session_group="test_sg",
+                            ),
                         ),
                     ],
                     vrfs=[dict(vrf="vrf1", default_metric=5)],
@@ -386,6 +409,10 @@ class TestIosxrBgpGlobalModule(TestIosxrModule):
                         dict(
                             neighbor="192.0.2.14",
                             remote_as="65538",
+                            use=dict(
+                                neighbor_group="test_nb",
+                                session_group="test_sg",
+                            ),
                             bfd=dict(
                                 multiplier=6,
                                 minimum_interval=20,
@@ -415,6 +442,8 @@ class TestIosxrBgpGlobalModule(TestIosxrModule):
             "bfd fast-detect",
             "bfd minimum-interval 20",
             "bfd multiplier 6",
+            "use neighbor-group test_nb",
+            "use session-group test_sg",
             "remote-as 65538",
             "vrf vrf1",
             "default-metric 5",
@@ -429,7 +458,9 @@ class TestIosxrBgpGlobalModule(TestIosxrModule):
                 running_config="router bgp 65536\n bgp confederation identifier 4\n "
                 "bgp router-id 192.0.2.10\n bgp cluster-id 5\n default-metric 4\n "
                 "socket send-buffer-size 4098\n bgp bestpath med confed\n "
-                "socket receive-buffer-size 514\n neighbor 192.0.2.11\n  remote-as 65537\n  "
+                "socket receive-buffer-size 514\n neighbor 192.0.2.11\n  "
+                "local-as 4 no-prepend replace-as\n  "
+                "password encrypted 15060E1F107B\n  remote-as 65537\n  "
                 "cluster-id 3\n !\n neighbor 192.0.2.14\n  remote-as 65538\n  description test nbr description\n"
                 " bfd fast-detect strict-mode\n "
                 " bfd multiplier 6\n  bfd minimum-interval 20\n !\n!",
@@ -448,7 +479,16 @@ class TestIosxrBgpGlobalModule(TestIosxrModule):
             "default_metric": 4,
             "socket": {"send_buffer_size": 4098, "receive_buffer_size": 514},
             "neighbors": [
-                {"neighbor_address": "192.0.2.11", "remote_as": 65537, "cluster_id": "3"},
+                {
+                    "neighbor_address": "192.0.2.11",
+                    "remote_as": 65537,
+                    "cluster_id": "3",
+                    "password": {"encrypted": "15060E1F107B"},
+                    "local_as": {
+                        "no_prepend": {"replace_as": {"set": True}},
+                        "value": 4,
+                    },
+                },
                 {
                     "neighbor_address": "192.0.2.14",
                     "remote_as": 65538,
@@ -491,3 +531,158 @@ class TestIosxrBgpGlobalModule(TestIosxrModule):
 
         result = self.execute_module(changed=True)
         self.assertEqual(set(result["commands"]), set(commands))
+
+    def test_iosxr_bgp_global_ovrridden(self):
+        run_cfg = dedent(
+            """\
+            router bgp 65536
+              bgp confederation identifier 4
+              bgp router-id 192.0.2.10
+              bgp cluster-id 5
+              default-metric 4
+              socket send-buffer-size 4098
+              bgp bestpath med confed
+              socket receive-buffer-size 514
+              neighbor 192.0.2.11
+                remote-as 65537
+                cluster-id 3
+              neighbor 192.0.2.14
+                remote-as 65538
+                bfd fast-detect strict-mode
+                bfd multiplier 6
+                bfd minimum-interval 20
+              vrf vrf1
+                default-metric 5
+            """,
+        )
+        self.get_config.return_value = run_cfg
+        set_module_args(
+            dict(
+                config=dict(
+                    as_number="65536",
+                    default_metric=5,
+                    socket=dict(
+                        receive_buffer_size=514,
+                        send_buffer_size=4098,
+                    ),
+                    bgp=dict(
+                        confederation=dict(identifier=4),
+                        bestpath=dict(med=dict(confed=True)),
+                        cluster_id=5,
+                        router_id="192.0.2.10",
+                    ),
+                    neighbors=[
+                        dict(
+                            neighbor="192.0.2.13",
+                            remote_as="65538",
+                            bfd=dict(
+                                multiplier=6,
+                                minimum_interval=20,
+                                fast_detect=dict(strict_mode=True),
+                            ),
+                            use=dict(
+                                neighbor_group="test_ng",
+                                session_group="test_sg",
+                            ),
+                            password=dict(
+                                inheritance_disable="true",
+                            ),
+                            local_as=dict(
+                                value="65539",
+                                no_prepend=dict(
+                                    set="true",
+                                ),
+                            ),
+                        ),
+                    ],
+                    vrfs=[dict(vrf="vrf1", default_metric=5)],
+                ),
+                state="overridden",
+            ),
+        )
+        commands = [
+            "router bgp 65536",
+            "no neighbor 192.0.2.11",
+            "no neighbor 192.0.2.14",
+            "default-metric 5",
+            "neighbor 192.0.2.13",
+            "bfd fast-detect strict-mode",
+            "bfd minimum-interval 20",
+            "bfd multiplier 6",
+            "use session-group test_sg",
+            "use neighbor-group test_ng",
+            "local-as 65539 no-prepend",
+            "password inheritance-disable",
+            "remote-as 65538",
+        ]
+        result = self.execute_module(changed=True)
+        self.assertEqual(sorted(result["commands"]), sorted(commands))
+
+    def test_iosxr_bgp_global_overridden_idempotent(self):
+        run_cfg = dedent(
+            """\
+            router bgp 65536
+              bgp confederation identifier 4
+              bgp router-id 192.0.2.10
+              bgp cluster-id 5
+              default-metric 4
+              socket send-buffer-size 4098
+              bgp bestpath med confed
+              socket receive-buffer-size 514
+              neighbor 192.0.2.11
+                remote-as 65537
+                cluster-id 3
+              neighbor 192.0.2.14
+                remote-as 65538
+                bfd fast-detect strict-mode
+                bfd multiplier 6
+                bfd minimum-interval 20
+                use session-group test_sg
+                use neighbor-group test_ng
+              vrf vrf1
+                default-metric 5
+            """,
+        )
+        self.get_config.return_value = run_cfg
+        set_module_args(
+            dict(
+                config=dict(
+                    as_number="65536",
+                    default_metric=4,
+                    socket=dict(
+                        receive_buffer_size=514,
+                        send_buffer_size=4098,
+                    ),
+                    bgp=dict(
+                        confederation=dict(identifier=4),
+                        bestpath=dict(med=dict(confed=True)),
+                        cluster_id=5,
+                        router_id="192.0.2.10",
+                    ),
+                    neighbors=[
+                        dict(
+                            neighbor="192.0.2.11",
+                            cluster_id=3,
+                            remote_as="65537",
+                        ),
+                        dict(
+                            neighbor="192.0.2.14",
+                            remote_as="65538",
+                            bfd=dict(
+                                multiplier=6,
+                                minimum_interval=20,
+                                fast_detect=dict(strict_mode=True),
+                            ),
+                            use=dict(
+                                neighbor_group="test_ng",
+                                session_group="test_sg",
+                            ),
+                        ),
+                    ],
+                    vrfs=[dict(vrf="vrf1", default_metric=5)],
+                ),
+                state="overridden",
+            ),
+        )
+
+        self.execute_module(changed=False, commands=[])
