@@ -21,6 +21,9 @@ options:
   id:
     description: Id path parameter. Rule id.
     type: str
+  identitySourceId:
+    description: Identity source id from the identity stores.
+    type: str
   identitySourceName:
     description: Identity source name from the identity stores.
     type: str
@@ -56,6 +59,9 @@ options:
       condition:
         description: Network Access Authentication Rules's condition.
         suboptions:
+          attributeId:
+            description: Dictionary attribute id (Optional), used for additional verification.
+            type: str
           attributeName:
             description: Dictionary attribute name.
             type: str
@@ -102,11 +108,12 @@ options:
               that additional conditions are present under the children field</li></ul>.
             type: str
           datesRange:
-            description: <p>Defines for which date/s TimeAndDate condition will be matched<br>
-              Options are - Date range, for specific date, the same date should be used
-              for start/end date <br> Default - no specific dates<br> In order to reset
-              the dates to have no specific dates Date format - yyyy-mm-dd (MM = month,
-              dd = day, yyyy = year)</p>.
+            description: <p>Defines for which date/s TimeAndDate condition will be matched
+              or NOT matched if used in exceptionDates prooperty<br> Options are - Date
+              range, for specific date, the same date should be used for start/end date
+              <br> Default - no specific dates<br> In order to reset the dates to have
+              no specific dates Date format - yyyy-mm-dd (MM = month, dd = day, yyyy
+              = year)</p>.
             suboptions:
               endDate:
                 description: Network Access Authentication Rules's endDate.
@@ -116,11 +123,12 @@ options:
                 type: str
             type: dict
           datesRangeException:
-            description: <p>Defines for which date/s TimeAndDate condition will be matched<br>
-              Options are - Date range, for specific date, the same date should be used
-              for start/end date <br> Default - no specific dates<br> In order to reset
-              the dates to have no specific dates Date format - yyyy-mm-dd (MM = month,
-              dd = day, yyyy = year)</p>.
+            description: <p>Defines for which date/s TimeAndDate condition will be matched
+              or NOT matched if used in exceptionDates prooperty<br> Options are - Date
+              range, for specific date, the same date should be used for start/end date
+              <br> Default - no specific dates<br> In order to reset the dates to have
+              no specific dates Date format - yyyy-mm-dd (MM = month, dd = day, yyyy
+              = year)</p>.
             suboptions:
               endDate:
                 description: Network Access Authentication Rules's endDate.
@@ -140,8 +148,8 @@ options:
             type: str
           hoursRange:
             description: <p>Defines for which hours a TimeAndDate condition will be
-              matched<br> Time format - hh mm ( h = hour , mm = minutes ) <br> Default
-              - All Day </p>.
+              matched or not matched if used in exceptionHours property<br> Time foramt
+              - hh mm ( h = hour , mm = minutes ) <br> Default - All Day </p>.
             suboptions:
               endTime:
                 description: Network Access Authentication Rules's endTime.
@@ -152,8 +160,8 @@ options:
             type: dict
           hoursRangeException:
             description: <p>Defines for which hours a TimeAndDate condition will be
-              matched<br> Time format - hh mm ( h = hour , mm = minutes ) <br> Default
-              - All Day </p>.
+              matched or not matched if used in exceptionHours property<br> Time foramt
+              - hh mm ( h = hour , mm = minutes ) <br> Default - All Day </p>.
             suboptions:
               endTime:
                 description: Network Access Authentication Rules's endTime.
@@ -221,7 +229,7 @@ options:
         type: str
     type: dict
 requirements:
-- ciscoisesdk >= 2.0.8
+- ciscoisesdk >= 2.1.1
 - python >= 3.5
 seealso:
 - name: Cisco ISE documentation for Network Access - Authentication Rules
@@ -248,6 +256,7 @@ EXAMPLES = r"""
     ise_password: "{{ise_password}}"
     ise_verify: "{{ise_verify}}"
     state: present
+    identitySourceId: string
     identitySourceName: string
     ifAuthFail: string
     ifProcessFail: string
@@ -259,6 +268,7 @@ EXAMPLES = r"""
     policyId: string
     rule:
       condition:
+        attributeId: string
         attributeName: string
         attributeValue: string
         children:
@@ -311,6 +321,7 @@ EXAMPLES = r"""
     ise_verify: "{{ise_verify}}"
     state: present
     id: string
+    identitySourceId: string
     identitySourceName: string
     ifAuthFail: string
     ifProcessFail: string
@@ -322,6 +333,7 @@ EXAMPLES = r"""
     policyId: string
     rule:
       condition:
+        attributeId: string
         attributeName: string
         attributeValue: string
         children:
@@ -385,6 +397,7 @@ ise_response:
   type: dict
   sample: >
     {
+      "identitySourceId": "string",
       "identitySourceName": "string",
       "ifAuthFail": "string",
       "ifProcessFail": "string",
@@ -407,6 +420,7 @@ ise_response:
           "id": "string",
           "name": "string",
           "attributeName": "string",
+          "attributeId": "string",
           "attributeValue": "string",
           "dictionaryName": "string",
           "dictionaryValue": "string",
@@ -462,6 +476,7 @@ ise_update_response:
   sample: >
     {
       "response": {
+        "identitySourceId": "string",
         "identitySourceName": "string",
         "ifAuthFail": "string",
         "ifProcessFail": "string",
@@ -484,6 +499,7 @@ ise_update_response:
             "id": "string",
             "name": "string",
             "attributeName": "string",
+            "attributeId": "string",
             "attributeValue": "string",
             "dictionaryName": "string",
             "dictionaryValue": "string",
