@@ -47,6 +47,9 @@ options:
       condition:
         description: Network Access Authorization Rules's condition.
         suboptions:
+          attributeId:
+            description: Dictionary attribute id (Optional), used for additional verification.
+            type: str
           attributeName:
             description: Dictionary attribute name.
             type: str
@@ -93,11 +96,12 @@ options:
               that additional conditions are present under the children field</li></ul>.
             type: str
           datesRange:
-            description: <p>Defines for which date/s TimeAndDate condition will be matched<br>
-              Options are - Date range, for specific date, the same date should be used
-              for start/end date <br> Default - no specific dates<br> In order to reset
-              the dates to have no specific dates Date format - yyyy-mm-dd (MM = month,
-              dd = day, yyyy = year)</p>.
+            description: <p>Defines for which date/s TimeAndDate condition will be matched
+              or NOT matched if used in exceptionDates prooperty<br> Options are - Date
+              range, for specific date, the same date should be used for start/end date
+              <br> Default - no specific dates<br> In order to reset the dates to have
+              no specific dates Date format - yyyy-mm-dd (MM = month, dd = day, yyyy
+              = year)</p>.
             suboptions:
               endDate:
                 description: Network Access Authorization Rules's endDate.
@@ -107,11 +111,12 @@ options:
                 type: str
             type: dict
           datesRangeException:
-            description: <p>Defines for which date/s TimeAndDate condition will be matched<br>
-              Options are - Date range, for specific date, the same date should be used
-              for start/end date <br> Default - no specific dates<br> In order to reset
-              the dates to have no specific dates Date format - yyyy-mm-dd (MM = month,
-              dd = day, yyyy = year)</p>.
+            description: <p>Defines for which date/s TimeAndDate condition will be matched
+              or NOT matched if used in exceptionDates prooperty<br> Options are - Date
+              range, for specific date, the same date should be used for start/end date
+              <br> Default - no specific dates<br> In order to reset the dates to have
+              no specific dates Date format - yyyy-mm-dd (MM = month, dd = day, yyyy
+              = year)</p>.
             suboptions:
               endDate:
                 description: Network Access Authorization Rules's endDate.
@@ -131,8 +136,8 @@ options:
             type: str
           hoursRange:
             description: <p>Defines for which hours a TimeAndDate condition will be
-              matched<br> Time format - hh mm ( h = hour , mm = minutes ) <br> Default
-              - All Day </p>.
+              matched or not matched if used in exceptionHours property<br> Time foramt
+              - hh mm ( h = hour , mm = minutes ) <br> Default - All Day </p>.
             suboptions:
               endTime:
                 description: Network Access Authorization Rules's endTime.
@@ -143,8 +148,8 @@ options:
             type: dict
           hoursRangeException:
             description: <p>Defines for which hours a TimeAndDate condition will be
-              matched<br> Time format - hh mm ( h = hour , mm = minutes ) <br> Default
-              - All Day </p>.
+              matched or not matched if used in exceptionHours property<br> Time foramt
+              - hh mm ( h = hour , mm = minutes ) <br> Default - All Day </p>.
             suboptions:
               endTime:
                 description: Network Access Authorization Rules's endTime.
@@ -215,7 +220,7 @@ options:
     description: Security group used in authorization policies.
     type: str
 requirements:
-- ciscoisesdk >= 2.0.8
+- ciscoisesdk >= 2.1.1
 - python >= 3.5
 seealso:
 - name: Cisco ISE documentation for Network Access - Authorization Rules
@@ -251,6 +256,7 @@ EXAMPLES = r"""
     - string
     rule:
       condition:
+        attributeId: string
         attributeName: string
         attributeValue: string
         children:
@@ -313,6 +319,7 @@ EXAMPLES = r"""
     - string
     rule:
       condition:
+        attributeId: string
         attributeName: string
         attributeValue: string
         children:
@@ -398,6 +405,7 @@ ise_response:
           "id": "string",
           "name": "string",
           "attributeName": "string",
+          "attributeId": "string",
           "attributeValue": "string",
           "dictionaryName": "string",
           "dictionaryValue": "string",
@@ -475,6 +483,7 @@ ise_update_response:
             "id": "string",
             "name": "string",
             "attributeName": "string",
+            "attributeId": "string",
             "attributeValue": "string",
             "dictionaryName": "string",
             "dictionaryValue": "string",
