@@ -10,7 +10,7 @@ __metaclass__ = type
 
 ANSIBLE_METADATA = {
     "metadata_version": "1.1",
-    "status": ["preview"],
+    "status": ["deprecated"],
     "supported_by": "community",
 }
 
@@ -22,6 +22,10 @@ description:
 - Allows for management of SSIDs in a Meraki wireless environment.
 notes:
 - Deleting an SSID does not delete RADIUS servers.
+deprecated:
+  removed_in: '3.0.0'
+  why: Updated modules released with increased functionality
+  alternative: cisco.meraki.networks_wireless_ssids
 options:
     state:
         description:
