@@ -10,7 +10,7 @@ __metaclass__ = type
 
 ANSIBLE_METADATA = {
     "metadata_version": "1.1",
-    "status": ["preview"],
+    "status": ["deprecated"],
     "supported_by": "community",
 }
 
@@ -20,6 +20,10 @@ module: meraki_network
 short_description: Manage networks in the Meraki cloud
 description:
 - Allows for creation, management, and visibility into networks within Meraki.
+deprecated:
+  removed_in: '3.0.0'
+  why: Updated modules released with increased functionality
+  alternative: cisco.meraki.networks
 options:
     state:
         description:
