@@ -10,7 +10,7 @@ __metaclass__ = type
 
 ANSIBLE_METADATA = {
     "metadata_version": "1.1",
-    "status": ["preview"],
+    "status": ["deprecated"],
     "supported_by": "community",
 }
 
@@ -22,6 +22,10 @@ description:
 - Configure and query information about webhooks within the Meraki cloud.
 notes:
 - Some of the options are likely only used for developers within Meraki.
+deprecated:
+  removed_in: '3.0.0'
+  why: Updated modules released with increased functionality
+  alternative: cisco.meraki.networks_webhooks_http_servers
 options:
     state:
       description:
