@@ -19,8 +19,6 @@
 
 from __future__ import absolute_import, division, print_function
 
-from typing import Sequence
-
 
 __metaclass__ = type
 
@@ -28,7 +26,6 @@ from textwrap import dedent
 
 from ansible_collections.cisco.nxos.plugins.modules import nxos_prefix_lists
 from ansible_collections.cisco.nxos.tests.unit.compat.mock import patch
-from ansible_collections.cisco.nxos.tests.unit.modules.utils import AnsibleFailJson
 
 from .nxos_module import TestNxosModule, set_module_args
 
@@ -37,7 +34,6 @@ ignore_provider_arg = True
 
 
 class TestNxosPrefixListsModule(TestNxosModule):
-
     # Testing strategy
     # ------------------
     # (a) The unit tests cover `merged` and `replaced` for every attribute.
