@@ -1,29 +1,16 @@
 #!/usr/bin/python
-#
-# This is a free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This Ansible library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this library.  If not, see <http://www.gnu.org/licenses/>.
+# -*- coding: utf-8 -*-
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+# Copyright: Contributors to the Ansible project
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-
-DOCUMENTATION = r'''
+DOCUMENTATION = r"""
 ---
 module: elb_classic_lb_info
 version_added: 1.0.0
 short_description: Gather information about EC2 Elastic Load Balancers in AWS
 description:
-    - Gather information about EC2 Elastic Load Balancers in AWS
+  - Gather information about EC2 Elastic Load Balancers in AWS
 author:
   - "Michael Schultz (@mjschultz)"
   - "Fernando Jose Pando (@nand0p)"
@@ -35,12 +22,12 @@ options:
     elements: str
     default: []
 extends_documentation_fragment:
-- amazon.aws.aws
-- amazon.aws.ec2
-- amazon.aws.boto3
-'''
+  - amazon.aws.common.modules
+  - amazon.aws.region.modules
+  - amazon.aws.boto3
+"""
 
-EXAMPLES = r'''
+EXAMPLES = r"""
 # Note: These examples do not set authentication details, see the AWS Guide for details.
 # Output format tries to match amazon.aws.ec2_elb_lb module input parameters
 
@@ -63,17 +50,16 @@ EXAMPLES = r'''
 # Gather information about a set of ELBs
 - community.aws.elb_classic_lb_info:
     names:
-    - frontend-prod-elb
-    - backend-prod-elb
+      - frontend-prod-elb
+      - backend-prod-elb
   register: elb_info
 
 - ansible.builtin.debug:
     msg: "{{ item.dns_name }}"
   loop: "{{ elb_info.elbs }}"
+"""
 
-'''
-
-RETURN = r'''
+RETURN = r"""
 elbs:
   description: a list of load balancers
   returned: always
@@ -137,20 +123,21 @@ elbs:
           - subnet-XXXXXXXX
         tags: {}
         vpc_id: vpc-c248fda4
-'''
-
-from ansible_collections.amazon.aws.plugins.module_utils.core import AnsibleAWSModule, is_boto3_error_code
-from ansible_collections.amazon.aws.plugins.module_utils.ec2 import (
-    AWSRetry,
-    camel_dict_to_snake_dict,
-    boto3_tag_list_to_ansible_dict
-)
+"""
 
 try:
     import botocore
 except ImportError:
     pass  # caught by AnsibleAWSModule
 
+from ansible.module_utils.common.dict_transformations import camel_dict_to_snake_dict
+
+from ansible_collections.amazon.aws.plugins.module_utils.botocore import is_boto3_error_code
+from ansible_collections.amazon.aws.plugins.module_utils.retries import AWSRetry
+from ansible_collections.amazon.aws.plugins.module_utils.tagging import boto3_tag_list_to_ansible_dict
+
+from ansible_collections.community.aws.plugins.module_utils.modules import AnsibleCommunityAWSModule as AnsibleAWSModule
+
 MAX_AWS_RETRIES = 5
 MAX_AWS_DELAY = 5
 
@@ -172,63 +159,79 @@ def list_elbs(connection, load_balancer_names):
 
 def describe_elb(connection, lb):
     description = camel_dict_to_snake_dict(lb)
-    name = lb['LoadBalancerName']
-    instances = lb.get('Instances', [])
-    description['tags'] = get_tags(connection, name)
-    description['instances_inservice'], description['instances_inservice_count'] = lb_instance_health(connection, name, instances, 'InService')
-    description['instances_outofservice'], description['instances_outofservice_count'] = lb_instance_health(connection, name, instances, 'OutOfService')
-    description['instances_unknownservice'], description['instances_unknownservice_count'] = lb_instance_health(connection, name, instances, 'Unknown')
-    description['attributes'] = get_lb_attributes(connection, name)
+    name = lb["LoadBalancerName"]
+    instances = lb.get("Instances", [])
+    description["tags"] = get_tags(connection, name)
+    description["instances_inservice"], description["instances_inservice_count"] = lb_instance_health(
+        connection, name, instances, "InService"
+    )
+    description["instances_outofservice"], description["instances_outofservice_count"] = lb_instance_health(
+        connection, name, instances, "OutOfService"
+    )
+    description["instances_unknownservice"], description["instances_unknownservice_count"] = lb_instance_health(
+        connection, name, instances, "Unknown"
+    )
+    description["attributes"] = get_lb_attributes(connection, name)
     return description
 
 
 @AWSRetry.jittered_backoff()
 def get_all_lb(connection):
-    paginator = connection.get_paginator('describe_load_balancers')
-    return paginator.paginate().build_full_result()['LoadBalancerDescriptions']
+    paginator = connection.get_paginator("describe_load_balancers")
+    return paginator.paginate().build_full_result()["LoadBalancerDescriptions"]
 
 
 def get_lb(connection, load_balancer_name):
     try:
-        return connection.describe_load_balancers(aws_retry=True, LoadBalancerNames=[load_balancer_name])['LoadBalancerDescriptions'][0]
-    except is_boto3_error_code('LoadBalancerNotFound'):
+        return connection.describe_load_balancers(aws_retry=True, LoadBalancerNames=[load_balancer_name])[
+            "LoadBalancerDescriptions"
+        ][0]
+    except is_boto3_error_code("LoadBalancerNotFound"):
         return []
 
 
 def get_lb_attributes(connection, load_balancer_name):
-    attributes = connection.describe_load_balancer_attributes(aws_retry=True, LoadBalancerName=load_balancer_name).get('LoadBalancerAttributes', {})
+    attributes = connection.describe_load_balancer_attributes(aws_retry=True, LoadBalancerName=load_balancer_name).get(
+        "LoadBalancerAttributes", {}
+    )
     return camel_dict_to_snake_dict(attributes)
 
 
 def get_tags(connection, load_balancer_name):
-    tags = connection.describe_tags(aws_retry=True, LoadBalancerNames=[load_balancer_name])['TagDescriptions']
+    tags = connection.describe_tags(aws_retry=True, LoadBalancerNames=[load_balancer_name])["TagDescriptions"]
     if not tags:
         return {}
-    return boto3_tag_list_to_ansible_dict(tags[0]['Tags'])
+    return boto3_tag_list_to_ansible_dict(tags[0]["Tags"])
 
 
 def lb_instance_health(connection, load_balancer_name, instances, state):
-    instance_states = connection.describe_instance_health(LoadBalancerName=load_balancer_name, Instances=instances).get('InstanceStates', [])
-    instate = [instance['InstanceId'] for instance in instance_states if instance['State'] == state]
+    instance_states = connection.describe_instance_health(LoadBalancerName=load_balancer_name, Instances=instances).get(
+        "InstanceStates", []
+    )
+    instate = [instance["InstanceId"] for instance in instance_states if instance["State"] == state]
     return instate, len(instate)
 
 
 def main():
     argument_spec = dict(
-        names=dict(default=[], type='list', elements='str')
+        names=dict(default=[], type="list", elements="str"),
+    )
+    module = AnsibleAWSModule(
+        argument_spec=argument_spec,
+        supports_check_mode=True,
     )
-    module = AnsibleAWSModule(argument_spec=argument_spec,
-                              supports_check_mode=True)
 
-    connection = module.client('elb', retry_decorator=AWSRetry.jittered_backoff(retries=MAX_AWS_RETRIES, delay=MAX_AWS_DELAY))
+    connection = module.client(
+        "elb", retry_decorator=AWSRetry.jittered_backoff(retries=MAX_AWS_RETRIES, delay=MAX_AWS_DELAY)
+    )
 
     try:
-        elbs = list_elbs(connection, module.params.get('names'))
+        elbs = list_elbs(connection, module.params.get("names"))
     except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
         module.fail_json_aws(e, msg="Failed to get load balancer information.")
 
     module.exit_json(elbs=elbs)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
