@@ -8,24 +8,26 @@ ssh-keygen -f id_rsa.pub -e -m PKCS8 | openssl pkey -pubin -outform DER | openss
 (but without needing the OpenSSL CLI)
 """
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
 
 import hashlib
 import sys
-from Crypto.PublicKey import RSA
+
+from cryptography.hazmat.primitives import serialization
 
 if len(sys.argv) == 0:
     ssh_public_key = "id_rsa.pub"
 else:
     ssh_public_key = sys.argv[1]
 
-with open(ssh_public_key, 'r') as key_fh:
-    data = key_fh.read()
-
-# Convert from SSH format to DER format
-public_key = RSA.importKey(data).exportKey('DER')
-md5digest = hashlib.md5(public_key).hexdigest()
+with open(ssh_public_key, "rb") as key_file:
+    public_key = serialization.load_ssh_public_key(
+        key_file.read(),
+    )
+pub_der = public_key.public_bytes(
+    encoding=serialization.Encoding.DER,
+    format=serialization.PublicFormat.SubjectPublicKeyInfo,
+)
+md5digest = hashlib.md5(pub_der).hexdigest()
 # Format the md5sum into the normal format
 pairs = zip(md5digest[::2], md5digest[1::2])
 md5string = ":".join(["".join(pair) for pair in pairs])
