@@ -36,24 +36,26 @@ def test_assert_requirements_present():
     class ModuleFailException(Exception):
         pass
 
-    def fail_json(**kwargs):
-        raise ModuleFailException(kwargs)
+    class FakeModule(object):
+        def fail_json(self, **kwargs):
+            raise ModuleFailException(kwargs)
 
-    module = MagicMock()
-    module.fail_json = MagicMock(side_effect=fail_json)
+    module = FakeModule()
 
     orig_importerror = resolver.DNSPYTHON_IMPORTERROR
-    resolver.DNSPYTHON_IMPORTERROR = None
-    assert_requirements_present(module)
-
-    resolver.DNSPYTHON_IMPORTERROR = 'asdf'
-    with pytest.raises(ModuleFailException) as exc:
+    try:
+        resolver.DNSPYTHON_IMPORTERROR = None
         assert_requirements_present(module)
 
-    assert 'dnspython' in exc.value.args[0]['msg']
-    assert 'asdf' == exc.value.args[0]['exception']
+        resolver.DNSPYTHON_IMPORTERROR = 'asdf'
+        with pytest.raises(ModuleFailException) as exc:
+            assert_requirements_present(module)
 
-    resolver.DNSPYTHON_IMPORTERROR = orig_importerror
+        assert 'dnspython' in exc.value.args[0]['msg']
+        assert 'asdf' == exc.value.args[0]['exception']
+
+    finally:
+        resolver.DNSPYTHON_IMPORTERROR = orig_importerror
 
 
 def test_lookup_ns_names():
@@ -449,7 +451,7 @@ def test_timeout_failure():
                 assert exc.value.kwargs['timeout'] == 4
 
 
-def test_error_nxdomain():
+def test_error_nameserver_nxdomain_none():
     resolver = mock_resolver(['1.1.1.1'], {})
     udp_sequence = [
         {
@@ -461,14 +463,221 @@ def test_error_nxdomain():
             },
             'result': create_mock_response(dns.rcode.NXDOMAIN),
         },
+        {
+            'query_target': dns.name.from_unicode(u'example.com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NXDOMAIN),
+        },
     ]
     with patch('dns.resolver.get_default_resolver', resolver):
         with patch('dns.resolver.Resolver', resolver):
             with patch('dns.query.udp', mock_query_udp(udp_sequence)):
+                resolver = ResolveDirectlyFromNameServers()
+                assert resolver.resolve_nameservers('example.com') == []
+
+
+def test_error_nameserver_nxdomain_partial_first():
+    resolver = mock_resolver(['1.1.1.1'], {})
+    udp_sequence = [
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NOERROR, answer=[dns.rrset.from_rdata(
+                'com',
+                3600,
+                dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.NS, 'ns.com'),
+            )]),
+        },
+        {
+            'query_target': dns.name.from_unicode(u'example.com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NXDOMAIN),
+        },
+    ]
+    with patch('dns.resolver.get_default_resolver', resolver):
+        with patch('dns.resolver.Resolver', resolver):
+            with patch('dns.query.udp', mock_query_udp(udp_sequence)):
+                resolver = ResolveDirectlyFromNameServers()
+                assert resolver.resolve_nameservers('example.com') == ['ns.com']
+
+
+def test_error_nameserver_nxdomain_partial_second():
+    resolver = mock_resolver(['1.1.1.1'], {})
+    udp_sequence = [
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NXDOMAIN),
+        },
+        {
+            'query_target': dns.name.from_unicode(u'example.com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NOERROR, answer=[dns.rrset.from_rdata(
+                'com',
+                3600,
+                dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.NS, 'ns.com'),
+            )]),
+        },
+    ]
+    with patch('dns.resolver.get_default_resolver', resolver):
+        with patch('dns.resolver.Resolver', resolver):
+            with patch('dns.query.udp', mock_query_udp(udp_sequence)):
+                resolver = ResolveDirectlyFromNameServers()
+                assert resolver.resolve_nameservers('example.com') == ['ns.com']
+
+
+def test_error_nxdomain_ok():
+    resolver = mock_resolver(['1.1.1.1'], {
+        ('1.1.1.1', ): [
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.A,
+                'lifetime': 10,
+                'result': create_mock_answer(dns.rrset.from_rdata(
+                    'ns.com',
+                    300,
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
+                )),
+            },
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.AAAA,
+                'lifetime': 10,
+                'result': create_mock_answer(dns.rrset.from_rdata(
+                    'ns.com',
+                    300,
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.AAAA, '1:2::3'),
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.AAAA, '2:3::4'),
+                )),
+            },
+        ],
+        ('1:2::3', '2:3::4', '3.3.3.3'): [
+            {
+                'target': dns.name.from_unicode(u'example.com'),
+                'lifetime': 10,
+                'result': create_mock_answer(rcode=dns.rcode.NXDOMAIN),
+            },
+        ],
+    })
+    udp_sequence = [
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NOERROR, answer=[dns.rrset.from_rdata(
+                'com',
+                3600,
+                dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.NS, 'ns.com'),
+            )]),
+        },
+        {
+            'query_target': dns.name.from_unicode(u'example.com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NXDOMAIN),
+        },
+    ]
+    with patch('dns.resolver.get_default_resolver', resolver):
+        with patch('dns.resolver.Resolver', resolver):
+            with patch('dns.query.udp', mock_query_udp(udp_sequence)):
+                resolver = ResolveDirectlyFromNameServers()
+                rrset_dict = resolver.resolve('example.com', nxdomain_is_empty=True)
+                print(rrset_dict)
+                assert sorted(rrset_dict.keys()) == ['ns.com']
+                assert rrset_dict['ns.com'] == []
+
+
+def test_error_nxdomain_fail():
+    resolver = mock_resolver(['1.1.1.1'], {
+        ('1.1.1.1', ): [
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.A,
+                'lifetime': 10,
+                'result': create_mock_answer(dns.rrset.from_rdata(
+                    'ns.com',
+                    300,
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
+                )),
+            },
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.AAAA,
+                'lifetime': 10,
+                'result': create_mock_answer(dns.rrset.from_rdata(
+                    'ns.com',
+                    300,
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.AAAA, '1:2::3'),
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.AAAA, '2:3::4'),
+                )),
+            },
+        ],
+        ('1:2::3', '2:3::4', '3.3.3.3'): [
+            {
+                'target': dns.name.from_unicode(u'example.com'),
+                'lifetime': 10,
+                'result': create_mock_answer(rcode=dns.rcode.NXDOMAIN),
+            },
+        ],
+    })
+    udp_sequence = [
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NOERROR, answer=[dns.rrset.from_rdata(
+                'com',
+                3600,
+                dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.NS, 'ns.com'),
+            )]),
+        },
+        {
+            'query_target': dns.name.from_unicode(u'example.com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NXDOMAIN),
+        },
+    ]
+    with patch('dns.resolver.get_default_resolver', resolver):
+        with patch('dns.resolver.Resolver', resolver):
+            with patch('dns.query.udp', mock_query_udp(udp_sequence)):
+                resolver = ResolveDirectlyFromNameServers()
                 with pytest.raises(dns.resolver.NXDOMAIN) as exc:
-                    resolver = ResolveDirectlyFromNameServers()
-                    resolver.resolve_nameservers('example.com')
-                assert exc.value.kwargs['qnames'] == [dns.name.from_unicode(u'com')]
+                    resolver.resolve('example.com', nxdomain_is_empty=False)
+                print(exc.value.args[0])
+                assert exc.value.args[0] == 'The DNS query name does not exist: example.com.'
 
 
 def test_error_servfail():
@@ -493,6 +702,306 @@ def test_error_servfail():
                 assert exc.value.args[0] == 'Error SERVFAIL while querying 1.1.1.1 with query get NS for "com."'
 
 
+def test_error_servfail_retry_success():
+    resolver = mock_resolver(['1.1.1.1'], {})
+    udp_sequence = [
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.SERVFAIL),
+        },
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.SERVFAIL),
+        },
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NOERROR, authority=[dns.rrset.from_rdata(
+                'com',
+                3600,
+                dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.NS, 'ns.com'),
+            )]),
+        },
+    ]
+    with patch('dns.resolver.get_default_resolver', resolver):
+        with patch('dns.resolver.Resolver', resolver):
+            with patch('dns.query.udp', mock_query_udp(udp_sequence)):
+                resolver = ResolveDirectlyFromNameServers(servfail_retries=2)
+                assert resolver.resolve_nameservers('com') == ['ns.com']
+
+
+def test_error_servfail_retry_fail():
+    resolver = mock_resolver(['1.1.1.1'], {})
+    udp_sequence = [
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.SERVFAIL),
+        },
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.SERVFAIL),
+        },
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.SERVFAIL),
+        },
+    ]
+    with patch('dns.resolver.get_default_resolver', resolver):
+        with patch('dns.resolver.Resolver', resolver):
+            with patch('dns.query.udp', mock_query_udp(udp_sequence)):
+                with pytest.raises(ResolverError) as exc:
+                    resolver = ResolveDirectlyFromNameServers(servfail_retries=2)
+                    resolver.resolve_nameservers('example.com')
+                assert exc.value.args[0] == 'Error SERVFAIL while querying 1.1.1.1 with query get NS for "com."'
+
+
+def test_servfail_handling():
+    fake_query = MagicMock()
+    fake_query.question = 'Doctor Who?'
+    resolver = mock_resolver(['1.1.1.1'], {
+        ('1.1.1.1', ): [
+            {
+                'target': 'ns.example.com',
+                'rdtype': dns.rdatatype.A,
+                'lifetime': 10,
+                'result': create_mock_answer(rcode=dns.rcode.SERVFAIL),
+            },
+            {
+                'target': 'ns.example.com',
+                'rdtype': dns.rdatatype.A,
+                'lifetime': 10,
+                'result': create_mock_answer(dns.rrset.from_rdata(
+                    'ns.example.com',
+                    300,
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
+                )),
+            },
+            {
+                'target': 'ns.example.com',
+                'rdtype': dns.rdatatype.AAAA,
+                'lifetime': 10,
+                'result': create_mock_answer(rcode=dns.rcode.SERVFAIL),
+            },
+            {
+                'target': 'ns.example.com',
+                'rdtype': dns.rdatatype.AAAA,
+                'lifetime': 10,
+                'raise': dns.resolver.NoAnswer(response=fake_query),
+            },
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.A,
+                'lifetime': 10,
+                'result': create_mock_answer(rcode=dns.rcode.SERVFAIL),
+            },
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.A,
+                'lifetime': 10,
+                'result': create_mock_answer(rcode=dns.rcode.SERVFAIL),
+            },
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.A,
+                'lifetime': 10,
+                'result': create_mock_answer(dns.rrset.from_rdata(
+                    'ns.com',
+                    300,
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '2.2.2.2'),
+                )),
+            },
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.AAAA,
+                'lifetime': 10,
+                'raise': dns.resolver.NoAnswer(response=fake_query),
+            },
+        ],
+    })
+    udp_sequence = [
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NOERROR, answer=[dns.rrset.from_rdata(
+                'com',
+                3600,
+                dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.NS, 'ns.com'),
+            )]),
+        },
+        {
+            'query_target': dns.name.from_unicode(u'example.com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NOERROR, authority=[dns.rrset.from_rdata(
+                'example.com',
+                3600,
+                dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.NS, 'ns.example.com'),
+            )]),
+        },
+    ]
+    with patch('dns.resolver.get_default_resolver', resolver):
+        with patch('dns.resolver.Resolver', resolver):
+            with patch('dns.query.udp', mock_query_udp(udp_sequence)):
+                resolver = ResolveDirectlyFromNameServers(servfail_retries=2)
+                assert resolver.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3']
+                # The following results should be cached:
+                assert resolver.resolve_nameservers('com') == ['ns.com']
+                assert resolver.resolve_nameservers('com', resolve_addresses=True) == ['2.2.2.2']
+                assert resolver.resolve_nameservers('example.com') == ['ns.example.com']
+                assert resolver.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3']
+
+
+def test_servfail_failing():
+    fake_query = MagicMock()
+    fake_query.question = 'Doctor Who?'
+    resolver = mock_resolver(['1.1.1.1'], {
+        ('1.1.1.1', ): [
+            {
+                'target': 'ns.example.com',
+                'rdtype': dns.rdatatype.A,
+                'lifetime': 10,
+                'result': create_mock_answer(rcode=dns.rcode.SERVFAIL),
+            },
+            {
+                'target': 'ns.example.com',
+                'rdtype': dns.rdatatype.A,
+                'lifetime': 10,
+                'result': create_mock_answer(dns.rrset.from_rdata(
+                    'ns.example.com',
+                    300,
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '3.3.3.3'),
+                )),
+            },
+            {
+                'target': 'ns.example.com',
+                'rdtype': dns.rdatatype.AAAA,
+                'lifetime': 10,
+                'result': create_mock_answer(rcode=dns.rcode.SERVFAIL),
+            },
+            {
+                'target': 'ns.example.com',
+                'rdtype': dns.rdatatype.AAAA,
+                'lifetime': 10,
+                'raise': dns.resolver.NoAnswer(response=fake_query),
+            },
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.A,
+                'lifetime': 10,
+                'result': create_mock_answer(rcode=dns.rcode.SERVFAIL),
+            },
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.A,
+                'lifetime': 10,
+                'result': create_mock_answer(rcode=dns.rcode.SERVFAIL),
+            },
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.A,
+                'lifetime': 10,
+                'result': create_mock_answer(dns.rrset.from_rdata(
+                    'ns.com',
+                    300,
+                    dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.A, '2.2.2.2'),
+                )),
+            },
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.AAAA,
+                'lifetime': 10,
+                'result': create_mock_answer(rcode=dns.rcode.SERVFAIL),
+            },
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.AAAA,
+                'lifetime': 10,
+                'result': create_mock_answer(rcode=dns.rcode.SERVFAIL),
+            },
+            {
+                'target': 'ns.com',
+                'rdtype': dns.rdatatype.AAAA,
+                'lifetime': 10,
+                'result': create_mock_answer(rcode=dns.rcode.SERVFAIL),
+            },
+        ],
+    })
+    udp_sequence = [
+        {
+            'query_target': dns.name.from_unicode(u'com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NOERROR, answer=[dns.rrset.from_rdata(
+                'com',
+                3600,
+                dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.NS, 'ns.com'),
+            )]),
+        },
+        {
+            'query_target': dns.name.from_unicode(u'example.com'),
+            'query_type': dns.rdatatype.NS,
+            'nameserver': '1.1.1.1',
+            'kwargs': {
+                'timeout': 10,
+            },
+            'result': create_mock_response(dns.rcode.NOERROR, authority=[dns.rrset.from_rdata(
+                'example.com',
+                3600,
+                dns.rdata.from_text(dns.rdataclass.IN, dns.rdatatype.NS, 'ns.example.com'),
+            )]),
+        },
+    ]
+    with patch('dns.resolver.get_default_resolver', resolver):
+        with patch('dns.resolver.Resolver', resolver):
+            with patch('dns.query.udp', mock_query_udp(udp_sequence)):
+                resolver = ResolveDirectlyFromNameServers(servfail_retries=2)
+                assert resolver.resolve_nameservers('example.com', resolve_addresses=True) == ['3.3.3.3']
+                # The following results should be cached:
+                assert resolver.resolve_nameservers('com') == ['ns.com']
+                with pytest.raises(ResolverError) as exc:
+                    resolver.resolve_nameservers('com', resolve_addresses=True)
+                assert exc.value.args[0] == "Error SERVFAIL while querying ['1.1.1.1']"
+
+
 def test_no_response():
     fake_query = MagicMock()
     fake_query.question = 'Doctor Who?'
