@@ -6,6 +6,7 @@ from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
 
+import json
 import re
 from datetime import timedelta
 
@@ -14,7 +15,7 @@ from ansible.module_utils.common.collections import is_sequence
 from ansible.module_utils.six.moves.urllib.parse import urlparse
 
 
-DEFAULT_DOCKER_HOST = 'unix://var/run/docker.sock'
+DEFAULT_DOCKER_HOST = 'unix:///var/run/docker.sock'
 DEFAULT_TLS = False
 DEFAULT_TLS_VERIFY = False
 DEFAULT_TLS_HOSTNAME = 'localhost'  # deprecated
@@ -25,7 +26,7 @@ DOCKER_COMMON_ARGS = dict(
     tls_hostname=dict(type='str', fallback=(env_fallback, ['DOCKER_TLS_HOSTNAME'])),
     api_version=dict(type='str', default='auto', fallback=(env_fallback, ['DOCKER_API_VERSION']), aliases=['docker_api_version']),
     timeout=dict(type='int', default=DEFAULT_TIMEOUT_SECONDS, fallback=(env_fallback, ['DOCKER_TIMEOUT'])),
-    ca_cert=dict(type='path', aliases=['tls_ca_cert', 'cacert_path']),
+    ca_path=dict(type='path', aliases=['ca_cert', 'tls_ca_cert', 'cacert_path']),
     client_cert=dict(type='path', aliases=['tls_client_cert', 'cert_path']),
     client_key=dict(type='path', aliases=['tls_client_key', 'key_path']),
     ssl_version=dict(type='str', fallback=(env_fallback, ['DOCKER_SSL_VERSION'])),
@@ -85,6 +86,19 @@ def sanitize_result(data):
         return data
 
 
+def log_debug(msg, pretty_print=False):
+    """Write a log message to docker.log.
+
+    If ``pretty_print=True``, the message will be pretty-printed as JSON.
+    """
+    with open('docker.log', 'a') as log_file:
+        if pretty_print:
+            log_file.write(json.dumps(msg, sort_keys=True, indent=4, separators=(',', ': ')))
+            log_file.write(u'\n')
+        else:
+            log_file.write(msg + u'\n')
+
+
 class DockerBaseClass(object):
     def __init__(self):
         self.debug = False
@@ -92,12 +106,7 @@ class DockerBaseClass(object):
     def log(self, msg, pretty_print=False):
         pass
         # if self.debug:
-        #     log_file = open('docker.log', 'a')
-        #     if pretty_print:
-        #         log_file.write(json.dumps(msg, sort_keys=True, indent=4, separators=(',', ': ')))
-        #         log_file.write(u'\n')
-        #     else:
-        #         log_file.write(msg + u'\n')
+        #     log_debug(msg, pretty_print=pretty_print)
 
 
 def update_tls_hostname(result, old_behavior=False, deprecate_function=None, uses_tls=True):
