@@ -13,6 +13,7 @@ from ansible_collections.community.docker.tests.unit.compat import unittest
 from ansible.errors import AnsibleError
 from ansible.playbook.play_context import PlayContext
 from ansible.plugins.loader import connection_loader
+from ansible.module_utils.six import PY2
 
 
 class TestDockerConnectionClass(unittest.TestCase):
@@ -36,7 +37,8 @@ class TestDockerConnectionClass(unittest.TestCase):
     def test_docker_connection_module_too_old(self, mock_new_docker_verison, mock_old_docker_version):
         self.dc._version = None
         self.dc.remote_user = 'foo'
-        self.assertRaisesRegexp(AnsibleError, '^docker connection type requires docker 1.3 or higher$', self.dc._get_actual_user)
+        (self.assertRaisesRegexp if PY2 else self.assertRaisesRegex)(
+            AnsibleError, '^docker connection type requires docker 1.3 or higher$', self.dc._get_actual_user)
 
     @mock.patch('ansible_collections.community.docker.plugins.connection.docker.Connection._old_docker_version',
                 return_value=('false', 'garbage', '', 1))
@@ -54,4 +56,5 @@ class TestDockerConnectionClass(unittest.TestCase):
     def test_docker_connection_module_wrong_cmd(self, mock_new_docker_version, mock_old_docker_version):
         self.dc._version = None
         self.dc.remote_user = 'foo'
-        self.assertRaisesRegexp(AnsibleError, '^Docker version check (.*?) failed: ', self.dc._get_actual_user)
+        (self.assertRaisesRegexp if PY2 else self.assertRaisesRegex)(
+            AnsibleError, '^Docker version check (.*?) failed: ', self.dc._get_actual_user)
