@@ -16,23 +16,25 @@ options:
   client_id:
     description:
       - The OAuth consumer key.
-      - If not set the environment variable C(BITBUCKET_CLIENT_ID) will be used.
+      - If not set the environment variable E(BITBUCKET_CLIENT_ID) will be used.
     type: str
   client_secret:
     description:
       - The OAuth consumer secret.
-      - If not set the environment variable C(BITBUCKET_CLIENT_SECRET) will be used.
+      - If not set the environment variable E(BITBUCKET_CLIENT_SECRET) will be used.
     type: str
   user:
     description:
       - The username.
-      - If not set the environment variable C(BITBUCKET_USERNAME) will be used.
+      - If not set the environment variable E(BITBUCKET_USERNAME) will be used.
+      - O(ignore:username) is an alias of O(user) since community.general 6.0.0. It was an alias of O(workspace) before.
     type: str
     version_added: 4.0.0
+    aliases: [ username ]
   password:
     description:
       - The App password.
-      - If not set the environment variable C(BITBUCKET_PASSWORD) will be used.
+      - If not set the environment variable E(BITBUCKET_PASSWORD) will be used.
     type: str
     version_added: 4.0.0
 notes:
