@@ -41,14 +41,28 @@ DOCUMENTATION = r'''
             aliases: [ cert_file ]
             default: $HOME/.config/lxc/client.crt
             type: path
+        server_cert:
+            description:
+            - The server certificate file path.
+            type: path
+            version_added: 8.0.0
+        server_check_hostname:
+            description:
+            - This option controls if the server's hostname is checked as part of the HTTPS connection verification.
+              This can be useful to disable, if for example, the server certificate provided (see O(server_cert) option)
+              does not cover a name matching the one used to communicate with the server. Such mismatch is common as LXD
+              generates self-signed server certificates by default.
+            type: bool
+            default: true
+            version_added: 8.0.0
         trust_password:
             description:
             - The client trusted password.
             - You need to set this password on the lxd server before
                 running this module using the following command
                 C(lxc config set core.trust_password <some random password>)
-                See U(https://www.stgraber.org/2016/04/18/lxd-api-direct-interaction/).
-            - If I(trust_password) is set, this module send a request for authentication before sending any requests.
+                See U(https://documentation.ubuntu.com/lxd/en/latest/authentication/#adding-client-certificates-using-a-trust-password).
+            - If O(trust_password) is set, this module send a request for authentication before sending any requests.
             type: str
         state:
             description: Filter the instance according to the current status.
@@ -62,7 +76,7 @@ DOCUMENTATION = r'''
             version_added: 6.2.0
         type_filter:
             description:
-            - Filter the instances by type C(virtual-machine), C(container) or C(both).
+            - Filter the instances by type V(virtual-machine), V(container) or V(both).
             - The first version of the inventory only supported containers.
             type: str
             default: container
@@ -70,18 +84,18 @@ DOCUMENTATION = r'''
             version_added: 4.2.0
         prefered_instance_network_interface:
             description:
-            - If an instance has multiple network interfaces, select which one is the prefered as pattern.
+            - If an instance has multiple network interfaces, select which one is the preferred as pattern.
             - Combined with the first number that can be found e.g. 'eth' + 0.
-            - The option has been renamed from I(prefered_container_network_interface) to I(prefered_instance_network_interface) in community.general 3.8.0.
-              The old name still works as an alias.
+            - The option has been renamed from O(prefered_container_network_interface) to O(prefered_instance_network_interface)
+              in community.general 3.8.0. The old name still works as an alias.
             type: str
             default: eth
             aliases:
               - prefered_container_network_interface
         prefered_instance_network_family:
             description:
-            - If an instance has multiple network interfaces, which one is the prefered by family.
-            - Specify C(inet) for IPv4 and C(inet6) for IPv6.
+            - If an instance has multiple network interfaces, which one is the preferred by family.
+            - Specify V(inet) for IPv4 and V(inet6) for IPv6.
             type: str
             default: inet
             choices: [ 'inet', 'inet6' ]
@@ -150,12 +164,10 @@ groupby:
     attribute: internals
 '''
 
-import binascii
 import json
 import re
 import time
 import os
-import socket
 from ansible.plugins.inventory import BaseInventoryPlugin
 from ansible.module_utils.common.text.converters import to_native, to_text
 from ansible.module_utils.common.dict_transformations import dict_merge
@@ -288,7 +300,7 @@ class InventoryModule(BaseInventoryPlugin):
         urls = (url for url in url_list if self.validate_url(url))
         for url in urls:
             try:
-                socket_connection = LXDClient(url, self.client_key, self.client_cert, self.debug)
+                socket_connection = LXDClient(url, self.client_key, self.client_cert, self.debug, self.server_cert, self.server_check_hostname)
                 return socket_connection
             except LXDClientException as err:
                 error_storage[url] = err
@@ -361,7 +373,7 @@ class InventoryModule(BaseInventoryPlugin):
         Kwargs:
             None
         Source:
-            https://github.com/lxc/lxd/blob/master/doc/rest-api.md
+            https://documentation.ubuntu.com/lxd/en/latest/rest-api/
         Raises:
             None
         Returns:
@@ -378,7 +390,7 @@ class InventoryModule(BaseInventoryPlugin):
     def get_instance_data(self, names):
         """Create Inventory of the instance
 
-        Iterate through the different branches of the instances and collect Informations.
+        Iterate through the different branches of the instances and collect Information.
 
         Args:
             list(names): List of instance names
@@ -400,7 +412,7 @@ class InventoryModule(BaseInventoryPlugin):
     def get_network_data(self, names):
         """Create Inventory of the instance
 
-        Iterate through the different branches of the instances and collect Informations.
+        Iterate through the different branches of the instances and collect Information.
 
         Args:
             list(names): List of instance names
@@ -453,12 +465,12 @@ class InventoryModule(BaseInventoryPlugin):
         return network_configuration
 
     def get_prefered_instance_network_interface(self, instance_name):
-        """Helper to get the prefered interface of thr instance
+        """Helper to get the preferred interface of thr instance
 
-        Helper to get the prefered interface provide by neme pattern from 'prefered_instance_network_interface'.
+        Helper to get the preferred interface provide by neme pattern from 'prefered_instance_network_interface'.
 
         Args:
-            str(containe_name): name of instance
+            str(instance_name): name of instance
         Kwargs:
             None
         Raises:
@@ -483,7 +495,7 @@ class InventoryModule(BaseInventoryPlugin):
         Helper to get the VLAN_ID from the instance
 
         Args:
-            str(containe_name): name of instance
+            str(instance_name): name of instance
         Kwargs:
             None
         Raises:
@@ -565,7 +577,7 @@ class InventoryModule(BaseInventoryPlugin):
             else:
                 path[instance_name][key] = value
         except KeyError as err:
-            raise AnsibleParserError("Unable to store Informations: {0}".format(to_native(err)))
+            raise AnsibleParserError("Unable to store Information: {0}".format(to_native(err)))
 
     def extract_information_from_instance_configs(self):
         """Process configuration information
@@ -685,7 +697,7 @@ class InventoryModule(BaseInventoryPlugin):
                     continue
             # add instance
             self.inventory.add_host(instance_name)
-            # add network informations
+            # add network information
             self.build_inventory_network(instance_name)
             # add os
             v = self._get_data_entry('inventory/{0}/os'.format(instance_name))
@@ -1080,6 +1092,8 @@ class InventoryModule(BaseInventoryPlugin):
         try:
             self.client_key = self.get_option('client_key')
             self.client_cert = self.get_option('client_cert')
+            self.server_cert = self.get_option('server_cert')
+            self.server_check_hostname = self.get_option('server_check_hostname')
             self.project = self.get_option('project')
             self.debug = self.DEBUG
             self.data = {}  # store for inventory-data
