@@ -16,7 +16,7 @@ DOCUMENTATION = '''
       - Enables Ansible to retrieve, create or update passwords from the passwordstore.org pass utility.
         It also retrieves YAML style keys stored as multilines in the passwordfile.
       - To avoid problems when accessing multiple secrets at once, add C(auto-expand-secmem) to
-        C(~/.gnupg/gpg-agent.conf). Where this is not possible, consider using I(lock=readwrite) instead.
+        C(~/.gnupg/gpg-agent.conf). Where this is not possible, consider using O(lock=readwrite) instead.
     options:
       _terms:
         description: query key.
@@ -24,16 +24,16 @@ DOCUMENTATION = '''
       directory:
         description:
           - The directory of the password store.
-          - If I(backend=pass), the default is C(~/.password-store) is used.
-          - If I(backend=gopass), then the default is the C(path) field in C(~/.config/gopass/config.yml),
-            falling back to C(~/.local/share/gopass/stores/root) if C(path) is not defined in the gopass config.
+          - If O(backend=pass), the default is V(~/.password-store) is used.
+          - If O(backend=gopass), then the default is the C(path) field in C(~/.config/gopass/config.yml),
+            falling back to V(~/.local/share/gopass/stores/root) if C(path) is not defined in the gopass config.
         type: path
         vars:
           - name: passwordstore
         env:
           - name: PASSWORD_STORE_DIR
       create:
-        description: Create the password if it does not already exist. Takes precedence over C(missing).
+        description: Create the password if it does not already exist. Takes precedence over O(missing).
         type: bool
         default: false
       overwrite:
@@ -43,7 +43,7 @@ DOCUMENTATION = '''
       umask:
         description:
           - Sets the umask for the created .gpg files. The first octed must be greater than 3 (user readable).
-          - Note pass' default value is C('077').
+          - Note pass' default value is V('077').
         env:
           - name: PASSWORD_STORE_UMASK
         version_added: 1.3.0
@@ -52,7 +52,7 @@ DOCUMENTATION = '''
         type: bool
         default: false
       subkey:
-        description: Return a specific subkey of the password. When set to C(password), always returns the first line.
+        description: Return a specific subkey of the password. When set to V(password), always returns the first line.
         type: str
         default: password
       userpass:
@@ -63,7 +63,7 @@ DOCUMENTATION = '''
         type: integer
         default: 16
       backup:
-        description: Used with C(overwrite=true). Backup the previous password in a subkey.
+        description: Used with O(overwrite=true). Backup the previous password in a subkey.
         type: bool
         default: false
       nosymbols:
@@ -73,10 +73,10 @@ DOCUMENTATION = '''
       missing:
         description:
           - List of preference about what to do if the password file is missing.
-          - If I(create=true), the value for this option is ignored and assumed to be C(create).
-          - If set to C(error), the lookup will error out if the passname does not exist.
-          - If set to C(create), the passname will be created with the provided length I(length) if it does not exist.
-          - If set to C(empty) or C(warn), will return a C(none) in case the passname does not exist.
+          - If O(create=true), the value for this option is ignored and assumed to be V(create).
+          - If set to V(error), the lookup will error out if the passname does not exist.
+          - If set to V(create), the passname will be created with the provided length O(length) if it does not exist.
+          - If set to V(empty) or V(warn), will return a V(none) in case the passname does not exist.
             When using C(lookup) and not C(query), this will be translated to an empty string.
         version_added: 3.1.0
         type: str
@@ -89,9 +89,9 @@ DOCUMENTATION = '''
       lock:
         description:
           - How to synchronize operations.
-          - The default of C(write) only synchronizes write operations.
-          - C(readwrite) synchronizes all operations (including read). This makes sure that gpg-agent is never called in parallel.
-          - C(none) does not do any synchronization.
+          - The default of V(write) only synchronizes write operations.
+          - V(readwrite) synchronizes all operations (including read). This makes sure that gpg-agent is never called in parallel.
+          - V(none) does not do any synchronization.
         ini:
           - section: passwordstore_lookup
             key: lock
@@ -104,8 +104,8 @@ DOCUMENTATION = '''
         version_added: 4.5.0
       locktimeout:
         description:
-          - Lock timeout applied when I(lock) is not C(none).
-          - Time with a unit suffix, C(s), C(m), C(h) for seconds, minutes, and hours, respectively. For example, C(900s) equals C(15m).
+          - Lock timeout applied when O(lock) is not V(none).
+          - Time with a unit suffix, V(s), V(m), V(h) for seconds, minutes, and hours, respectively. For example, V(900s) equals V(15m).
           - Correlates with C(pinentry-timeout) in C(~/.gnupg/gpg-agent.conf), see C(man gpg-agent) for details.
         ini:
           - section: passwordstore_lookup
@@ -116,8 +116,8 @@ DOCUMENTATION = '''
       backend:
         description:
           - Specify which backend to use.
-          - Defaults to C(pass), passwordstore.org's original pass utility.
-          - C(gopass) support is incomplete.
+          - Defaults to V(pass), passwordstore.org's original pass utility.
+          - V(gopass) support is incomplete.
         ini:
           - section: passwordstore_lookup
             key: backend
@@ -129,6 +129,16 @@ DOCUMENTATION = '''
           - pass
           - gopass
         version_added: 5.2.0
+      timestamp:
+        description: Add the password generation information to the end of the file.
+        type: bool
+        default: true
+        version_added: 8.1.0
+      preserve:
+        description: Include the old (edited) password inside the pass file.
+        type: bool
+        default: true
+        version_added: 8.1.0
     notes:
       - The lookup supports passing all options as lookup parameters since community.general 6.0.0.
 '''
@@ -386,11 +396,13 @@ class LookupModule(LookupBase):
         # generate new password, insert old lines from current result and return new password
         newpass = self.get_newpass()
         datetime = time.strftime("%d/%m/%Y %H:%M:%S")
-        msg = newpass + '\n'
-        if self.passoutput[1:]:
-            msg += '\n'.join(self.passoutput[1:]) + '\n'
-        if self.paramvals['backup']:
-            msg += "lookup_pass: old password was {0} (Updated on {1})\n".format(self.password, datetime)
+        msg = newpass
+        if self.paramvals['preserve'] or self.paramvals['timestamp']:
+            msg += '\n'
+            if self.paramvals['preserve'] and self.passoutput[1:]:
+                msg += '\n'.join(self.passoutput[1:]) + '\n'
+            if self.paramvals['timestamp'] and self.paramvals['backup']:
+                msg += "lookup_pass: old password was {0} (Updated on {1})\n".format(self.password, datetime)
         try:
             check_output2([self.pass_cmd, 'insert', '-f', '-m', self.passname], input=msg, env=self.env)
         except (subprocess.CalledProcessError) as e:
@@ -402,7 +414,9 @@ class LookupModule(LookupBase):
         # use pwgen to generate the password and insert values with pass -m
         newpass = self.get_newpass()
         datetime = time.strftime("%d/%m/%Y %H:%M:%S")
-        msg = newpass + '\n' + "lookup_pass: First generated by ansible on {0}\n".format(datetime)
+        msg = newpass
+        if self.paramvals['timestamp']:
+            msg += '\n' + "lookup_pass: First generated by ansible on {0}\n".format(datetime)
         try:
             check_output2([self.pass_cmd, 'insert', '-f', '-m', self.passname], input=msg, env=self.env)
         except (subprocess.CalledProcessError) as e:
@@ -465,6 +479,8 @@ class LookupModule(LookupBase):
             'backup': self.get_option('backup'),
             'missing': self.get_option('missing'),
             'umask': self.get_option('umask'),
+            'timestamp': self.get_option('timestamp'),
+            'preserve': self.get_option('preserve'),
         }
 
     def run(self, terms, variables, **kwargs):
