@@ -15,13 +15,12 @@ module: gitlab_project
 short_description: Creates/updates/deletes GitLab Projects
 description:
   - When the project does not exist in GitLab, it will be created.
-  - When the project does exists and I(state=absent), the project will be deleted.
+  - When the project does exists and O(state=absent), the project will be deleted.
   - When changes are made to the project, the project will be updated.
 author:
   - Werner Dijkerman (@dj-wasabi)
   - Guillaume Martinez (@Lunik)
 requirements:
-  - python >= 2.7
   - python-gitlab python module
 extends_documentation_fragment:
   - community.general.auth_basic
@@ -84,9 +83,9 @@ options:
     default: true
   visibility:
     description:
-      - C(private) Project access must be granted explicitly for each user.
-      - C(internal) The project can be cloned by any logged in user.
-      - C(public) The project can be cloned without any authentication.
+      - V(private) Project access must be granted explicitly for each user.
+      - V(internal) The project can be cloned by any logged in user.
+      - V(public) The project can be cloned without any authentication.
     default: private
     type: str
     choices: ["private", "internal", "public"]
@@ -108,7 +107,7 @@ options:
   merge_method:
     description:
       - What requirements are placed upon merges.
-      - Possible values are C(merge), C(rebase_merge) merge commit with semi-linear history, C(ff) fast-forward merges only.
+      - Possible values are V(merge), V(rebase_merge) merge commit with semi-linear history, V(ff) fast-forward merges only.
     type: str
     choices: ["ff", "merge", "rebase_merge"]
     default: merge
@@ -175,79 +174,81 @@ options:
     version_added: "4.2.0"
   default_branch:
     description:
-      - Default branch name for a new project.
-      - This option is only used on creation, not for updates. This is also only used if I(initialize_with_readme=true).
+      - The default branch name for this project.
+      - For project creation, this option requires O(initialize_with_readme=true).
+      - For project update, the branch must exist.
+      - Supports project's default branch update since community.general 8.0.0.
     type: str
     version_added: "4.2.0"
   builds_access_level:
     description:
-      - C(private) means that repository CI/CD is allowed only to project members.
-      - C(disabled) means that repository CI/CD is disabled.
-      - C(enabled) means that repository CI/CD is enabled.
+      - V(private) means that repository CI/CD is allowed only to project members.
+      - V(disabled) means that repository CI/CD is disabled.
+      - V(enabled) means that repository CI/CD is enabled.
     type: str
     choices: ["private", "disabled", "enabled"]
     version_added: "6.2.0"
   forking_access_level:
     description:
-      - C(private) means that repository forks is allowed only to project members.
-      - C(disabled) means that repository forks are disabled.
-      - C(enabled) means that repository forks are enabled.
+      - V(private) means that repository forks is allowed only to project members.
+      - V(disabled) means that repository forks are disabled.
+      - V(enabled) means that repository forks are enabled.
     type: str
     choices: ["private", "disabled", "enabled"]
     version_added: "6.2.0"
   container_registry_access_level:
     description:
-      - C(private) means that container registry is allowed only to project members.
-      - C(disabled) means that container registry is disabled.
-      - C(enabled) means that container registry is enabled.
+      - V(private) means that container registry is allowed only to project members.
+      - V(disabled) means that container registry is disabled.
+      - V(enabled) means that container registry is enabled.
     type: str
     choices: ["private", "disabled", "enabled"]
     version_added: "6.2.0"
   releases_access_level:
     description:
-      - C(private) means that accessing release is allowed only to project members.
-      - C(disabled) means that accessing release is disabled.
-      - C(enabled) means that accessing release is enabled.
+      - V(private) means that accessing release is allowed only to project members.
+      - V(disabled) means that accessing release is disabled.
+      - V(enabled) means that accessing release is enabled.
     type: str
     choices: ["private", "disabled", "enabled"]
     version_added: "6.4.0"
   environments_access_level:
     description:
-      - C(private) means that deployment to environment is allowed only to project members.
-      - C(disabled) means that deployment to environment is disabled.
-      - C(enabled) means that deployment to environment is enabled.
+      - V(private) means that deployment to environment is allowed only to project members.
+      - V(disabled) means that deployment to environment is disabled.
+      - V(enabled) means that deployment to environment is enabled.
     type: str
     choices: ["private", "disabled", "enabled"]
     version_added: "6.4.0"
   feature_flags_access_level:
     description:
-      - C(private) means that feature rollout is allowed only to project members.
-      - C(disabled) means that feature rollout is disabled.
-      - C(enabled) means that feature rollout is enabled.
+      - V(private) means that feature rollout is allowed only to project members.
+      - V(disabled) means that feature rollout is disabled.
+      - V(enabled) means that feature rollout is enabled.
     type: str
     choices: ["private", "disabled", "enabled"]
     version_added: "6.4.0"
   infrastructure_access_level:
     description:
-      - C(private) means that configuring infrastructure is allowed only to project members.
-      - C(disabled) means that configuring infrastructure is disabled.
-      - C(enabled) means that configuring infrastructure is enabled.
+      - V(private) means that configuring infrastructure is allowed only to project members.
+      - V(disabled) means that configuring infrastructure is disabled.
+      - V(enabled) means that configuring infrastructure is enabled.
     type: str
     choices: ["private", "disabled", "enabled"]
     version_added: "6.4.0"
   monitor_access_level:
     description:
-      - C(private) means that monitoring health is allowed only to project members.
-      - C(disabled) means that monitoring health is disabled.
-      - C(enabled) means that monitoring health is enabled.
+      - V(private) means that monitoring health is allowed only to project members.
+      - V(disabled) means that monitoring health is disabled.
+      - V(enabled) means that monitoring health is enabled.
     type: str
     choices: ["private", "disabled", "enabled"]
     version_added: "6.4.0"
   security_and_compliance_access_level:
     description:
-      - C(private) means that accessing security and complicance tab is allowed only to project members.
-      - C(disabled) means that accessing security and complicance tab is disabled.
-      - C(enabled) means that accessing security and complicance tab is enabled.
+      - V(private) means that accessing security and complicance tab is allowed only to project members.
+      - V(disabled) means that accessing security and complicance tab is disabled.
+      - V(enabled) means that accessing security and complicance tab is enabled.
     type: str
     choices: ["private", "disabled", "enabled"]
     version_added: "6.4.0"
@@ -272,7 +273,6 @@ EXAMPLES = r'''
   community.general.gitlab_project:
     api_url: https://gitlab.example.com/
     api_token: "{{ access_token }}"
-    validate_certs: false
     name: my_first_project
     state: absent
   delegate_to: localhost
@@ -338,7 +338,7 @@ from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.common.text.converters import to_native
 
 from ansible_collections.community.general.plugins.module_utils.gitlab import (
-    auth_argument_spec, find_group, find_project, gitlab_authentication, gitlab, ensure_gitlab_package
+    auth_argument_spec, find_group, find_project, gitlab_authentication, gitlab
 )
 
 from ansible_collections.community.general.plugins.module_utils.version import LooseVersion
@@ -355,7 +355,7 @@ class GitLabProject(object):
     @param namespace Namespace Object (User or Group)
     @param options Options of the project
     '''
-    def create_or_update_project(self, project_name, namespace, options):
+    def create_or_update_project(self, module, project_name, namespace, options):
         changed = False
         project_options = {
             'name': project_name,
@@ -395,6 +395,8 @@ class GitLabProject(object):
 
         # Because we have already call userExists in main()
         if self.project_object is None:
+            if options['default_branch'] and not options['initialize_with_readme']:
+                module.fail_json(msg="Param default_branch need param initialize_with_readme set to true")
             project_options.update({
                 'path': options['path'],
                 'import_url': options['import_url'],
@@ -416,6 +418,8 @@ class GitLabProject(object):
 
             changed = True
         else:
+            if options['default_branch']:
+                project_options['default_branch'] = options['default_branch']
             changed, project = self.update_project(self.project_object, project_options)
 
         self.project_object = project
@@ -552,7 +556,9 @@ def main():
         ],
         supports_check_mode=True,
     )
-    ensure_gitlab_package(module)
+
+    # check prerequisites and connect to gitlab server
+    gitlab_instance = gitlab_authentication(module)
 
     group_identifier = module.params['group']
     project_name = module.params['name']
@@ -590,11 +596,6 @@ def main():
     security_and_compliance_access_level = module.params['security_and_compliance_access_level']
     topics = module.params['topics']
 
-    if default_branch and not initialize_with_readme:
-        module.fail_json(msg="Param default_branch need param initialize_with_readme set to true")
-
-    gitlab_instance = gitlab_authentication(module)
-
     # Set project_path to project_name if it is empty.
     if project_path is None:
         project_path = project_name.replace(" ", "_")
@@ -636,7 +637,7 @@ def main():
 
     if state == 'present':
 
-        if gitlab_project.create_or_update_project(project_name, namespace, {
+        if gitlab_project.create_or_update_project(module, project_name, namespace, {
             "path": project_path,
             "description": project_description,
             "initialize_with_readme": initialize_with_readme,
