@@ -27,7 +27,7 @@ options:
   group:
     type: str
     description:
-      - Name of the Jenkins group on the OS.
+      - GID or name of the Jenkins group on the OS.
     default: jenkins
   jenkins_home:
     type: path
@@ -47,13 +47,13 @@ options:
   owner:
     type: str
     description:
-      - Name of the Jenkins user on the OS.
+      - UID or name of the Jenkins user on the OS.
     default: jenkins
   state:
     type: str
     description:
       - Desired plugin state.
-      - If the C(latest) is set, the check for new version will be performed
+      - If set to V(latest), the check for new version will be performed
         every time. This is suitable to keep the plugin up-to-date.
     choices: [absent, present, pinned, unpinned, enabled, disabled, latest]
     default: present
@@ -65,18 +65,18 @@ options:
   updates_expiration:
     type: int
     description:
-      - Number of seconds after which a new copy of the I(update-center.json)
+      - Number of seconds after which a new copy of the C(update-center.json)
         file is downloaded. This is used to avoid the need to download the
-        plugin to calculate its checksum when C(latest) is specified.
-      - Set it to C(0) if no cache file should be used. In that case, the
+        plugin to calculate its checksum when O(state=latest) is specified.
+      - Set it to V(0) if no cache file should be used. In that case, the
         plugin file will always be downloaded to calculate its checksum when
-        C(latest) is specified.
+        O(state=latest) is specified.
     default: 86400
   updates_url:
     type: list
     elements: str
     description:
-      - A list of base URL(s) to retrieve I(update-center.json), and direct plugin files from.
+      - A list of base URL(s) to retrieve C(update-center.json), and direct plugin files from.
       - This can be a list since community.general 3.3.0.
     default: ['https://updates.jenkins.io', 'http://mirrors.jenkins.io']
   update_json_url_segment:
@@ -90,14 +90,14 @@ options:
     type: list
     elements: str
     description:
-      - Path inside the I(updates_url) to get latest plugins from.
+      - Path inside the O(updates_url) to get latest plugins from.
     default: ['latest']
     version_added: 3.3.0
   versioned_plugins_url_segments:
     type: list
     elements: str
     description:
-      - Path inside the I(updates_url) to get specific version of plugins from.
+      - Path inside the O(updates_url) to get specific version of plugins from.
     default: ['download/plugins', 'plugins']
     version_added: 3.3.0
   url:
@@ -114,11 +114,11 @@ options:
       - It might take longer to verify that the correct version is installed.
         This is especially true if a specific version number is specified.
       - Quote the version to prevent the value to be interpreted as float. For
-        example if C(1.20) would be unquoted, it would become C(1.2).
+        example if V(1.20) would be unquoted, it would become V(1.2).
   with_dependencies:
     description:
       - Defines whether to install plugin dependencies.
-      - This option takes effect only if the I(version) is not defined.
+      - This option takes effect only if the O(version) is not defined.
     type: bool
     default: true
 
@@ -127,11 +127,11 @@ notes:
     the plugin files on the disk. Only if the plugin is not installed yet and
     no version is specified, the API installation is performed which requires
     only the Web UI credentials.
-  - It's necessary to notify the handler or call the I(service) module to
+  - It is necessary to notify the handler or call the M(ansible.builtin.service) module to
     restart the Jenkins service after a new plugin was installed.
   - Pinning works only if the plugin is installed and Jenkins service was
     successfully restarted after the plugin installation.
-  - It is not possible to run the module remotely by changing the I(url)
+  - It is not possible to run the module remotely by changing the O(url)
     parameter to point to the Jenkins server. The module must be used on the
     host where Jenkins runs as it needs direct access to the plugin files.
 extends_documentation_fragment:
@@ -195,6 +195,29 @@ EXAMPLES = '''
     url_password: p4ssw0rd
     url: http://localhost:8888
 
+#
+# Example of how to authenticate with serverless deployment
+#
+- name: Update plugins on ECS Fargate Jenkins instance
+  community.general.jenkins_plugin:
+    # plugin name and version
+    name: ws-cleanup
+    version: '0.45'
+    # Jenkins home path mounted on ec2-helper VM (example)
+    jenkins_home: "/mnt/{{ jenkins_instance }}"
+    # matching the UID/GID to one in official Jenkins image
+    owner: 1000
+    group: 1000
+    # Jenkins instance URL and admin credentials
+    url: "https://{{ jenkins_instance }}.com/"
+    url_username: admin
+    url_password: p4ssw0rd
+  # make module work from EC2 which has local access
+  # to EFS mount as well as Jenkins URL
+  delegate_to: ec2-helper
+  vars:
+    jenkins_instance: foobar
+
 #
 # Example of a Play which handles Jenkins restarts during the state changes
 #
