@@ -13,8 +13,6 @@ module: oneview_fc_network_info
 short_description: Retrieve the information about one or more of the OneView Fibre Channel Networks
 description:
     - Retrieve the information about one or more of the Fibre Channel Networks from OneView.
-    - This module was called C(oneview_fc_network_facts) before Ansible 2.9, returning C(ansible_facts).
-      Note that the M(community.general.oneview_fc_network_info) module no longer returns C(ansible_facts)!
 requirements:
     - hpOneView >= 2.0.1
 author:
