@@ -30,7 +30,7 @@ author:
 notes:
     - "Known bug with pkgin < 0.8.0: if a package is removed and another
       package depends on it, the other package will be silently removed as
-      well.  New to Ansible 1.9: check-mode support."
+      well."
 extends_documentation_fragment:
     - community.general.attributes
 attributes:
