@@ -16,21 +16,26 @@ version_added: 5.7.0
 description:
   - Allows you to perform some supported operations on a disk in Qemu(KVM) Virtual Machines in a Proxmox VE cluster.
 author: "Castor Sky (@castorsky) <csky57@gmail.com>"
+attributes:
+  check_mode:
+    support: none
+  diff_mode:
+    support: none
 options:
   name:
     description:
       - The unique name of the VM.
-      - You can specify either I(name) or I(vmid) or both of them.
+      - You can specify either O(name) or O(vmid) or both of them.
     type: str
   vmid:
     description:
       - The unique ID of the VM.
-      - You can specify either I(vmid) or I(name) or both of them.
+      - You can specify either O(vmid) or O(name) or both of them.
     type: int
   disk:
     description:
-      - The disk key (C(unused[n]), C(ide[n]), C(sata[n]), C(scsi[n]) or C(virtio[n])) you want to operate on.
-      - Disk buses (IDE, SATA and so on) have fixed ranges of C(n) that accepted by Proxmox API.
+      - The disk key (V(unused[n]), V(ide[n]), V(sata[n]), V(scsi[n]) or V(virtio[n])) you want to operate on.
+      - Disk buses (IDE, SATA and so on) have fixed ranges of V(n) that accepted by Proxmox API.
       - >
         For IDE: 0-3;
         for SCSI: 0-30;
@@ -43,79 +48,79 @@ options:
     description:
       - Indicates desired state of the disk.
       - >
-        I(state=present) can be used to create, replace disk or update options in existing disk. It will create missing
-        disk or update options in existing one by default. See the I(create) parameter description to control behavior
+        O(state=present) can be used to create, replace disk or update options in existing disk. It will create missing
+        disk or update options in existing one by default. See the O(create) parameter description to control behavior
         of this option.
-      - Some updates on options (like I(cache)) are not being applied instantly and require VM restart.
+      - Some updates on options (like O(cache)) are not being applied instantly and require VM restart.
       - >
-        Use I(state=detached) to detach existing disk from VM but do not remove it entirely.
-        When I(state=detached) and disk is C(unused[n]) it will be left in same state (not removed).
+        Use O(state=detached) to detach existing disk from VM but do not remove it entirely.
+        When O(state=detached) and disk is V(unused[n]) it will be left in same state (not removed).
       - >
-        I(state=moved) may be used to change backing storage for the disk in bounds of the same VM
+        O(state=moved) may be used to change backing storage for the disk in bounds of the same VM
         or to send the disk to another VM (using the same backing storage).
       - >
-        I(state=resized) intended to change the disk size. As of Proxmox 7.2 you can only increase the disk size
+        O(state=resized) intended to change the disk size. As of Proxmox 7.2 you can only increase the disk size
         because shrinking disks is not supported by the PVE API and has to be done manually.
-      - To entirely remove the disk from backing storage use I(state=absent).
+      - To entirely remove the disk from backing storage use O(state=absent).
     type: str
     choices: ['present', 'resized', 'detached', 'moved', 'absent']
     default: present
   create:
     description:
-      - With I(create) flag you can control behavior of I(state=present).
-      - When I(create=disabled) it will not create new disk (if not exists) but will update options in existing disk.
-      - When I(create=regular) it will either create new disk (if not exists) or update options in existing disk.
-      - When I(create=forced) it will always create new disk (if disk exists it will be detached and left unused).
+      - With O(create) flag you can control behavior of O(state=present).
+      - When O(create=disabled) it will not create new disk (if not exists) but will update options in existing disk.
+      - When O(create=regular) it will either create new disk (if not exists) or update options in existing disk.
+      - When O(create=forced) it will always create new disk (if disk exists it will be detached and left unused).
     type: str
     choices: ['disabled', 'regular', 'forced']
     default: regular
   storage:
     description:
       - The drive's backing storage.
-      - Used only when I(state) is C(present).
+      - Used only when O(state) is V(present).
     type: str
   size:
     description:
-      - Desired volume size in GB to allocate when I(state=present) (specify I(size) without suffix).
+      - Desired volume size in GB to allocate when O(state=present) (specify O(size) without suffix).
       - >
-        New (or additional) size of volume when I(state=resized). With the C(+) sign
+        New (or additional) size of volume when O(state=resized). With the V(+) sign
         the value is added to the actual size of the volume
         and without it, the value is taken as an absolute one.
     type: str
   bwlimit:
     description:
       - Override I/O bandwidth limit (in KB/s).
-      - Used only when I(state=moved).
+      - Used only when O(state=moved).
     type: int
   delete_moved:
     description:
       - Delete the original disk after successful copy.
       - By default the original disk is kept as unused disk.
-      - Used only when I(state=moved).
+      - Used only when O(state=moved).
     type: bool
   target_disk:
     description:
-      - The config key the disk will be moved to on the target VM (for example, C(ide0) or C(scsi1)).
+      - The config key the disk will be moved to on the target VM (for example, V(ide0) or V(scsi1)).
       - Default is the source disk key.
-      - Used only when I(state=moved).
+      - Used only when O(state=moved).
     type: str
   target_storage:
     description:
-      - Move the disk to this storage when I(state=moved).
+      - Move the disk to this storage when O(state=moved).
       - You can move between storages only in scope of one VM.
-      - Mutually exclusive with I(target_vmid).
-      - Consider increasing I(timeout) in case of large disk images or slow storage backend.
+      - Mutually exclusive with O(target_vmid).
+      - Consider increasing O(timeout) in case of large disk images or slow storage backend.
     type: str
   target_vmid:
     description:
-      - The (unique) ID of the VM where disk will be placed when I(state=moved).
+      - The (unique) ID of the VM where disk will be placed when O(state=moved).
       - You can move disk between VMs only when the same storage is used.
-      - Mutually exclusive with I(target_vmid).
+      - Mutually exclusive with O(target_vmid).
     type: int
   timeout:
     description:
       - Timeout in seconds to wait for slow operations such as importing disk or moving disk between storages.
-      - Used only when I(state) is C(present) or C(moved).
+      - Used only when O(state) is V(present) or V(moved).
     type: int
     default: 600
   aio:
@@ -172,13 +177,13 @@ options:
       - Volume string format
       - C(<STORAGE>:<VMID>/<FULL_NAME>) or C(<ABSOLUTE_PATH>/<FULL_NAME>)
       - Attention! Only root can use absolute paths.
-      - This parameter is mutually exclusive with I(size).
-      - Increase I(timeout) parameter when importing large disk images or using slow storage.
+      - This parameter is mutually exclusive with O(size).
+      - Increase O(timeout) parameter when importing large disk images or using slow storage.
     type: str
   iops:
     description:
       - Maximum total r/w I/O in operations per second.
-      - You can specify either total limit or per operation (mutually exclusive with I(iops_rd) and I(iops_wr)).
+      - You can specify either total limit or per operation (mutually exclusive with O(iops_rd) and O(iops_wr)).
     type: int
   iops_max:
     description:
@@ -191,7 +196,7 @@ options:
   iops_rd:
     description:
       - Maximum read I/O in operations per second.
-      - You can specify either read or total limit (mutually exclusive with I(iops)).
+      - You can specify either read or total limit (mutually exclusive with O(iops)).
     type: int
   iops_rd_max:
     description:
@@ -204,7 +209,7 @@ options:
   iops_wr:
     description:
       - Maximum write I/O in operations per second.
-      - You can specify either write or total limit (mutually exclusive with I(iops)).
+      - You can specify either write or total limit (mutually exclusive with O(iops)).
     type: int
   iops_wr_max:
     description:
@@ -222,7 +227,7 @@ options:
     description:
       - Maximum total r/w speed in megabytes per second.
       - Can be fractional but use with caution - fractionals less than 1 are not supported officially.
-      - You can specify either total limit or per operation (mutually exclusive with I(mbps_rd) and I(mbps_wr)).
+      - You can specify either total limit or per operation (mutually exclusive with O(mbps_rd) and O(mbps_wr)).
     type: float
   mbps_max:
     description:
@@ -231,7 +236,7 @@ options:
   mbps_rd:
     description:
       - Maximum read speed in megabytes per second.
-      - You can specify either read or total limit (mutually exclusive with I(mbps)).
+      - You can specify either read or total limit (mutually exclusive with O(mbps)).
     type: float
   mbps_rd_max:
     description:
@@ -240,7 +245,7 @@ options:
   mbps_wr:
     description:
       - Maximum write speed in megabytes per second.
-      - You can specify either write or total limit (mutually exclusive with I(mbps)).
+      - You can specify either write or total limit (mutually exclusive with O(mbps)).
     type: float
   mbps_wr_max:
     description:
@@ -251,6 +256,16 @@ options:
       - The drive's media type.
     type: str
     choices: ['cdrom', 'disk']
+  iso_image:
+    description:
+      - The ISO image to be mounted on the specified in O(disk) CD-ROM.
+      - O(media=cdrom) needs to be specified for this option to work.
+      - "Image string format:"
+      - V(<STORAGE>:iso/<ISO_NAME>) to mount ISO.
+      - V(cdrom) to use physical CD/DVD drive.
+      - V(none) to unmount image from existent CD-ROM or create empty CD-ROM drive.
+    type: str
+    version_added: 8.1.0
   queues:
     description:
       - Number of queues (SCSI only).
@@ -307,10 +322,11 @@ options:
     choices: ['enospc', 'ignore', 'report', 'stop']
   wwn:
     description:
-      - The drive's worldwide name, encoded as 16 bytes hex string, prefixed by C(0x).
+      - The drive's worldwide name, encoded as 16 bytes hex string, prefixed by V(0x).
     type: str
 extends_documentation_fragment:
   - community.general.proxmox.documentation
+  - community.general.attributes
 '''
 
 EXAMPLES = '''
@@ -406,6 +422,18 @@ EXAMPLES = '''
     vmid: 101
     disk: scsi4
     state: absent
+
+- name: Mount ISO image on CD-ROM (create drive if missing)
+  community.general.proxmox_disk:
+    api_host: node1
+    api_user: root@pam
+    api_token_id: token1
+    api_token_secret: some-token-data
+    vmid: 101
+    disk: ide2
+    media: cdrom
+    iso_image: local:iso/favorite_distro_amd64.iso
+    state: present
 '''
 
 RETURN = '''
@@ -429,17 +457,41 @@ from time import sleep
 
 
 def disk_conf_str_to_dict(config_string):
+    """
+    Transform Proxmox configuration string for disk element into dictionary which has
+    volume option parsed in '{ storage }:{ volume }' format and other options parsed
+    in '{ option }={ value }' format. This dictionary will be compared afterward with
+    attributes that user passed to this module in playbook.\n
+    config_string examples:
+      - local-lvm:vm-100-disk-0,ssd=1,discard=on,size=25G
+      - local:iso/new-vm-ignition.iso,media=cdrom,size=70k
+      - none,media=cdrom
+    :param config_string: Retrieved from Proxmox API configuration string
+    :return: Dictionary with volume option divided into parts ('volume_name', 'storage_name', 'volume') \n
+        and other options as key:value.
+    """
     config = config_string.split(',')
-    storage_volume = config.pop(0).split(':')
-    config.sort()
-    storage_name = storage_volume[0]
-    volume_name = storage_volume[1]
-    config_current = dict(
-        volume='%s:%s' % (storage_name, volume_name),
-        storage_name=storage_name,
-        volume_name=volume_name
-    )
 
+    # When empty CD-ROM drive present, the volume part of config string is "none".
+    storage_volume = config.pop(0)
+    if storage_volume in ["none", "cdrom"]:
+        config_current = dict(
+            volume=storage_volume,
+            storage_name=None,
+            volume_name=None,
+            size=None,
+        )
+    else:
+        storage_volume = storage_volume.split(':')
+        storage_name = storage_volume[0]
+        volume_name = storage_volume[1]
+        config_current = dict(
+            volume='%s:%s' % (storage_name, volume_name),
+            storage_name=storage_name,
+            volume_name=volume_name,
+        )
+
+    config.sort()
     for option in config:
         k, v = option.split('=')
         config_current[k] = v
@@ -491,41 +543,61 @@ class ProxmoxDiskAnsible(ProxmoxAnsible):
 
         if (create == 'regular' and disk not in vm_config) or (create == 'forced'):
             # CREATE
-            attributes = self.get_create_attributes()
-            import_string = attributes.pop('import_from', None)
+            playbook_config = self.get_create_attributes()
+            import_string = playbook_config.pop('import_from', None)
+            iso_image = self.module.params.get('iso_image', None)
 
             if import_string:
+                # When 'import_from' option is present in task options.
                 config_str = "%s:%s,import-from=%s" % (self.module.params["storage"], "0", import_string)
                 timeout_str = "Reached timeout while importing VM disk. Last line in task before timeout: %s"
                 ok_str = "Disk %s imported into VM %s"
+            elif iso_image is not None:
+                # disk=<busN>, media=cdrom, iso_image=<ISO_NAME>
+                config_str = iso_image
+                ok_str = "CD-ROM was created on %s bus in VM %s"
             else:
-                config_str = "%s:%s" % (self.module.params["storage"], self.module.params["size"])
+                config_str = self.module.params["storage"]
+                if self.module.params.get("media") != "cdrom":
+                    config_str += ":%s" % (self.module.params["size"])
                 ok_str = "Disk %s created in VM %s"
                 timeout_str = "Reached timeout while creating VM disk. Last line in task before timeout: %s"
 
-            for k, v in attributes.items():
+            for k, v in playbook_config.items():
                 config_str += ',%s=%s' % (k, v)
 
             disk_config_to_apply = {self.module.params["disk"]: config_str}
 
         if create in ['disabled', 'regular'] and disk in vm_config:
             # UPDATE
-            disk_config = disk_conf_str_to_dict(vm_config[disk])
-            config_str = disk_config["volume"]
             ok_str = "Disk %s updated in VM %s"
-            attributes = self.get_create_attributes()
-            # 'import_from' fails on disk updates
-            attributes.pop('import_from', None)
+            iso_image = self.module.params.get('iso_image', None)
 
-            for k, v in attributes.items():
+            proxmox_config = disk_conf_str_to_dict(vm_config[disk])
+            # 'import_from' fails on disk updates
+            playbook_config = self.get_create_attributes()
+            playbook_config.pop('import_from', None)
+
+            # Begin composing configuration string
+            if iso_image is not None:
+                config_str = iso_image
+            else:
+                config_str = proxmox_config["volume"]
+            # Append all mandatory fields from playbook_config
+            for k, v in playbook_config.items():
                 config_str += ',%s=%s' % (k, v)
 
-            # Now compare old and new config to detect if changes are needed
+            # Append to playbook_config fields which are constants for disk images
             for option in ['size', 'storage_name', 'volume', 'volume_name']:
-                attributes.update({option: disk_config[option]})
+                playbook_config.update({option: proxmox_config[option]})
+            # CD-ROM is special disk device and its disk image is subject to change
+            if iso_image is not None:
+                playbook_config['volume'] = iso_image
             # Values in params are numbers, but strings are needed to compare with disk_config
-            attributes = dict((k, str(v)) for k, v in attributes.items())
-            if disk_config == attributes:
+            playbook_config = dict((k, str(v)) for k, v in playbook_config.items())
+
+            # Now compare old and new config to detect if changes are needed
+            if proxmox_config == playbook_config:
                 return False, "Disk %s is up to date in VM %s" % (disk, vmid)
 
             disk_config_to_apply = {self.module.params["disk"]: config_str}
@@ -594,6 +666,7 @@ def main():
         iops_wr_max=dict(type='int'),
         iops_wr_max_length=dict(type='int'),
         iothread=dict(type='bool'),
+        iso_image=dict(type='str'),
         mbps=dict(type='float'),
         mbps_max=dict(type='float'),
         mbps_rd=dict(type='float'),
@@ -658,6 +731,7 @@ def main():
             'iops_max_length': 'iops_max',
             'iops_rd_max_length': 'iops_rd_max',
             'iops_wr_max_length': 'iops_wr_max',
+            'iso_image': 'media',
         },
         supports_check_mode=False,
         mutually_exclusive=[
