@@ -40,7 +40,7 @@ options:
 
     state:
         description:
-            - state of the package, you can use "installed" as an alias for C(present) and removed as one for C(absent).
+            - State of the package, you can use V(installed) as an alias for V(present) and V(removed) as one for V(absent).
         choices: [ 'present', 'absent', 'latest', 'installed', 'removed' ]
         required: false
         default: present
