@@ -42,18 +42,17 @@ options:
     host:
         required: false
         description:
-            - Host FQDN (server which provides the share), e.g. C({{
-              ansible_fqdn }}). Required if I(state=present).
+            - Host FQDN (server which provides the share), for example V({{ ansible_fqdn }}). Required if O(state=present).
         type: str
     path:
         required: false
         description:
-            - Directory on the providing server, e.g. C(/home). Required if I(state=present).
+            - Directory on the providing server, for example V(/home). Required if O(state=present).
         type: path
     sambaName:
         required: false
         description:
-            - Windows name. Required if I(state=present).
+            - Windows name. Required if O(state=present).
         type: str
         aliases: [ samba_name ]
     ou:
