@@ -73,7 +73,7 @@ EXAMPLES = '''
 - name: CloudEngine snmp community test
   hosts: cloudengine
   connection: local
-  gather_facts: no
+  gather_facts: false
   vars:
     cli:
       host: "{{ inventory_hostname }}"
