@@ -101,7 +101,7 @@ EXAMPLES = '''
 - name: CloudEngine stp test
   hosts: cloudengine
   connection: local
-  gather_facts: no
+  gather_facts: false
 
   tasks:
 
