@@ -201,7 +201,7 @@ options:
   purge:
     description:
       - Purge VLANs not defined in the I(aggregate) parameter.
-    default: no
+    default: false
     type: bool
   state:
     description:
@@ -214,7 +214,7 @@ options:
       - Check running configuration. This can be set as environment variable.
        Module will use environment variable value(default:True), unless it is overridden, by specifying it as module parameter.
     type: bool
-    default: yes
+    default: true
 '''
 
 EXAMPLES = """
