@@ -5,6 +5,7 @@
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 
 DOCUMENTATION = r'''
@@ -130,6 +131,12 @@ options:
     type: bool
     default: true
     version_added: '0.2.0'
+  comment:
+    description:
+    - Sets a comment on the database.
+    - To reset the comment, pass an empty string.
+    type: str
+    version_added: '3.3.0'
 seealso:
 - name: CREATE DATABASE reference
   description: Complete reference of the CREATE DATABASE command documentation.
@@ -148,7 +155,7 @@ seealso:
 - module: community.postgresql.postgresql_ping
 
 notes:
-- State C(dump) and C(restore) don't require I(psycopg2) since version 2.8.
+- State C(dump) and C(restore) don't require I(psycopg) since ansible version 2.8.
 
 attributes:
   check_mode:
@@ -164,6 +171,7 @@ EXAMPLES = r'''
 - name: Create a new database with name "acme"
   community.postgresql.postgresql_db:
     name: acme
+    comment: My test DB
 
 # Note: If a template different from "template0" is specified,
 # encoding and locale settings must match those of the template.
@@ -257,7 +265,7 @@ EXAMPLES = r'''
 RETURN = r'''
 executed_commands:
   description: List of commands which tried to run.
-  returned: always
+  returned: success
   type: list
   sample: ["CREATE DATABASE acme"]
   version_added: '0.2.0'
@@ -268,26 +276,22 @@ import os
 import subprocess
 import traceback
 
-try:
-    from psycopg2.extras import DictCursor
-except ImportError:
-    HAS_PSYCOPG2 = False
-else:
-    HAS_PSYCOPG2 = True
-
+from ansible.module_utils._text import to_native
+from ansible.module_utils.basic import AnsibleModule
+from ansible.module_utils.six.moves import shlex_quote
+from ansible_collections.community.postgresql.plugins.module_utils.database import (
+    SQLParseError,
+    check_input,
+)
 from ansible_collections.community.postgresql.plugins.module_utils.postgres import (
     connect_to_db,
-    get_conn_params,
     ensure_required_libs,
-    postgres_common_argument_spec
+    get_conn_params,
+    get_server_version,
+    pg_cursor_args,
+    postgres_common_argument_spec,
+    set_comment,
 )
-from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.postgresql.plugins.module_utils.database import (
-    check_input,
-    SQLParseError,
-)
-from ansible.module_utils.six.moves import shlex_quote
-from ansible.module_utils._text import to_native
 
 executed_commands = []
 
@@ -325,7 +329,8 @@ def get_db_info(cursor, db):
     SELECT rolname AS owner,
     pg_encoding_to_char(encoding) AS encoding, encoding AS encoding_id,
     datcollate AS lc_collate, datctype AS lc_ctype, pg_database.datconnlimit AS conn_limit,
-    spcname AS tablespace
+    spcname AS tablespace,
+    pg_catalog.shobj_description(pg_database.oid, 'pg_database') AS comment
     FROM pg_database
     JOIN pg_roles ON pg_roles.oid = pg_database.datdba
     JOIN pg_tablespace ON pg_tablespace.oid = pg_database.dattablespace
@@ -342,7 +347,7 @@ def db_exists(cursor, db):
 
 
 def db_dropconns(cursor, db):
-    if cursor.connection.server_version >= 90200:
+    if get_server_version(cursor.connection) >= 90200:
         """ Drop DB connections in Postgres 9.2 and above """
         query_terminate = ("SELECT pg_terminate_backend(pg_stat_activity.pid) FROM pg_stat_activity "
                            "WHERE pg_stat_activity.datname=%(db)s AND pid <> pg_backend_pid()")
@@ -360,7 +365,7 @@ def db_delete(cursor, db, force=False):
     if db_exists(cursor, db):
         query = 'DROP DATABASE "%s"' % db
         if force:
-            if cursor.connection.server_version >= 130000:
+            if get_server_version(cursor.connection) >= 130000:
                 query = ('DROP DATABASE "%s" WITH (FORCE)' % db)
             else:
                 db_dropconns(cursor, db)
@@ -371,7 +376,7 @@ def db_delete(cursor, db, force=False):
         return False
 
 
-def db_create(cursor, db, owner, template, encoding, lc_collate, lc_ctype, conn_limit, tablespace):
+def db_create(cursor, db, owner, template, encoding, lc_collate, lc_ctype, conn_limit, tablespace, comment, check_mode):
     params = dict(enc=encoding, collate=lc_collate, ctype=lc_ctype, conn_limit=conn_limit, tablespace=tablespace)
     if not db_exists(cursor, db):
         query_fragments = ['CREATE DATABASE "%s"' % db]
@@ -392,6 +397,8 @@ def db_create(cursor, db, owner, template, encoding, lc_collate, lc_ctype, conn_
         query = ' '.join(query_fragments)
         executed_commands.append(cursor.mogrify(query, params))
         cursor.execute(query, params)
+        if comment:
+            set_comment(cursor, comment, 'database', db, check_mode, executed_commands)
         return True
     else:
         db_info = get_db_info(cursor, db)
@@ -413,6 +420,10 @@ def db_create(cursor, db, owner, template, encoding, lc_collate, lc_ctype, conn_
         else:
             changed = False
 
+            if db_info['comment'] is None:
+                # For the resetting comment feature (comment: '') to work correctly
+                db_info['comment'] = ''
+
             if owner and owner != db_info['owner']:
                 changed = set_owner(cursor, db, owner)
 
@@ -422,14 +433,22 @@ def db_create(cursor, db, owner, template, encoding, lc_collate, lc_ctype, conn_
             if tablespace and tablespace != db_info['tablespace']:
                 changed = set_tablespace(cursor, db, tablespace)
 
+            if comment is not None and comment != db_info['comment']:
+                changed = set_comment(cursor, comment, 'database', db, check_mode, executed_commands)
+
             return changed
 
 
-def db_matches(cursor, db, owner, template, encoding, lc_collate, lc_ctype, conn_limit, tablespace):
+def db_matches(cursor, db, owner, template, encoding, lc_collate, lc_ctype, conn_limit, tablespace, comment):
     if not db_exists(cursor, db):
         return False
     else:
         db_info = get_db_info(cursor, db)
+
+        if db_info['comment'] is None:
+            # For the resetting comment feature (comment: '') to work correctly
+            db_info['comment'] = ''
+
         if (encoding and get_encoding_id(cursor, encoding) != db_info['encoding_id']):
             return False
         elif lc_collate and lc_collate != db_info['lc_collate']:
@@ -442,6 +461,8 @@ def db_matches(cursor, db, owner, template, encoding, lc_collate, lc_ctype, conn
             return False
         elif tablespace and tablespace != db_info['tablespace']:
             return False
+        elif comment is not None and comment != db_info['comment']:
+            return False
         else:
             return True
 
@@ -654,6 +675,7 @@ def main():
         dump_extra_args=dict(type='str', default=None),
         trust_input=dict(type='bool', default=True),
         force=dict(type='bool', default=False),
+        comment=dict(type='str', default=None),
     )
 
     module = AnsibleModule(
@@ -678,6 +700,7 @@ def main():
     dump_extra_args = module.params['dump_extra_args']
     trust_input = module.params['trust_input']
     force = module.params['force']
+    comment = module.params['comment']
 
     if state == 'rename':
         if not target:
@@ -692,7 +715,8 @@ def main():
     # Check input
     if not trust_input:
         # Check input for potentially dangerous elements:
-        check_input(module, owner, conn_limit, encoding, db, template, tablespace, session_role)
+        check_input(module, owner, conn_limit, encoding, db,
+                    template, tablespace, session_role, comment)
 
     raw_connection = state in ("dump", "restore")
 
@@ -712,7 +736,7 @@ def main():
 
     if not raw_connection:
         db_connection, dummy = connect_to_db(module, conn_params, autocommit=True)
-        cursor = db_connection.cursor(cursor_factory=DictCursor)
+        cursor = db_connection.cursor(**pg_cursor_args)
 
         if session_role:
             try:
@@ -726,7 +750,7 @@ def main():
                 changed = db_exists(cursor, db)
 
             elif state == "present":
-                changed = not db_matches(cursor, db, owner, template, encoding, lc_collate, lc_ctype, conn_limit, tablespace)
+                changed = not db_matches(cursor, db, owner, template, encoding, lc_collate, lc_ctype, conn_limit, tablespace, comment)
 
             elif state == "rename":
                 changed = rename_db(module, cursor, db, target, check_mode=True)
@@ -741,7 +765,8 @@ def main():
 
         elif state == "present":
             try:
-                changed = db_create(cursor, db, owner, template, encoding, lc_collate, lc_ctype, conn_limit, tablespace)
+                changed = db_create(cursor, db, owner, template, encoding, lc_collate,
+                                    lc_ctype, conn_limit, tablespace, comment, module.check_mode)
             except SQLParseError as e:
                 module.fail_json(msg=to_native(e), exception=traceback.format_exc())
 
