@@ -5,6 +5,7 @@
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 
 DOCUMENTATION = r'''
@@ -77,7 +78,7 @@ options:
         path exists.
       - Downgrading is only supported if the extension provides a downgrade path otherwise
         the extension must be removed and a lower version of the extension must be made available.
-      - Set I(version=latest) to always update the extension to the latest available version.
+      - Set I(version=latest) to update the extension to the latest available version.
     type: str
   trust_input:
     description:
@@ -87,6 +88,13 @@ options:
     type: bool
     default: true
     version_added: '0.2.0'
+  comment:
+    description:
+    - Sets a comment on the extension.
+    - To reset the comment, pass an empty string.
+    type: str
+    version_added: '3.3.0'
+
 seealso:
 - name: PostgreSQL extensions
   description: General information about PostgreSQL extensions.
@@ -114,6 +122,7 @@ author:
 - Sandro Santilli (@strk)
 - Andrew Klychkov (@Andersson007)
 - Keith Fiske (@keithf4)
+- Daniele Giudice (@RealGreenDragon)
 
 extends_documentation_fragment:
 - community.postgresql.postgres
@@ -125,6 +134,7 @@ EXAMPLES = r'''
     name: postgis
     db: acme
     schema: foo
+    comment: Test extension
 
 - name: Removes postgis extension to the database acme
   community.postgresql.postgresql_ext:
@@ -161,34 +171,40 @@ EXAMPLES = r'''
 '''
 
 RETURN = r'''
-query:
+queries:
   description: List of executed queries.
-  returned: always
+  returned: success
   type: list
   sample: ["DROP EXTENSION \"acme\""]
-
+prev_version:
+  description: Previous installed extension version or empty string if the extension was not installed.
+  returned: success
+  type: str
+  sample: '1.0'
+  version_added: '3.1.0'
+version:
+  description: Current installed extension version or empty string if the extension is not installed.
+  returned: success
+  type: str
+  sample: '2.0'
+  version_added: '3.1.0'
 '''
 
 import traceback
 
-try:
-    from psycopg2.extras import DictCursor
-except ImportError:
-    # psycopg2 is checked by connect_to_db()
-    # from ansible.module_utils.postgres
-    pass
-
+from ansible.module_utils._text import to_native
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.postgresql.plugins.module_utils.database import (
-    check_input,
-)
+from ansible_collections.community.postgresql.plugins.module_utils.database import \
+    check_input
 from ansible_collections.community.postgresql.plugins.module_utils.postgres import (
     connect_to_db,
     ensure_required_libs,
+    get_comment,
     get_conn_params,
+    pg_cursor_args,
     postgres_common_argument_spec,
+    set_comment,
 )
-from ansible.module_utils._text import to_native
 
 executed_queries = []
 
@@ -198,37 +214,35 @@ executed_queries = []
 #
 
 
-def ext_delete(cursor, ext, current_version, cascade):
+def ext_delete(check_mode, cursor, ext, cascade):
     """Remove the extension from the database.
 
     Return True if success.
 
     Args:
-      cursor (cursor) -- cursor object of psycopg2 library
+      cursor (cursor) -- cursor object of psycopg library
       ext (str) -- extension name
-      current_version (str) -- installed version of the extension.
-        Value obtained from ext_get_versions and used to
-        determine if the extension was installed.
-      cascade (boolean) -- Pass the CASCADE flag to the DROP commmand
+      cascade (boolean) -- Pass the CASCADE flag to the DROP command
     """
-    if current_version:
-        query = "DROP EXTENSION \"%s\"" % ext
-        if cascade:
-            query += " CASCADE"
+    query = "DROP EXTENSION \"%s\"" % ext
+
+    if cascade:
+        query += " CASCADE"
+
+    if not check_mode:
         cursor.execute(query)
-        executed_queries.append(cursor.mogrify(query))
-        return True
-    else:
-        return False
+    executed_queries.append(cursor.mogrify(query))
+
+    return True
 
 
-def ext_update_version(cursor, ext, version):
+def ext_update_version(check_mode, cursor, ext, version):
     """Update extension version.
 
     Return True if success.
 
     Args:
-      cursor (cursor) -- cursor object of psycopg2 library
+      cursor (cursor) -- cursor object of psycopg library
       ext (str) -- extension name
       version (str) -- extension version
     """
@@ -239,22 +253,24 @@ def ext_update_version(cursor, ext, version):
         query += " TO %(ver)s"
         params['ver'] = version
 
-    cursor.execute(query, params)
+    if not check_mode:
+        cursor.execute(query, params)
     executed_queries.append(cursor.mogrify(query, params))
 
     return True
 
 
-def ext_create(cursor, ext, schema, cascade, version):
+def ext_create(check_mode, cursor, ext, schema, cascade, version):
     """
     Create the extension objects inside the database.
 
     Return True if success.
 
     Args:
-      cursor (cursor) -- cursor object of psycopg2 library
+      cursor (cursor) -- cursor object of psycopg library
       ext (str) -- extension name
       schema (str) -- target schema for extension objects
+      cascade (boolean) -- Pass the CASCADE flag to the CREATE command
       version (str) -- extension version
     """
     query = "CREATE EXTENSION \"%s\"" % ext
@@ -268,18 +284,20 @@ def ext_create(cursor, ext, schema, cascade, version):
     if cascade:
         query += " CASCADE"
 
-    cursor.execute(query, params)
+    if not check_mode:
+        cursor.execute(query, params)
     executed_queries.append(cursor.mogrify(query, params))
+
     return True
 
 
 def ext_get_versions(cursor, ext):
     """
     Get the currently created extension version if it is installed
-    in the database and versions that are available if it is
-    installed on the system.
+    in the database, its default version (used to update to 'latest'),
+    and versions that are available if it is installed on the system.
 
-    Return tuple (current_version, [list of available versions]).
+    Return tuple (current_version, default_version, [list of available versions]).
 
     Note: the list of available versions contains only versions
           that higher than the current created version.
@@ -287,11 +305,12 @@ def ext_get_versions(cursor, ext):
           available versions.
 
     Args:
-      cursor (cursor) -- cursor object of psycopg2 library
+      cursor (cursor) -- cursor object of psycopg library
       ext (str) -- extension name
     """
 
     current_version = None
+    default_version = None
     params = {}
     params['ext'] = ext
 
@@ -303,54 +322,64 @@ def ext_get_versions(cursor, ext):
 
     res = cursor.fetchone()
     if res:
-        current_version = res[0]
+        current_version = res["extversion"]
 
-    # 2. Get available versions:
-    query = ("SELECT version FROM pg_available_extension_versions "
+    # 2. Get the extension default version:
+    query = ("SELECT default_version FROM pg_catalog.pg_available_extensions "
              "WHERE name = %(ext)s")
 
     cursor.execute(query, params)
 
-    available_versions = set(r[0] for r in cursor.fetchall())
+    res = cursor.fetchone()
+    if res:
+        default_version = res["default_version"]
+
+    # 3. Get extension available versions:
+    query = ("SELECT version FROM pg_catalog.pg_available_extension_versions "
+             "WHERE name = %(ext)s")
+
+    cursor.execute(query, params)
+
+    available_versions = set(r["version"] for r in cursor.fetchall())
 
     if current_version is None:
         current_version = False
+    if default_version is None:
+        default_version = False
 
-    return (current_version, available_versions)
+    return (current_version, default_version, available_versions)
 
 
 def ext_valid_update_path(cursor, ext, current_version, version):
     """
     Check to see if the installed extension version has a valid update
-    path to the given version. A version of 'latest' is always a valid path.
+    path to the given version.
 
     Return True if a valid path exists. Otherwise return False.
 
+    Note: 'latest' is not a valid value for version here as it can be
+          replaced with default_version specified in extension control file.
+
     Args:
-      cursor (cursor) -- cursor object of psycopg2 library
+      cursor (cursor) -- cursor object of psycopg library
       ext (str) -- extension name
       current_version (str) -- installed version of the extension.
       version (str) -- target extension version to update to.
-        A value of 'latest' is always a valid path and will result
-        in the extension update command always being run.
     """
 
     valid_path = False
     params = {}
-    if version != 'latest':
-        query = ("SELECT path FROM pg_extension_update_paths(%(ext)s) "
-                 "WHERE source = %(cv)s "
-                 "AND target = %(ver)s")
+    query = ("SELECT path FROM pg_extension_update_paths(%(ext)s) "
+             "WHERE source = %(cv)s "
+             "AND target = %(ver)s")
 
-        params['ext'] = ext
-        params['cv'] = current_version
-        params['ver'] = version
+    params['ext'] = ext
+    params['cv'] = current_version
+    params['ver'] = version
 
-        cursor.execute(query, params)
-        res = cursor.fetchone()
-        if res is not None:
-            valid_path = True
-    else:
+    cursor.execute(query, params)
+    res = cursor.fetchone()
+    if res is not None:
         valid_path = True
 
     return (valid_path)
@@ -372,6 +401,7 @@ def main():
         session_role=dict(type="str"),
         version=dict(type="str"),
         trust_input=dict(type="bool", default=True),
+        comment=dict(type="str", default=None),
     )
 
     module = AnsibleModule(
@@ -386,56 +416,82 @@ def main():
     version = module.params["version"]
     session_role = module.params["session_role"]
     trust_input = module.params["trust_input"]
+    comment = module.params["comment"]
+
     changed = False
 
     if not trust_input:
-        check_input(module, ext, schema, version, session_role)
+        check_input(module, ext, schema, version, session_role, comment)
 
     if version and state == 'absent':
         module.warn("Parameter version is ignored when state=absent")
 
-    # Ensure psycopg2 libraries are available before connecting to DB:
+    # Ensure psycopg libraries are available before connecting to DB:
     ensure_required_libs(module)
     conn_params = get_conn_params(module, module.params)
     db_connection, dummy = connect_to_db(module, conn_params, autocommit=True)
-    cursor = db_connection.cursor(cursor_factory=DictCursor)
+    cursor = db_connection.cursor(**pg_cursor_args)
 
     try:
         # Get extension info and available versions:
-        curr_version, available_versions = ext_get_versions(cursor, ext)
+        curr_version, default_version, available_versions = ext_get_versions(cursor, ext)
+
+        # Decode version 'latest' when passed (if version is not passed 'latest' is assumed)
+        # Note: real_version used for checks but not in CREATE/DROP/ALTER EXTENSION commands,
+        #       as the correct way to obtain 'latest' version is not specify the version
+        if not version or version == 'latest':
+            # If there are not available versions the extension is not available
+            if not available_versions:
+                module.fail_json(msg="Extension %s is not available" % ext)
+            # Check default_version is available
+            if default_version:
+                # 'latest' version matches default_version specified in extension control file
+                real_version = default_version
+            else:
+                # Passed version is 'latest', versions are available, but no default_version is specified
+                # in extension control file. In this situation CREATE/ALTER EXTENSION commands fail if
+                # a specific version is not passed ('latest' cannot be determined).
+                module.fail_json(msg="Passed version 'latest' but no default_version available "
+                                     "in extension control file")
+        else:
+            real_version = version
 
         if state == "present":
 
-            # If version passed
+            # If version passed:
             if version:
                 # If extension is installed, update to passed version if a valid path exists
                 if curr_version:
-                    # Given version already installed
-                    if curr_version == version:
+                    # Given/Latest version already installed
+                    if curr_version == real_version:
                         changed = False
-                    # Attempt to update to given version or latest version defined in extension control file
-                    # ALTER EXTENSION is actually run if valid, so 'changed' will be true even if nothing updated
+                    # Attempt to update to given/latest version
                     else:
-                        valid_update_path = ext_valid_update_path(cursor, ext, curr_version, version)
+                        valid_update_path = ext_valid_update_path(cursor, ext, curr_version, real_version)
                         if valid_update_path:
-                            if module.check_mode:
-                                changed = True
+                            changed = ext_update_version(module.check_mode, cursor, ext, version)
+                        else:
+                            if version == 'latest':
+                                # No valid update path from curr_version to latest extension version
+                                # (extension is buggy or no direct update supported)
+                                module.fail_json(msg="Latest version '%s' has no valid update path from "
+                                                     "the currently installed version '%s'" % (real_version, curr_version))
                             else:
-                                changed = ext_update_version(cursor, ext, version)
-                        else:
-                            module.fail_json(msg="Passed version '%s' has no valid update path from "
-                                                 "the currently installed version '%s' or "
-                                                 "the passed version is not available" % (version, curr_version))
+                                module.fail_json(msg="Passed version '%s' has no valid update path from "
+                                                     "the currently installed version '%s' or "
+                                                     "the passed version is not available" % (version, curr_version))
+                # If extension is not installed, install passed version
                 else:
-                    # If not requesting latest version and passed version not available
-                    if version != 'latest' and version not in available_versions:
-                        module.fail_json(msg="Passed version '%s' is not available" % version)
-                    # Else install the passed version when available
-                    else:
-                        if module.check_mode:
-                            changed = True
+                    # If passed version not available fail
+                    if real_version not in available_versions:
+                        if version == 'latest':
+                            # Latest version not available (extension is buggy)
+                            module.fail_json(msg="Latest version '%s' is not available" % real_version)
                         else:
-                            changed = ext_create(cursor, ext, schema, cascade, version)
+                            module.fail_json(msg="Passed version '%s' is not available" % real_version)
+                    # Else install the passed version
+                    else:
+                        changed = ext_create(module.check_mode, cursor, ext, schema, cascade, version)
 
             # If version is not passed:
             else:
@@ -445,30 +501,51 @@ def main():
                 else:
                     # If the ext doesn't exist and is available:
                     if available_versions:
-                        if module.check_mode:
-                            changed = True
-                        else:
-                            changed = ext_create(cursor, ext, schema, cascade, 'latest')
-
+                        # 'latest' version installed by default if version not passed
+                        changed = ext_create(module.check_mode, cursor, ext, schema, cascade, 'latest')
                     # If the ext doesn't exist and is not available:
                     else:
                         module.fail_json(msg="Extension %s is not available" % ext)
 
+            if comment is not None:
+                current_comment = get_comment(cursor, 'extension', ext)
+                # For the resetting comment feature (comment: '') to work correctly
+                current_comment = current_comment if current_comment is not None else ''
+                if comment != current_comment:
+                    changed = set_comment(cursor, comment, 'extension', ext, module.check_mode, executed_queries)
+
         elif state == "absent":
             if curr_version:
-                if module.check_mode:
-                    changed = True
-                else:
-                    changed = ext_delete(cursor, ext, curr_version, cascade)
+                changed = ext_delete(module.check_mode, cursor, ext, cascade)
             else:
                 changed = False
 
+        # Get extension info again:
+        new_version, new_default_version, new_available_versions = ext_get_versions(cursor, ext)
+
+        # Parse previous and current version for module output
+        out_prev_version = curr_version if curr_version else ''
+        if module.check_mode and changed:
+            if state == "present":
+                out_version = real_version
+            elif state == "absent":
+                out_version = ''
+        else:
+            out_version = new_version if new_version else ''
+
     except Exception as e:
         db_connection.close()
         module.fail_json(msg="Management of PostgreSQL extension failed: %s" % to_native(e), exception=traceback.format_exc())
 
     db_connection.close()
-    module.exit_json(changed=changed, db=module.params["db"], ext=ext, queries=executed_queries)
+    module.exit_json(
+        changed=changed,
+        db=module.params["db"],
+        ext=ext,
+        prev_version=out_prev_version,
+        version=out_version,
+        queries=executed_queries,
+    )
 
 
 if __name__ == '__main__':
