@@ -5,6 +5,7 @@
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 
 DOCUMENTATION = r'''
@@ -109,18 +110,18 @@ EXAMPLES = r'''
 RETURN = r'''
 version:
   description: Database server version U(https://www.postgresql.org/support/versioning/).
-  returned: always
+  returned: success
   type: dict
   sample: { "version": { "major": 10, "minor": 6 } }
   contains:
     major:
       description: Major server version.
-      returned: always
+      returned: success
       type: int
       sample: 11
     minor:
       description: Minor server version.
-      returned: always
+      returned: success
       type: int
       sample: 1
     patch:
@@ -131,24 +132,24 @@ version:
       version_added: '1.2.0'
     full:
       description: Full server version.
-      returned: always
+      returned: success
       type: str
       sample: '13.2'
       version_added: '1.2.0'
     raw:
       description: Full output returned by ``SELECT version()``.
-      returned: always
+      returned: success
       type: str
       sample: 'PostgreSQL 13.2 on x86_64-pc-linux-gnu, compiled by gcc (GCC) 10.2.1 20201125 (Red Hat 10.2.1-9), 64-bit'
       version_added: '1.2.0'
 in_recovery:
   description: Indicates if the service is in recovery mode or not.
-  returned: always
+  returned: success
   type: bool
   sample: false
 databases:
   description: Information about databases.
-  returned: always
+  returned: success
   type: dict
   sample:
   - { "postgres": { "access_priv": "", "collate": "en_US.UTF-8",
@@ -156,48 +157,48 @@ databases:
   contains:
     database_name:
       description: Database name.
-      returned: always
+      returned: success
       type: dict
       sample: template1
       contains:
         access_priv:
           description: Database access privileges.
-          returned: always
+          returned: success
           type: str
           sample: "=c/postgres_npostgres=CTc/postgres"
         collate:
           description:
           - Database collation U(https://www.postgresql.org/docs/current/collation.html).
-          returned: always
+          returned: success
           type: str
           sample: en_US.UTF-8
         ctype:
           description:
           - Database LC_CTYPE U(https://www.postgresql.org/docs/current/multibyte.html).
-          returned: always
+          returned: success
           type: str
           sample: en_US.UTF-8
         encoding:
           description:
           - Database encoding U(https://www.postgresql.org/docs/current/multibyte.html).
-          returned: always
+          returned: success
           type: str
           sample: UTF8
         owner:
           description:
           - Database owner U(https://www.postgresql.org/docs/current/sql-createdatabase.html).
-          returned: always
+          returned: success
           type: str
           sample: postgres
         size:
           description: Database size in bytes.
-          returned: always
+          returned: success
           type: str
           sample: 8189415
         extensions:
           description:
           - Extensions U(https://www.postgresql.org/docs/current/sql-createextension.html).
-          returned: always
+          returned: success
           type: dict
           sample:
           - { "plpgsql": { "description": "PL/pgSQL procedural language",
@@ -210,32 +211,32 @@ databases:
               sample: PL/pgSQL procedural language
             extversion:
               description: Extension description.
-              returned: always
+              returned: success
               type: dict
               contains:
                 major:
                   description: Extension major version.
-                  returned: always
+                  returned: success
                   type: int
                   sample: 1
                 minor:
                   description: Extension minor version.
-                  returned: always
+                  returned: success
                   type: int
                   sample: 0
                 raw:
                   description: Extension full version.
-                  returned: always
+                  returned: success
                   type: str
                   sample: '1.0'
             nspname:
               description: Namespace where the extension is.
-              returned: always
+              returned: success
               type: str
               sample: pg_catalog
         languages:
           description: Procedural languages U(https://www.postgresql.org/docs/current/xplang.html).
-          returned: always
+          returned: success
           type: dict
           sample: { "sql": { "lanacl": "", "lanowner": "postgres" } }
           contains:
@@ -243,32 +244,32 @@ databases:
               description:
               - Language access privileges
                 U(https://www.postgresql.org/docs/current/catalog-pg-language.html).
-              returned: always
+              returned: success
               type: str
               sample: "{postgres=UC/postgres,=U/postgres}"
             lanowner:
               description:
               - Language owner U(https://www.postgresql.org/docs/current/catalog-pg-language.html).
-              returned: always
+              returned: success
               type: str
               sample: postgres
         namespaces:
           description:
           - Namespaces (schema) U(https://www.postgresql.org/docs/current/sql-createschema.html).
-          returned: always
+          returned: success
           type: dict
           sample: { "pg_catalog": { "nspacl": "{postgres=UC/postgres,=U/postgres}", "nspowner": "postgres" } }
           contains:
             nspacl:
               description:
               - Access privileges U(https://www.postgresql.org/docs/current/catalog-pg-namespace.html).
-              returned: always
+              returned: success
               type: str
               sample: "{postgres=UC/postgres,=U/postgres}"
             nspowner:
               description:
               - Schema owner U(https://www.postgresql.org/docs/current/catalog-pg-namespace.html).
-              returned: always
+              returned: success
               type: str
               sample: postgres
         publications:
@@ -303,24 +304,24 @@ repl_slots:
     active:
       description:
       - True means that a receiver has connected to it, and it is currently reserving archives.
-      returned: always
+      returned: success
       type: bool
       sample: true
     database:
       description: Database name this slot is associated with, or null.
-      returned: always
+      returned: success
       type: str
       sample: acme
     plugin:
       description:
       - Base name of the shared object containing the output plugin
         this logical slot is using, or null for physical slots.
-      returned: always
+      returned: success
       type: str
       sample: pgoutput
     slot_type:
       description: The slot type - physical or logical.
-      returned: always
+      returned: success
       type: str
       sample: logical
 replications:
@@ -336,7 +337,7 @@ replications:
     usename:
       description:
       - Name of the user logged into this WAL sender process ('usename' is a column name in pg_stat_replication view).
-      returned: always
+      returned: success
       type: str
       sample: replication_user
     app_name:
@@ -349,30 +350,30 @@ replications:
       - IP address of the client connected to this WAL sender.
       - If this field is null, it indicates that the client is connected
         via a Unix socket on the server machine.
-      returned: always
+      returned: success
       type: str
       sample: 10.0.0.101
     client_hostname:
       description:
       - Host name of the connected client, as reported by a reverse DNS lookup of client_addr.
       - This field will only be non-null for IP connections, and only when log_hostname is enabled.
-      returned: always
+      returned: success
       type: str
       sample: dbsrv1
     backend_start:
       description: Time when this process was started, i.e., when the client connected to this WAL sender.
-      returned: always
+      returned: success
       type: str
       sample: "2019-02-03 00:14:33.908593+03"
     state:
       description: Current WAL sender state.
-      returned: always
+      returned: success
       type: str
       sample: streaming
 tablespaces:
   description:
   - Information about tablespaces U(https://www.postgresql.org/docs/current/catalog-pg-tablespace.html).
-  returned: always
+  returned: success
   type: dict
   sample:
   - { "test": { "spcacl": "{postgres=C/postgres,andreyk=C/postgres}", "spcoptions": [ "seq_page_cost=1" ],
@@ -380,23 +381,23 @@ tablespaces:
   contains:
     spcacl:
       description: Tablespace access privileges.
-      returned: always
+      returned: success
       type: str
       sample: "{postgres=C/postgres,andreyk=C/postgres}"
     spcoptions:
       description: Tablespace-level options.
-      returned: always
+      returned: success
       type: list
       sample: [ "seq_page_cost=1" ]
     spcowner:
       description: Owner of the tablespace.
-      returned: always
+      returned: success
       type: str
       sample: test_user
 roles:
   description:
   - Information about roles U(https://www.postgresql.org/docs/current/user-manag.html).
-  returned: always
+  returned: success
   type: dict
   sample:
   - { "test_role": { "canlogin": true, "member_of": [ "user_ro" ], "superuser": false,
@@ -404,37 +405,37 @@ roles:
   contains:
     canlogin:
       description: Login privilege U(https://www.postgresql.org/docs/current/role-attributes.html).
-      returned: always
+      returned: success
       type: bool
       sample: true
     member_of:
       description:
       - Role membership U(https://www.postgresql.org/docs/current/role-membership.html).
-      returned: always
+      returned: success
       type: list
       sample: [ "read_only_users" ]
     superuser:
       description: User is a superuser or not.
-      returned: always
+      returned: success
       type: bool
       sample: false
     valid_until:
       description:
       - Password expiration date U(https://www.postgresql.org/docs/current/sql-alterrole.html).
-      returned: always
+      returned: success
       type: str
       sample: "9999-12-31T23:59:59.999999+00:00"
 pending_restart_settings:
   description:
   - List of settings that are pending restart to be set.
-  returned: always
+  returned: success
   type: list
   sample: [ "shared_buffers" ]
 settings:
   description:
   - Information about run-time server parameters
     U(https://www.postgresql.org/docs/current/view-pg-settings.html).
-  returned: always
+  returned: success
   type: dict
   sample:
   - { "work_mem": { "boot_val": "4096", "context": "user", "max_val": "2147483647",
@@ -443,30 +444,30 @@ settings:
   contains:
     setting:
       description: Current value of the parameter.
-      returned: always
+      returned: success
       type: str
       sample: 49152
     unit:
       description: Implicit unit of the parameter.
-      returned: always
+      returned: success
       type: str
       sample: kB
     boot_val:
       description:
       - Parameter value assumed at server startup if the parameter is not otherwise set.
-      returned: always
+      returned: success
       type: str
       sample: 4096
     min_val:
       description:
       - Minimum allowed value of the parameter (null for non-numeric values).
-      returned: always
+      returned: success
       type: str
       sample: 64
     max_val:
       description:
       - Maximum allowed value of the parameter (null for non-numeric values).
-      returned: always
+      returned: success
       type: str
       sample: 2147483647
     sourcefile:
@@ -475,20 +476,20 @@ settings:
       - Null for values set from sources other than configuration files,
         or when examined by a user who is neither a superuser or a member of pg_read_all_settings.
       - Helpful when using include directives in configuration files.
-      returned: always
+      returned: success
       type: str
       sample: /var/lib/pgsql/10/data/postgresql.auto.conf
     context:
       description:
       - Context required to set the parameter's value.
       - For more information see U(https://www.postgresql.org/docs/current/view-pg-settings.html).
-      returned: always
+      returned: success
       type: str
       sample: user
     vartype:
       description:
       - Parameter type (bool, enum, integer, real, or string).
-      returned: always
+      returned: success
       type: str
       sample: integer
     val_in_bytes:
@@ -500,14 +501,14 @@ settings:
     pretty_val:
       description:
       - Value presented in the pretty form.
-      returned: always
+      returned: success
       type: str
       sample: 2MB
     pending_restart:
       description:
       - True if the value has been changed in the configuration file but needs a restart; or false otherwise.
       - Returns only if C(settings) is passed.
-      returned: always
+      returned: success
       type: bool
       sample: false
 '''
@@ -515,31 +516,25 @@ settings:
 import re
 from fnmatch import fnmatch
 
-try:
-    from psycopg2.extras import DictCursor
-except ImportError:
-    # psycopg2 is checked by connect_to_db()
-    # from ansible.module_utils.postgres
-    pass
-
+from ansible.module_utils._text import to_native
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.postgresql.plugins.module_utils.database import (
-    check_input,
-)
+from ansible.module_utils.six import iteritems
+from ansible_collections.community.postgresql.plugins.module_utils.database import \
+    check_input
 from ansible_collections.community.postgresql.plugins.module_utils.postgres import (
     connect_to_db,
     ensure_required_libs,
     get_conn_params,
+    get_server_version,
+    pg_cursor_args,
     postgres_common_argument_spec,
 )
-from ansible.module_utils.six import iteritems
-from ansible.module_utils._text import to_native
-
 
 # ===========================================
 # PostgreSQL module specific support methods.
 #
 
+
 class PgDbConn(object):
     """Auxiliary class for working with PostgreSQL connection objects.
 
@@ -558,14 +553,14 @@ class PgDbConn(object):
 
         Note: connection parameters are passed by self.module object.
         """
-        # Ensure psycopg2 libraries are available before connecting to DB:
+        # Ensure psycopg libraries are available before connecting to DB:
         ensure_required_libs(self.module)
         conn_params = get_conn_params(self.module, self.module.params, warn_db_default=False)
         self.db_conn, dummy = connect_to_db(self.module, conn_params, fail_on_conn=fail_on_conn)
         if self.db_conn is None:
             # only happens if fail_on_conn is False and there actually was an issue connecting to the DB
             return None
-        return self.db_conn.cursor(cursor_factory=DictCursor)
+        return self.db_conn.cursor(**pg_cursor_args)
 
     def reconnect(self, dbname):
         """Reconnect to another database and return a PostgreSQL cursor object.
@@ -588,7 +583,7 @@ class PgClusterInfo(object):
 
     Arguments:
         module (AnsibleModule): Object of AnsibleModule class.
-        db_conn_obj (psycopg2.connect): PostgreSQL connection object.
+        db_conn_obj (psycopg.connect): PostgreSQL connection object.
     """
 
     def __init__(self, module, db_conn_obj):
@@ -696,7 +691,7 @@ class PgClusterInfo(object):
                              "WHERE table_schema = 'pg_catalog' "
                              "AND table_name = 'pg_subscription'")
         columns_result = self.__exec_sql(columns_sub_table)
-        columns = ", ".join(["s.%s" % column[0] for column in columns_result])
+        columns = ", ".join(["s.%s" % column["column_name"] for column in columns_result])
 
         query = ("SELECT %s, r.rolname AS ownername, d.datname AS dbname "
                  "FROM pg_catalog.pg_subscription s "
@@ -736,22 +731,22 @@ class PgClusterInfo(object):
                               "AND column_name = 'spcoptions'")
 
         if not opt:
-            query = ("SELECT s.spcname, pg_catalog.pg_get_userbyid(s.spcowner) as rolname, s.spcacl "
+            query = ("SELECT s.spcname, pg_catalog.pg_get_userbyid(s.spcowner) as rolname, s.spcacl::text "
                      "FROM pg_tablespace AS s ")
         else:
-            query = ("SELECT s.spcname, pg_catalog.pg_get_userbyid(s.spcowner) as rolname, s.spcacl, s.spcoptions "
+            query = ("SELECT s.spcname, pg_catalog.pg_get_userbyid(s.spcowner) as rolname, s.spcacl::text, s.spcoptions "
                      "FROM pg_tablespace AS s ")
 
         res = self.__exec_sql(query)
         ts_dict = {}
         for i in res:
-            ts_name = i[0]
+            ts_name = i["spcname"]
             ts_info = dict(
-                spcowner=i[1],
-                spcacl=i[2] if i[2] else '',
+                spcowner=i["rolname"],
+                spcacl=i["spcacl"] if i["spcacl"] else '',
             )
             if opt:
-                ts_info['spcoptions'] = i[3] if i[3] else []
+                ts_info["spcoptions"] = i["spcoptions"] if i["spcoptions"] else []
 
             ts_dict[ts_name] = ts_info
 
@@ -763,7 +758,7 @@ class PgClusterInfo(object):
         res = self.__exec_sql("SELECT EXISTS (SELECT 1 FROM "
                               "information_schema.tables "
                               "WHERE table_name = 'pg_extension')")
-        if not res[0][0]:
+        if not res[0]["exists"]:
             return True
 
         query = ("SELECT e.extname, e.extversion, n.nspname, c.description "
@@ -776,12 +771,12 @@ class PgClusterInfo(object):
         res = self.__exec_sql(query)
         ext_dict = {}
         for i in res:
-            ext_ver_raw = i[1]
+            ext_ver_raw = i["extversion"]
 
-            if re.search(r'^([0-9]+([\-]*[0-9]+)?\.)*[0-9]+([\-]*[0-9]+)?$', i[1]) is None:
+            if re.search(r'^([0-9]+([\-]*[0-9]+)?\.)*[0-9]+([\-]*[0-9]+)?$', i["extversion"]) is None:
                 ext_ver = [None, None]
             else:
-                ext_ver = i[1].split('.')
+                ext_ver = i["extversion"].split('.')
                 if re.search(r'-', ext_ver[0]) is not None:
                     ext_ver = ext_ver[0].split('-')
                 else:
@@ -791,14 +786,14 @@ class PgClusterInfo(object):
                     except IndexError:
                         ext_ver.append(None)
 
-            ext_dict[i[0]] = dict(
+            ext_dict[i["extname"]] = dict(
                 extversion=dict(
                     major=int(ext_ver[0]) if ext_ver[0] else None,
                     minor=int(ext_ver[1]) if ext_ver[1] else None,
                     raw=ext_ver_raw,
                 ),
-                nspname=i[2],
-                description=i[3],
+                nspname=i["nspname"],
+                description=i["description"],
             )
 
         return ext_dict
@@ -817,11 +812,11 @@ class PgClusterInfo(object):
         res = self.__exec_sql(query)
         rol_dict = {}
         for i in res:
-            rol_dict[i[0]] = dict(
-                superuser=i[1],
-                canlogin=i[2],
-                valid_until=i[3] if i[3] else '',
-                member_of=i[4] if i[4] else [],
+            rol_dict[i["rolname"]] = dict(
+                superuser=i["rolsuper"],
+                canlogin=i["rolcanlogin"],
+                valid_until=i["rolvaliduntil"] if i["rolvaliduntil"] else '',
+                member_of=i["memberof"] if i["memberof"] else [],
             )
 
         self.pg_info["roles"] = rol_dict
@@ -832,7 +827,7 @@ class PgClusterInfo(object):
         res = self.__exec_sql("SELECT EXISTS (SELECT 1 FROM "
                               "information_schema.tables "
                               "WHERE table_name = 'pg_replication_slots')")
-        if not res[0][0]:
+        if not res[0]["exists"]:
             return True
 
         query = ("SELECT slot_name, plugin, slot_type, database, "
@@ -845,11 +840,11 @@ class PgClusterInfo(object):
 
         rslot_dict = {}
         for i in res:
-            rslot_dict[i[0]] = dict(
-                plugin=i[1],
-                slot_type=i[2],
-                database=i[3],
-                active=i[4],
+            rslot_dict[i["slot_name"]] = dict(
+                plugin=i["plugin"],
+                slot_type=i["slot_type"],
+                database=i["database"],
+                active=i["active"],
             )
 
         self.pg_info["repl_slots"] = rslot_dict
@@ -874,9 +869,9 @@ class PgClusterInfo(object):
         set_dict = {}
         for i in res:
             val_in_bytes = None
-            setting = i[1]
-            if i[2]:
-                unit = i[2]
+            setting = i["setting"]
+            if i["unit"]:
+                unit = i["unit"]
             else:
                 unit = ''
 
@@ -892,22 +887,22 @@ class PgClusterInfo(object):
             if val_in_bytes is not None and val_in_bytes < 0:
                 val_in_bytes = 0
 
-            setting_name = i[0]
+            setting_name = i["name"]
             pretty_val = self.__get_pretty_val(setting_name)
 
             pending_restart = None
             if pend_rest_col_exists:
-                pending_restart = i[9]
+                pending_restart = i["pending_restart"]
 
             set_dict[setting_name] = dict(
                 setting=setting,
                 unit=unit,
-                context=i[3],
-                vartype=i[4],
-                boot_val=i[5] if i[5] else '',
-                min_val=i[6] if i[6] else '',
-                max_val=i[7] if i[7] else '',
-                sourcefile=i[8] if i[8] else '',
+                context=i["context"],
+                vartype=i["vartype"],
+                boot_val=i["boot_val"] if i["boot_val"] else '',
+                min_val=i["min_val"] if i["min_val"] else '',
+                max_val=i["max_val"] if i["max_val"] else '',
+                sourcefile=i["sourcefile"] if i["sourcefile"] else '',
                 pretty_val=pretty_val,
             )
             if val_in_bytes is not None:
@@ -926,10 +921,10 @@ class PgClusterInfo(object):
         res = self.__exec_sql("SELECT EXISTS (SELECT 1 FROM "
                               "information_schema.tables "
                               "WHERE table_name = 'pg_stat_replication')")
-        if not res[0][0]:
+        if not res[0]["exists"]:
             return True
 
-        query = ("SELECT r.pid, pg_catalog.pg_get_userbyid(r.usesysid) AS rolname, r.application_name, r.client_addr, "
+        query = ("SELECT r.pid, pg_catalog.pg_get_userbyid(r.usesysid) AS rolname, r.application_name, r.client_addr::text, "
                  "r.client_hostname, r.backend_start::text, r.state "
                  "FROM pg_stat_replication AS r ")
         res = self.__exec_sql(query)
@@ -940,42 +935,42 @@ class PgClusterInfo(object):
 
         repl_dict = {}
         for i in res:
-            repl_dict[i[0]] = dict(
-                usename=i[1],
-                app_name=i[2] if i[2] else '',
-                client_addr=i[3],
-                client_hostname=i[4] if i[4] else '',
-                backend_start=i[5],
-                state=i[6],
+            repl_dict[i["pid"]] = dict(
+                usename=i["rolname"],
+                app_name=i["application_name"] if i["application_name"] else '',
+                client_addr=i["client_addr"],
+                client_hostname=i["client_hostname"] if i["client_hostname"] else '',
+                backend_start=i["backend_start"],
+                state=i["state"],
             )
 
         self.pg_info["replications"] = repl_dict
 
     def get_lang_info(self):
         """Get information about current supported languages."""
-        query = ("SELECT l.lanname, pg_catalog.pg_get_userbyid(l.lanowner) AS rolname, l.lanacl "
+        query = ("SELECT l.lanname, pg_catalog.pg_get_userbyid(l.lanowner) AS rolname, l.lanacl::text "
                  "FROM pg_language AS l ")
         res = self.__exec_sql(query)
         lang_dict = {}
         for i in res:
-            lang_dict[i[0]] = dict(
-                lanowner=i[1],
-                lanacl=i[2] if i[2] else '',
+            lang_dict[i["lanname"]] = dict(
+                lanowner=i["rolname"],
+                lanacl=i["lanacl"] if i["lanacl"] else '',
             )
 
         return lang_dict
 
     def get_namespaces(self):
         """Get information about namespaces."""
-        query = ("SELECT n.nspname, pg_catalog.pg_get_userbyid(n.nspowner) AS rolname, n.nspacl "
+        query = ("SELECT n.nspname, pg_catalog.pg_get_userbyid(n.nspowner) AS rolname, n.nspacl::text "
                  "FROM pg_catalog.pg_namespace AS n ")
         res = self.__exec_sql(query)
 
         nsp_dict = {}
         for i in res:
-            nsp_dict[i[0]] = dict(
-                nspowner=i[1],
-                nspacl=i[2] if i[2] else '',
+            nsp_dict[i["nspname"]] = dict(
+                nspowner=i["rolname"],
+                nspacl=i["nspacl"] if i["nspacl"] else '',
             )
 
         return nsp_dict
@@ -983,7 +978,7 @@ class PgClusterInfo(object):
     def get_pg_version(self):
         """Get major and minor PostgreSQL server version."""
         query = "SELECT version()"
-        raw = self.__exec_sql(query)[0][0]
+        raw = self.__exec_sql(query)[0]["version"]
         full = raw.split()[1]
         m = re.match(r"(\d+)\.(\d+)(?:\.(\d+))?", full)
 
@@ -1005,21 +1000,21 @@ class PgClusterInfo(object):
 
     def get_recovery_state(self):
         """Get if the service is in recovery mode."""
-        self.pg_info["in_recovery"] = self.__exec_sql("SELECT pg_is_in_recovery()")[0][0]
+        self.pg_info["in_recovery"] = self.__exec_sql("SELECT pg_is_in_recovery()")[0]["pg_is_in_recovery"]
 
     def get_db_info(self):
         """Get information about the current database."""
         # Following query returns:
         # Name, Owner, Encoding, Collate, Ctype, Access Priv, Size
         query = ("SELECT d.datname, "
-                 "pg_catalog.pg_get_userbyid(d.datdba), "
-                 "pg_catalog.pg_encoding_to_char(d.encoding), "
+                 "pg_catalog.pg_get_userbyid(d.datdba) AS username, "
+                 "pg_catalog.pg_encoding_to_char(d.encoding) AS encoding, "
                  "d.datcollate, "
                  "d.datctype, "
-                 "pg_catalog.array_to_string(d.datacl, E'\n'), "
+                 "pg_catalog.array_to_string(d.datacl, E'\n') aclstring, "
                  "CASE WHEN pg_catalog.has_database_privilege(d.datname, 'CONNECT') "
                  "THEN pg_catalog.pg_database_size(d.datname)::text "
-                 "ELSE 'No Access' END, "
+                 "ELSE 'No Access' END as dbsize, "
                  "t.spcname "
                  "FROM pg_catalog.pg_database AS d "
                  "JOIN pg_catalog.pg_tablespace t ON d.dattablespace = t.oid "
@@ -1029,16 +1024,16 @@ class PgClusterInfo(object):
 
         db_dict = {}
         for i in res:
-            db_dict[i[0]] = dict(
-                owner=i[1],
-                encoding=i[2],
-                collate=i[3],
-                ctype=i[4],
-                access_priv=i[5] if i[5] else '',
-                size=i[6],
+            db_dict[i["datname"]] = dict(
+                owner=i["username"],
+                encoding=i["encoding"],
+                collate=i["datcollate"],
+                ctype=i["datctype"],
+                access_priv=i["aclstring"] if i["aclstring"] else '',
+                size=i["dbsize"],
             )
 
-        if self.cursor.connection.server_version >= 100000:
+        if get_server_version(self.cursor.connection) >= 100000:
             subscr_info = self.get_subscr_info()
 
         for datname in db_dict:
@@ -1053,7 +1048,7 @@ class PgClusterInfo(object):
             db_dict[datname]['namespaces'] = self.get_namespaces()
             db_dict[datname]['extensions'] = self.get_ext_info()
             db_dict[datname]['languages'] = self.get_lang_info()
-            if self.cursor.connection.server_version >= 100000:
+            if get_server_version(self.cursor.connection) >= 100000:
                 db_dict[datname]['publications'] = self.get_pub_info()
                 db_dict[datname]['subscriptions'] = subscr_info.get(datname, {})
 
@@ -1061,7 +1056,7 @@ class PgClusterInfo(object):
 
     def __get_pretty_val(self, setting):
         """Get setting's value represented by SHOW command."""
-        return self.__exec_sql('SHOW "%s"' % setting)[0][0]
+        return self.__exec_sql('SHOW "%s"' % setting)[0][setting]
 
     def __exec_sql(self, query):
         """Execute SQL and return the result."""
