@@ -6,6 +6,7 @@
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 
 DOCUMENTATION = r'''
@@ -17,9 +18,6 @@ description:
 - This module is basically a wrapper around most of the functionality of
   PostgreSQL's GRANT and REVOKE statements with detection of changes
   (GRANT/REVOKE I(privs) ON I(type) I(objs) TO/FROM I(roles)).
-- B(WARNING) The C(usage_on_types) option has been B(deprecated) and will be removed in
-  community.postgresql 3.0.0, please use the C(type) option with value C(type) to
-  GRANT/REVOKE permissions on types explicitly.
 options:
   database:
     description:
@@ -48,10 +46,11 @@ options:
     - The C(foreign_data_wrapper) and C(foreign_server) object types are available since Ansible version 2.8.
     - The C(type) choice is available since Ansible version 2.10.
     - The C(procedure) is supported since collection version 1.3.0 and PostgreSQL 11.
+    - The C(parameter) is supported since collection version 3.1.0 and PostgreSQL 15.
     type: str
     default: table
     choices: [ database, default_privs, foreign_data_wrapper, foreign_server, function,
-               group, language, table, tablespace, schema, sequence, type , procedure]
+               group, language, table, tablespace, schema, sequence, type, procedure, parameter ]
   objs:
     description:
     - Comma separated list of database objects to set privileges on.
@@ -61,6 +60,7 @@ options:
       (This also works with PostgreSQL < 9.0.) (C(ALL_IN_SCHEMA) is available
        for C(function) and C(partition table) since Ansible 2.8).
     - C(procedure) is supported since PostgreSQL 11 and community.postgresql collection 1.3.0.
+    - C(parameter) is supported since PostgreSQL 15 and community.postgresql collection 3.1.0.
     - If I(type) is C(database), this parameter can be omitted, in which case
       privileges are set for the database specified via I(database).
     - If I(type) is C(function) or C(procedure), colons (":") in object names will be
@@ -80,8 +80,9 @@ options:
   roles:
     description:
     - Comma separated list of role (user/group) names to set permissions for.
-    - The special value C(PUBLIC) can be provided instead to set permissions
-      for the implicitly defined PUBLIC group.
+    - Roles C(PUBLIC), C(CURRENT_ROLE), C(CURRENT_USER), C(SESSION_USER) are implicitly defined in PostgreSQL.
+    - C(CURRENT_USER) and C(SESSION_USER) implicit roles are supported since collection version 3.1.0 and PostgreSQL 9.5.
+    - C(CURRENT_ROLE) implicit role is supported since collection version 3.1.0 and PostgreSQL 14.
     type: str
     required: true
     aliases:
@@ -128,18 +129,6 @@ options:
     type: bool
     default: true
     version_added: '0.2.0'
-  usage_on_types:
-    description:
-    - This option has been B(deprecated) and will be removed in community.postgresql 3.0.0,
-      please use the I(type) option with value C(type) to GRANT/REVOKE permissions on types
-      explicitly.
-    - When adding default privileges, the module always implicitly adds ``USAGE ON TYPES``.
-    - To avoid this behavior, set I(usage_on_types) to C(false).
-    - Added to save backwards compatibility.
-    - Used only when adding default privileges, ignored otherwise.
-    type: bool
-    default: true
-    version_added: '1.2.0'
 
 notes:
 - Parameters that accept comma separated lists (I(privs), I(objs), I(roles))
@@ -148,7 +137,6 @@ notes:
   C(present) and I(grant_option) to C(false) (see examples).
 - Note that when revoking privileges from a role R, this role  may still have
   access via privileges granted to any role R is a member of including C(PUBLIC).
-- Note that when you use C(PUBLIC) role, the module always reports that the state has been changed.
 - Note that when revoking privileges from a role R, you do so as the user
   specified via I(login_user). If R has been granted the same privileges by
   another user also, R can still access database objects via these privileges.
@@ -178,6 +166,7 @@ extends_documentation_fragment:
 author:
 - Bernhard Weitzhofer (@b6d)
 - Tobias Birkefeld (@tcraxs)
+- Daniele Giudice (@RealGreenDragon)
 '''
 
 EXAMPLES = r'''
@@ -402,43 +391,74 @@ EXAMPLES = r'''
     privs: usage
     objs: schemas
     role: datascience
+
+# Available since community.postgresql 3.1.0
+# Needs PostgreSQL 15 or higher
+- name: GRANT SET ON PARAMETER log_destination,log_line_prefix TO logtest
+  community.postgresql.postgresql_privs:
+    database: logtest
+    state: present
+    privs: SET
+    type: parameter
+    objs: log_destination,log_line_prefix
+    roles: logtest
+
+- name: GRANT ALTER SYSTEM ON PARAMETER primary_conninfo,synchronous_standby_names TO replicamgr
+  community.postgresql.postgresql_privs:
+    database: replicamgr
+    state: present
+    privs: ALTER_SYSTEM
+    type: parameter
+    objs: primary_conninfo,synchronous_standby_names
+    roles: replicamgr
 '''
 
 RETURN = r'''
 queries:
   description: List of executed queries.
-  returned: always
+  returned: success
   type: list
   sample: ['REVOKE GRANT OPTION FOR INSERT ON TABLE "books" FROM "reader";']
 '''
 
 import traceback
 
-PSYCOPG2_IMP_ERR = None
-try:
-    import psycopg2
-    import psycopg2.extensions
-except ImportError:
-    PSYCOPG2_IMP_ERR = traceback.format_exc()
-    psycopg2 = None
-
-# import module snippets
-from ansible.module_utils.basic import AnsibleModule, missing_required_lib
-from ansible_collections.community.postgresql.plugins.module_utils.database import (
-    pg_quote_identifier,
-    check_input,
-)
-from ansible_collections.community.postgresql.plugins.module_utils.postgres import postgres_common_argument_spec, get_conn_params
 from ansible.module_utils._text import to_native
+# import module snippets
+from ansible.module_utils.basic import AnsibleModule
+from ansible_collections.community.postgresql.plugins.module_utils.database import (
+    check_input,
+    pg_quote_identifier,
+)
+from ansible_collections.community.postgresql.plugins.module_utils.postgres import (
+    HAS_PSYCOPG,
+    PSYCOPG_VERSION,
+    connect_to_db,
+    ensure_required_libs,
+    get_conn_params,
+    get_server_version,
+    pg_cursor_args,
+    postgres_common_argument_spec,
+)
+from ansible_collections.community.postgresql.plugins.module_utils.version import \
+    LooseVersion
 
-VALID_PRIVS = frozenset(('SELECT', 'INSERT', 'UPDATE', 'DELETE', 'TRUNCATE',
-                         'REFERENCES', 'TRIGGER', 'CREATE', 'CONNECT',
-                         'TEMPORARY', 'TEMP', 'EXECUTE', 'USAGE', 'ALL'))
+if HAS_PSYCOPG and PSYCOPG_VERSION < LooseVersion("3.0"):
+    from psycopg2 import Error as PsycopgError
+elif HAS_PSYCOPG:
+    from psycopg import Error as PsycopgError
+
+VALID_PRIVS = frozenset(('SELECT', 'INSERT', 'UPDATE', 'DELETE', 'TRUNCATE', 'REFERENCES', 'TRIGGER', 'CREATE',
+                         'CONNECT', 'TEMPORARY', 'TEMP', 'EXECUTE', 'USAGE', 'ALL', 'SET', 'ALTER_SYSTEM'))
 VALID_DEFAULT_OBJS = {'TABLES': ('ALL', 'SELECT', 'INSERT', 'UPDATE', 'DELETE', 'TRUNCATE', 'REFERENCES', 'TRIGGER'),
                       'SEQUENCES': ('ALL', 'SELECT', 'UPDATE', 'USAGE'),
                       'FUNCTIONS': ('ALL', 'EXECUTE'),
                       'TYPES': ('ALL', 'USAGE'),
                       'SCHEMAS': ('CREATE', 'USAGE'), }
+VALID_IMPLICIT_ROLES = {'PUBLIC': 0,
+                        'CURRENT_USER': 95000,
+                        'SESSION_USER': 95000,
+                        'CURRENT_ROLE': 140000, }
 
 executed_queries = []
 
@@ -447,19 +467,6 @@ class Error(Exception):
     pass
 
 
-def role_exists(module, cursor, rolname):
-    """Check user exists or not"""
-    query = "SELECT 1 FROM pg_roles WHERE rolname = '%s'" % rolname
-    try:
-        cursor.execute(query)
-        return cursor.rowcount > 0
-
-    except Exception as e:
-        module.fail_json(msg="Cannot execute SQL '%s': %s" % (query, to_native(e)))
-
-    return False
-
-
 # We don't have functools.partial in Python < 2.5
 def partial(f, *args, **kwargs):
     """Partial function application"""
@@ -476,21 +483,30 @@ def partial(f, *args, **kwargs):
 
 
 class Connection(object):
-    """Wrapper around a psycopg2 connection with some convenience methods"""
+    """Wrapper around a psycopg connection with some convenience methods"""
 
     def __init__(self, params, module):
         self.database = params.database
         self.module = module
 
+        # Ensure psycopg libraries are available before connecting to DB:
+        ensure_required_libs(module)
         conn_params = get_conn_params(module, params.__dict__, warn_db_default=False)
 
-        sslrootcert = params.ca_cert
-        if psycopg2.__version__ < '2.4.3' and sslrootcert is not None:
-            raise ValueError('psycopg2 must be at least 2.4.3 in order to user the ca_cert parameter')
+        self.connection, dummy = connect_to_db(module, conn_params, autocommit=False)
+        self.cursor = self.connection.cursor(**pg_cursor_args)
+        self.pg_version = get_server_version(self.connection)
 
-        self.connection = psycopg2.connect(**conn_params)
-        self.cursor = self.connection.cursor()
-        self.pg_version = self.connection.server_version
+        # implicit roles in current pg version
+        self.pg_implicit_roles = tuple(
+            implicit_role for implicit_role, version_min in VALID_IMPLICIT_ROLES.items() if self.pg_version >= version_min
+        )
+
+    def execute(self, query, input_vars=None):
+        try:
+            self.cursor.execute(query, input_vars)
+        except Exception as e:
+            self.module.fail_json(msg="Cannot execute SQL '%s': %s" % (query, to_native(e)))
 
     def commit(self):
         self.connection.commit()
@@ -498,22 +514,32 @@ class Connection(object):
     def rollback(self):
         self.connection.rollback()
 
-    @property
-    def encoding(self):
-        """Connection encoding in Python-compatible form"""
-        return psycopg2.extensions.encodings[self.connection.encoding]
+    # Methods for implicit roles managements
+
+    def is_implicit_role(self, rolname):
+        return rolname.upper() in self.pg_implicit_roles
 
     # Methods for querying database objects
 
+    def role_exists(self, rolname):
+        # check if rolname is a implicit role
+        if self.is_implicit_role(rolname):
+            return True
+
+        # check if rolname is present in pg_catalog.pg_roles
+        query = "SELECT 1 FROM pg_catalog.pg_roles WHERE rolname = %s"
+        self.execute(query, (rolname,))
+        return self.cursor.rowcount > 0
+
     # PostgreSQL < 9.0 doesn't support "ALL TABLES IN SCHEMA schema"-like
     # phrases in GRANT or REVOKE statements, therefore alternative methods are
     # provided here.
 
     def schema_exists(self, schema):
-        query = """SELECT count(*)
+        query = """SELECT count(*) c
                    FROM pg_catalog.pg_namespace WHERE nspname = %s"""
-        self.cursor.execute(query, (schema,))
-        return self.cursor.fetchone()[0] > 0
+        self.execute(query, (schema,))
+        return self.cursor.fetchone()["c"] > 0
 
     def get_all_tables_in_schema(self, schema):
         if schema:
@@ -524,12 +550,12 @@ class Connection(object):
                        FROM pg_catalog.pg_class c
                        JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace
                        WHERE nspname = %s AND relkind in ('r', 'v', 'm', 'p')"""
-            self.cursor.execute(query, (schema,))
+            self.execute(query, (schema,))
         else:
             query = ("SELECT relname FROM pg_catalog.pg_class "
                      "WHERE relkind in ('r', 'v', 'm', 'p')")
-            self.cursor.execute(query)
-        return [t[0] for t in self.cursor.fetchall()]
+            self.execute(query)
+        return [t["relname"] for t in self.cursor.fetchall()]
 
     def get_all_sequences_in_schema(self, schema):
         if schema:
@@ -539,17 +565,17 @@ class Connection(object):
                        FROM pg_catalog.pg_class c
                        JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace
                        WHERE nspname = %s AND relkind = 'S'"""
-            self.cursor.execute(query, (schema,))
+            self.execute(query, (schema,))
         else:
-            self.cursor.execute("SELECT relname FROM pg_catalog.pg_class WHERE relkind = 'S'")
-        return [t[0] for t in self.cursor.fetchall()]
+            self.execute("SELECT relname FROM pg_catalog.pg_class WHERE relkind = 'S'")
+        return [t["relname"] for t in self.cursor.fetchall()]
 
     def get_all_functions_in_schema(self, schema):
         if schema:
             if not self.schema_exists(schema):
                 raise Error('Schema "%s" does not exist.' % schema)
 
-            query = ("SELECT p.proname, oidvectortypes(p.proargtypes) "
+            query = ("SELECT p.proname, oidvectortypes(p.proargtypes) ptypes "
                      "FROM pg_catalog.pg_proc p "
                      "JOIN pg_namespace n ON n.oid = p.pronamespace "
                      "WHERE nspname = %s")
@@ -557,30 +583,30 @@ class Connection(object):
             if self.pg_version >= 110000:
                 query += " and p.prokind = 'f'"
 
-            self.cursor.execute(query, (schema,))
+            self.execute(query, (schema,))
         else:
-            self.cursor.execute("SELECT p.proname, oidvectortypes(p.proargtypes) FROM pg_catalog.pg_proc p")
-        return ["%s(%s)" % (t[0], t[1]) for t in self.cursor.fetchall()]
+            self.execute("SELECT p.proname, oidvectortypes(p.proargtypes) ptypes FROM pg_catalog.pg_proc p")
+        return ["%s(%s)" % (t["proname"], t["ptypes"]) for t in self.cursor.fetchall()]
 
     def get_all_procedures_in_schema(self, schema):
         if self.pg_version < 110000:
-            raise Error("PostgreSQL verion must be >= 11 for type=procedure. Exit")
+            raise Error("PostgreSQL version must be >= 11 for type=procedure. Exit")
 
         if schema:
             if not self.schema_exists(schema):
                 raise Error('Schema "%s" does not exist.' % schema)
 
-            query = ("SELECT p.proname, oidvectortypes(p.proargtypes) "
+            query = ("SELECT p.proname, oidvectortypes(p.proargtypes) ptypes "
                      "FROM pg_catalog.pg_proc p "
                      "JOIN pg_namespace n ON n.oid = p.pronamespace "
                      "WHERE nspname = %s and p.prokind = 'p'")
 
-            self.cursor.execute(query, (schema,))
+            self.execute(query, (schema,))
         else:
-            query = ("SELECT p.proname, oidvectortypes(p.proargtypes) "
+            query = ("SELECT p.proname, oidvectortypes(p.proargtypes) ptypes "
                      "FROM pg_catalog.pg_proc p WHERE p.prokind = 'p'")
-            self.cursor.execute(query)
-        return ["%s(%s)" % (t[0], t[1]) for t in self.cursor.fetchall()]
+            self.execute(query)
+        return ["%s(%s)" % (t["proname"], t["ptypes"]) for t in self.cursor.fetchall()]
 
     # Methods for getting access control lists and group membership info
 
@@ -592,71 +618,71 @@ class Connection(object):
 
     def get_table_acls(self, schema, tables):
         if schema:
-            query = """SELECT relacl
+            query = """SELECT relacl::text
                        FROM pg_catalog.pg_class c
                        JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace
                        WHERE nspname = %s AND relkind in ('r','p','v','m') AND relname = ANY (%s)
                        ORDER BY relname"""
-            self.cursor.execute(query, (schema, tables))
+            self.execute(query, (schema, tables))
         else:
-            query = ("SELECT relacl FROM pg_catalog.pg_class "
+            query = ("SELECT relacl::text FROM pg_catalog.pg_class "
                      "WHERE relkind in ('r','p','v','m') AND relname = ANY (%s) "
                      "ORDER BY relname")
-            self.cursor.execute(query)
-        return [t[0] for t in self.cursor.fetchall()]
+            self.execute(query)
+        return [t["relacl"] for t in self.cursor.fetchall()]
 
     def get_sequence_acls(self, schema, sequences):
         if schema:
-            query = """SELECT relacl
+            query = """SELECT relacl::text
                        FROM pg_catalog.pg_class c
                        JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace
                        WHERE nspname = %s AND relkind = 'S' AND relname = ANY (%s)
                        ORDER BY relname"""
-            self.cursor.execute(query, (schema, sequences))
+            self.execute(query, (schema, sequences))
         else:
-            query = ("SELECT relacl FROM pg_catalog.pg_class "
+            query = ("SELECT relacl::text FROM pg_catalog.pg_class "
                      "WHERE  relkind = 'S' AND relname = ANY (%s) ORDER BY relname")
-            self.cursor.execute(query)
-        return [t[0] for t in self.cursor.fetchall()]
+            self.execute(query)
+        return [t["relacl"] for t in self.cursor.fetchall()]
 
     def get_function_acls(self, schema, function_signatures):
         funcnames = [f.split('(', 1)[0] for f in function_signatures]
         if schema:
-            query = """SELECT proacl
+            query = """SELECT proacl::text
                        FROM pg_catalog.pg_proc p
                        JOIN pg_catalog.pg_namespace n ON n.oid = p.pronamespace
                        WHERE nspname = %s AND proname = ANY (%s)
                        ORDER BY proname, proargtypes"""
-            self.cursor.execute(query, (schema, funcnames))
+            self.execute(query, (schema, funcnames))
         else:
-            query = ("SELECT proacl FROM pg_catalog.pg_proc WHERE proname = ANY (%s) "
+            query = ("SELECT proacl::text FROM pg_catalog.pg_proc WHERE proname = ANY (%s) "
                      "ORDER BY proname, proargtypes")
-            self.cursor.execute(query)
-        return [t[0] for t in self.cursor.fetchall()]
+            self.execute(query)
+        return [t["proacl"] for t in self.cursor.fetchall()]
 
     def get_schema_acls(self, schemas):
-        query = """SELECT nspacl FROM pg_catalog.pg_namespace
+        query = """SELECT nspacl::text FROM pg_catalog.pg_namespace
                    WHERE nspname = ANY (%s) ORDER BY nspname"""
-        self.cursor.execute(query, (schemas,))
-        return [t[0] for t in self.cursor.fetchall()]
+        self.execute(query, (schemas,))
+        return [t["nspacl"] for t in self.cursor.fetchall()]
 
     def get_language_acls(self, languages):
-        query = """SELECT lanacl FROM pg_catalog.pg_language
+        query = """SELECT lanacl::text FROM pg_catalog.pg_language
                    WHERE lanname = ANY (%s) ORDER BY lanname"""
-        self.cursor.execute(query, (languages,))
-        return [t[0] for t in self.cursor.fetchall()]
+        self.execute(query, (languages,))
+        return [t["lanacl"] for t in self.cursor.fetchall()]
 
     def get_tablespace_acls(self, tablespaces):
-        query = """SELECT spcacl FROM pg_catalog.pg_tablespace
+        query = """SELECT spcacl::text FROM pg_catalog.pg_tablespace
                    WHERE spcname = ANY (%s) ORDER BY spcname"""
-        self.cursor.execute(query, (tablespaces,))
-        return [t[0] for t in self.cursor.fetchall()]
+        self.execute(query, (tablespaces,))
+        return [t["spcacl"] for t in self.cursor.fetchall()]
 
     def get_database_acls(self, databases):
-        query = """SELECT datacl FROM pg_catalog.pg_database
+        query = """SELECT datacl::text FROM pg_catalog.pg_database
                    WHERE datname = ANY (%s) ORDER BY datname"""
-        self.cursor.execute(query, (databases,))
-        return [t[0] for t in self.cursor.fetchall()]
+        self.execute(query, (databases,))
+        return [t["datacl"] for t in self.cursor.fetchall()]
 
     def get_group_memberships(self, groups):
         query = """SELECT roleid, grantor, member, admin_option
@@ -664,48 +690,56 @@ class Connection(object):
                    JOIN pg_catalog.pg_roles r ON r.oid = am.roleid
                    WHERE r.rolname = ANY(%s)
                    ORDER BY roleid, grantor, member"""
-        self.cursor.execute(query, (groups,))
+        self.execute(query, (groups,))
         return self.cursor.fetchall()
 
     def get_default_privs(self, schema, *args):
         if schema:
-            query = """SELECT defaclacl
+            query = """SELECT defaclacl::text
                        FROM pg_default_acl a
                        JOIN pg_namespace b ON a.defaclnamespace=b.oid
                        WHERE b.nspname = %s;"""
-            self.cursor.execute(query, (schema,))
+            self.execute(query, (schema,))
         else:
-            self.cursor.execute("SELECT defaclacl FROM pg_default_acl;")
-        return [t[0] for t in self.cursor.fetchall()]
+            self.execute("SELECT defaclacl::text FROM pg_default_acl;")
+        return [t["defaclacl"] for t in self.cursor.fetchall()]
 
     def get_foreign_data_wrapper_acls(self, fdws):
-        query = """SELECT fdwacl FROM pg_catalog.pg_foreign_data_wrapper
+        query = """SELECT fdwacl::text FROM pg_catalog.pg_foreign_data_wrapper
                    WHERE fdwname = ANY (%s) ORDER BY fdwname"""
-        self.cursor.execute(query, (fdws,))
-        return [t[0] for t in self.cursor.fetchall()]
+        self.execute(query, (fdws,))
+        return [t["fdwacl"] for t in self.cursor.fetchall()]
 
     def get_foreign_server_acls(self, fs):
-        query = """SELECT srvacl FROM pg_catalog.pg_foreign_server
+        query = """SELECT srvacl::text FROM pg_catalog.pg_foreign_server
                    WHERE srvname = ANY (%s) ORDER BY srvname"""
-        self.cursor.execute(query, (fs,))
-        return [t[0] for t in self.cursor.fetchall()]
+        self.execute(query, (fs,))
+        return [t["srvacl"] for t in self.cursor.fetchall()]
 
     def get_type_acls(self, schema, types):
         if schema:
-            query = """SELECT t.typacl FROM pg_catalog.pg_type t
+            query = """SELECT t.typacl::text FROM pg_catalog.pg_type t
                        JOIN pg_catalog.pg_namespace n ON n.oid = t.typnamespace
                        WHERE n.nspname = %s AND t.typname = ANY (%s) ORDER BY typname"""
-            self.cursor.execute(query, (schema, types))
+            self.execute(query, (schema, types))
         else:
-            query = "SELECT typacl FROM pg_catalog.pg_type WHERE typname = ANY (%s) ORDER BY typname"
-            self.cursor.execute(query)
-        return [t[0] for t in self.cursor.fetchall()]
+            query = "SELECT typacl::text FROM pg_catalog.pg_type WHERE typname = ANY (%s) ORDER BY typname"
+            self.execute(query)
+        return [t["typacl"] for t in self.cursor.fetchall()]
+
+    def get_parameter_acls(self, parameters):
+        if self.pg_version < 150000:
+            raise Error("PostgreSQL version must be >= 15 for type=parameter. Exit")
+
+        query = """SELECT paracl::text FROM pg_catalog.pg_parameter_acl
+                   WHERE parname = ANY (%s) ORDER BY parname"""
+        self.cursor.execute(query, (parameters,))
+        return [t["paracl"] for t in self.cursor.fetchall()]
 
     # Manipulating privileges
 
-    # WARNING: usage_on_types has been deprecated and will be removed in community.postgresql 3.0.0, please use an obj_type of 'type' instead.
     def manipulate_privs(self, obj_type, privs, objs, orig_objs, roles, target_roles,
-                         state, grant_option, schema_qualifier=None, fail_on_role=True, usage_on_types=True):
+                         state, grant_option, schema_qualifier=None, fail_on_role=True):
         """Manipulate database object privileges.
 
         :param obj_type: Type of database object to grant/revoke
@@ -714,9 +748,8 @@ class Connection(object):
                       or None if type is "group".
         :param objs: List of database objects to grant/revoke
                      privileges for.
-        :param orig_objs: ALL_IN_SCHEMA or None
-        :param roles: Either a list of role names or "PUBLIC"
-                      for the implicitly defined "PUBLIC" group
+        :param orig_objs: ALL_IN_SCHEMA or None.
+        :param roles: List of role names.
         :param target_roles: List of role names to grant/revoke
                              default privileges as.
         :param state: "present" to grant privileges, "absent" to revoke.
@@ -752,6 +785,8 @@ class Connection(object):
             get_status = self.get_foreign_server_acls
         elif obj_type == 'type':
             get_status = partial(self.get_type_acls, schema_qualifier)
+        elif obj_type == 'parameter':
+            get_status = self.get_parameter_acls
         else:
             raise Error('Unsupported database object type "%s".' % obj_type)
 
@@ -787,33 +822,18 @@ class Connection(object):
                 obj_ids = [pg_quote_identifier(i, 'table') for i in obj_ids]
             # Note: obj_type has been checked against a set of string literals
             # and privs was escaped when it was parsed
-            # Note: Underscores are replaced with spaces to support multi-word obj_type
+            # Note: Underscores are replaced with spaces to support multi-word privs and obj_type
             if orig_objs is not None:
-                set_what = '%s ON %s %s' % (','.join(privs), orig_objs, quoted_schema_qualifier)
+                set_what = '%s ON %s %s' % (','.join(privs).replace('_', ' '), orig_objs, quoted_schema_qualifier)
             else:
-                set_what = '%s ON %s %s' % (','.join(privs), obj_type.replace('_', ' '), ','.join(obj_ids))
+                set_what = '%s ON %s %s' % (','.join(privs).replace('_', ' '), obj_type.replace('_', ' '), ','.join(obj_ids))
 
         # for_whom: SQL-fragment specifying for whom to set the above
-        if roles == 'PUBLIC':
-            for_whom = 'PUBLIC'
-        else:
-            for_whom = []
-            for r in roles:
-                if not role_exists(self.module, self.cursor, r):
-                    if fail_on_role:
-                        self.module.fail_json(msg="Role '%s' does not exist" % r.strip())
+        if not roles:
+            return False
+        for_whom = ','.join(roles)
 
-                    else:
-                        self.module.warn("Role '%s' does not exist, pass it" % r.strip())
-                else:
-                    for_whom.append('"%s"' % r)
-
-            if not for_whom:
-                return False
-
-            for_whom = ','.join(for_whom)
-
-        # as_who:
+        # as_who: SQL-fragment specifying to who to set the above
         as_who = None
         if target_roles:
             as_who = ','.join('"%s"' % r for r in target_roles)
@@ -828,13 +848,10 @@ class Connection(object):
             .for_schema(quoted_schema_qualifier) \
             .set_what(set_what) \
             .for_objs(objs) \
-            .usage_on_types(usage_on_types) \
             .build()
 
         executed_queries.append(query)
-        self.cursor.execute(query)
-        if roles == 'PUBLIC':
-            return True
+        self.execute(query)
 
         status_after = get_status(objs)
 
@@ -843,7 +860,8 @@ class Connection(object):
             # to compare NoneType elements by sort method.
             if e is None:
                 return ''
-            return e
+            # With Psycopg 3 we get a list of dicts, it is easier to sort it as strings
+            return str(e)
 
         status_before.sort(key=nonesorted)
         status_after.sort(key=nonesorted)
@@ -860,7 +878,6 @@ class QueryBuilder(object):
         self._state = state
         self._schema = None
         self._objs = None
-        self._usage_on_types = None
         self.query = []
 
     def for_objs(self, objs):
@@ -879,10 +896,6 @@ class QueryBuilder(object):
         self._for_whom = who
         return self
 
-    def usage_on_types(self, usage_on_types):
-        self._usage_on_types = usage_on_types
-        return self
-
     def as_who(self, target_roles):
         self._as_who = target_roles
         return self
@@ -948,16 +961,6 @@ class QueryBuilder(object):
                                                                                  self._for_whom))
             self.add_grant_option()
 
-        if self._usage_on_types:
-
-            if self._as_who:
-                self.query.append(
-                    'ALTER DEFAULT PRIVILEGES FOR ROLE {0}{1} GRANT USAGE ON TYPES TO {2}'.format(self._as_who,
-                                                                                                  self._schema,
-                                                                                                  self._for_whom))
-            else:
-                self.query.append(
-                    'ALTER DEFAULT PRIVILEGES{0} GRANT USAGE ON TYPES TO {1}'.format(self._schema, self._for_whom))
         self.add_grant_option()
 
     def build_present(self):
@@ -1004,7 +1007,8 @@ def main():
                            'default_privs',
                            'foreign_data_wrapper',
                            'foreign_server',
-                           'type', ]),
+                           'type',
+                           'parameter', ]),
         objs=dict(required=False, aliases=['obj']),
         schema=dict(required=False),
         roles=dict(required=True, aliases=['role']),
@@ -1019,9 +1023,6 @@ def main():
                       removed_from_collection='community.postgreql'),
         fail_on_role=dict(type='bool', default=True),
         trust_input=dict(type='bool', default=True),
-        usage_on_types=dict(type='bool', default=True,
-                            removed_in_version='3.0.0',
-                            removed_from_collection='community.postgresql'),
     )
 
     module = AnsibleModule(
@@ -1030,7 +1031,6 @@ def main():
     )
 
     fail_on_role = module.params['fail_on_role']
-    usage_on_types = module.params['usage_on_types']
 
     # Create type object as namespace for module params
     p = type('Params', (), module.params)
@@ -1083,19 +1083,7 @@ def main():
         check_input(module, p.roles, p.target_roles, p.session_role, p.schema)
 
     # Connect to Database
-    if not psycopg2:
-        module.fail_json(msg=missing_required_lib('psycopg2'), exception=PSYCOPG2_IMP_ERR)
-    try:
-        conn = Connection(p, module)
-    except psycopg2.Error as e:
-        module.fail_json(msg='Could not connect to database: %s' % to_native(e), exception=traceback.format_exc())
-    except TypeError as e:
-        if 'sslrootcert' in e.args[0]:
-            module.fail_json(msg='Postgresql server must be at least version 8.4 to support sslrootcert')
-        module.fail_json(msg="unable to connect to database: %s" % to_native(e), exception=traceback.format_exc())
-    except ValueError as e:
-        # We raise this when the psycopg library is too old
-        module.fail_json(msg=to_native(e))
+    conn = Connection(p, module)
 
     if p.session_role:
         try:
@@ -1156,17 +1144,25 @@ def main():
                 objs = [obj.replace(':', ',') for obj in objs]
 
         # roles
-        if p.roles.upper() == 'PUBLIC':
-            roles = 'PUBLIC'
-        else:
-            roles = p.roles.split(',')
-
-            if len(roles) == 1 and not role_exists(module, conn.cursor, roles[0]):
-                if fail_on_role:
-                    module.fail_json(msg="Role '%s' does not exist" % roles[0].strip())
+        roles = []
+        roles_raw = p.roles.split(',')
+        for r in roles_raw:
+            if conn.role_exists(r):
+                if conn.is_implicit_role(r):
+                    # Some implicit roles (as PUBLIC) works in uppercase without double quotes and in lowercase with double quotes.
+                    # Other implicit roles (as SESSION_USER) works only in uppercase without double quotes.
+                    # So the approach that works for all implicit roles is uppercase without double quotes.
+                    roles.append('%s' % r.upper())
                 else:
-                    module.warn("Role '%s' does not exist, nothing to do" % roles[0].strip())
-                module.exit_json(changed=False, queries=executed_queries)
+                    roles.append('"%s"' % r.replace('"', '""'))
+            else:
+                if fail_on_role:
+                    module.fail_json(msg="Role '%s' does not exist" % r)
+                else:
+                    module.warn("Role '%s' does not exist, pass it" % r)
+        if not roles:
+            module.warn("No valid roles provided, nothing to do")
+            module.exit_json(changed=False, queries=executed_queries)
 
         # check if target_roles is set with type: default_privs
         if p.target_roles and not p.type == 'default_privs':
@@ -1190,14 +1186,13 @@ def main():
             grant_option=p.grant_option,
             schema_qualifier=p.schema,
             fail_on_role=fail_on_role,
-            usage_on_types=usage_on_types,
         )
 
     except Error as e:
         conn.rollback()
         module.fail_json(msg=to_native(e), exception=traceback.format_exc())
 
-    except psycopg2.Error as e:
+    except PsycopgError as e:
         conn.rollback()
         module.fail_json(msg=to_native(e))
 
