@@ -6,7 +6,8 @@
 # Copyright: (c) 2019, Andrew Klychkov (@Andersson007) <aaklychkov@mail.ru>
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import (absolute_import, division, print_function)
+from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 
 DOCUMENTATION = r'''
@@ -77,6 +78,12 @@ options:
     type: bool
     default: true
     version_added: '0.2.0'
+  comment:
+    description:
+    - Sets a comment on the tablespace.
+    - To reset the comment, pass an empty string.
+    type: str
+    version_added: '3.3.0'
 
 attributes:
   check_mode:
@@ -104,6 +111,7 @@ author:
 - Flavien Chantelot (@Dorn-)
 - Antoine Levy-Lambert (@antoinell)
 - Andrew Klychkov (@Andersson007)
+- Daniele Giudice (@RealGreenDragon)
 
 extends_documentation_fragment:
 - community.postgresql.postgres
@@ -115,6 +123,7 @@ EXAMPLES = r'''
     name: acme
     owner: bob
     location: /data/foo
+    comment: "Bob's tablespace"
 
 - name: Create a new tablespace called bar with tablespace options
   community.postgresql.postgresql_tablespace:
@@ -143,27 +152,32 @@ EXAMPLES = r'''
 RETURN = r'''
 queries:
     description: List of queries that was tried to be executed.
-    returned: always
+    returned: success
     type: str
     sample: [ "CREATE TABLESPACE bar LOCATION '/incredible/ssd'" ]
 tablespace:
     description: Tablespace name.
-    returned: always
+    returned: success
     type: str
     sample: 'ssd'
 owner:
     description: Tablespace owner.
-    returned: always
+    returned: success
     type: str
     sample: 'Bob'
+comment:
+    description: Tablespace comment.
+    returned: success
+    type: str
+    sample: 'Test tablespace'
 options:
     description: Tablespace options.
-    returned: always
+    returned: success
     type: dict
     sample: { 'random_page_cost': 1, 'seq_page_cost': 1 }
 location:
     description: Path to the tablespace in the file system.
-    returned: always
+    returned: success
     type: str
     sample: '/incredible/fast/ssd'
 newname:
@@ -173,33 +187,24 @@ newname:
     sample: new_ssd
 state:
     description: Tablespace state at the end of execution.
-    returned: always
+    returned: success
     type: str
     sample: 'present'
 '''
 
-try:
-    from psycopg2 import __version__ as PSYCOPG2_VERSION
-    from psycopg2.extras import DictCursor
-    from psycopg2.extensions import ISOLATION_LEVEL_AUTOCOMMIT as AUTOCOMMIT
-    from psycopg2.extensions import ISOLATION_LEVEL_READ_COMMITTED as READ_COMMITTED
-except ImportError:
-    # psycopg2 is checked by connect_to_db()
-    # from ansible.module_utils.postgres
-    pass
-
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.six import iteritems
-
-from ansible_collections.community.postgresql.plugins.module_utils.database import (
-    check_input,
-)
+from ansible_collections.community.postgresql.plugins.module_utils.database import \
+    check_input
 from ansible_collections.community.postgresql.plugins.module_utils.postgres import (
     connect_to_db,
-    exec_sql,
     ensure_required_libs,
+    exec_sql,
     get_conn_params,
+    pg_cursor_args,
     postgres_common_argument_spec,
+    set_autocommit,
+    set_comment,
 )
 
 
@@ -209,12 +214,12 @@ class PgTablespace(object):
 
     Args:
         module (AnsibleModule) -- object of AnsibleModule class
-        cursor (cursor) -- cursor object of psycopg2 library
+        cursor (cursor) -- cursor object of psycopg library
         name (str) -- name of the tablespace
 
     Attrs:
         module (AnsibleModule) -- object of AnsibleModule class
-        cursor (cursor) -- cursor object of psycopg2 library
+        cursor (cursor) -- cursor object of psycopg library
         name (str) -- name of the tablespace
         exists (bool) -- flag the tablespace exists in the DB or not
         owner (str) -- tablespace owner
@@ -235,6 +240,7 @@ class PgTablespace(object):
         self.executed_queries = []
         self.new_name = ''
         self.opt_not_supported = False
+        self.comment = None
         # Collect info:
         self.get_info()
 
@@ -256,12 +262,14 @@ class PgTablespace(object):
 
         if not opt:
             self.opt_not_supported = True
-            query = ("SELECT r.rolname, (SELECT Null), %s "
+            query = ("SELECT shobj_description(t.oid, 'pg_tablespace') AS comment, "
+                     "r.rolname, (SELECT Null) spcoptions, %s loc_string "
                      "FROM pg_catalog.pg_tablespace AS t "
                      "JOIN pg_catalog.pg_roles AS r "
                      "ON t.spcowner = r.oid " % location)
         else:
-            query = ("SELECT r.rolname, t.spcoptions, %s "
+            query = ("SELECT shobj_description(t.oid, 'pg_tablespace') AS comment, "
+                     "r.rolname, t.spcoptions, %s loc_string "
                      "FROM pg_catalog.pg_tablespace AS t "
                      "JOIN pg_catalog.pg_roles AS r "
                      "ON t.spcowner = r.oid " % location)
@@ -273,19 +281,21 @@ class PgTablespace(object):
             self.exists = False
             return False
 
-        if res[0][0]:
+        if res[0]["rolname"]:
             self.exists = True
-            self.owner = res[0][0]
+            self.owner = res[0]["rolname"]
 
-            if res[0][1]:
+            if res[0]["spcoptions"]:
                 # Options exist:
-                for i in res[0][1]:
+                for i in res[0]["spcoptions"]:
                     i = i.split('=')
                     self.settings[i[0]] = i[1]
 
-            if res[0][2]:
+            if res[0]["loc_string"]:
                 # Location exists:
-                self.location = res[0][2]
+                self.location = res[0]["loc_string"]
+
+            self.comment = res[0]["comment"] if res[0]["comment"] is not None else ''
 
     def create(self, location):
         """Create tablespace.
@@ -319,6 +329,20 @@ class PgTablespace(object):
         query = 'ALTER TABLESPACE "%s" OWNER TO "%s"' % (self.name, new_owner)
         return exec_sql(self, query, return_bool=True)
 
+    def set_comment(self, comment, check_mode):
+        """Set tablespace comment.
+
+        Return True if success, otherwise, return False.
+
+        args:
+            comment (str) -- comment to set for the tablespace"
+        """
+        if comment == self.comment:
+            return False
+
+        return set_comment(self.cursor, comment, 'tablespace', self.name,
+                           check_mode, self.executed_queries)
+
     def rename(self, newname):
         """Rename tablespace.
 
@@ -398,6 +422,7 @@ def main():
         db=dict(type='str', aliases=['login_db']),
         session_role=dict(type='str'),
         trust_input=dict(type='bool', default=True),
+        comment=dict(type='str', default=None),
     )
 
     module = AnsibleModule(
@@ -414,6 +439,7 @@ def main():
     settings = module.params["set"]
     session_role = module.params["session_role"]
     trust_input = module.params["trust_input"]
+    comment = module.params["comment"]
 
     if state == 'absent' and (location or owner or rename_to or settings):
         module.fail_json(msg="state=absent is mutually exclusive location, "
@@ -427,20 +453,13 @@ def main():
             settings_list = ['%s = %s' % (k, v) for k, v in iteritems(settings)]
 
         check_input(module, tablespace, location, owner,
-                    rename_to, session_role, settings_list)
+                    rename_to, session_role, settings_list, comment)
 
-    # Ensure psycopg2 libraries are available before connecting to DB:
+    # Ensure psycopg libraries are available before connecting to DB:
     ensure_required_libs(module)
     conn_params = get_conn_params(module, module.params, warn_db_default=False)
-    db_connection, dummy = connect_to_db(module, conn_params, autocommit=True)
-    cursor = db_connection.cursor(cursor_factory=DictCursor)
-
-    # Change autocommit to False if check_mode:
-    if module.check_mode:
-        if PSYCOPG2_VERSION >= '2.4.2':
-            db_connection.set_session(autocommit=False)
-        else:
-            db_connection.set_isolation_level(READ_COMMITTED)
+    db_connection, dummy = connect_to_db(module, conn_params, autocommit=False if module.check_mode else True)
+    cursor = db_connection.cursor(**pg_cursor_args)
 
     # Set defaults:
     autocommit = False
@@ -466,26 +485,15 @@ def main():
 
         # Because CREATE TABLESPACE can not be run inside the transaction block:
         autocommit = True
-        if PSYCOPG2_VERSION >= '2.4.2':
-            db_connection.set_session(autocommit=True)
-        else:
-            db_connection.set_isolation_level(AUTOCOMMIT)
+        set_autocommit(db_connection, True)
 
         changed = tblspace.create(location)
 
-    # Drop non-existing tablespace:
-    elif not tblspace.exists and state == 'absent':
-        # Nothing to do:
-        module.fail_json(msg="Tries to drop nonexistent tablespace '%s'" % tblspace.name)
-
     # Drop existing tablespace:
     elif tblspace.exists and state == 'absent':
         # Because DROP TABLESPACE can not be run inside the transaction block:
         autocommit = True
-        if PSYCOPG2_VERSION >= '2.4.2':
-            db_connection.set_session(autocommit=True)
-        else:
-            db_connection.set_isolation_level(AUTOCOMMIT)
+        set_autocommit(db_connection, True)
 
         changed = tblspace.drop()
 
@@ -498,14 +506,18 @@ def main():
         # Refresh information:
         tblspace.get_info()
 
-    # Change owner and settings:
+    # Change owner, comment and settings:
     if state == 'present' and tblspace.exists:
         if owner:
-            changed = tblspace.set_owner(owner)
+            changed = tblspace.set_owner(owner) or changed
 
         if settings:
-            changed = tblspace.set_settings(settings)
+            changed = tblspace.set_settings(settings) or changed
 
+        if comment is not None:
+            changed = tblspace.set_comment(comment, module.check_mode) or changed
+
+        # Update tablespace information in the class
         tblspace.get_info()
 
     # Rollback if it's possible and check_mode:
@@ -527,6 +539,7 @@ def main():
         queries=tblspace.executed_queries,
         options=tblspace.settings,
         location=tblspace.location,
+        comment=tblspace.comment,
     )
 
     if state == 'present':
