@@ -8,7 +8,7 @@ __metaclass__ = type
 
 from ansible_collections.community.routeros.tests.unit.compat.mock import patch, MagicMock
 from ansible_collections.community.routeros.tests.unit.plugins.modules.fake_api import (
-    FakeLibRouterosError, fake_ros_api, massage_expected_result_data, create_fake_path,
+    FAKE_ROS_VERSION, FakeLibRouterosError, fake_ros_api, massage_expected_result_data, create_fake_path,
 )
 from ansible_collections.community.routeros.tests.unit.plugins.modules.utils import set_module_args, AnsibleExitJson, AnsibleFailJson, ModuleTestCase
 from ansible_collections.community.routeros.plugins.modules import api_modify
@@ -302,6 +302,10 @@ class TestRouterosApiModifyModule(ModuleTestCase):
             'ansible_collections.community.routeros.plugins.modules.api_modify.create_api',
             MagicMock(new=fake_ros_api))
         self.patch_create_api.start()
+        self.patch_get_api_version = patch(
+            'ansible_collections.community.routeros.plugins.modules.api_modify.get_api_version',
+            MagicMock(return_value=FAKE_ROS_VERSION))
+        self.patch_get_api_version.start()
         self.config_module_args = {
             'username': 'admin',
             'password': 'pаss',
@@ -309,6 +313,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
         }
 
     def tearDown(self):
+        self.patch_get_api_version.stop()
         self.patch_create_api.stop()
 
     def test_module_fail_when_required_args_missing(self):
@@ -600,6 +605,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.1',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*A',
@@ -607,6 +613,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'text': 'Router Text Entry',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*7',
@@ -614,6 +621,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*NEW1',
@@ -621,6 +629,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'text': 'Router Text Entry 2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
         ])
 
@@ -661,6 +670,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.1',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*A',
@@ -668,6 +678,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'text': 'Router Text Entry',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*7',
@@ -675,6 +686,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*NEW1',
@@ -682,6 +694,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'text': 'Router Text Entry 2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
         ])
 
@@ -723,6 +736,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.1',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*A',
@@ -730,6 +744,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'text': 'Router Text Entry',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*7',
@@ -737,6 +752,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 'name': 'router',
@@ -782,6 +798,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.1',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*A',
@@ -789,6 +806,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'text': 'Router Text Entry 2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*7',
@@ -796,6 +814,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
         ])
 
@@ -838,6 +857,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.1',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*A',
@@ -845,6 +865,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'text': 'Router Text Entry 2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*7',
@@ -852,6 +873,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
         ])
 
@@ -894,6 +916,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.1',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*7',
@@ -901,6 +924,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*NEW1',
@@ -908,6 +932,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'cname': 'router.com.',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
         ])
 
@@ -951,6 +976,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.1',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*7',
@@ -958,6 +984,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 'name': 'router',
@@ -1003,6 +1030,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.1',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*A',
@@ -1011,6 +1039,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'text': 'Router Text Entry 2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*7',
@@ -1018,6 +1047,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
         ])
 
@@ -1060,6 +1090,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.1',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*A',
@@ -1068,6 +1099,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'text': 'Router Text Entry 2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*7',
@@ -1075,6 +1107,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
         ])
 
@@ -1109,6 +1142,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.1',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
         ])
 
@@ -1144,6 +1178,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.1',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
         ])
 
@@ -1190,6 +1225,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*NEW1',
@@ -1197,6 +1233,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'text': 'bar',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*A',
@@ -1204,6 +1241,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'text': 'Router Text Entry',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*1',
@@ -1212,6 +1250,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.1',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
         ])
 
@@ -1259,6 +1298,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.2',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 'name': 'foo',
@@ -1270,6 +1310,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'text': 'Router Text Entry',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*1',
@@ -1278,6 +1319,7 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'address': '192.168.88.1',
                 'ttl': '1d',
                 'disabled': False,
+                'match-subdomain': False,
             },
         ])
 
