@@ -38,7 +38,7 @@ DOCUMENTATION = '''
           - If the cache is disabled, the files will be decrypted for almost every task. This is very slow!
           - Only disable caching if you modify the variable files during a playbook run and want the updated
             result to be available from the next task on.
-          - "Note that setting I(stage) to C(inventory) has the same effect as setting I(cache) to C(true):
+          - "Note that setting O(stage=inventory) has the same effect as setting O(cache=true):
              the variables will be loaded only once (during inventory loading) and the vars plugin will not
              be called for every task."
         type: bool
@@ -64,14 +64,12 @@ DOCUMENTATION = '''
         - community.sops.sops.ansible_env
         - community.sops.sops.ansible_ini
     seealso:
-        - ref: community.sops.sops lookup <ansible_collections.community.sops.sops_lookup>
+        - plugin: community.sops.sops
+          plugin_type: lookup
           description: The sops lookup can be used decrypt sops-encrypted files.
-        # - plugin: community.sops.sops
-        #   plugin_type: lookup
-        - ref: community.sops.decrypt filter <ansible_collections.community.sops.decrypt_filter>
+        - plugin: community.sops.decrypt
+          plugin_type: filter
           description: The decrypt filter can be used to descrypt sops-encrypted in-memory data.
-        # - plugin: community.sops.decrypt
-        #   plugin_type: filter
         - module: community.sops.load_vars
 '''
 
@@ -137,7 +135,7 @@ class VarsModule(BaseVarsPlugin):
                         if os.path.exists(b_opath):
                             if os.path.isdir(b_opath):
                                 self._display.debug("\tprocessing dir %s" % opath)
-                                # NOTE: iterating without extension allow retriving files recursively
+                                # NOTE: iterating without extension allow retrieving files recursively
                                 # A filter is then applied by iterating on all results and filtering by
                                 # extension.
                                 # See:
