@@ -24,7 +24,7 @@ DOCUMENTATION = r'''
     options:
         hostname:
             description: Name of vCenter or ESXi server.
-            required: True
+            required: true
             env:
               - name: VMWARE_HOST
               - name: VMWARE_SERVER
@@ -32,7 +32,8 @@ DOCUMENTATION = r'''
             description:
             - Name of vSphere user.
             - Accepts vault encrypted variable.
-            required: True
+            - Accepts Jinja to template the value
+            required: true
             env:
               - name: VMWARE_USER
               - name: VMWARE_USERNAME
@@ -40,7 +41,8 @@ DOCUMENTATION = r'''
             description:
             - Password of vSphere user.
             - Accepts vault encrypted variable.
-            required: True
+            - Accepts Jinja to template the value
+            required: true
             env:
               - name: VMWARE_PASSWORD
         port:
@@ -52,8 +54,8 @@ DOCUMENTATION = r'''
         validate_certs:
             description:
             - Allows connection when SSL certificates are not valid.
-            - Set to C(false) when certificates are not trusted.
-            default: True
+            - Set to V(false) when certificates are not trusted.
+            default: true
             type: bool
             env:
               - name: VMWARE_VALIDATE_CERTS
@@ -63,13 +65,13 @@ DOCUMENTATION = r'''
             - Requires 'vSphere Automation SDK' library to be installed on the given controller machine.
             - Please refer following URLs for installation steps
             - U(https://code.vmware.com/web/sdk/7.0/vsphere-automation-python)
-            default: False
+            default: false
             type: bool
         hostnames:
             description:
             - A list of templates in order of precedence to compose inventory_hostname.
             - Ignores template if resulted in an empty string or None value.
-            - You can use property specified in I(properties) as variables in the template.
+            - You can use property specified in O(properties) as variables in the template.
             type: list
             elements: string
             default: ['config.name + "_" + config.uuid']
@@ -78,15 +80,15 @@ DOCUMENTATION = r'''
             - Specify the list of VMware schema properties associated with the VM.
             - These properties will be populated in hostvars of the given VM.
             - Each value in the list can be a path to a specific property in VM object or a path to a collection of VM objects.
-            - C(config.name), C(config.uuid) are required properties if C(hostnames) is set to default.
-            - C(config.guestId), C(summary.runtime.powerState) are required if C(keyed_groups) is set to default.
+            - V(config.name), V(config.uuid) are required properties if O(hostnames) is set to default.
+            - V(config.guestId), V(summary.runtime.powerState) are required if O(keyed_groups) is set to default.
             - Please make sure that all the properties that are used in other parameters are included in this options.
             - In addition to VM properties, the following are special values
-            - Use C(customValue) to populate virtual machine's custom attributes. C(customValue) is only supported by vCenter and not by ESXi.
-            - Use C(all) to populate all the properties of the virtual machine.
-              The value C(all) is time consuming operation, do not use unless required absolutely.
+            - Use V(customValue) to populate virtual machine's custom attributes. V(customValue) is only supported by vCenter and not by ESXi.
+            - Use V(all) to populate all the properties of the virtual machine.
+              The value V(all) is time consuming operation, do not use unless required absolutely.
             - Please refer more VMware guest attributes which can be used as properties
-              U(https://github.com/ansible/ansible/blob/devel/docs/docsite/rst/scenario_guides/vmware_scenarios/vmware_inventory_vm_attributes.rst)
+              U(https://docs.ansible.com/ansible/latest/collections/community/vmware/docsite/vmware_scenarios/vmware_inventory_vm_attributes.html)
             type: list
             elements: string
             default: [ 'name', 'config.cpuHotAddEnabled', 'config.cpuHotRemoveEnabled',
@@ -98,9 +100,8 @@ DOCUMENTATION = r'''
         with_nested_properties:
             description:
             - This option transform flatten properties name to nested dictionary.
-            - From 1.10.0 and onwards, default value is set to C(True).
             type: bool
-            default: True
+            default: true
         keyed_groups:
             description:
             - Add hosts to group based on the values of a variable.
@@ -120,9 +121,9 @@ DOCUMENTATION = r'''
             description:
             - A list of resources to limit search scope.
             - Each resource item is represented by exactly one C('vim_type_snake_case):C(list of resource names) pair and optional nested I(resources)
-            - Key name is based on snake case of a vim type name; e.g C(host_system) correspond to C(vim.HostSystem)
+            - Key name is based on snake case of a vim type name; e.g V(host_system) correspond to C(vim.HostSystem)
             - See  L(VIM Types,https://pubs.vmware.com/vi-sdk/visdk250/ReferenceGuide/index-mo_types.html)
-            required: False
+            required: false
             type: list
             elements: dict
             default: []
@@ -130,28 +131,27 @@ DOCUMENTATION = r'''
             description:
             - Include virtual machines path.
             - Set this option to a string value to replace root name from I('Datacenters').
-            default: False
+            default: false
             type: bool
         with_sanitized_property_name:
             description:
                 - This option allows property name sanitization to create safe property names for use in Ansible.
                 - Also, transforms property name to snake case.
             type: bool
-            default: False
+            default: false
         proxy_host:
           description:
           - Address of a proxy that will receive all HTTPS requests and relay them.
           - The format is a hostname or a IP.
-          - This feature depends on a version of pyvmomi>=v6.7.1.2018.12.
           type: str
-          required: False
+          required: false
           env:
             - name: VMWARE_PROXY_HOST
         proxy_port:
           description:
           - Port of the HTTP proxy that will receive all HTTPS requests and relay them.
           type: int
-          required: False
+          required: false
           env:
             - name: VMWARE_PROXY_PORT
 '''
@@ -159,20 +159,29 @@ DOCUMENTATION = r'''
 EXAMPLES = r'''
 # Sample configuration file for VMware Guest dynamic inventory
     plugin: community.vmware.vmware_vm_inventory
-    strict: False
+    strict: false
     hostname: 10.65.223.31
     username: administrator@vsphere.local
     password: Esxi@123$%
-    validate_certs: False
-    with_tags: True
+    validate_certs: false
+    with_tags: true
+
+# Sample configuration file for VMware Guest dynamic inventory using Jinja to template the username and password.
+    plugin: community.vmware.vmware_vm_inventory
+    strict: false
+    hostname: 10.65.223.31
+    username: '{{ (lookup("file","~/.config/vmware.yaml") | from_yaml).username }}'
+    password: '{{ (lookup("file","~/.config/vmware.yaml") | from_yaml).password }}'
+    validate_certs: false
+    with_tags: true
 
 # Gather minimum set of properties for VMware guest
     plugin: community.vmware.vmware_vm_inventory
-    strict: False
+    strict: false
     hostname: 10.65.223.31
     username: administrator@vsphere.local
     password: Esxi@123$%
-    validate_certs: False
+    validate_certs: false
     properties:
     - 'name'
     - 'guest.ipAddress'
@@ -181,11 +190,11 @@ EXAMPLES = r'''
 
 # Create Groups based upon VMware Tools status
     plugin: community.vmware.vmware_vm_inventory
-    strict: False
+    strict: false
     hostname: 10.65.223.31
     username: administrator@vsphere.local
     password: Esxi@123$%
-    validate_certs: False
+    validate_certs: false
     properties:
     - 'name'
     - 'config.name'
@@ -201,11 +210,11 @@ EXAMPLES = r'''
 
 # Filter VMs based upon condition
     plugin: community.vmware.vmware_vm_inventory
-    strict: False
+    strict: false
     hostname: 10.65.223.31
     username: administrator@vsphere.local
     password: Esxi@123$%
-    validate_certs: False
+    validate_certs: false
     properties:
     - 'runtime.powerState'
     - 'config.name'
@@ -216,11 +225,11 @@ EXAMPLES = r'''
 
 # Filter VM's based on OR conditions
     plugin: community.vmware.vmware_vm_inventory
-    strict: False
+    strict: false
     hostname: 10.65.223.31
     username: administrator@vsphere.local
     password: Esxi@123$%
-    validate_certs: False
+    validate_certs: false
     properties:
     - 'name'
     - 'config.name'
@@ -236,11 +245,11 @@ EXAMPLES = r'''
 
 # Filter VM's based on regex conditions
     plugin: community.vmware.vmware_vm_inventory
-    strict: False
+    strict: false
     hostname: 10.65.223.31
     username: administrator@vsphere.local
     password: Esxi@123$%
-    validate_certs: False
+    validate_certs: false
     properties:
     - 'config.name'
     - 'config.guestId'
@@ -251,11 +260,11 @@ EXAMPLES = r'''
 
 # Using compose and groups
     plugin: community.vmware.vmware_vm_inventory
-    strict: False
+    strict: false
     hostname: 10.65.223.31
     username: administrator@vsphere.local
     password: Esxi@123$%
-    validate_certs: False
+    validate_certs: false
     properties:
     - 'name'
     - 'config.name'
@@ -269,18 +278,18 @@ EXAMPLES = r'''
       ansible_user: "'admin'"
       ansible_connection: "'ssh'"
     groups:
-      VMs: True
+      VMs: true
     hostnames:
     - config.name
 
 # Use Datacenter, Cluster and Folder value to list VMs
     plugin: community.vmware.vmware_vm_inventory
-    strict: False
+    strict: false
     hostname: 10.65.200.241
     username: administrator@vsphere.local
     password: Esxi@123$%
-    validate_certs: False
-    with_tags: True
+    validate_certs: false
+    with_tags: true
     resources:
       - datacenter:
         - Asia-Datacenter1
@@ -297,11 +306,11 @@ EXAMPLES = r'''
 
 # Use Category and it's relation with Tag
     plugin: community.vmware.vmware_vm_inventory
-    strict: False
+    strict: false
     hostname: 10.65.201.128
     username: administrator@vsphere.local
     password: Esxi@123$%
-    validate_certs: False
+    validate_certs: false
     hostnames:
     - 'config.name'
     properties:
@@ -309,22 +318,22 @@ EXAMPLES = r'''
     - 'config.guestId'
     - 'guest.ipAddress'
     - 'summary.runtime.powerState'
-    with_tags: True
+    with_tags: true
     keyed_groups:
     - key: tag_category.OS
       prefix: "vmware_tag_os_category_"
       separator: ""
-    with_nested_properties: True
+    with_nested_properties: true
     filters:
     - "tag_category.OS is defined and 'Linux' in tag_category.OS"
 
 # customizing hostnames based on VM's FQDN. The second hostnames template acts as a fallback mechanism.
     plugin: community.vmware.vmware_vm_inventory
-    strict: False
+    strict: false
     hostname: 10.65.223.31
     username: administrator@vsphere.local
     password: Esxi@123$%
-    validate_certs: False
+    validate_certs: false
     hostnames:
      - 'config.name+"."+guest.ipStack.0.dnsConfig.domainName'
      - 'config.name'
@@ -338,11 +347,11 @@ EXAMPLES = r'''
 
 # Select a specific IP address for use by ansible when multiple NICs are present on the VM
     plugin: community.vmware.vmware_vm_inventory
-    strict: False
+    strict: false
     hostname: 10.65.223.31
     username: administrator@vsphere.local
     password: Esxi@123$%
-    validate_certs: False
+    validate_certs: false
     compose:
       # Set the IP address used by ansible to one that starts by 10.42. or 10.43.
       ansible_host: >-
@@ -355,6 +364,23 @@ EXAMPLES = r'''
         | first
     properties:
       - guest.net
+
+# Group hosts using Jinja2 conditionals
+    plugin: community.vmware.vmware_vm_inventory
+    strict: false
+    hostname: 10.65.13.37
+    username: administrator@vsphere.local
+    password: Esxi@123$%
+    validate_certs: false
+    hostnames:
+    - config.name
+    properties:
+    - 'name'
+    - 'config.name'
+    - 'config.datastoreUrl'
+    groups:
+      slow_storage: "'Nas01' in config.datastoreUrl[0].name"
+      fast_storage: "'SSD' in config.datastoreUrl[0].name"
 '''
 
 from ansible.errors import AnsibleError, AnsibleParserError
@@ -641,12 +667,16 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         username = self.get_option('username')
         password = self.get_option('password')
 
-        if isinstance(username, AnsibleVaultEncryptedUnicode):
-            username = username.data
-
-        if isinstance(password, AnsibleVaultEncryptedUnicode):
+        if self.templar.is_template(password):
+            password = self.templar.template(variable=password, disable_lookups=False)
+        elif isinstance(password, AnsibleVaultEncryptedUnicode):
             password = password.data
 
+        if self.templar.is_template(username):
+            username = self.templar.template(variable=username, disable_lookups=False)
+        elif isinstance(username, AnsibleVaultEncryptedUnicode):
+            username = username.data
+
         self.pyv = BaseVMwareInventory(
             hostname=self.get_option('hostname'),
             username=username,
