@@ -20,8 +20,8 @@ except ImportError:
 
 PYVMOMI_IMP_ERR = None
 try:
-    from pyVim import connect  # noqa: F401
-    from pyVmomi import vim  # noqa: F401
+    from pyVim import connect  # noqa: F401, pylint: disable=unused-import
+    from pyVmomi import vim  # noqa: F401, pylint: disable=unused-import
     HAS_PYVMOMI = True
 except ImportError:
     PYVMOMI_IMP_ERR = traceback.format_exc()
@@ -44,6 +44,16 @@ except ImportError:
     VSPHERE_IMP_ERR = traceback.format_exc()
     HAS_VSPHERE = False
 
+try:
+    from requests.packages import urllib3
+    HAS_URLLIB3 = True
+except ImportError:
+    try:
+        import urllib3
+        HAS_URLLIB3 = True
+    except ImportError:
+        HAS_URLLIB3 = False
+
 from ansible.module_utils.basic import env_fallback, missing_required_lib
 from ansible.module_utils._text import to_native
 
@@ -131,13 +141,17 @@ class VmwareRestClient(object):
         username = self.params.get('username')
         password = self.params.get('password')
         hostname = self.params.get('hostname')
+        validate_certs = self.params.get('validate_certs')
         port = self.params.get('port')
         session = requests.Session()
-        session.verify = self.params.get('validate_certs')
+        session.verify = validate_certs
         protocol = self.params.get('protocol')
         proxy_host = self.params.get('proxy_host')
         proxy_port = self.params.get('proxy_port')
 
+        if validate_certs is False:
+            if HAS_URLLIB3:
+                urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
         if all([protocol, proxy_host, proxy_port]):
             proxies = {protocol: "{0}://{1}:{2}".format(protocol, proxy_host, proxy_port)}
             session.proxies.update(proxies)
@@ -165,18 +179,24 @@ class VmwareRestClient(object):
 
         return client
 
-    def get_tags_for_object(self, tag_service=None, tag_assoc_svc=None, dobj=None):
+    def get_tags_for_object(self, tag_service=None, tag_assoc_svc=None, dobj=None, tags=None):
         """
-        Return list of tag objects associated with an object
+        Return tag objects associated with an object
         Args:
             dobj: Dynamic object
             tag_service: Tag service object
             tag_assoc_svc: Tag Association object
-        Returns: List of tag objects associated with the given object
+            tags: List or set to which the tag objects are being added, reference is returned by the method
+        Returns: Tag objects associated with the given object
         """
-        # This method returns list of tag objects only,
+        # This method returns tag objects only,
         # Please use get_tags_for_dynamic_obj for more object details
-        tags = []
+        if tags is None:
+            tags = []
+
+        if not (isinstance(tags, list) or isinstance(tags, set)):
+            self.module.fail_json(msg="The parameter 'tags' must be of type 'list' or 'set', but type %s was passed" % type(tags))
+
         if not dobj:
             return tags
 
@@ -187,21 +207,29 @@ class VmwareRestClient(object):
             tag_assoc_svc = self.api_client.tagging.TagAssociation
 
         tag_ids = tag_assoc_svc.list_attached_tags(dobj)
+
+        add_tag = tags.append if isinstance(tags, list) else tags.add
         for tag_id in tag_ids:
-            tags.append(tag_service.get(tag_id))
+            add_tag(tag_service.get(tag_id))
 
         return tags
 
-    def get_tags_for_dynamic_obj(self, dobj=None):
+    def get_tags_for_dynamic_obj(self, dobj=None, tags=None):
         """
-        Return list of tag object details associated with object
+        Return tag object details associated with object
         Args:
             mid: Dynamic object for specified object
+            tags: List or set to which the tag objects are being added, reference is returned by the method
 
-        Returns: List of tag object details associated with the given object
+        Returns: Tag object details associated with the given object
 
         """
-        tags = []
+        if tags is None:
+            tags = []
+
+        if not (isinstance(tags, list) or isinstance(tags, set)):
+            self.module.fail_json(msg="The parameter 'tags' must be of type 'list' or 'set', but type %s was passed" % type(tags))
+
         if dobj is None:
             return tags
 
@@ -209,8 +237,9 @@ class VmwareRestClient(object):
 
         category_service = self.api_client.tagging.Category
 
+        add_tag = tags.append if isinstance(tags, list) else tags.add
         for tag_obj in temp_tags_model:
-            tags.append({
+            add_tag({
                 'id': tag_obj.id,
                 'category_name': category_service.get(tag_obj.category_id).name,
                 'name': tag_obj.name,
@@ -486,32 +515,41 @@ class VmwareRestClient(object):
 
         return self.search_svc_object_by_name(service=self.api_client.tagging.Category, svc_obj_name=category_name)
 
-    def get_tag_by_category(self, tag_name=None, category_name=None, category_id=None):
+    def get_tag_by_category_id(self, tag_name=None, category_id=None):
         """
-        Return tag object by name and category name specified
+        Return tag object by category id
         Args:
             tag_name: Name of tag
-            category_name: Name of category (mutually exclusive with 'category_id')
-            category_id: Id of category, if known in advance (mutually exclusive with 'category_name')
+            category_id: Id of category
         Returns: Tag object if found else None
         """
-
-        if not tag_name:
+        if tag_name is None:
             return None
 
-        if category_id or category_name:
-            if not category_id:
-                category_obj = self.get_category_by_name(category_name=category_name)
+        if category_id is None:
+            return self.search_svc_object_by_name(service=self.api_client.tagging.Tag, svc_obj_name=tag_name)
 
-                if not category_obj:
-                    return None
+        result = None
+        for tag_id in self.api_client.tagging.Tag.list_tags_for_category(category_id):
+            tag_obj = self.api_client.tagging.Tag.get(tag_id)
+            if tag_obj.name == tag_name:
+                result = tag_obj
+                break
 
+        return result
+
+    def get_tag_by_category_name(self, tag_name=None, category_name=None):
+        """
+        Return tag object by category name
+        Args:
+            tag_name: Name of tag
+            category_id: Id of category
+        Returns: Tag object if found else None
+        """
+        category_id = None
+        if category_name is not None:
+            category_obj = self.get_category_by_name(category_name=category_name)
+            if category_obj is not None:
                 category_id = category_obj.id
 
-            for tag_object in self.api_client.tagging.Tag.list_tags_for_category(category_id):
-                tag_obj = self.api_client.tagging.Tag.get(tag_object)
-
-                if tag_obj.name == tag_name:
-                    return tag_obj
-        else:
-            return self.search_svc_object_by_name(service=self.api_client.tagging.Tag, svc_obj_name=tag_name)
+        return self.get_tag_by_category_id(tag_name=tag_name, category_id=category_id)
