@@ -7,7 +7,7 @@
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-DOCUMENTATION = r'''
+DOCUMENTATION = r"""
 ---
 module: zabbix_discovery_rule
 short_description: Create/delete/update Zabbix discovery rules
@@ -18,7 +18,7 @@ description:
 author:
     - "Tobias Birkefeld (@tcraxs)"
 requirements:
-    - "python >= 2.6"
+    - "python >= 3.9"
 options:
     state:
         description:
@@ -46,22 +46,22 @@ options:
                 description:
                     - Type of check.
                 type: str
-                choices: ['SSH',
-                          'LDAP',
-                          'SMTP',
-                          'FTP',
-                          'HTTP',
-                          'POP',
-                          'NNTP',
-                          'IMAP',
-                          'TCP',
-                          'Zabbix',
-                          'SNMPv1',
-                          'SNMPv2',
-                          'ICMP',
-                          'SNMPv3',
-                          'HTTPS',
-                          'Telnet']
+                choices: ["SSH",
+                          "LDAP",
+                          "SMTP",
+                          "FTP",
+                          "HTTP",
+                          "POP",
+                          "NNTP",
+                          "IMAP",
+                          "TCP",
+                          "Zabbix",
+                          "SNMPv1",
+                          "SNMPv2",
+                          "ICMP",
+                          "SNMPv3",
+                          "HTTPS",
+                          "Telnet"]
             ports:
                 description:
                     - One or several port ranges to check separated by commas. Used for all checks except for ICMP.
@@ -173,23 +173,22 @@ options:
         type: str
         default: "enabled"
         choices: ["enabled", "disabled"]
-notes:
-    - Only Zabbix >= 4.0 is supported.
+
 extends_documentation_fragment:
     - community.zabbix.zabbix
-'''
+"""
 
-EXAMPLES = r'''
+EXAMPLES = r"""
 # If you want to use Username and Password to be authenticated by Zabbix Server
 - name: Set credentials to access Zabbix Server API
-  set_fact:
+  ansible.builtin.set_fact:
     ansible_user: Admin
     ansible_httpapi_pass: zabbix
 
 # If you want to use API token to be authenticated by Zabbix Server
 # https://www.zabbix.com/documentation/current/en/manual/web_interface/frontend_sections/administration/general#api-tokens
 - name: Set API token
-  set_fact:
+  ansible.builtin.set_fact:
     ansible_zabbix_auth_key: 8ec0d52432c15c91fcafe9888500cf9a607f44091ab554dbee860f6b44fac895
 
 # Base create discovery rule example
@@ -201,7 +200,7 @@ EXAMPLES = r'''
     ansible_httpapi_port: 443
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
-    ansible_zabbix_url_path: 'zabbixeu'  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
+    ansible_zabbix_url_path: "zabbixeu"  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
     ansible_host: zabbix-example-fqdn.org
   community.zabbix.zabbix_discovery_rule:
     name: ACME
@@ -224,7 +223,7 @@ EXAMPLES = r'''
     ansible_httpapi_port: 443
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
-    ansible_zabbix_url_path: 'zabbixeu'  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
+    ansible_zabbix_url_path: "zabbixeu"  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
     ansible_host: zabbix-example-fqdn.org
   community.zabbix.zabbix_discovery_rule:
     name: ACME
@@ -255,35 +254,35 @@ EXAMPLES = r'''
     ansible_httpapi_port: 443
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
-    ansible_zabbix_url_path: 'zabbixeu'  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
+    ansible_zabbix_url_path: "zabbixeu"  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
     ansible_host: zabbix-example-fqdn.org
   community.zabbix.zabbix_discovery_rule:
     name: ACME
     state: absent
-'''
+"""
 
-RETURN = r'''
+RETURN = r"""
 state:
   description: Discovery rule state at the end of execution.
   returned: on success
   type: str
-  sample: 'present'
+  sample: "present"
 drule:
   description: Discovery rule name.
   returned: on success
   type: str
-  sample: 'ACME'
+  sample: "ACME"
 druleid:
     description: Discovery rule id.
     returned: on success
     type: str
-    sample: '42'
+    sample: "42"
 msg:
     description: The result of the operation
     returned: always
     type: str
-    sample: 'Discovery rule created: ACME, ID: 42'
-'''
+    sample: "Discovery rule created: ACME, ID: 42"
+"""
 
 
 from ansible.module_utils.basic import AnsibleModule
@@ -312,72 +311,71 @@ class Dchecks(ZabbixBase):
         constructed_data = []
         for check in _dchecks:
             constructed_check = {
-                'type': zabbix_utils.helper_to_numeric_value([
-                    'SSH',
-                    'LDAP',
-                    'SMTP',
-                    'FTP',
-                    'HTTP',
-                    'POP',
-                    'NNTP',
-                    'IMAP',
-                    'TCP',
-                    'Zabbix',
-                    'SNMPv1',
-                    'SNMPv2',
-                    'ICMP',
-                    'SNMPv3',
-                    'HTTPS',
-                    'Telnet'], check.get('type')
+                "type": zabbix_utils.helper_to_numeric_value([
+                    "SSH",
+                    "LDAP",
+                    "SMTP",
+                    "FTP",
+                    "HTTP",
+                    "POP",
+                    "NNTP",
+                    "IMAP",
+                    "TCP",
+                    "Zabbix",
+                    "SNMPv1",
+                    "SNMPv2",
+                    "ICMP",
+                    "SNMPv3",
+                    "HTTPS",
+                    "Telnet"], check.get("type")
                 ),
-                'uniq': int(check.get('uniq'))
+                "uniq": int(check.get("uniq"))
             }
-            if LooseVersion(self._zbx_api_version) >= LooseVersion('4.4'):
-                constructed_check.update({
-                    'host_source': zabbix_utils.helper_to_numeric_value([
-                        'None',
-                        'DNS',
-                        'IP',
-                        'discovery'], check.get('host_source')
-                    ),
-                    'name_source': zabbix_utils.helper_to_numeric_value([
-                        'None',
-                        'DNS',
-                        'IP',
-                        'discovery'], check.get('name_source')
-                    )
-                })
-            if constructed_check['type'] in (0, 1, 2, 3, 4, 5, 6, 7, 8, 14, 15):
-                constructed_check['ports'] = check.get('ports')
-            if constructed_check['type'] == 9:
-                constructed_check['ports'] = check.get('ports')
-                constructed_check['key_'] = check.get('key')
-            if constructed_check['type'] in (10, 11):
-                constructed_check['ports'] = check.get('ports')
-                constructed_check['snmp_community'] = check.get('snmp_community')
-                constructed_check['key_'] = check.get('key')
-            if constructed_check['type'] == 13:
-                constructed_check['ports'] = check.get('ports')
-                constructed_check['key_'] = check.get('key')
-                constructed_check['snmpv3_contextname'] = check.get('snmpv3_contextname')
-                constructed_check['snmpv3_securityname'] = check.get('snmpv3_securityname')
-                constructed_check['snmpv3_securitylevel'] = zabbix_utils.helper_to_numeric_value([
-                    'noAuthNoPriv',
-                    'authNoPriv',
-                    'authPriv'], check.get('snmpv3_securitylevel')
+            constructed_check.update({
+                "host_source": zabbix_utils.helper_to_numeric_value([
+                    "None",
+                    "DNS",
+                    "IP",
+                    "discovery"], check.get("host_source")
+                ),
+                "name_source": zabbix_utils.helper_to_numeric_value([
+                    "None",
+                    "DNS",
+                    "IP",
+                    "discovery"], check.get("name_source")
                 )
-                if constructed_check['snmpv3_securitylevel'] in (1, 2):
-                    constructed_check['snmpv3_authprotocol'] = zabbix_utils.helper_to_numeric_value([
-                        'MD5',
-                        'SHA'], check.get('snmpv3_authprotocol')
+            })
+            if constructed_check["type"] in (0, 1, 2, 3, 4, 5, 6, 7, 8, 14, 15):
+                constructed_check["ports"] = check.get("ports")
+            if constructed_check["type"] == 9:
+                constructed_check["ports"] = check.get("ports")
+                constructed_check["key_"] = check.get("key")
+            if constructed_check["type"] in (10, 11):
+                constructed_check["ports"] = check.get("ports")
+                constructed_check["snmp_community"] = check.get("snmp_community")
+                constructed_check["key_"] = check.get("key")
+            if constructed_check["type"] == 13:
+                constructed_check["ports"] = check.get("ports")
+                constructed_check["key_"] = check.get("key")
+                constructed_check["snmpv3_contextname"] = check.get("snmpv3_contextname")
+                constructed_check["snmpv3_securityname"] = check.get("snmpv3_securityname")
+                constructed_check["snmpv3_securitylevel"] = zabbix_utils.helper_to_numeric_value([
+                    "noAuthNoPriv",
+                    "authNoPriv",
+                    "authPriv"], check.get("snmpv3_securitylevel")
+                )
+                if constructed_check["snmpv3_securitylevel"] in (1, 2):
+                    constructed_check["snmpv3_authprotocol"] = zabbix_utils.helper_to_numeric_value([
+                        "MD5",
+                        "SHA"], check.get("snmpv3_authprotocol")
                     )
-                    constructed_check['snmpv3_authpassphrase'] = check.get('snmpv3_authpassphrase')
-                if constructed_check['snmpv3_securitylevel'] == 2:
-                    constructed_check['snmpv3_privprotocol'] = zabbix_utils.helper_to_numeric_value([
-                        'DES',
-                        'AES'], check.get('snmpv3_privprotocol')
+                    constructed_check["snmpv3_authpassphrase"] = check.get("snmpv3_authpassphrase")
+                if constructed_check["snmpv3_securitylevel"] == 2:
+                    constructed_check["snmpv3_privprotocol"] = zabbix_utils.helper_to_numeric_value([
+                        "DES",
+                        "AES"], check.get("snmpv3_privprotocol")
                     )
-                    constructed_check['snmpv3_privpassphrase'] = check.get('snmpv3_privpassphrase')
+                    constructed_check["snmpv3_privpassphrase"] = check.get("snmpv3_privpassphrase")
             constructed_data.append(constructed_check)
         return zabbix_utils.helper_cleanup_data(constructed_data)
 
@@ -392,9 +390,9 @@ class DiscoveryRule(ZabbixBase):
         """
         try:
             _drule = self._zapi.drule.get({
-                'output': 'extend',
-                'selectDChecks': 'extend',
-                'filter': {'name': [name]}
+                "output": "extend",
+                "selectDChecks": "extend",
+                "filter": {"name": [name]}
             })
             if len(_drule) > 0:
                 return _drule
@@ -411,9 +409,9 @@ class DiscoveryRule(ZabbixBase):
         """
         try:
             drule_list = self._zapi.drule.get({
-                'output': 'extend',
-                'selectDChecks': 'extend',
-                'filter': {'name': [name]}
+                "output": "extend",
+                "selectDChecks": "extend",
+                "filter": {"name": [name]}
             })
             if len(drule_list) < 1:
                 self._module.fail_json(msg="Discovery rule not found: %s" % name)
@@ -431,9 +429,9 @@ class DiscoveryRule(ZabbixBase):
         """
         try:
             proxy_list = self._zapi.proxy.get({
-                'output': 'extend',
-                'selectInterface': 'extend',
-                'filter': {'host': [proxy_name]}
+                "output": "extend",
+                "selectInterface": "extend",
+                "filter": {"host": [proxy_name]}
             })
             if len(proxy_list) < 1:
                 self._module.fail_json(msg="Proxy not found: %s" % proxy_name)
@@ -450,17 +448,17 @@ class DiscoveryRule(ZabbixBase):
             dict: dictionary of specified parameters
         """
         _params = {
-            'name': kwargs['name'],
-            'iprange': ','.join(kwargs['iprange']),
-            'delay': kwargs['delay'],
-            'status': zabbix_utils.helper_to_numeric_value([
-                'enabled',
-                'disabled'], kwargs['status']
+            "name": kwargs["name"],
+            "iprange": ",".join(kwargs["iprange"]),
+            "delay": kwargs["delay"],
+            "status": zabbix_utils.helper_to_numeric_value([
+                "enabled",
+                "disabled"], kwargs["status"]
             ),
-            'dchecks': kwargs['dchecks']
+            "dchecks": kwargs["dchecks"]
         }
-        if kwargs['proxy']:
-            _params['proxy_hostid'] = self.get_proxy_by_proxy_name(kwargs['proxy'])['proxyid']
+        if kwargs["proxy"]:
+            _params["proxy_hostid"] = self.get_proxy_by_proxy_name(kwargs["proxy"])["proxyid"]
         return _params
 
     def check_difference(self, **kwargs):
@@ -470,13 +468,13 @@ class DiscoveryRule(ZabbixBase):
         Returns:
             dict: dictionary of differences
         """
-        existing_drule = zabbix_utils.helper_convert_unicode_to_str(self.check_if_drule_exists(kwargs['name'])[0])
+        existing_drule = zabbix_utils.helper_convert_unicode_to_str(self.check_if_drule_exists(kwargs["name"])[0])
         parameters = zabbix_utils.helper_convert_unicode_to_str(self._construct_parameters(**kwargs))
         change_parameters = {}
-        if LooseVersion(self._zbx_api_version) < LooseVersion('6.4'):
-            if existing_drule['nextcheck']:
-                existing_drule.pop('nextcheck')
-        _diff = zabbix_utils.helper_cleanup_data(compare_dictionaries(parameters, existing_drule, change_parameters))
+        if LooseVersion(self._zbx_api_version) < LooseVersion("6.4"):
+            if existing_drule["nextcheck"]:
+                existing_drule.pop("nextcheck")
+        _diff = zabbix_utils.helper_cleanup_data(zabbix_utils.helper_compare_dictionaries(parameters, existing_drule, change_parameters))
         return _diff
 
     def update_drule(self, **kwargs):
@@ -488,11 +486,11 @@ class DiscoveryRule(ZabbixBase):
         """
         try:
             if self._module.check_mode:
-                self._module.exit_json(msg="Discovery rule would be updated if check mode was not specified: ID %s" % kwargs['drule_id'], changed=True)
-            kwargs['druleid'] = kwargs.pop('drule_id')
+                self._module.exit_json(msg="Discovery rule would be updated if check mode was not specified: ID %s" % kwargs["drule_id"], changed=True)
+            kwargs["druleid"] = kwargs.pop("drule_id")
             return self._zapi.drule.update(kwargs)
         except Exception as e:
-            self._module.fail_json(msg="Failed to update discovery rule ID '%s': %s" % (kwargs['drule_id'], e))
+            self._module.fail_json(msg="Failed to update discovery rule ID '%s': %s" % (kwargs["drule_id"], e))
 
     def add_drule(self, **kwargs):
         """Add discovery rule
@@ -506,9 +504,9 @@ class DiscoveryRule(ZabbixBase):
                 self._module.exit_json(msg="Discovery rule would be added if check mode was not specified", changed=True)
             parameters = self._construct_parameters(**kwargs)
             drule_list = self._zapi.drule.create(parameters)
-            return drule_list['druleids'][0]
+            return drule_list["druleids"][0]
         except Exception as e:
-            self._module.fail_json(msg="Failed to create discovery rule %s: %s" % (kwargs['name'], e))
+            self._module.fail_json(msg="Failed to create discovery rule %s: %s" % (kwargs["name"], e))
 
     def delete_drule(self, drule_id):
         """Delete discovery rule.
@@ -525,159 +523,90 @@ class DiscoveryRule(ZabbixBase):
             self._module.fail_json(msg="Failed to delete discovery rule '%s': %s" % (drule_id, e))
 
 
-def compare_lists(l1, l2, diff_dict):
-    """
-    Compares l1 and l2 lists and adds the items that are different
-    to the diff_dict dictionary.
-    Used in recursion with compare_dictionaries() function.
-    Args:
-        l1: first list to compare
-        l2: second list to compare
-        diff_dict: dictionary to store the difference
-    Returns:
-        dict: items that are different
-    """
-    if len(l1) != len(l2):
-        diff_dict.append(l1)
-        return diff_dict
-    for i, item in enumerate(l1):
-        if isinstance(item, dict):
-            diff_dict.insert(i, {})
-            diff_dict[i] = compare_dictionaries(item, l2[i], diff_dict[i])
-        else:
-            if item != l2[i]:
-                diff_dict.append(item)
-    while {} in diff_dict:
-        diff_dict.remove({})
-    return diff_dict
-
-
-def compare_dictionaries(d1, d2, diff_dict):
-    """
-    Compares d1 and d2 dictionaries and adds the items that are different
-    to the diff_dict dictionary.
-    Used in recursion with compare_lists() function.
-    Args:
-        d1: first dictionary to compare
-        d2: second dictionary to compare
-        diff_dict: dictionary to store the difference
-    Returns:
-        dict: items that are different
-    """
-    for k, v in d1.items():
-        if k not in d2:
-            diff_dict[k] = v
-            continue
-        if isinstance(v, dict):
-            diff_dict[k] = {}
-            compare_dictionaries(v, d2[k], diff_dict[k])
-            if diff_dict[k] == {}:
-                del diff_dict[k]
-            else:
-                diff_dict[k] = v
-        elif isinstance(v, list):
-            diff_dict[k] = []
-            compare_lists(v, d2[k], diff_dict[k])
-            if diff_dict[k] == []:
-                del diff_dict[k]
-            else:
-                diff_dict[k] = v
-        else:
-            if v != d2[k]:
-                diff_dict[k] = v
-    return diff_dict
-
-
 def main():
     argument_spec = zabbix_utils.zabbix_common_argument_spec()
     argument_spec.update(
-        name=dict(type='str', required=True),
-        iprange=dict(type='list', required=False, elements='str'),
+        name=dict(type="str", required=True),
+        iprange=dict(type="list", required=False, elements="str"),
         dchecks=dict(
-            type='list',
+            type="list",
             required=False,
-            aliases=['dcheck'],
-            elements='dict',
+            aliases=["dcheck"],
+            elements="dict",
             options=dict(
-                type=dict(type='str', choices=[
-                    'SSH',
-                    'LDAP',
-                    'SMTP',
-                    'FTP',
-                    'HTTP',
-                    'POP',
-                    'NNTP',
-                    'IMAP',
-                    'TCP',
-                    'Zabbix',
-                    'SNMPv1',
-                    'SNMPv2',
-                    'ICMP',
-                    'SNMPv3',
-                    'HTTPS',
-                    'Telnet']
+                type=dict(type="str", choices=[
+                    "SSH",
+                    "LDAP",
+                    "SMTP",
+                    "FTP",
+                    "HTTP",
+                    "POP",
+                    "NNTP",
+                    "IMAP",
+                    "TCP",
+                    "Zabbix",
+                    "SNMPv1",
+                    "SNMPv2",
+                    "ICMP",
+                    "SNMPv3",
+                    "HTTPS",
+                    "Telnet"]
                 ),
-                ports=dict(type='str'),
-                key=dict(type='str', no_log=False),
-                snmp_community=dict(type='str'),
-                snmpv3_authpassphrase=dict(type='str', no_log=True),
-                snmpv3_authprotocol=dict(type='str', choices=['MD5', 'SHA']),
-                snmpv3_contextname=dict(type='str'),
-                snmpv3_privpassphrase=dict(type='str', no_log=True),
-                snmpv3_privprotocol=dict(type='str', choices=['DES', 'AES']),
-                snmpv3_securitylevel=dict(type='str', choices=['noAuthNoPriv', 'authNoPriv', 'authPriv']),
-                snmpv3_securityname=dict(type='str'),
-                uniq=dict(type='bool', default=False),
-                host_source=dict(type='str', choices=['DNS', 'IP', 'discovery'], default='DNS'),
-                name_source=dict(type='str', choices=['None', 'DNS', 'IP', 'discovery'], default='None')
+                ports=dict(type="str"),
+                key=dict(type="str", no_log=False),
+                snmp_community=dict(type="str"),
+                snmpv3_authpassphrase=dict(type="str", no_log=True),
+                snmpv3_authprotocol=dict(type="str", choices=["MD5", "SHA"]),
+                snmpv3_contextname=dict(type="str"),
+                snmpv3_privpassphrase=dict(type="str", no_log=True),
+                snmpv3_privprotocol=dict(type="str", choices=["DES", "AES"]),
+                snmpv3_securitylevel=dict(type="str", choices=["noAuthNoPriv", "authNoPriv", "authPriv"]),
+                snmpv3_securityname=dict(type="str"),
+                uniq=dict(type="bool", default=False),
+                host_source=dict(type="str", choices=["DNS", "IP", "discovery"], default="DNS"),
+                name_source=dict(type="str", choices=["None", "DNS", "IP", "discovery"], default="None")
             ),
             required_if=[
-                ['type', 'SSH', ['ports']],
-                ['type', 'LDAP', ['ports']],
-                ['type', 'SMTP', ['ports']],
-                ['type', 'FTP', ['ports']],
-                ['type', 'HTTP', ['ports']],
-                ['type', 'POP', ['ports']],
-                ['type', 'NNTP', ['ports']],
-                ['type', 'IMAP', ['ports']],
-                ['type', 'TCP', ['ports']],
-                ['type', 'Zabbix', ['ports', 'key']],
-                ['type', 'SNMPv1', ['ports', 'key', 'snmp_community']],
-                ['type', 'SNMPv2', ['ports', 'key', 'snmp_community']],
-                ['type', 'SNMPv3', ['ports', 'key']],
-                ['type', 'HTTPS', ['ports']],
-                ['type', 'Telnet', ['ports']],
-                ['snmpv3_securitylevel', 'authPriv', ['snmpv3_privpassphrase']]
+                ["type", "SSH", ["ports"]],
+                ["type", "LDAP", ["ports"]],
+                ["type", "SMTP", ["ports"]],
+                ["type", "FTP", ["ports"]],
+                ["type", "HTTP", ["ports"]],
+                ["type", "POP", ["ports"]],
+                ["type", "NNTP", ["ports"]],
+                ["type", "IMAP", ["ports"]],
+                ["type", "TCP", ["ports"]],
+                ["type", "Zabbix", ["ports", "key"]],
+                ["type", "SNMPv1", ["ports", "key", "snmp_community"]],
+                ["type", "SNMPv2", ["ports", "key", "snmp_community"]],
+                ["type", "SNMPv3", ["ports", "key"]],
+                ["type", "HTTPS", ["ports"]],
+                ["type", "Telnet", ["ports"]],
+                ["snmpv3_securitylevel", "authPriv", ["snmpv3_privpassphrase"]]
             ]
         ),
-        delay=dict(type='str', required=False, default='1h'),
-        proxy=dict(type='str', required=False, default=None),
-        status=dict(type='str', default="enabled", choices=["enabled", "disabled"]),
-        state=dict(type='str', default='present', choices=['present', 'absent'])
+        delay=dict(type="str", required=False, default="1h"),
+        proxy=dict(type="str", required=False, default=None),
+        status=dict(type="str", default="enabled", choices=["enabled", "disabled"]),
+        state=dict(type="str", default="present", choices=["present", "absent"])
     )
 
     module = AnsibleModule(
         argument_spec=argument_spec,
         required_if=[
-            ['state', 'present', ['name', 'iprange', 'dchecks']],
-            ['state', 'absent', ['name']],
+            ["state", "present", ["name", "iprange", "dchecks"]],
+            ["state", "absent", ["name"]],
         ],
         supports_check_mode=True
     )
 
-    zabbix_utils.require_creds_params(module)
-
-    for p in ['server_url', 'login_user', 'login_password', 'timeout', 'validate_certs']:
-        if p in module.params and not module.params[p] is None:
-            module.warn('Option "%s" is deprecated with the move to httpapi connection and will be removed in the next release' % p)
-
-    state = module.params['state']
-    name = module.params['name']
-    iprange = module.params['iprange']
-    dchecks = module.params['dchecks']
-    delay = module.params['delay']
-    proxy = module.params['proxy']
-    status = module.params['status']
+    state = module.params["state"]
+    name = module.params["name"]
+    iprange = module.params["iprange"]
+    dchecks = module.params["dchecks"]
+    delay = module.params["delay"]
+    proxy = module.params["proxy"]
+    status = module.params["status"]
 
     drule = DiscoveryRule(module)
     zbx = drule._zapi
@@ -686,7 +615,7 @@ def main():
     drule_exists = drule.check_if_drule_exists(name)
 
     if drule_exists:
-        drule_id = drule.get_drule_by_drule_name(name)['druleid']
+        drule_id = drule.get_drule_by_drule_name(name)["druleid"]
         if state == "absent":
             drule.delete_drule(drule_id)
             module.exit_json(changed=True, state=state, drule=name, druleid=drule_id, msg="Discovery Rule deleted: %s, ID: %s" % (name, drule_id))
@@ -724,5 +653,5 @@ def main():
             module.exit_json(changed=True, state=state, drule=name, druleid=drule_id, msg="Discovery Rule created: %s, ID: %s" % (name, drule_id))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
