@@ -5,9 +5,10 @@
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 
-DOCUMENTATION = r'''
+DOCUMENTATION = r"""
 ---
 module: zabbix_usergroup
 short_description: Create/delete/update Zabbix user groups
@@ -18,7 +19,7 @@ description:
 author:
     - "Tobias Birkefeld (@tcraxs)"
 requirements:
-    - "python >= 2.6"
+    - "python >= 3.9"
 options:
     name:
         description:
@@ -126,13 +127,13 @@ options:
                     - Tag name.
                 required: false
                 type: str
-                default: ''
+                default: ""
             value:
                 description:
                     - Tag value.
                 required: false
                 type: str
-                default: ''
+                default: ""
     userdirectory:
         description:
             - Authentication user directory when gui_access set to LDAP or System default.
@@ -148,23 +149,22 @@ options:
         type: str
         default: "present"
         choices: [ "present", "absent" ]
-notes:
-    - Only Zabbix >= 4.0 is supported.
+
 extends_documentation_fragment:
 - community.zabbix.zabbix
-'''
+"""
 
-EXAMPLES = r'''
+EXAMPLES = r"""
 # If you want to use Username and Password to be authenticated by Zabbix Server
 - name: Set credentials to access Zabbix Server API
-  set_fact:
+  ansible.builtin.set_fact:
     ansible_user: Admin
     ansible_httpapi_pass: zabbix
 
 # If you want to use API token to be authenticated by Zabbix Server
 # https://www.zabbix.com/documentation/current/en/manual/web_interface/frontend_sections/administration/general#api-tokens
 - name: Set API token
-  set_fact:
+  ansible.builtin.set_fact:
     ansible_zabbix_auth_key: 8ec0d52432c15c91fcafe9888500cf9a607f44091ab554dbee860f6b44fac895
 
 # Base create user group example
@@ -176,10 +176,11 @@ EXAMPLES = r'''
     ansible_httpapi_port: 443
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
-    ansible_zabbix_url_path: 'zabbixeu'  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
+    ansible_zabbix_url_path: "zabbixeu"  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
     ansible_host: zabbix-example-fqdn.org
   community.zabbix.zabbix_usergroup:
     name: ACME
+    userdirectory: LDAP infra 1
     state: present
 
 # Base create user group with selected user directory for LDAP authentication
@@ -191,7 +192,7 @@ EXAMPLES = r'''
     ansible_httpapi_port: 443
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
-    ansible_zabbix_url_path: 'zabbixeu'  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
+    ansible_zabbix_url_path: "zabbixeu"  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
     ansible_host: zabbix-example-fqdn.org
   community.zabbix.zabbix_usergroup:
     name: ACME
@@ -207,7 +208,7 @@ EXAMPLES = r'''
     ansible_httpapi_port: 443
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
-    ansible_zabbix_url_path: 'zabbixeu'  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
+    ansible_zabbix_url_path: "zabbixeu"  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
     ansible_host: zabbix-example-fqdn.org
   community.zabbix.zabbix_usergroup:
     name: ACME
@@ -222,7 +223,7 @@ EXAMPLES = r'''
     ansible_httpapi_port: 443
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
-    ansible_zabbix_url_path: 'zabbixeu'  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
+    ansible_zabbix_url_path: "zabbixeu"  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
     ansible_host: zabbix-example-fqdn.org
   community.zabbix.zabbix_usergroup:
     name: ACME
@@ -242,7 +243,7 @@ EXAMPLES = r'''
     ansible_httpapi_port: 443
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
-    ansible_zabbix_url_path: 'zabbixeu'  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
+    ansible_zabbix_url_path: "zabbixeu"  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
     ansible_host: zabbix-example-fqdn.org
   community.zabbix.zabbix_usergroup:
     name: ACME
@@ -267,7 +268,7 @@ EXAMPLES = r'''
     ansible_httpapi_port: 443
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
-    ansible_zabbix_url_path: 'zabbixeu'  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
+    ansible_zabbix_url_path: "zabbixeu"  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
     ansible_host: zabbix-example-fqdn.org
   community.zabbix.zabbix_usergroup:
     name: ACME
@@ -289,35 +290,35 @@ EXAMPLES = r'''
     ansible_httpapi_port: 443
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
-    ansible_zabbix_url_path: 'zabbixeu'  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
+    ansible_zabbix_url_path: "zabbixeu"  # If Zabbix WebUI runs on non-default (zabbix) path ,e.g. http://<FQDN>/zabbixeu
     ansible_host: zabbix-example-fqdn.org
   community.zabbix.zabbix_usergroup:
     name: ACME
     state: absent
-'''
+"""
 
-RETURN = r'''
+RETURN = r"""
 state:
   description: User group state at the end of execution.
   returned: on success
   type: str
-  sample: 'present'
+  sample: "present"
 usergroup:
   description: User group name.
   returned: on success
   type: str
-  sample: 'ACME'
+  sample: "ACME"
 usrgrpid:
     description: User group id, if created, changed or deleted.
     returned: on success
     type: str
-    sample: '42'
+    sample: "42"
 msg:
     description: The result of the operation
     returned: always
     type: str
-    sample: 'User group created: ACME, ID: 42'
-'''
+    sample: "User group created: ACME, ID: 42"
+"""
 
 from ansible.module_utils.basic import AnsibleModule
 
@@ -341,16 +342,15 @@ class Rights(ZabbixBase):
             host group matching host group name.
         """
         try:
-            _hostgroup = self._zapi.hostgroup.get({
-                'output': 'extend',
-                'filter': {'name': [name]}
-            })
+            _hostgroup = self._zapi.hostgroup.get(
+                {"output": "extend", "filter": {"name": [name]}}
+            )
             if len(_hostgroup) < 1:
-                self._module.fail_json(msg='Host group not found: %s' % name)
+                self._module.fail_json(msg="Host group not found: %s" % name)
             else:
                 return _hostgroup[0]
         except Exception as e:
-            self._module.fail_json(msg='Failed to get host group "%s": %s' % (name, e))
+            self._module.fail_json(msg="Failed to get host group '%s': %s" % (name, e))
 
     def construct_the_data(self, _rights):
         """Construct the user defined rights to fit the Zabbix API requirements
@@ -366,13 +366,12 @@ class Rights(ZabbixBase):
         constructed_data = []
         for right in _rights:
             constructed_right = {
-                'id': self.get_hostgroup_by_hostgroup_name(right.get('host_group'))['groupid'],
-                'permission': zabbix_utils.helper_to_numeric_value([
-                    'denied',
-                    None,
-                    'read-only',
-                    'read-write'], right.get('permission')
-                )
+                "id": self.get_hostgroup_by_hostgroup_name(right.get("host_group"))[
+                    "groupid"
+                ],
+                "permission": zabbix_utils.helper_to_numeric_value(
+                    ["denied", None, "read-only", "read-write"], right.get("permission")
+                ),
             }
             constructed_data.append(constructed_right)
         return zabbix_utils.helper_cleanup_data(constructed_data)
@@ -394,15 +393,15 @@ class HostgroupRights(ZabbixBase):
         """
         try:
             _hostgroup = self._zapi.hostgroup.get({
-                'output': 'extend',
-                'filter': {'name': [name]}
+                "output": "extend",
+                "filter": {"name": [name]}
             })
             if len(_hostgroup) < 1:
-                self._module.fail_json(msg='Host group not found: %s' % name)
+                self._module.fail_json(msg="Host group not found: %s" % name)
             else:
                 return _hostgroup[0]
         except Exception as e:
-            self._module.fail_json(msg='Failed to get host group "%s": %s' % (name, e))
+            self._module.fail_json(msg="Failed to get host group '%s': %s" % (name, e))
 
     def construct_the_data(self, _rights):
         """Construct the user defined host group rights to fit the Zabbix API requirements
@@ -418,12 +417,12 @@ class HostgroupRights(ZabbixBase):
         constructed_data = []
         for right in _rights:
             constructed_right = {
-                'id': self.get_hostgroup_by_hostgroup_name(right.get('host_group'))['groupid'],
-                'permission': zabbix_utils.helper_to_numeric_value([
-                    'denied',
+                "id": self.get_hostgroup_by_hostgroup_name(right.get("host_group"))["groupid"],
+                "permission": zabbix_utils.helper_to_numeric_value([
+                    "denied",
                     None,
-                    'read-only',
-                    'read-write'], right.get('permission')
+                    "read-only",
+                    "read-write"], right.get("permission")
                 )
             }
             constructed_data.append(constructed_right)
@@ -446,15 +445,15 @@ class TemplategroupRights(ZabbixBase):
         """
         try:
             _templategroup = self._zapi.templategroup.get({
-                'output': 'extend',
-                'filter': {'name': [name]}
+                "output": "extend",
+                "filter": {"name": [name]}
             })
             if len(_templategroup) < 1:
-                self._module.fail_json(msg='Template group not found: %s' % name)
+                self._module.fail_json(msg="Template group not found: %s" % name)
             else:
                 return _templategroup[0]
         except Exception as e:
-            self._module.fail_json(msg='Failed to get template group "%s": %s' % (name, e))
+            self._module.fail_json(msg="Failed to get template group '%s': %s" % (name, e))
 
     def construct_the_data(self, _rights):
         """Construct the user defined template rights to fit the Zabbix API requirements
@@ -470,12 +469,12 @@ class TemplategroupRights(ZabbixBase):
         constructed_data = []
         for right in _rights:
             constructed_right = {
-                'id': self.get_templategroup_by_templategroup_name(right.get('template_group'))['groupid'],
-                'permission': zabbix_utils.helper_to_numeric_value([
-                    'denied',
+                "id": self.get_templategroup_by_templategroup_name(right.get("template_group"))["groupid"],
+                "permission": zabbix_utils.helper_to_numeric_value([
+                    "denied",
                     None,
-                    'read-only',
-                    'read-write'], right.get('permission')
+                    "read-only",
+                    "read-write"], right.get("permission")
                 )
             }
             constructed_data.append(constructed_right)
@@ -501,9 +500,11 @@ class TagFilters(Rights):
         constructed_data = []
         for tag_filter in _tag_filters:
             constructed_tag_filter = {
-                'groupid': self.get_hostgroup_by_hostgroup_name(tag_filter.get('host_group'))['groupid'],
-                'tag': tag_filter.get('tag'),
-                'value': tag_filter.get('value')
+                "groupid": self.get_hostgroup_by_hostgroup_name(
+                    tag_filter.get("host_group")
+                )["groupid"],
+                "tag": tag_filter.get("tag"),
+                "value": tag_filter.get("value"),
             }
             constructed_data.append(constructed_tag_filter)
         return zabbix_utils.helper_cleanup_data(constructed_data)
@@ -520,46 +521,50 @@ class UserGroup(ZabbixBase):
             dict: dictionary of specified parameters
         """
         _params = {
-            'name': kwargs['name'],
-            'gui_access': zabbix_utils.helper_to_numeric_value([
-                'default',
-                'internal',
-                'LDAP',
-                'disable'], kwargs['gui_access']
+            "name": kwargs["name"],
+            "gui_access": zabbix_utils.helper_to_numeric_value(
+                ["default", "internal", "LDAP", "disable"], kwargs["gui_access"]
             ),
-            'debug_mode': zabbix_utils.helper_to_numeric_value([
-                'disabled',
-                'enabled'], kwargs['debug_mode']
+            "debug_mode": zabbix_utils.helper_to_numeric_value(
+                ["disabled", "enabled"], kwargs["debug_mode"]
             ),
-            'users_status': zabbix_utils.helper_to_numeric_value([
-                'enabled',
-                'disabled'], kwargs['status']
+            "users_status": zabbix_utils.helper_to_numeric_value(
+                ["enabled", "disabled"], kwargs["status"]
             ),
-            'tag_filters': kwargs['tag_filters']
+            "tag_filters": kwargs["tag_filters"],
         }
-        if LooseVersion(self._zbx_api_version) < LooseVersion('6.2'):
-            _params['rights'] = kwargs['rights']
+        if LooseVersion(self._zbx_api_version) < LooseVersion("6.2"):
+            _params["rights"] = kwargs["rights"]
         else:
-            _params['hostgroup_rights'] = kwargs['hostgroup_rights']
-            _params['templategroup_rights'] = kwargs['templategroup_rights']
+            _params["hostgroup_rights"] = kwargs["hostgroup_rights"]
+            _params["templategroup_rights"] = kwargs["templategroup_rights"]
 
-            if kwargs['userdirectory']:
+            if kwargs["userdirectory"]:
                 try:
-                    if LooseVersion(self._zbx_api_version) <= LooseVersion('6.2'):
-                        _userdir = self._zapi.userdirectory.get({
-                            'output': 'extend',
-                            'filter': {'name': [kwargs['userdirectory']]}
-                        })
+                    if LooseVersion(self._zbx_api_version) <= LooseVersion("6.2"):
+                        _userdir = self._zapi.userdirectory.get(
+                            {
+                                "output": "extend",
+                                "filter": {"name": [kwargs["userdirectory"]]},
+                            }
+                        )
                     else:
-                        _userdir = self._zapi.userdirectory.get({
-                            'output': 'extend',
-                            'search': {'name': [kwargs['userdirectory']]}
-                        })
+                        _userdir = self._zapi.userdirectory.get(
+                            {
+                                "output": "extend",
+                                "search": {"name": [kwargs["userdirectory"]]},
+                            }
+                        )
                 except Exception as e:
-                    self._module.fail_json(msg='Failed to get user directory "%s": %s' % (kwargs['userdirectory'], e))
+                    self._module.fail_json(
+                        msg="Failed to get user directory '%s': %s"
+                        % (kwargs["userdirectory"], e)
+                    )
                 if len(_userdir) == 0:
-                    self._module.fail_json(msg='User directory "%s" not found' % kwargs['userdirectory'])
-                _params['userdirectoryid'] = _userdir[0]['userdirectoryid']
+                    self._module.fail_json(
+                        msg="User directory '%s' not found" % kwargs["userdirectory"]
+                    )
+                _params["userdirectoryid"] = _userdir[0]["userdirectoryid"]
 
         return _params
 
@@ -573,14 +578,15 @@ class UserGroup(ZabbixBase):
             The return value. True for success, False otherwise.
         """
         try:
-            _usergroup = self._zapi.usergroup.get({
-                'output': 'extend',
-                'filter': {'name': [name]}
-            })
+            _usergroup = self._zapi.usergroup.get(
+                {"output": "extend", "filter": {"name": [name]}}
+            )
             if len(_usergroup) > 0:
                 return _usergroup
         except Exception as e:
-            self._module.fail_json(msg='Failed to check if user group "%s" exists: %s' % (name, e))
+            self._module.fail_json(
+                msg="Failed to check if user group '%s' exists: %s" % (name, e)
+            )
 
     def get_usergroup_by_usergroup_name(self, name):
         """Get user group by user group name.
@@ -592,28 +598,32 @@ class UserGroup(ZabbixBase):
             User group matching user group name.
         """
         try:
-            if LooseVersion(self._zbx_api_version) < LooseVersion('6.2'):
-                _usergroup = self._zapi.usergroup.get({
-                    'output': 'extend',
-                    'selectTagFilters': 'extend',
-                    'selectRights': 'extend',
-                    'filter': {'name': [name]}
-                })
+            if LooseVersion(self._zbx_api_version) < LooseVersion("6.2"):
+                _usergroup = self._zapi.usergroup.get(
+                    {
+                        "output": "extend",
+                        "selectTagFilters": "extend",
+                        "selectRights": "extend",
+                        "filter": {"name": [name]},
+                    }
+                )
             else:
-                _usergroup = self._zapi.usergroup.get({
-                    'output': 'extend',
-                    'selectTagFilters': 'extend',
-                    'selectHostGroupRights': 'extend',
-                    'selectTemplateGroupRights': 'extend',
-                    'filter': {'name': [name]}
-                })
+                _usergroup = self._zapi.usergroup.get(
+                    {
+                        "output": "extend",
+                        "selectTagFilters": "extend",
+                        "selectHostGroupRights": "extend",
+                        "selectTemplateGroupRights": "extend",
+                        "filter": {"name": [name]},
+                    }
+                )
 
             if len(_usergroup) < 1:
-                self._module.fail_json(msg='User group not found: %s' % name)
+                self._module.fail_json(msg="User group not found: %s" % name)
             else:
                 return _usergroup[0]
         except Exception as e:
-            self._module.fail_json(msg='Failed to get user group "%s": %s' % (name, e))
+            self._module.fail_json(msg="Failed to get user group '%s': %s" % (name, e))
 
     def check_difference(self, **kwargs):
         """Check difference between user group and user specified parameters.
@@ -624,10 +634,16 @@ class UserGroup(ZabbixBase):
         Returns:
             dict: dictionary of differences
         """
-        existing_usergroup = zabbix_utils.helper_convert_unicode_to_str(self.get_usergroup_by_usergroup_name(kwargs['name']))
-        parameters = zabbix_utils.helper_convert_unicode_to_str(self._construct_parameters(**kwargs))
+        existing_usergroup = zabbix_utils.helper_convert_unicode_to_str(
+            self.get_usergroup_by_usergroup_name(kwargs["name"])
+        )
+        parameters = zabbix_utils.helper_convert_unicode_to_str(
+            self._construct_parameters(**kwargs)
+        )
         change_parameters = {}
-        _diff = zabbix_utils.helper_compare_dictionaries(parameters, existing_usergroup, change_parameters)
+        _diff = zabbix_utils.helper_compare_dictionaries(
+            parameters, existing_usergroup, change_parameters
+        )
         return _diff
 
     def update(self, **kwargs):
@@ -644,7 +660,9 @@ class UserGroup(ZabbixBase):
                 self._module.exit_json(changed=True)
             return self._zapi.usergroup.update(kwargs)
         except Exception as e:
-            self._module.fail_json(msg='Failed to update user group "%s": %s' % (kwargs['usrgrpid'], e))
+            self._module.fail_json(
+                msg="Failed to update user group '%s': %s" % (kwargs["usrgrpid"], e)
+            )
 
     def add(self, **kwargs):
         """Add user group.
@@ -660,9 +678,11 @@ class UserGroup(ZabbixBase):
                 self._module.exit_json(changed=True)
             parameters = self._construct_parameters(**kwargs)
             usergroup = self._zapi.usergroup.create(parameters)
-            return usergroup['usrgrpids'][0]
+            return usergroup["usrgrpids"][0]
         except Exception as e:
-            self._module.fail_json(msg='Failed to create user group "%s": %s' % (kwargs['name'], e))
+            self._module.fail_json(
+                msg="Failed to create user group '%s': %s" % (kwargs["name"], e)
+            )
 
     def delete(self, usrgrpid):
         """Delete user group.
@@ -679,62 +699,102 @@ class UserGroup(ZabbixBase):
             else:
                 return self._zapi.usergroup.delete([usrgrpid])
         except Exception as e:
-            self._module.fail_json(msg='Failed to delete user group "%s": %s' % (usrgrpid, e))
+            self._module.fail_json(
+                msg="Failed to delete user group '%s': %s" % (usrgrpid, e)
+            )
 
 
 def main():
     argument_spec = zabbix_utils.zabbix_common_argument_spec()
     argument_spec.update(
-        name=dict(type='str', required=True, aliases=['user_group']),
-        gui_access=dict(type='str', required=False, default='default', choices=['default', 'internal', 'LDAP', 'disable']),
-        debug_mode=dict(type='str', required=False, default='disabled', choices=['disabled', 'enabled']),
-        status=dict(type='str', required=False, default='enabled', choices=['enabled', 'disabled']),
-        rights=dict(type='list', elements='dict', required=False, options=dict(
-            host_group=dict(type='str', required=True),
-            permission=dict(type='str', required=True, choices=['denied', 'read-only', 'read-write'])
-        )),
-        hostgroup_rights=dict(type='list', elements='dict', required=False, options=dict(
-            host_group=dict(type='str', required=True),
-            permission=dict(type='str', required=True, choices=['denied', 'read-only', 'read-write'])
-        )),
-        templategroup_rights=dict(type='list', elements='dict', required=False, options=dict(
-            template_group=dict(type='str', required=True),
-            permission=dict(type='str', required=True, choices=['denied', 'read-only', 'read-write'])
-        )),
-        tag_filters=dict(type='list', elements='dict', required=False, options=dict(
-            host_group=dict(type='str', required=True),
-            tag=dict(type='str', default=''),
-            value=dict(type='str', default='')
-        )),
-        userdirectory=dict(type='str', required=False),
-        state=dict(type='str', default='present', choices=['present', 'absent'])
+        name=dict(type="str", required=True, aliases=["user_group"]),
+        gui_access=dict(
+            type="str",
+            required=False,
+            default="default",
+            choices=["default", "internal", "LDAP", "disable"],
+        ),
+        debug_mode=dict(
+            type="str",
+            required=False,
+            default="disabled",
+            choices=["disabled", "enabled"],
+        ),
+        status=dict(
+            type="str",
+            required=False,
+            default="enabled",
+            choices=["enabled", "disabled"],
+        ),
+        rights=dict(
+            type="list",
+            elements="dict",
+            required=False,
+            options=dict(
+                host_group=dict(type="str", required=True),
+                permission=dict(
+                    type="str",
+                    required=True,
+                    choices=["denied", "read-only", "read-write"],
+                ),
+            ),
+        ),
+        hostgroup_rights=dict(
+            type="list",
+            elements="dict",
+            required=False,
+            options=dict(
+                host_group=dict(type="str", required=True),
+                permission=dict(
+                    type="str",
+                    required=True,
+                    choices=["denied", "read-only", "read-write"],
+                ),
+            ),
+        ),
+        templategroup_rights=dict(
+            type="list",
+            elements="dict",
+            required=False,
+            options=dict(
+                template_group=dict(type="str", required=True),
+                permission=dict(
+                    type="str",
+                    required=True,
+                    choices=["denied", "read-only", "read-write"],
+                ),
+            ),
+        ),
+        tag_filters=dict(
+            type="list",
+            elements="dict",
+            required=False,
+            options=dict(
+                host_group=dict(type="str", required=True),
+                tag=dict(type="str", default=""),
+                value=dict(type="str", default=""),
+            ),
+        ),
+        userdirectory=dict(type="str", required=False),
+        state=dict(type="str", default="present", choices=["present", "absent"]),
     )
 
-    module = AnsibleModule(
-        argument_spec=argument_spec,
-        supports_check_mode=True
-    )
+    module = AnsibleModule(argument_spec=argument_spec, supports_check_mode=True)
 
-    zabbix_utils.require_creds_params(module)
-
-    for p in ['server_url', 'login_user', 'login_password', 'timeout', 'validate_certs']:
-        if p in module.params and not module.params[p] is None:
-            module.warn('Option "%s" is deprecated with the move to httpapi connection and will be removed in the next release' % p)
-
-    name = module.params['name']
-    gui_access = module.params['gui_access']
-    debug_mode = module.params['debug_mode']
-    status = module.params['status']
-    rights = module.params['rights']
-    hostgroup_rights = module.params['hostgroup_rights']
-    templategroup_rights = module.params['templategroup_rights']
-    tag_filters = module.params['tag_filters']
-    userdirectory = module.params['userdirectory']
-    state = module.params['state']
+    name = module.params["name"]
+    gui_access = module.params["gui_access"]
+    debug_mode = module.params["debug_mode"]
+    status = module.params["status"]
+    rights = module.params["rights"]
+    hostgroup_rights = module.params["hostgroup_rights"]
+    templategroup_rights = module.params["templategroup_rights"]
+    tag_filters = module.params["tag_filters"]
+    userdirectory = module.params["userdirectory"]
+    state = module.params["state"]
 
     userGroup = UserGroup(module)
     zbx = userGroup._zapi
-    if LooseVersion(userGroup._zbx_api_version) < LooseVersion('6.2'):
+    if LooseVersion(userGroup._zbx_api_version) < LooseVersion("6.2"):
         rgts = Rights(module, zbx)
     else:
         hostgroup_rgts = HostgroupRights(module, zbx)
@@ -744,12 +804,18 @@ def main():
     usergroup_exists = userGroup.check_if_usergroup_exists(name)
 
     if usergroup_exists:
-        usrgrpid = userGroup.get_usergroup_by_usergroup_name(name)['usrgrpid']
-        if state == 'absent':
+        usrgrpid = userGroup.get_usergroup_by_usergroup_name(name)["usrgrpid"]
+        if state == "absent":
             userGroup.delete(usrgrpid)
-            module.exit_json(changed=True, state=state, usergroup=name, usrgrpid=usrgrpid, msg='User group deleted: %s, ID: %s' % (name, usrgrpid))
+            module.exit_json(
+                changed=True,
+                state=state,
+                usergroup=name,
+                usrgrpid=usrgrpid,
+                msg="User group deleted: %s, ID: %s" % (name, usrgrpid),
+            )
         else:
-            if LooseVersion(userGroup._zbx_api_version) < LooseVersion('6.2'):
+            if LooseVersion(userGroup._zbx_api_version) < LooseVersion("6.2"):
                 difference = userGroup.check_difference(
                     usrgrpid=usrgrpid,
                     name=name,
@@ -757,7 +823,7 @@ def main():
                     debug_mode=debug_mode,
                     status=status,
                     rights=rgts.construct_the_data(rights),
-                    tag_filters=tgflts.construct_the_data(tag_filters)
+                    tag_filters=tgflts.construct_the_data(tag_filters),
                 )
             else:
                 difference = userGroup.check_difference(
@@ -766,31 +832,49 @@ def main():
                     gui_access=gui_access,
                     debug_mode=debug_mode,
                     status=status,
-                    hostgroup_rights=hostgroup_rgts.construct_the_data(hostgroup_rights),
-                    templategroup_rights=templategroup_rgts.construct_the_data(templategroup_rights),
+                    hostgroup_rights=hostgroup_rgts.construct_the_data(
+                        hostgroup_rights
+                    ),
+                    templategroup_rights=templategroup_rgts.construct_the_data(
+                        templategroup_rights
+                    ),
                     tag_filters=tgflts.construct_the_data(tag_filters),
-                    userdirectory=userdirectory
+                    userdirectory=userdirectory,
                 )
             if difference == {}:
-                module.exit_json(changed=False, state=state, usergroup=name, usrgrpid=usrgrpid, msg='User group is up to date: %s' % name)
-            else:
-                userGroup.update(
+                module.exit_json(
+                    changed=False,
+                    state=state,
+                    usergroup=name,
                     usrgrpid=usrgrpid,
-                    **difference
+                    msg="User group is up to date: %s" % name,
+                )
+            else:
+                userGroup.update(usrgrpid=usrgrpid, **difference)
+                module.exit_json(
+                    changed=True,
+                    state=state,
+                    usergroup=name,
+                    usrgrpid=usrgrpid,
+                    msg="User group updated: %s, ID: %s" % (name, usrgrpid),
                 )
-                module.exit_json(changed=True, state=state, usergroup=name, usrgrpid=usrgrpid, msg='User group updated: %s, ID: %s' % (name, usrgrpid))
     else:
-        if state == 'absent':
-            module.exit_json(changed=False, state=state, usergroup=name, msg='User group %s does not exists, nothing to delete' % name)
+        if state == "absent":
+            module.exit_json(
+                changed=False,
+                state=state,
+                usergroup=name,
+                msg="User group %s does not exists, nothing to delete" % name,
+            )
         else:
-            if LooseVersion(userGroup._zbx_api_version) < LooseVersion('6.2'):
+            if LooseVersion(userGroup._zbx_api_version) < LooseVersion("6.2"):
                 usrgrpid = userGroup.add(
                     name=name,
                     gui_access=gui_access,
                     debug_mode=debug_mode,
                     status=status,
                     rights=rgts.construct_the_data(rights),
-                    tag_filters=tgflts.construct_the_data(tag_filters)
+                    tag_filters=tgflts.construct_the_data(tag_filters),
                 )
             else:
                 usrgrpid = userGroup.add(
@@ -798,13 +882,23 @@ def main():
                     gui_access=gui_access,
                     debug_mode=debug_mode,
                     status=status,
-                    hostgroup_rights=hostgroup_rgts.construct_the_data(hostgroup_rights),
-                    templategroup_rights=templategroup_rgts.construct_the_data(templategroup_rights),
+                    hostgroup_rights=hostgroup_rgts.construct_the_data(
+                        hostgroup_rights
+                    ),
+                    templategroup_rights=templategroup_rgts.construct_the_data(
+                        templategroup_rights
+                    ),
                     tag_filters=tgflts.construct_the_data(tag_filters),
-                    userdirectory=userdirectory
+                    userdirectory=userdirectory,
                 )
-            module.exit_json(changed=True, state=state, usergroup=name, usrgrpid=usrgrpid, msg='User group created: %s, ID: %s' % (name, usrgrpid))
+            module.exit_json(
+                changed=True,
+                state=state,
+                usergroup=name,
+                usrgrpid=usrgrpid,
+                msg="User group created: %s, ID: %s" % (name, usrgrpid),
+            )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
