@@ -149,7 +149,11 @@ options:
     type: raw
   cpu_period:
     description:
-      - Limit the CPU real-time period in microseconds
+      - Limit the CPU CFS (Completely Fair Scheduler) period
+    type: int
+  cpu_quota:
+    description:
+      - Limit the CPU CFS (Completely Fair Scheduler) quota
     type: int
   cpu_rt_period:
     description:
@@ -262,6 +266,10 @@ options:
       - Read in a line delimited file of environment variables. Doesn't support
         idempotency. If users changes the file with environment variables it's
         on them to recreate the container.
+        The file must be present on the REMOTE machine where actual podman is
+        running, not on the controller machine where Ansible is executing.
+        If you need to copy the file from controller to remote machine, use the
+        copy or slurp module.
     type: path
   env_host:
     description:
@@ -319,6 +327,18 @@ options:
             - 'on-watchdog'
             - 'on-abort'
             - 'always'
+      restart_sec:
+        description: Set the systemd service restartsec value.
+        type: int
+        required: false
+      start_timeout:
+        description: Override the default start timeout for the container with the given value.
+        type: int
+        required: false
+      stop_timeout:
+        description: Override the default stop timeout for the container with the given value.
+        type: int
+        required: false
       time:
         description:
           - Override the default stop timeout for the container with the given value.
@@ -416,6 +436,17 @@ options:
         is considered failed. Like start-period, the value can be expressed in
         a time format such as 1m22s. The default value is 30s
     type: str
+  healthcheck_failure_action:
+    description:
+      - The action to be taken when the container is considered unhealthy. The action must be one of
+            "none", "kill", "restart", or "stop".
+            The default policy is "none".
+    type: str
+    choices:
+      - 'none'
+      - 'kill'
+      - 'restart'
+      - 'stop'
   hooks_dir:
     description:
       - Each .json file in the path configures a hook for Podman containers.
@@ -912,6 +943,16 @@ EXAMPLES = r"""
     image: busybox
     log_options: path=/var/log/container/mycontainer.json
     log_driver: k8s-file
+
+- name: Run container with complex command with quotes
+  containers.podman.podman_container:
+    name: mycontainer
+    image: certbot/certbot
+    command:
+      - renew
+      - --deploy-hook
+      - "echo 1 > /var/lib/letsencrypt/complete"
+
 """
 
 RETURN = r"""
