@@ -27,6 +27,12 @@ options:
       - Use C(/etc/systemd/system) for the system-wide systemd instance.
       - Use C(/etc/systemd/user) or C(~/.config/systemd/user) for use with per-user instances of systemd.
     type: path
+  force:
+    description:
+      - Replace the systemd unit file(s) even if it already exists.
+      - This works with dest option.
+    type: bool
+    default: false
   new:
     description:
       - Generate unit files that create containers and pods, not only start them.
@@ -219,7 +225,7 @@ podman_command:
 import os
 from ansible.module_utils.basic import AnsibleModule
 import json
-
+from ansible_collections.containers.podman.plugins.module_utils.podman.common import compare_systemd_file_content
 
 RESTART_POLICY_CHOICES = [
     'no-restart',
@@ -388,7 +394,7 @@ def generate_systemd(module):
 
     # In case of error in running the command
     if return_code != 0:
-        # Print informations about the error and return and empty dictionary
+        # Print information about the error and return and empty dictionary
         message = 'Error generating systemd .service unit(s).'
         message += ' Command executed: {command_str}'
         message += ' Command returned with code: {return_code}.'
@@ -425,7 +431,7 @@ def generate_systemd(module):
                 changed = True
             # If destination exist but not a directory
             if not os.path.isdir(systemd_units_dest):
-                # Stop and tell user that the destination is not a directry
+                # Stop and tell user that the destination is not a directory
                 message = "Destination {systemd_units_dest} is not a directory."
                 message += " Can't save systemd unit files in."
                 module.fail_json(
@@ -446,26 +452,13 @@ def generate_systemd(module):
                     unit_file_name,
                 )
 
-                # See if we need to write the unit file, default yes
-                need_to_write_file = True
-                # If the unit file already exist, compare it with the
-                # generated content
-                if os.path.exists(unit_file_full_path):
-                    # Read the file
-                    with open(unit_file_full_path, 'r') as unit_file:
-                        current_unit_file_content = unit_file.read()
-                    # If current unit file content is the same as the
-                    # generated content
-                    # Remove comments from files, before comparing
-                    current_unit_file_content_nocmnt = "\n".join([
-                        line for line in current_unit_file_content.splitlines()
-                        if not line.startswith('#')])
-                    unit_content_nocmnt = "\n".join([
-                        line for line in unit_content.splitlines()
-                        if not line.startswith('#')])
-                    if current_unit_file_content_nocmnt == unit_content_nocmnt:
-                        # We don't need to write it
-                        need_to_write_file = False
+                if module.params['force']:
+                    # Force to replace the existing unit file
+                    need_to_write_file = True
+                else:
+                    # See if we need to write the unit file, default yes
+                    need_to_write_file = bool(compare_systemd_file_content(
+                        unit_file_full_path, unit_content))
 
                 # Write the file, if needed
                 if need_to_write_file:
@@ -506,6 +499,11 @@ def run_module():
             'required': False,
             'default': False,
         },
+        'force': {
+            'type': 'bool',
+            'required': False,
+            'default': False,
+        },
         'restart_policy': {
             'type': 'str',
             'required': False,
