@@ -14,8 +14,6 @@ created
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-import re
-
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.cfg.base import (
     ConfigBase,
 )
@@ -29,20 +27,30 @@ from ansible_collections.dellemc.enterprise_sonic.plugins.module_utils.network.s
 )
 from ansible_collections.dellemc.enterprise_sonic.plugins.module_utils.network.sonic.utils.utils import (
     get_diff,
+    get_replaced_config,
     update_states,
-    normalize_interface_name,
     normalize_interface_name_list
 )
+from ansible_collections.dellemc.enterprise_sonic.plugins.module_utils.network.sonic.utils.formatted_diff_utils import (
+    __DELETE_CONFIG_IF_NO_SUBCONFIG,
+    __DELETE_LEAFS_OR_CONFIG_IF_NO_NON_KEY_LEAF,
+    get_new_config,
+    get_formatted_config_diff
+)
+
 from ansible.module_utils.connection import ConnectionError
 
 PATCH = 'PATCH'
 DELETE = 'DELETE'
 
 TEST_KEYS = [
-    {
-        "vrf": "", "enable_ntp_auth": "", "source_interfaces": "", "trusted_keys": "",
-        "servers": {"address": ""}, "ntp_keys": {"key_id": ""}
-    }
+    {"servers": {"address": ""}},
+    {"ntp_keys": {"key_id": ""}}
+]
+TEST_KEYS_formatted_diff = [
+    {'__default_ops': {'__delete_op': __DELETE_LEAFS_OR_CONFIG_IF_NO_NON_KEY_LEAF}},
+    {"servers": {"address": "", '__delete_op': __DELETE_CONFIG_IF_NO_SUBCONFIG}},
+    {"ntp_keys": {"key_id": "", '__delete_op': __DELETE_CONFIG_IF_NO_SUBCONFIG}}
 ]
 
 
@@ -106,6 +114,17 @@ class Ntp(ConfigBase):
         if result['changed']:
             result['after'] = changed_ntp_facts
 
+        new_config = changed_ntp_facts
+        if self._module.check_mode:
+            result.pop('after', None)
+            new_config = get_new_config(commands, existing_ntp_facts,
+                                        TEST_KEYS_formatted_diff)
+            result['after(generated)'] = new_config
+
+        if self._module._diff:
+            result['diff'] = get_formatted_config_diff(existing_ntp_facts,
+                                                       new_config,
+                                                       self._module._verbosity)
         result['warnings'] = warnings
         return result
 
@@ -119,7 +138,7 @@ class Ntp(ConfigBase):
         """
         want = self._module.params['config']
         if want is None:
-            want = []
+            want = {}
 
         have = existing_ntp_facts
 
@@ -145,6 +164,10 @@ class Ntp(ConfigBase):
             commands, requests = self._state_deleted(want, have)
         elif state == 'merged':
             commands, requests = self._state_merged(want, have)
+        elif state == 'overridden':
+            commands, requests = self._state_overridden(want, have)
+        elif state == 'replaced':
+            commands, requests = self._state_replaced(want, have)
 
         return commands, requests
 
@@ -160,6 +183,8 @@ class Ntp(ConfigBase):
 
         commands = diff
         requests = []
+
+        self.preprocess_merge_commands(commands, want)
         if commands:
             requests = self.get_merge_requests(commands, have)
 
@@ -207,6 +232,77 @@ class Ntp(ConfigBase):
 
         return commands, requests
 
+    def _state_replaced(self, want, have):
+        """ The command generator when state is replaced
+
+        :param want: the desired configuration as a dictionary
+        :param have: the current configuration as a dictionary
+        :param diff: the difference between want and have
+        :rtype: A list
+        :returns: the commands necessary to migrate the current configuration
+                  to the desired configuration
+        """
+        commands = []
+        requests = []
+        replaced_config = get_replaced_config(want, have, TEST_KEYS)
+
+        add_commands = []
+        if replaced_config:
+            self.sort_lists_in_config(replaced_config)
+            self.sort_lists_in_config(have)
+            delete_all = (replaced_config == have)
+            del_requests = self.get_delete_requests(replaced_config, delete_all)
+            requests.extend(del_requests)
+            commands.extend(update_states(replaced_config, "deleted"))
+
+            add_commands = want
+        else:
+            diff = get_diff(want, have, TEST_KEYS)
+            add_commands = diff
+
+        if add_commands:
+            self.preprocess_merge_commands(add_commands, want)
+            add_requests = self.get_merge_requests(add_commands, have)
+
+            if len(add_requests) > 0:
+                requests.extend(add_requests)
+                commands.extend(update_states(add_commands, "replaced"))
+
+        return commands, requests
+
+    def _state_overridden(self, want, have):
+        """ The command generator when state is overridden
+
+        :param want: the desired configuration as a dictionary
+        :param have: the current configuration as a dictionary
+        :param diff: the difference between want and have
+        :rtype: A list
+        :returns: the commands necessary to migrate the current configuration
+                  to the desired configuration
+        """
+        self.sort_lists_in_config(want)
+        self.sort_lists_in_config(have)
+
+        commands = []
+        requests = []
+
+        if have and have != want:
+            delete_all = True
+            del_requests = self.get_delete_requests(have, delete_all)
+            requests.extend(del_requests)
+            commands.extend(update_states(have, "deleted"))
+            have = []
+
+        if not have and want:
+            add_commands = want
+            add_requests = self.get_merge_requests(add_commands, have)
+
+            if len(add_requests) > 0:
+                requests.extend(add_requests)
+                commands.extend(update_states(add_commands, "overridden"))
+
+        return commands, requests
+
     def validate_want(self, want, state):
 
         if state == 'deleted':
@@ -215,7 +311,9 @@ class Ntp(ConfigBase):
                     key_id_config = server.get('key_id', None)
                     minpoll_config = server.get('minpoll', None)
                     maxpoll_config = server.get('maxpoll', None)
-                    if key_id_config or minpoll_config or maxpoll_config:
+                    prefer_config = server.get('prefer', None)
+                    if key_id_config or minpoll_config or maxpoll_config or \
+                       prefer_config is not None:
                         err_msg = "NTP server parameter(s) can not be deleted."
                         self._module.fail_json(msg=err_msg, code=405)
 
@@ -247,6 +345,52 @@ class Ntp(ConfigBase):
                         server.pop('minpoll')
                     if 'maxpoll' in server and not server['maxpoll']:
                         server.pop('maxpoll')
+                    if 'prefer' in server and server['prefer'] is None:
+                        server.pop('prefer')
+
+        if state == 'replaced' or state == 'overridden':
+            enable_auth_want = want.get('enable_ntp_auth', None)
+            if enable_auth_want is None:
+                want['enable_ntp_auth'] = False
+            if 'servers' in want and want['servers'] is not None:
+                for server in want['servers']:
+                    if 'prefer' in server and server['prefer'] is None:
+                        server['prefer'] = False
+
+    def search_servers(self, svr_address, servers):
+
+        found_server = dict()
+        if servers is not None:
+            for server in servers:
+                if server['address'] == svr_address:
+                    found_server = server
+        return found_server
+
+    def preprocess_merge_commands(self, commands, want):
+
+        if 'servers' in commands and commands['servers'] is not None:
+            for server in commands['servers']:
+                if 'minpoll' in server and 'maxpoll' not in server:
+                    want_server = dict()
+                    if 'servers' in want:
+                        want_server = self.search_servers(server['address'], want['servers'])
+
+                    if want_server:
+                        server['maxpoll'] = want_server['maxpoll']
+                    else:
+                        err_msg = "Internal error with NTP server maxpoll configuration."
+                        self._module.fail_json(msg=err_msg, code=500)
+
+                if 'maxpoll' in server and 'minpoll' not in server:
+                    want_server = dict()
+                    if 'servers' in want:
+                        want_server = self.search_servers(server['address'], want['servers'])
+
+                    if want_server:
+                        server['minpoll'] = want_server['minpoll']
+                    else:
+                        err_msg = "Internal error with NTP server minpoll configuration."
+                        self._module.fail_json(msg=err_msg, code=500)
 
     def get_merge_requests(self, configs, have):
 
@@ -448,18 +592,23 @@ class Ntp(ConfigBase):
         # Create URL and payload
         method = DELETE
 
-        servers_config = configs.get('servers', None)
         src_intf_config = configs.get('source_interfaces', None)
         vrf_config = configs.get('vrf', None)
         enable_auth_config = configs.get('enable_ntp_auth', None)
         trusted_key_config = configs.get('trusted_keys', None)
 
-        if servers_config or src_intf_config or vrf_config or \
+        if src_intf_config or vrf_config or \
            trusted_key_config or enable_auth_config is not None:
             url = 'data/openconfig-system:system/ntp'
             request = {"path": url, "method": method}
             requests.append(request)
 
+        servers_config = configs.get('servers', None)
+        if servers_config:
+            url = 'data/openconfig-system:system/ntp/servers'
+            request = {"path": url, "method": method}
+            requests.append(request)
+
         keys_config = configs.get('ntp_keys', None)
         if keys_config:
             url = 'data/openconfig-system:system/ntp/ntp-keys'
@@ -546,3 +695,20 @@ class Ntp(ConfigBase):
             requests.append(request)
 
         return requests
+
+    def get_server_address(self, ntp_server):
+        return ntp_server.get('address')
+
+    def get_ntp_key_id(self, ntp_key):
+        return ntp_key.get('key_id')
+
+    def sort_lists_in_config(self, config):
+
+        if 'source_interfaces' in config and config['source_interfaces'] is not None:
+            config['source_interfaces'].sort()
+        if 'servers' in config and config['servers'] is not None:
+            config['servers'].sort(key=self.get_server_address)
+        if 'trusted_keys' in config and config['trusted_keys'] is not None:
+            config['trusted_keys'].sort()
+        if 'ntp_keys' in config and config['ntp_keys'] is not None:
+            config['ntp_keys'].sort(key=self.get_ntp_key_id)
