@@ -1,6 +1,6 @@
 #
 # -*- coding: utf-8 -*-
-# Copyright 2019 Red Hat
+# Copyright 2023 Dell Inc. or its subsidiaries. All Rights Reserved
 # GNU General Public License v3.0+
 # (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 """
@@ -40,7 +40,7 @@ from ansible_collections.dellemc.enterprise_sonic.plugins.module_utils.network.s
 
 TEST_KEYS = [
     {"config": {"afi": "", "name": ""}},
-    {"prefixes": {"action": "", "ge": "", "le": "", "prefix": "", "sequence": ""}}
+    {"prefixes": {"ge": "", "le": "", "prefix": "", "sequence": ""}}
 ]
 
 DELETE = "delete"
@@ -149,6 +149,10 @@ openconfig-routing-policy-ext:extended-prefixes/extended-prefix={},{},{}'
             commands, requests = self._state_deleted(want, have)
         elif state == 'merged':
             commands, requests = self._state_merged(diff)
+        elif state == 'replaced':
+            commands, requests = self._state_replaced(diff)
+        elif state == 'overridden':
+            commands, requests = self._state_overridden(want, have)
         ret_commands = commands
         return ret_commands, requests
 
@@ -188,6 +192,51 @@ openconfig-routing-policy-ext:extended-prefixes/extended-prefix={},{},{}'
             commands = []
         return commands, requests
 
+    def _state_replaced(self, diff):
+        """ The command generator when state is replaced
+        :rtype: A list
+        :returns: the commands necessary to migrate the current configuration
+                  to the desired configuration
+        """
+        commands = diff
+        requests = self.get_modify_prefix_lists_requests(commands)
+        if commands and len(requests) > 0:
+            commands = update_states(commands, "replaced")
+        else:
+            commands = []
+
+        return commands, requests
+
+    def _state_overridden(self, want, have):
+        """ The command generator when state is overridden
+        :param want: the desired configuration as a dictionary
+        :param have: the current configuration as a dictionary
+        :param diff: the difference between want and have
+        :rtype: A list
+        :returns: the commands necessary to migrate the current configuration
+                  to the desired configuration
+        """
+        commands = []
+        requests = []
+        self.sort_lists_in_config(want)
+        self.sort_lists_in_config(have)
+
+        if have and have != want:
+            del_requests = self.get_delete_all_prefix_list_cfg_requests()
+            requests.extend(del_requests)
+            commands.extend(update_states(have, "deleted"))
+            have = []
+
+        if not have and want:
+            mod_commands = want
+            mod_requests = self.get_modify_prefix_lists_requests(mod_commands)
+
+            if len(mod_requests) > 0:
+                requests.extend(mod_requests)
+                commands.extend(update_states(mod_commands, "overridden"))
+
+        return commands, requests
+
     def get_modify_prefix_lists_requests(self, commands):
         '''Traverse the input list of configuration "modify" commands obtained
         from parsing the input playbook parameters. For each command,
@@ -456,3 +505,13 @@ openconfig-routing-policy-ext:extended-prefixes/extended-prefix={},{},{}'
 
         prefix_net['prefixlen'] = int(prefix_val.split("/")[1])
         return prefix_net
+
+    def sort_lists_in_config(self, config):
+        if config:
+            config.sort(key=self.get_name)
+            for cfg in config:
+                if 'prefixes' in cfg and cfg['prefixes']:
+                    cfg['prefixes'].sort(key=lambda x: (x['sequence'], x['action'], x['prefix']))
+
+    def get_name(self, name):
+        return name.get('name')
