@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 #
-# Dell EMC OpenManage Ansible Modules
-# Version 5.0.1
+# Dell OpenManage Ansible Modules
+# Version 7.0.0
 # Copyright (C) 2020-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
@@ -20,22 +20,28 @@ options:
   baseuri:
     description: "IP address of the target out-of-band controller. For example- <ipaddress>:<port>."
     type: str
-    required: True
+    required: true
   username:
-    description: Username of the target out-of-band controller.
+    description:
+      - Username of the target out-of-band controller.
+      - If the username is not provided, then the environment variable C(IDRAC_USERNAME) is used.
+      - "Example: export IDRAC_USERNAME=username"
     type: str
-    required: True
+    required: true
   password:
-    description: Password of the target out-of-band controller.
+    description:
+      - Password of the target out-of-band controller.
+      - If the password is not provided, then the environment variable C(IDRAC_PASSWORD) is used.
+      - "Example: export IDRAC_PASSWORD=password"
     type: str
-    required: True
+    required: true
   validate_certs:
     description:
-     - If C(False), the SSL certificates will not be validated.
-     - Configure C(False) only on personally controlled sites where self-signed certificates are used.
-     - Prior to collection version C(5.0.0), the I(validate_certs) is C(False) by default.
+     - If C(false), the SSL certificates will not be validated.
+     - Configure C(false) only on personally controlled sites where self-signed certificates are used.
+     - Prior to collection version C(5.0.0), the I(validate_certs) is C(false) by default.
     type: bool
-    default: True
+    default: true
     version_added: 5.0.0
   ca_path:
     description:
