@@ -2,8 +2,8 @@
 # -*- coding: utf-8 -*-
 
 #
-# Dell EMC OpenManage Ansible Modules
-# Version 6.0.0
+# Dell OpenManage Ansible Modules
+# Version 7.1.0
 # Copyright (C) 2018-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
@@ -136,13 +136,14 @@ options:
         description: Enter the static IP subnet mask to iDRAC.
 requirements:
     - "omsdk >= 1.2.488"
-    - "python >= 3.8.6"
+    - "python >= 3.9.6"
 author:
     - "Felix Stephen (@felixs88)"
     - "Anooja Vardhineni (@anooja-vardhineni)"
 notes:
     - This module requires 'Administrator' privilege for I(idrac_user).
-    - Run this module from a system that has direct access to Dell EMC iDRAC.
+    - Run this module from a system that has direct access to Dell iDRAC.
+    - This module supports both IPv4 and IPv6 address for I(idrac_ip).
     - This module supports C(check_mode).
 """
 
@@ -150,9 +151,9 @@ EXAMPLES = """
 ---
 - name: Configure iDRAC network settings
   dellemc.openmanage.idrac_network:
-       idrac_ip:   "192.168.0.1"
+       idrac_ip: "192.168.0.1"
        idrac_user: "user_name"
-       idrac_password:  "user_password"
+       idrac_password: "user_password"
        ca_path: "/path/to/ca_cert.pem"
        register_idrac_on_dns: Enabled
        dns_idrac_name: None
@@ -246,10 +247,8 @@ try:
                                              Selection_NICTypes, Failover_NICTypes,
                                              AutoDetect_NICTypes, Autoneg_NICTypes,
                                              Speed_NICTypes, Duplex_NICTypes, DHCPEnable_IPv4Types,
-                                             DNSFromDHCP_IPv4Types, Enable_IPv4Types,
-                                             DNSFromDHCP_IPv4StaticTypes)
+                                             Enable_IPv4Types, DNSFromDHCP_IPv4StaticTypes)
     from omsdk.sdkfile import file_share_manager
-    from omsdk.sdkcreds import UserCredentials
 except ImportError:
     pass
 
