@@ -2,8 +2,8 @@
 # -*- coding: utf-8 -*-
 
 #
-# Dell EMC OpenManage Ansible Modules
-# Version 5.1.0
+# Dell OpenManage Ansible Modules
+# Version 7.0.0
 # Copyright (C) 2019-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
@@ -64,7 +64,7 @@ requirements:
     - "python >= 3.8.6"
 author: "Sajna Shetty(@Sajna-Shetty)"
 notes:
-    - Run this module from a system that has direct access to DellEMC OpenManage Enterprise.
+    - Run this module from a system that has direct access to Dell OpenManage Enterprise.
     - This module supports C(check_mode).
 '''
 
@@ -77,8 +77,8 @@ EXAMPLES = r'''
     password: "password"
     ca_path: "/path/to/ca_cert.pem"
     device_ids:
-        - 11111
-        - 22222
+      - 11111
+      - 22222
 
 - name: Retrieves device based compliance report for specified service Tags
   dellemc.openmanage.ome_firmware_baseline_compliance_info:
@@ -87,8 +87,8 @@ EXAMPLES = r'''
     password: "password"
     ca_path: "/path/to/ca_cert.pem"
     device_service_tags:
-        - MXL1234
-        - MXL4567
+      - MXL1234
+      - MXL4567
 
 - name: Retrieves device based compliance report for specified group names
   dellemc.openmanage.ome_firmware_baseline_compliance_info:
@@ -97,8 +97,8 @@ EXAMPLES = r'''
     password: "password"
     ca_path: "/path/to/ca_cert.pem"
     device_group_names:
-        - "group1"
-        - "group2"
+      - "group1"
+      - "group2"
 
 - name: Retrieves device compliance report for a specified baseline
   dellemc.openmanage.ome_firmware_baseline_compliance_info:
