@@ -2,9 +2,9 @@
 # -*- coding: utf-8 -*-
 
 #
-# Dell EMC OpenManage Ansible Modules
-# Version 5.0.1
-# Copyright (C) 2019-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Dell OpenManage Ansible Modules
+# Version 8.2.0
+# Copyright (C) 2019-2023 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -96,9 +96,9 @@ options:
   check_certificate:
     type: bool
     description:
-      - The certificate warnings are ignored when I(repository_type) is HTTPS. If C(True). If not, certificate warnings
+      - The certificate warnings are ignored when I(repository_type) is HTTPS. If C(true). If not, certificate warnings
        are not ignored.
-    default: False
+    default: false
   job_wait:
     description:
       - Provides the option to wait for job completion.
@@ -109,7 +109,7 @@ options:
   job_wait_timeout:
     description:
       - The maximum wait time of I(job_wait) in seconds. The job is tracked only for this duration.
-      - This option is applicable when I(job_wait) is C(True).
+      - This option is applicable when I(job_wait) is C(true).
     type: int
     default: 600
     version_added: 3.4.0
@@ -120,7 +120,8 @@ author:
     - "Jagadeesh N V(@jagadeeshnv)"
 notes:
     - If I(repository_password) is provided, then the module always reports the changed status.
-    - Run this module from a system that has direct access to DellEMC OpenManage Enterprise or OpenManage Enterprise Modular.
+    - Run this module from a system that has direct access to Dell OpenManage Enterprise or OpenManage Enterprise Modular.
+    - This module supports IPv4 and IPv6 addresses.
     - This module supports C(check_mode).
 '''
 
@@ -138,7 +139,7 @@ EXAMPLES = r'''
     source: "downloads.dell.com"
     source_path: "catalog"
     file_name: "catalog.gz"
-    check_certificate: True
+    check_certificate: true
 
 - name: Create a catalog from HTTP repository
   dellemc.openmanage.ome_firmware_catalog:
@@ -191,7 +192,7 @@ EXAMPLES = r'''
     catalog_name: "catalog_name"
     catalog_description: "catalog_description"
     repository_type: "DELL_ONLINE"
-    check_certificate: True
+    check_certificate: true
 
 - name: Modify a catalog using a repository from CIFS share
   dellemc.openmanage.ome_firmware_catalog:
@@ -255,7 +256,7 @@ catalog_status:
         "BaseLocation": null,
         "BundlesCount": 0,
         "Filename": "catalog.gz",
-        "Id": 0,
+        "Id": 12,
         "LastUpdated": null,
         "ManifestIdentifier": null,
         "ManifestVersion": null,
@@ -351,9 +352,11 @@ SETTLING_TIME = 3
 
 import json
 import time
+import os
 from ssl import SSLError
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.dellemc.openmanage.plugins.module_utils.ome import RestOME, ome_auth_params
+from ansible_collections.dellemc.openmanage.plugins.module_utils.utils import remove_key
 from ansible.module_utils.six.moves.urllib.error import URLError, HTTPError
 from ansible.module_utils.urls import ConnectionError, SSLValidationError
 
@@ -408,7 +411,7 @@ def exit_catalog(module, rest_obj, catalog_resp, operation, msg):
         msg = CATALOG_UPDATED.format(operation=operation)
     time.sleep(SETTLING_TIME)
     catalog = get_updated_catalog_info(module, rest_obj, catalog_resp)
-    module.exit_json(msg=msg, catalog_status=catalog, changed=True)
+    module.exit_json(msg=msg, catalog_status=remove_key(catalog), changed=True)
 
 
 def _get_catalog_payload(params, name):
@@ -521,11 +524,21 @@ def modify_catalog(module, rest_obj, catalog_list, all_catalog):
     new_catalog_current_setting = catalog_payload.copy()
     repo_id = new_catalog_current_setting["Repository"]["Id"]
     del new_catalog_current_setting["Repository"]["Id"]
+    fname = modify_payload.get('Filename')
+    # Special case handling for .gz catalog files
+    if fname and fname.lower().endswith('.gz'):
+        modify_payload['Filename'] = new_catalog_current_setting.get('Filename')
+        src_path = modify_payload.get('SourcePath')
+        if src_path is None:
+            src_path = new_catalog_current_setting.get('SourcePath', "")
+            if src_path.lower().endswith('.gz'):
+                src_path = os.path.dirname(src_path)
+        modify_payload['SourcePath'] = os.path.join(src_path, fname)
     diff = compare_payloads(modify_payload, new_catalog_current_setting)
-    if module.check_mode and diff:
-        module.exit_json(msg=CHECK_MODE_CHANGE_FOUND_MSG, changed=True)
     if not diff:
         module.exit_json(msg=CHECK_MODE_CHANGE_NOT_FOUND_MSG, changed=False)
+    if module.check_mode:
+        module.exit_json(msg=CHECK_MODE_CHANGE_FOUND_MSG, changed=True)
     new_catalog_current_setting["Repository"].update(modify_payload["Repository"])
     catalog_payload.update(modify_payload)
     catalog_payload["Repository"] = new_catalog_current_setting["Repository"]
@@ -637,7 +650,7 @@ def main():
     except URLError as err:
         module.exit_json(msg=str(err), unreachable=True)
     except (IOError, ValueError, TypeError, SSLError, ConnectionError, SSLValidationError, OSError) as err:
-        module.fail_json(msg=str(err))
+        module.exit_json(msg=str(err), failed=True)
 
 
 if __name__ == '__main__':
