@@ -402,7 +402,7 @@ class TestConfigBios(FakeAnsibleModule):
         else:
             mocker.patch(
                 MODULE_PATH + 'run_server_bios_config',
-                side_effect=exc_type('http://testhost.com', 400, 'http error message',
+                side_effect=exc_type('https://testhost.com', 400, 'http error message',
                                      {"accept-type": "application/json"}, StringIO(json_str)))
         if not exc_type == URLError:
             result = self._run_module_with_fail_json(idrac_default_args)
@@ -585,3 +585,10 @@ class TestConfigBios(FakeAnsibleModule):
         ]
         result = self.module.check_params(params.get('each'), fields)
         assert result == params.get('message')
+
+    def test_validate_negative_job_time_out(self, idrac_default_args):
+        idrac_default_args.update({"job_wait": True, "job_wait_timeout": -5})
+        f_module = self.get_module_mock(params=idrac_default_args)
+        with pytest.raises(Exception) as ex:
+            self.module.validate_negative_job_time_out(f_module)
+        assert ex.value.args[0] == "The parameter job_wait_timeout value cannot be negative or zero."
