@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
 #
-# Dell EMC OpenManage Ansible Modules
-# Version 5.3.0
-# Copyright (C) 2019-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Dell OpenManage Ansible Modules
+# Version 8.2.0
+# Copyright (C) 2019-2023 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -259,11 +259,11 @@ class TestOmeFirmwareCatalog(FakeAnsibleModule):
             assert result["unreachable"] is True
         elif exc_type not in [HTTPError, SSLValidationError]:
             mocker.patch(MODULE_PATH + 'check_existing_catalog', side_effect=exc_type("exception message"))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         else:
             mocker.patch(MODULE_PATH + 'check_existing_catalog',
-                         side_effect=exc_type('http://testhost.com', 400, 'http error message',
+                         side_effect=exc_type('https://testhost.com', 400, 'http error message',
                                               {"accept-type": "application/json"}, StringIO(json_str)))
             result = self._run_module_with_fail_json(ome_default_args)
             assert result['failed'] is True
@@ -820,11 +820,11 @@ class TestOmeFirmwareCatalog(FakeAnsibleModule):
             assert result["unreachable"] is True
         elif exc_type not in [HTTPError, SSLValidationError]:
             mocker.patch(MODULE_PATH + 'validate_names', side_effect=exc_type("exception message"))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         else:
             mocker.patch(MODULE_PATH + 'validate_names',
-                         side_effect=exc_type('http://testhost.com', 400, 'http error message',
+                         side_effect=exc_type('https://testhost.com', 400, 'http error message',
                                               {"accept-type": "application/json"}, StringIO(json_str)))
             result = self._run_module_with_fail_json(ome_default_args)
             assert result['failed'] is True
@@ -862,3 +862,19 @@ class TestOmeFirmwareCatalog(FakeAnsibleModule):
         ome_default_args.update({"repository_type": "HTTPS", "catalog_name": "t1", "catalog_id": 1})
         result = self._run_module_with_fail_json(ome_default_args)
         assert result["msg"] == "parameters are mutually exclusive: catalog_name|catalog_id"
+
+    @pytest.mark.parametrize("param", [{"hostname": "invalid-host-abcd"}])
+    def test_ome_catalog_invalid_hostname_case1(self, ome_default_args, param):
+        # To verify invalid IP or hostname in module_utils/ome
+        ome_default_args.update({"hostname": param['hostname'], "catalog_name": "catalog1", "repository_type": "HTTPS", "ca_path": ""})
+        result = self._run_module(ome_default_args)
+        assert result["unreachable"] is True
+        assert "error" in result['msg']
+
+    @pytest.mark.parametrize("param", [{"hostname": "ABCD:ABCD:ABCD:EF12:3456:7890"}])
+    def _test_ome_catalog_invalid_hostname_case2(self, ome_default_args, param):
+        # To verify invalid IP or hostname in module_utils/ome
+        ome_default_args.update({"hostname": param['hostname'], "catalog_name": "catalog1", "repository_type": "HTTPS", "ca_path": ""})
+        result = self._run_module(ome_default_args)
+        assert "does not appear to be an IPv4 or IPv6 address" in result['msg']
+        assert param['hostname'] in result['msg']
