@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
 #
-# Dell EMC OpenManage Ansible Modules
-# Version 4.1.0
-# Copyright (C) 2021 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Dell OpenManage Ansible Modules
+# Version 7.0.0
+# Copyright (C) 2021-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -25,6 +25,7 @@ SUBSCRIPTION_UNABLE_ADD = "Unable to add a subscription."
 SUBSCRIPTION_ADDED = "Successfully added the subscription."
 DESTINATION_MISMATCH = "No changes found to be applied."
 EVENT_TYPE_INVALID = "value of event_type must be one of: Alert, MetricReport, got: Metricreport"
+PARAM_DESTINATION = "https://XX.XX.XX.XX:8188"
 
 
 @pytest.fixture
@@ -38,8 +39,8 @@ def redfish_connection_mock(mocker, redfish_response_mock):
 class TestRedfishSubscription(FakeAnsibleModule):
     module = redfish_event_subscription
 
-    @pytest.mark.parametrize("val", [{"destination": "https://192.168.1.100:8188"},
-                                     {"destination": "https://192.168.1.100:8189"}])
+    @pytest.mark.parametrize("val", [{"destination": PARAM_DESTINATION},
+                                     {"destination": "https://XX.XX.XX.XX:8189"}])
     def test_function_get_subscription_success(self, mocker, redfish_connection_mock, redfish_response_mock,
                                                redfish_default_args, val):
         redfish_default_args.update({"state": "absent"})
@@ -53,7 +54,7 @@ class TestRedfishSubscription(FakeAnsibleModule):
             "Context": "RedfishEvent",
             "DeliveryRetryPolicy": "RetryForever",
             "Description": "Event Subscription Details",
-            "Destination": "https://192.168.1.100:8189",
+            "Destination": "https://XX.XX.XX.XX:8189",
             "EventFormatType": "Event",
             "EventTypes": [
                 "Alert"
@@ -82,7 +83,7 @@ class TestRedfishSubscription(FakeAnsibleModule):
             "Context": "RedfishEvent",
             "DeliveryRetryPolicy": "RetryForever",
             "Description": "Event Subscription Details",
-            "Destination": "https://192.168.1.100:8188",
+            "Destination": PARAM_DESTINATION,
             "EventFormatType": "MetricReport",
             "EventTypes": [
                 "MetricReport"
@@ -130,9 +131,9 @@ class TestRedfishSubscription(FakeAnsibleModule):
         assert result["Destination"] == val["destination"]
 
     @pytest.mark.parametrize("val", [
-        {"destination": "https://192.168.1.100:8188", "event_type": "MetricReport",
+        {"destination": PARAM_DESTINATION, "event_type": "MetricReport",
          "event_format_type": "MetricReport"},
-        {"destination": "https://192.168.1.100:8188", "event_type": "Alert", "event_format_type": "Event"}])
+        {"destination": PARAM_DESTINATION, "event_type": "Alert", "event_format_type": "Event"}])
     def test_function_create_subscription(self, mocker, redfish_connection_mock, redfish_response_mock,
                                           redfish_default_args, val):
         redfish_default_args.update({"state": "absent"})
@@ -157,9 +158,9 @@ class TestRedfishSubscription(FakeAnsibleModule):
         assert result.json_data["EventTypes"] == [val["event_type"]]
 
     @pytest.mark.parametrize("val", [
-        {"destination": "https://100.96.80.1:161", "event_type": "MetricReport",
+        {"destination": "https://XX.XX.XX.XX:161", "event_type": "MetricReport",
          "event_format_type": "MetricReport"},
-        {"destination": "https://100.96.80.1:161", "event_type": "Alert", "event_format_type": "Event"}])
+        {"destination": "https://XX.XX.XX.XX:161", "event_type": "Alert", "event_format_type": "Event"}])
     def test_function_get_subscription_details(self, mocker, redfish_connection_mock, redfish_response_mock,
                                                redfish_default_args, val):
         redfish_default_args.update({"state": "absent"})
@@ -202,9 +203,9 @@ class TestRedfishSubscription(FakeAnsibleModule):
         assert result["EventTypes"] == [val["event_type"]]
 
     @pytest.mark.parametrize("val", [
-        {"destination": "https://100.96.80.1:161", "event_type": "MetricReport",
+        {"destination": "https://XX.XX.XX.XX:161", "event_type": "MetricReport",
          "event_format_type": "MetricReport"},
-        {"destination": "https://100.96.80.1:161", "event_type": "Alert", "event_format_type": "Event"}])
+        {"destination": "https://XX.XX.XX.XX:161", "event_type": "Alert", "event_format_type": "Event"}])
     def test_function_get_subscription_details_None(self, mocker, redfish_connection_mock, redfish_response_mock,
                                                     redfish_default_args, val):
         redfish_default_args.update({"state": "absent"})
@@ -245,8 +246,8 @@ class TestRedfishSubscription(FakeAnsibleModule):
         assert result is None
 
     @pytest.mark.parametrize("val", [
-        {"destination": "https://100.96.80.1:161"},
-        {"destination": "https://100.96.80.1:161"}])
+        {"destination": "https://XX.XX.XX.XX:161"},
+        {"destination": "https://XX.XX.XX.XX:161"}])
     def test_function_delete_subscription(self, mocker, redfish_connection_mock, redfish_response_mock,
                                           redfish_default_args, val):
         redfish_default_args.update({"state": "absent"})
@@ -284,7 +285,8 @@ class TestRedfishSubscription(FakeAnsibleModule):
     def test_module_validation_input_params(self, mocker, redfish_connection_mock, redfish_response_mock,
                                             redfish_default_args):
         redfish_default_args.update({"state": "absent"})
-        redfish_default_args.update({"destination": "http://192.168.1.100:8188"})
+        http_str = "http"
+        redfish_default_args.update({"destination": http_str + "://XX.XX.XX.XX:8188"})
         redfish_default_args.update({"event_type": "MetricReport"})
         redfish_default_args.update({"event_format_type": "MetricReport"})
         with pytest.raises(Exception) as err:
@@ -294,7 +296,7 @@ class TestRedfishSubscription(FakeAnsibleModule):
     def test_module_absent_does_not_exist(self, mocker, redfish_connection_mock, redfish_response_mock,
                                           redfish_default_args):
         redfish_default_args.update({"state": "absent"})
-        redfish_default_args.update({"destination": "https://192.168.1.100:8188"})
+        redfish_default_args.update({"destination": PARAM_DESTINATION})
         redfish_default_args.update({"event_type": "MetricReport"})
         redfish_default_args.update({"event_format_type": "MetricReport"})
 
@@ -307,13 +309,13 @@ class TestRedfishSubscription(FakeAnsibleModule):
     def test_module_absent_does_exist(self, mocker, redfish_connection_mock, redfish_response_mock,
                                       redfish_default_args):
         redfish_default_args.update({"state": "absent"})
-        redfish_default_args.update({"destination": "https://192.168.1.100:8188"})
+        redfish_default_args.update({"destination": PARAM_DESTINATION})
         redfish_default_args.update({"event_type": "MetricReport"})
         redfish_default_args.update({"event_format_type": "MetricReport"})
 
         json_data = {
             "Id": "c6ff37fc-8204-11eb-b08f-2cea7ff7fe80",
-            "Destination": "https://192.168.1.100:8188",
+            "Destination": PARAM_DESTINATION,
             "EventFormatType": "MetricReport",
             "Context": "RedfishEvent",
             "Protocol": "Redfish",
@@ -331,13 +333,13 @@ class TestRedfishSubscription(FakeAnsibleModule):
     def test_module_absent_does_exist_error(self, mocker, redfish_connection_mock, redfish_response_mock,
                                             redfish_default_args):
         redfish_default_args.update({"state": "absent"})
-        redfish_default_args.update({"destination": "https://192.168.1.100:8188"})
+        redfish_default_args.update({"destination": PARAM_DESTINATION})
         redfish_default_args.update({"event_type": "MetricReport"})
         redfish_default_args.update({"event_format_type": "MetricReport"})
 
         json_data = {
             "Id": "c6ff37fc-8204-11eb-b08f-2cea7ff7fe80",
-            "Destination": "https://192.168.1.100:8188",
+            "Destination": PARAM_DESTINATION,
             "EventFormatType": "MetricReport",
             "Context": "RedfishEvent",
             "Protocol": "Redfish",
@@ -354,12 +356,12 @@ class TestRedfishSubscription(FakeAnsibleModule):
     def test_module_present_does_not_exist(self, mocker, redfish_connection_mock, redfish_response_mock,
                                            redfish_default_args):
         redfish_default_args.update({"state": "present"})
-        redfish_default_args.update({"destination": "https://192.168.1.100:8188"})
+        redfish_default_args.update({"destination": PARAM_DESTINATION})
         redfish_default_args.update({"event_type": "MetricReport"})
         redfish_default_args.update({"event_format_type": "MetricReport"})
 
         json_data = {
-            "Destination": "https://192.168.1.100:8188",
+            "Destination": PARAM_DESTINATION,
             "EventFormatType": "MetricReport",
             "Context": "RedfishEvent",
             "Protocol": "Redfish",
@@ -380,12 +382,12 @@ class TestRedfishSubscription(FakeAnsibleModule):
     def test_module_present_does_not_exist_error(self, mocker, redfish_connection_mock, redfish_response_mock,
                                                  redfish_default_args):
         redfish_default_args.update({"state": "present"})
-        redfish_default_args.update({"destination": "https://192.168.1.100:8188"})
+        redfish_default_args.update({"destination": PARAM_DESTINATION})
         redfish_default_args.update({"event_type": "MetricReport"})
         redfish_default_args.update({"event_format_type": "MetricReport"})
 
         json_data = {
-            "Destination": "https://192.168.1.100:8188",
+            "Destination": PARAM_DESTINATION,
             "EventFormatType": "MetricReport",
             "Context": "RedfishEvent",
             "Protocol": "Redfish",
@@ -406,12 +408,12 @@ class TestRedfishSubscription(FakeAnsibleModule):
                                                              redfish_response_mock,
                                                              redfish_default_args):
         redfish_default_args.update({"state": "present"})
-        redfish_default_args.update({"destination": "https://192.168.1.100:8188"})
+        redfish_default_args.update({"destination": PARAM_DESTINATION})
         redfish_default_args.update({"event_type": "Metricreport"})
         redfish_default_args.update({"event_format_type": "MetricReport"})
 
         json_data = {
-            "Destination": "https://192.168.1.100:8188",
+            "Destination": PARAM_DESTINATION,
             "EventFormatType": "MetricReport",
             "Context": "RedfishEvent",
             "Protocol": "Redfish",
@@ -433,13 +435,13 @@ class TestRedfishSubscription(FakeAnsibleModule):
     def test_module_present_does_exist(self, mocker, redfish_connection_mock, redfish_response_mock,
                                        redfish_default_args):
         redfish_default_args.update({"state": "present"})
-        redfish_default_args.update({"destination": "https://192.168.1.100:8188"})
+        redfish_default_args.update({"destination": PARAM_DESTINATION})
         redfish_default_args.update({"event_type": "MetricReport"})
         redfish_default_args.update({"event_format_type": "MetricReport"})
 
         json_data = {
             "Id": "c6ff37fc-8204-11eb-b08f-2cea7ff7fe80",
-            "Destination": "https://192.168.1.100:8188",
+            "Destination": PARAM_DESTINATION,
             "EventFormatType": "MetricReport",
             "Context": "RedfishEvent",
             "Protocol": "Redfish",
