@@ -88,7 +88,6 @@ notes:
 '''
 
 EXAMPLES = r'''
-
 - name: Get the details of storage pool by name
   dellemc.powerflex.storagepool:
     hostname: "{{hostname}}"
@@ -127,8 +126,8 @@ EXAMPLES = r'''
     validate_certs: "{{validate_certs}}"
     storage_pool_name: "ansible_test_pool"
     protection_domain_id: "1c957da800000000"
-    use_rmcache: True
-    use_rfcache: True
+    use_rmcache: true
+    use_rfcache: true
     state: "present"
 
 - name: Rename storage pool by id
