@@ -199,7 +199,7 @@ changed:
     description: Whether or not the resource has changed.
     returned: always
     type: bool
-    sample: True
+    sample: true
 
 get_tree_quota_details:
     description: Details of the quota tree.
@@ -283,7 +283,7 @@ from ansible_collections.dellemc.unity.plugins.module_utils.storage.dell \
 
 LOG = utils.get_logger('tree_quota')
 
-application_type = "Ansible/1.6.0"
+application_type = "Ansible/1.7.1"
 
 
 class QuotaTree(object):
