@@ -105,9 +105,8 @@ options:
         type: dict
         suboptions:
             alert:
-                description: no description
                 type: dict
-                required: false
+                description: no description
                 suboptions:
                     data-exhausted:
                         type: str
@@ -131,14 +130,14 @@ options:
                         type: str
                         description: Display string when system rebooted.
             receiver:
-                description: description
                 type: list
                 elements: dict
+                description: no description
                 suboptions:
                     alert:
-                        description: description
                         type: list
                         elements: str
+                        description: no description
                         choices:
                             - 'system-reboot'
                             - 'data-exhausted'
@@ -169,47 +168,47 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
-   collections:
-     - fortinet.fortimanager
-   connection: httpapi
-   vars:
-      ansible_httpapi_use_ssl: True
-      ansible_httpapi_validate_certs: False
-      ansible_httpapi_port: 443
-   tasks:
+- hosts: fortimanager-inventory
+  collections:
+    - fortinet.fortimanager
+  connection: httpapi
+  vars:
+    ansible_httpapi_use_ssl: True
+    ansible_httpapi_validate_certs: False
+    ansible_httpapi_port: 443
+  tasks:
     - name: FortiExtender cellular SMS notification configuration.
       fmgr_extensioncontroller_extenderprofile_cellular_smsnotification:
-         bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         extender-profile: <your own value>
-         extensioncontroller_extenderprofile_cellular_smsnotification:
-            alert:
-               data-exhausted: <value of string>
-               fgt-backup-mode-switch: <value of string>
-               low-signal-strength: <value of string>
-               mode-switch: <value of string>
-               os-image-fallback: <value of string>
-               session-disconnect: <value of string>
-               system-reboot: <value of string>
-            receiver:
-              -
-                  alert:
-                    - system-reboot
-                    - data-exhausted
-                    - session-disconnect
-                    - low-signal-strength
-                    - mode-switch
-                    - os-image-fallback
-                    - fgt-backup-mode-switch
-                  name: <value of string>
-                  phone-number: <value of string>
-                  status: <value in [disable, enable]>
-            status: <value in [disable, enable]>
+        bypass_validation: False
+        workspace_locking_adom: <value in [global, custom adom including root]>
+        workspace_locking_timeout: 300
+        rc_succeeded: [0, -2, -3, ...]
+        rc_failed: [-2, -3, ...]
+        adom: <your own value>
+        extender-profile: <your own value>
+        extensioncontroller_extenderprofile_cellular_smsnotification:
+          alert:
+            data-exhausted: <string>
+            fgt-backup-mode-switch: <string>
+            low-signal-strength: <string>
+            mode-switch: <string>
+            os-image-fallback: <string>
+            session-disconnect: <string>
+            system-reboot: <string>
+          receiver:
+            -
+              alert:
+                - system-reboot
+                - data-exhausted
+                - session-disconnect
+                - low-signal-strength
+                - mode-switch
+                - os-image-fallback
+                - fgt-backup-mode-switch
+              name: <string>
+              phone-number: <string>
+              status: <value in [disable, enable]>
+          status: <value in [disable, enable]>
 
 '''
 
@@ -261,13 +260,13 @@ from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import
 
 def main():
     jrpc_urls = [
-        '/pm/config/global/obj/extension-controller/extender-profile/{extender-profile}/cellular/sms-notification',
-        '/pm/config/adom/{adom}/obj/extension-controller/extender-profile/{extender-profile}/cellular/sms-notification'
+        '/pm/config/adom/{adom}/obj/extension-controller/extender-profile/{extender-profile}/cellular/sms-notification',
+        '/pm/config/global/obj/extension-controller/extender-profile/{extender-profile}/cellular/sms-notification'
     ]
 
     perobject_jrpc_urls = [
-        '/pm/config/global/obj/extension-controller/extender-profile/{extender-profile}/cellular/sms-notification/{sms-notification}',
-        '/pm/config/adom/{adom}/obj/extension-controller/extender-profile/{extender-profile}/cellular/sms-notification/{sms-notification}'
+        '/pm/config/adom/{adom}/obj/extension-controller/extender-profile/{extender-profile}/cellular/sms-notification/{sms-notification}',
+        '/pm/config/global/obj/extension-controller/extender-profile/{extender-profile}/cellular/sms-notification/{sms-notification}'
     ]
 
     url_params = ['adom', 'extender-profile']
@@ -335,7 +334,10 @@ def main():
             'revision': {
                 '7.2.1': True,
                 '7.2.2': True,
-                '7.4.0': True
+                '7.2.3': True,
+                '7.2.4': True,
+                '7.4.0': True,
+                '7.4.1': True
             },
             'options': {
                 'alert': {
@@ -347,7 +349,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -356,7 +361,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -365,7 +373,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -374,7 +385,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -383,7 +397,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -392,7 +409,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -401,7 +421,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         }
@@ -412,7 +435,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'list',
                     'options': {
@@ -421,7 +447,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'list',
                             'choices': [
@@ -440,7 +469,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -449,7 +481,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -458,7 +493,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'choices': [
                                 'disable',
@@ -474,7 +512,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'choices': [
                         'disable',
