@@ -119,10 +119,11 @@ options:
             name:
                 type: str
                 description: no description
+                required: true
             platforms:
-                description: description
                 type: list
                 elements: dict
+                description: no description
                 suboptions:
                     count:
                         type: int
@@ -162,37 +163,37 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
-   collections:
-     - fortinet.fortimanager
-   connection: httpapi
-   vars:
-      ansible_httpapi_use_ssl: True
-      ansible_httpapi_validate_certs: False
-      ansible_httpapi_port: 443
-   tasks:
+- hosts: fortimanager-inventory
+  collections:
+    - fortinet.fortimanager
+  connection: httpapi
+  vars:
+    ansible_httpapi_use_ssl: True
+    ansible_httpapi_validate_certs: False
+    ansible_httpapi_port: 443
+  tasks:
     - name: no description
       fmgr_fmg_fabric_authorization_template:
-         bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         state: <value in [present, absent]>
-         fmg_fabric_authorization_template:
-            description: <value of string>
-            extender-controller: <value in [disable, enable]>
-            name: <value of string>
-            platforms:
-              -
-                  count: <value of integer>
-                  extension-type: <value in [wan-extension, lan-extension]>
-                  fortilink: <value of string>
-                  prefix: <value of string>
-                  type: <value in [ap, extender, switch]>
-            switch-controller: <value in [disable, enable]>
-            wireless-controller: <value in [disable, enable]>
+        bypass_validation: False
+        workspace_locking_adom: <value in [global, custom adom including root]>
+        workspace_locking_timeout: 300
+        rc_succeeded: [0, -2, -3, ...]
+        rc_failed: [-2, -3, ...]
+        adom: <your own value>
+        state: <value in [present, absent]>
+        fmg_fabric_authorization_template:
+          description: <string>
+          extender-controller: <value in [disable, enable]>
+          name: <string>
+          platforms:
+            -
+              count: <integer>
+              extension-type: <value in [wan-extension, lan-extension]>
+              fortilink: <string>
+              prefix: <string>
+              type: <value in [ap, extender, switch]>
+          switch-controller: <value in [disable, enable]>
+          wireless-controller: <value in [disable, enable]>
 
 '''
 
@@ -244,13 +245,13 @@ from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import
 
 def main():
     jrpc_urls = [
-        '/pm/config/global/obj/fmg/fabric/authorization/template',
-        '/pm/config/adom/{adom}/obj/fmg/fabric/authorization/template'
+        '/pm/config/adom/{adom}/obj/fmg/fabric/authorization/template',
+        '/pm/config/global/obj/fmg/fabric/authorization/template'
     ]
 
     perobject_jrpc_urls = [
-        '/pm/config/global/obj/fmg/fabric/authorization/template/{template}',
-        '/pm/config/adom/{adom}/obj/fmg/fabric/authorization/template/{template}'
+        '/pm/config/adom/{adom}/obj/fmg/fabric/authorization/template/{template}',
+        '/pm/config/global/obj/fmg/fabric/authorization/template/{template}'
     ]
 
     url_params = ['adom']
@@ -322,7 +323,10 @@ def main():
             'revision': {
                 '7.2.1': True,
                 '7.2.2': True,
-                '7.4.0': True
+                '7.2.3': True,
+                '7.2.4': True,
+                '7.4.0': True,
+                '7.4.1': True
             },
             'options': {
                 'description': {
@@ -330,7 +334,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
                 },
@@ -339,7 +346,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'choices': [
                         'disable',
@@ -352,7 +362,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
                 },
@@ -361,7 +374,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'list',
                     'options': {
@@ -370,7 +386,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'int'
                         },
@@ -379,7 +398,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'choices': [
                                 'wan-extension',
@@ -392,7 +414,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -401,7 +426,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -410,7 +438,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'choices': [
                                 'ap',
@@ -427,7 +458,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'choices': [
                         'disable',
@@ -440,7 +474,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'choices': [
                         'disable',
