@@ -139,8 +139,8 @@ options:
                 type: str
                 description: Match policy based on hardware vendor.
             interface-tags:
-                description: description
-                type: str
+                type: raw
+                description: (list) no description
             lldp-profile:
                 type: str
                 description: LLDP profile to be applied when using this policy.
@@ -150,6 +150,7 @@ options:
             name:
                 type: str
                 description: Policy name.
+                required: true
             qos-policy:
                 type: str
                 description: QoS policy to be applied when using this policy.
@@ -169,41 +170,41 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
-   collections:
-     - fortinet.fortimanager
-   connection: httpapi
-   vars:
-      ansible_httpapi_use_ssl: True
-      ansible_httpapi_validate_certs: False
-      ansible_httpapi_port: 443
-   tasks:
+- hosts: fortimanager-inventory
+  collections:
+    - fortinet.fortimanager
+  connection: httpapi
+  vars:
+    ansible_httpapi_use_ssl: True
+    ansible_httpapi_validate_certs: False
+    ansible_httpapi_port: 443
+  tasks:
     - name: Port policies with matching criteria and actions.
       fmgr_switchcontroller_dynamicportpolicy_policy:
-         bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         dynamic-port-policy: <your own value>
-         state: <value in [present, absent]>
-         switchcontroller_dynamicportpolicy_policy:
-            802-1x: <value of string>
-            bounce-port-link: <value in [disable, enable]>
-            category: <value in [device, interface-tag]>
-            description: <value of string>
-            family: <value of string>
-            host: <value of string>
-            hw-vendor: <value of string>
-            interface-tags: <value of string>
-            lldp-profile: <value of string>
-            mac: <value of string>
-            name: <value of string>
-            qos-policy: <value of string>
-            status: <value in [disable, enable]>
-            type: <value of string>
-            vlan-policy: <value of string>
+        bypass_validation: False
+        workspace_locking_adom: <value in [global, custom adom including root]>
+        workspace_locking_timeout: 300
+        rc_succeeded: [0, -2, -3, ...]
+        rc_failed: [-2, -3, ...]
+        adom: <your own value>
+        dynamic-port-policy: <your own value>
+        state: <value in [present, absent]>
+        switchcontroller_dynamicportpolicy_policy:
+          802-1x: <string>
+          bounce-port-link: <value in [disable, enable]>
+          category: <value in [device, interface-tag]>
+          description: <string>
+          family: <string>
+          host: <string>
+          hw-vendor: <string>
+          interface-tags: <list or string>
+          lldp-profile: <string>
+          mac: <string>
+          name: <string>
+          qos-policy: <string>
+          status: <value in [disable, enable]>
+          type: <string>
+          vlan-policy: <string>
 
 '''
 
@@ -255,13 +256,13 @@ from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import
 
 def main():
     jrpc_urls = [
-        '/pm/config/global/obj/switch-controller/dynamic-port-policy/{dynamic-port-policy}/policy',
-        '/pm/config/adom/{adom}/obj/switch-controller/dynamic-port-policy/{dynamic-port-policy}/policy'
+        '/pm/config/adom/{adom}/obj/switch-controller/dynamic-port-policy/{dynamic-port-policy}/policy',
+        '/pm/config/global/obj/switch-controller/dynamic-port-policy/{dynamic-port-policy}/policy'
     ]
 
     perobject_jrpc_urls = [
-        '/pm/config/global/obj/switch-controller/dynamic-port-policy/{dynamic-port-policy}/policy/{policy}',
-        '/pm/config/adom/{adom}/obj/switch-controller/dynamic-port-policy/{dynamic-port-policy}/policy/{policy}'
+        '/pm/config/adom/{adom}/obj/switch-controller/dynamic-port-policy/{dynamic-port-policy}/policy/{policy}',
+        '/pm/config/global/obj/switch-controller/dynamic-port-policy/{dynamic-port-policy}/policy/{policy}'
     ]
 
     url_params = ['adom', 'dynamic-port-policy']
@@ -337,7 +338,10 @@ def main():
             'revision': {
                 '7.2.1': True,
                 '7.2.2': True,
-                '7.4.0': True
+                '7.2.3': True,
+                '7.2.4': True,
+                '7.4.0': True,
+                '7.4.1': True
             },
             'options': {
                 '802-1x': {
@@ -345,7 +349,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
                 },
@@ -354,7 +361,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'choices': [
                         'disable',
@@ -367,7 +377,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'choices': [
                         'device',
@@ -380,7 +393,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
                 },
@@ -389,7 +405,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
                 },
@@ -398,7 +417,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
                 },
@@ -407,7 +429,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
                 },
@@ -416,16 +441,22 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
-                    'type': 'str'
+                    'type': 'raw'
                 },
                 'lldp-profile': {
                     'required': False,
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
                 },
@@ -434,7 +465,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
                 },
@@ -443,7 +477,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
                 },
@@ -452,7 +489,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
                 },
@@ -461,7 +501,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'choices': [
                         'disable',
@@ -474,7 +517,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
                 },
@@ -483,7 +529,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
                 }
