@@ -120,9 +120,8 @@ options:
                     - 'disable'
                     - 'enable'
             nac-ports:
-                description: no description
                 type: dict
-                required: false
+                description: no description
                 suboptions:
                     lan-segment:
                         type: str
@@ -137,8 +136,8 @@ options:
                         type: str
                         description: Configure NAC LAN interface.
                     nac-segment-vlans:
-                        description: description
-                        type: str
+                        type: raw
+                        description: (list) no description
                     onboarding-vlan:
                         type: str
                         description: Default NAC Onboarding VLAN when NAC devices are discovered.
@@ -154,41 +153,50 @@ options:
             name:
                 type: str
                 description: FortiLink settings name.
+                required: true
+            access-vlan-mode:
+                type: str
+                description: Intra VLAN traffic behavior with loss of connection to the FortiGate.
+                choices:
+                    - 'legacy'
+                    - 'fail-open'
+                    - 'fail-close'
 
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
-   collections:
-     - fortinet.fortimanager
-   connection: httpapi
-   vars:
-      ansible_httpapi_use_ssl: True
-      ansible_httpapi_validate_certs: False
-      ansible_httpapi_port: 443
-   tasks:
+- hosts: fortimanager-inventory
+  collections:
+    - fortinet.fortimanager
+  connection: httpapi
+  vars:
+    ansible_httpapi_use_ssl: True
+    ansible_httpapi_validate_certs: False
+    ansible_httpapi_port: 443
+  tasks:
     - name: Configure integrated FortiLink settings for FortiSwitch.
       fmgr_switchcontroller_fortilinksettings:
-         bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         state: <value in [present, absent]>
-         switchcontroller_fortilinksettings:
-            fortilink: <value of string>
-            inactive-timer: <value of integer>
-            link-down-flush: <value in [disable, enable]>
-            nac-ports:
-               lan-segment: <value in [disabled, enabled]>
-               member-change: <value of integer>
-               nac-lan-interface: <value of string>
-               nac-segment-vlans: <value of string>
-               onboarding-vlan: <value of string>
-               parent-key: <value of string>
-               bounce-nac-port: <value in [disable, enable]>
-            name: <value of string>
+        bypass_validation: False
+        workspace_locking_adom: <value in [global, custom adom including root]>
+        workspace_locking_timeout: 300
+        rc_succeeded: [0, -2, -3, ...]
+        rc_failed: [-2, -3, ...]
+        adom: <your own value>
+        state: <value in [present, absent]>
+        switchcontroller_fortilinksettings:
+          fortilink: <string>
+          inactive-timer: <integer>
+          link-down-flush: <value in [disable, enable]>
+          nac-ports:
+            lan-segment: <value in [disabled, enabled]>
+            member-change: <integer>
+            nac-lan-interface: <string>
+            nac-segment-vlans: <list or string>
+            onboarding-vlan: <string>
+            parent-key: <string>
+            bounce-nac-port: <value in [disable, enable]>
+          name: <string>
+          access-vlan-mode: <value in [legacy, fail-open, fail-close]>
 
 '''
 
@@ -240,13 +248,13 @@ from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import
 
 def main():
     jrpc_urls = [
-        '/pm/config/global/obj/switch-controller/fortilink-settings',
-        '/pm/config/adom/{adom}/obj/switch-controller/fortilink-settings'
+        '/pm/config/adom/{adom}/obj/switch-controller/fortilink-settings',
+        '/pm/config/global/obj/switch-controller/fortilink-settings'
     ]
 
     perobject_jrpc_urls = [
-        '/pm/config/global/obj/switch-controller/fortilink-settings/{fortilink-settings}',
-        '/pm/config/adom/{adom}/obj/switch-controller/fortilink-settings/{fortilink-settings}'
+        '/pm/config/adom/{adom}/obj/switch-controller/fortilink-settings/{fortilink-settings}',
+        '/pm/config/global/obj/switch-controller/fortilink-settings/{fortilink-settings}'
     ]
 
     url_params = ['adom']
@@ -318,7 +326,10 @@ def main():
             'revision': {
                 '7.2.1': True,
                 '7.2.2': True,
-                '7.4.0': True
+                '7.2.3': True,
+                '7.2.4': True,
+                '7.4.0': True,
+                '7.4.1': True
             },
             'options': {
                 'fortilink': {
@@ -326,7 +337,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': False,
+                        '7.4.0': True,
+                        '7.4.1': False
                     },
                     'type': 'str'
                 },
@@ -335,7 +349,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'int'
                 },
@@ -344,7 +361,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'choices': [
                         'disable',
@@ -361,7 +381,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'choices': [
                                 'disabled',
@@ -374,7 +397,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'int'
                         },
@@ -383,7 +409,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -392,16 +421,22 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
-                            'type': 'str'
+                            'type': 'raw'
                         },
                         'onboarding-vlan': {
                             'required': False,
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -410,8 +445,12 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
+                            'no_log': True,
                             'type': 'str'
                         },
                         'bounce-nac-port': {
@@ -419,7 +458,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'choices': [
                                 'disable',
@@ -434,9 +476,24 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
+                },
+                'access-vlan-mode': {
+                    'required': False,
+                    'revision': {
+                        '7.4.1': True
+                    },
+                    'choices': [
+                        'legacy',
+                        'fail-open',
+                        'fail-close'
+                    ],
+                    'type': 'str'
                 }
             }
 
