@@ -111,9 +111,9 @@ options:
                 type: str
                 description: Description.
             layer3-ipv4-rules:
-                description: description
                 type: list
                 elements: dict
+                description: no description
                 suboptions:
                     action:
                         type: str
@@ -143,9 +143,9 @@ options:
                         type: int
                         description: Source port
             layer3-ipv6-rules:
-                description: description
                 type: list
                 elements: dict
+                description: no description
                 suboptions:
                     action:
                         type: str
@@ -177,51 +177,52 @@ options:
             name:
                 type: str
                 description: AP access control list name.
+                required: true
 
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
-   collections:
-     - fortinet.fortimanager
-   connection: httpapi
-   vars:
-      ansible_httpapi_use_ssl: True
-      ansible_httpapi_validate_certs: False
-      ansible_httpapi_port: 443
-   tasks:
+- hosts: fortimanager-inventory
+  collections:
+    - fortinet.fortimanager
+  connection: httpapi
+  vars:
+    ansible_httpapi_use_ssl: True
+    ansible_httpapi_validate_certs: False
+    ansible_httpapi_port: 443
+  tasks:
     - name: Configure WiFi bridge access control list.
       fmgr_wireless_accesscontrollist:
-         bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         state: <value in [present, absent]>
-         wireless_accesscontrollist:
-            comment: <value of string>
-            layer3-ipv4-rules:
-              -
-                  action: <value in [allow, deny]>
-                  comment: <value of string>
-                  dstaddr: <value of string>
-                  dstport: <value of integer>
-                  protocol: <value of integer>
-                  rule-id: <value of integer>
-                  srcaddr: <value of string>
-                  srcport: <value of integer>
-            layer3-ipv6-rules:
-              -
-                  action: <value in [allow, deny]>
-                  comment: <value of string>
-                  dstaddr: <value of string>
-                  dstport: <value of integer>
-                  protocol: <value of integer>
-                  rule-id: <value of integer>
-                  srcaddr: <value of string>
-                  srcport: <value of integer>
-            name: <value of string>
+        bypass_validation: False
+        workspace_locking_adom: <value in [global, custom adom including root]>
+        workspace_locking_timeout: 300
+        rc_succeeded: [0, -2, -3, ...]
+        rc_failed: [-2, -3, ...]
+        adom: <your own value>
+        state: <value in [present, absent]>
+        wireless_accesscontrollist:
+          comment: <string>
+          layer3-ipv4-rules:
+            -
+              action: <value in [allow, deny]>
+              comment: <string>
+              dstaddr: <string>
+              dstport: <integer>
+              protocol: <integer>
+              rule-id: <integer>
+              srcaddr: <string>
+              srcport: <integer>
+          layer3-ipv6-rules:
+            -
+              action: <value in [allow, deny]>
+              comment: <string>
+              dstaddr: <string>
+              dstport: <integer>
+              protocol: <integer>
+              rule-id: <integer>
+              srcaddr: <string>
+              srcport: <integer>
+          name: <string>
 
 '''
 
@@ -273,13 +274,13 @@ from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import
 
 def main():
     jrpc_urls = [
-        '/pm/config/global/obj/wireless-controller/access-control-list',
-        '/pm/config/adom/{adom}/obj/wireless-controller/access-control-list'
+        '/pm/config/adom/{adom}/obj/wireless-controller/access-control-list',
+        '/pm/config/global/obj/wireless-controller/access-control-list'
     ]
 
     perobject_jrpc_urls = [
-        '/pm/config/global/obj/wireless-controller/access-control-list/{access-control-list}',
-        '/pm/config/adom/{adom}/obj/wireless-controller/access-control-list/{access-control-list}'
+        '/pm/config/adom/{adom}/obj/wireless-controller/access-control-list/{access-control-list}',
+        '/pm/config/global/obj/wireless-controller/access-control-list/{access-control-list}'
     ]
 
     url_params = ['adom']
@@ -351,7 +352,10 @@ def main():
             'revision': {
                 '7.2.1': True,
                 '7.2.2': True,
-                '7.4.0': True
+                '7.2.3': True,
+                '7.2.4': True,
+                '7.4.0': True,
+                '7.4.1': True
             },
             'options': {
                 'comment': {
@@ -359,7 +363,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
                 },
@@ -368,7 +375,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'list',
                     'options': {
@@ -377,7 +387,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'choices': [
                                 'allow',
@@ -390,7 +403,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -399,7 +415,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -408,7 +427,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'int'
                         },
@@ -417,7 +439,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'int'
                         },
@@ -426,7 +451,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'int'
                         },
@@ -435,7 +463,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -444,7 +475,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'int'
                         }
@@ -456,7 +490,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'list',
                     'options': {
@@ -465,7 +502,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'choices': [
                                 'allow',
@@ -478,7 +518,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -487,7 +530,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -496,7 +542,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'int'
                         },
@@ -505,7 +554,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'int'
                         },
@@ -514,7 +566,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'int'
                         },
@@ -523,7 +578,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'str'
                         },
@@ -532,7 +590,10 @@ def main():
                             'revision': {
                                 '7.2.1': True,
                                 '7.2.2': True,
-                                '7.4.0': True
+                                '7.2.3': True,
+                                '7.2.4': True,
+                                '7.4.0': True,
+                                '7.4.1': True
                             },
                             'type': 'int'
                         }
@@ -544,7 +605,10 @@ def main():
                     'revision': {
                         '7.2.1': True,
                         '7.2.2': True,
-                        '7.4.0': True
+                        '7.2.3': True,
+                        '7.2.4': True,
+                        '7.4.0': True,
+                        '7.4.1': True
                     },
                     'type': 'str'
                 }
